max

Function max 

pub fn max(arg1: &Variant, arg2: &Variant, varargs: &[Variant]) -> Variant
Returns the maximum of the given numeric values. This function can take any number of arguments.

max(1, 7, 3, -6, 5) # Returns 7

Note: When using this on vectors it will not perform component-wise maximum, and will pick the largest value when compared using x < y. To perform component-wise maximum, use coord_max, max, coord_max, max, coord_max, and max.