Function is_editor_hint
pub fn is_editor_hint() -> boolExpand description
Cached output of Engine::is_editor_hint, allowing to fetch the value without crossing the FFI barrier.
pub fn is_editor_hint() -> boolCached output of Engine::is_editor_hint, allowing to fetch the value without crossing the FFI barrier.