Struct PropertyHintInfo
pub struct PropertyHintInfo {
pub hint: PropertyHint,
pub hint_string: GString,
}Expand description
Info needed by Godot, for how to export a type to the editor.
Property hints provide extra metadata about the property, such as:
- Range constraints for numeric values.
- Enum value lists.
- File/directory paths.
- Resource types.
- Array element types.
Fields
hint: PropertyHinthint_string: GStringImplementations
impl PropertyHintInfo
impl PropertyHintInfo
pub fn none() -> PropertyHintInfo
pub fn none() -> PropertyHintInfo
Create a new PropertyHintInfo with a property hint of PROPERTY_HINT_NONE, and no hint string.