Trait ThreadSafety
pub trait ThreadSafety: Sealed { }Expand description
Determines if a type is expected to be thread safe or not.
See ToGodot::Threads.
pub trait ThreadSafety: Sealed { }Determines if a type is expected to be thread safe or not.
See ToGodot::Threads.