Error

Struct Error 

pub struct Error { /* private fields */ }

Implementations



impl Error

Manual extensions for the Error enum.

pub fn err(self) -> Result<(), Error>

Converts this Error into a Result<(), Error> which is Ok(()) if the given value is Error::OK.

This is a convenience method that may be used to convert this type into one that can be used with the try operator (?) for easy short circuiting of Godot Errors.

To assist with this, Result<(), Error> has a ToGodot implementation that turns it back into an Error on Godot’s side, so that it can be used as the return value of #[func] functions.

pub fn from_result(result: Result<(), Error>) -> Error

Creates an Error from a Result<(), Error>, the inverse of .err().

Ok(()) becomes Error::OK, and Err(e) becomes e.



impl Error

pub const OK: Error

pub const FAILED: Error

pub const ERR_UNAVAILABLE: Error

pub const ERR_UNCONFIGURED: Error

pub const ERR_UNAUTHORIZED: Error

pub const ERR_PARAMETER_RANGE_ERROR: Error

pub const ERR_OUT_OF_MEMORY: Error

pub const ERR_FILE_NOT_FOUND: Error

pub const ERR_FILE_BAD_DRIVE: Error

pub const ERR_FILE_BAD_PATH: Error

pub const ERR_FILE_NO_PERMISSION: Error

pub const ERR_FILE_ALREADY_IN_USE: Error

pub const ERR_FILE_CANT_OPEN: Error

pub const ERR_FILE_CANT_WRITE: Error

pub const ERR_FILE_CANT_READ: Error

pub const ERR_FILE_UNRECOGNIZED: Error

pub const ERR_FILE_CORRUPT: Error

pub const ERR_FILE_MISSING_DEPENDENCIES: Error

pub const ERR_FILE_EOF: Error

pub const ERR_CANT_OPEN: Error

pub const ERR_CANT_CREATE: Error

pub const ERR_QUERY_FAILED: Error

pub const ERR_ALREADY_IN_USE: Error

pub const ERR_LOCKED: Error

pub const ERR_TIMEOUT: Error

pub const ERR_CANT_CONNECT: Error

pub const ERR_CANT_RESOLVE: Error

pub const ERR_CONNECTION_ERROR: Error

pub const ERR_CANT_ACQUIRE_RESOURCE: Error

pub const ERR_CANT_FORK: Error

pub const ERR_INVALID_DATA: Error

pub const ERR_INVALID_PARAMETER: Error

pub const ERR_ALREADY_EXISTS: Error

pub const ERR_DOES_NOT_EXIST: Error

pub const ERR_DATABASE_CANT_READ: Error

pub const ERR_DATABASE_CANT_WRITE: Error

pub const ERR_COMPILATION_FAILED: Error

pub const ERR_METHOD_NOT_FOUND: Error

pub const ERR_SCRIPT_FAILED: Error

pub const ERR_INVALID_DECLARATION: Error

pub const ERR_DUPLICATE_SYMBOL: Error

pub const ERR_PARSE_ERROR: Error

pub const ERR_BUSY: Error

pub const ERR_SKIP: Error

pub const ERR_HELP: Error

pub const ERR_BUG: Error

pub const ERR_PRINTER_ON_FIRE: Error