Struct RenderSceneBuffersRd
pub struct RenderSceneBuffersRd { /* private fields */ }Expand description
Godot class RenderSceneBuffersRD.
Inherits RenderSceneBuffers.
Related symbols:
render_scene_buffers_rd: sidecar module with related enum/flag typesIRenderSceneBuffersRd: virtual methods
See also Godot docs for RenderSceneBuffersRD.
Construction
This class is reference-counted. You can create a new instance using RenderSceneBuffersRd::new_gd().
Godot docs
This object manages all 3D rendering buffers for the rendering device based renderers. An instance of this object is created for every viewport that has 3D rendering enabled. See also RenderSceneBuffers.
All buffers are organized in contexts. The default context is called render_buffers and can contain amongst others the color buffer, depth buffer, velocity buffers, VRS density map and MSAA variants of these buffers.
Buffers are only guaranteed to exist during rendering of the viewport.
Note: This is an internal rendering server object. Do not instantiate this class from a script.
Implementations
impl RenderSceneBuffersRd
impl RenderSceneBuffersRd
pub fn has_texture(
&self,
context: impl AsArg<StringName>,
name: impl AsArg<StringName>,
) -> bool
pub fn has_texture( &self, context: impl AsArg<StringName>, name: impl AsArg<StringName>, ) -> bool
Returns true if a cached texture exists for this name.
pub fn create_texture(
&mut self,
context: impl AsArg<StringName>,
name: impl AsArg<StringName>,
data_format: DataFormat,
usage_bits: u32,
texture_samples: TextureSamples,
size: Vector2i,
layers: u32,
mipmaps: u32,
unique: bool,
discardable: bool,
) -> Rid
pub fn create_texture( &mut self, context: impl AsArg<StringName>, name: impl AsArg<StringName>, data_format: DataFormat, usage_bits: u32, texture_samples: TextureSamples, size: Vector2i, layers: u32, mipmaps: u32, unique: bool, discardable: bool, ) -> Rid
Create a new texture with the given definition and cache this under the given name. Will return the existing texture if it already exists.
pub fn create_texture_from_format(
&mut self,
context: impl AsArg<StringName>,
name: impl AsArg<StringName>,
format: impl AsArg<Option<Gd<RdTextureFormat>>>,
view: impl AsArg<Option<Gd<RdTextureView>>>,
unique: bool,
) -> Rid
pub fn create_texture_from_format( &mut self, context: impl AsArg<StringName>, name: impl AsArg<StringName>, format: impl AsArg<Option<Gd<RdTextureFormat>>>, view: impl AsArg<Option<Gd<RdTextureView>>>, unique: bool, ) -> Rid
Create a new texture using the given format and view and cache this under the given name. Will return the existing texture if it already exists.
pub fn create_texture_view(
&mut self,
context: impl AsArg<StringName>,
name: impl AsArg<StringName>,
view_name: impl AsArg<StringName>,
view: impl AsArg<Option<Gd<RdTextureView>>>,
) -> Rid
pub fn create_texture_view( &mut self, context: impl AsArg<StringName>, name: impl AsArg<StringName>, view_name: impl AsArg<StringName>, view: impl AsArg<Option<Gd<RdTextureView>>>, ) -> Rid
Create a new texture view for an existing texture and cache this under the given view_name. Will return the existing texture view if it already exists. Will error if the source texture doesn’t exist.
pub fn get_texture(
&self,
context: impl AsArg<StringName>,
name: impl AsArg<StringName>,
) -> Rid
pub fn get_texture( &self, context: impl AsArg<StringName>, name: impl AsArg<StringName>, ) -> Rid
Returns a cached texture with this name.
pub fn get_texture_format(
&self,
context: impl AsArg<StringName>,
name: impl AsArg<StringName>,
) -> Option<Gd<RdTextureFormat>>
pub fn get_texture_format( &self, context: impl AsArg<StringName>, name: impl AsArg<StringName>, ) -> Option<Gd<RdTextureFormat>>
Returns the texture format information with which a cached texture was created.
pub fn get_texture_slice(
&self,
context: impl AsArg<StringName>,
name: impl AsArg<StringName>,
layer: u32,
mipmap: u32,
layers: u32,
mipmaps: u32,
) -> Rid
pub fn get_texture_slice( &self, context: impl AsArg<StringName>, name: impl AsArg<StringName>, layer: u32, mipmap: u32, layers: u32, mipmaps: u32, ) -> Rid
Returns a specific slice (layer or mipmap) for a cached texture.
pub fn get_texture_slice_view(
&self,
context: impl AsArg<StringName>,
name: impl AsArg<StringName>,
layer: u32,
mipmap: u32,
layers: u32,
mipmaps: u32,
view: impl AsArg<Option<Gd<RdTextureView>>>,
) -> Rid
pub fn get_texture_slice_view( &self, context: impl AsArg<StringName>, name: impl AsArg<StringName>, layer: u32, mipmap: u32, layers: u32, mipmaps: u32, view: impl AsArg<Option<Gd<RdTextureView>>>, ) -> Rid
Returns a specific view of a slice (layer or mipmap) for a cached texture.
pub fn get_texture_slice_size(
&self,
context: impl AsArg<StringName>,
name: impl AsArg<StringName>,
mipmap: u32,
) -> Vector2i
pub fn get_texture_slice_size( &self, context: impl AsArg<StringName>, name: impl AsArg<StringName>, mipmap: u32, ) -> Vector2i
Returns the texture size of a given slice of a cached texture.
pub fn clear_context(&mut self, context: impl AsArg<StringName>)
pub fn clear_context(&mut self, context: impl AsArg<StringName>)
Frees all buffers related to this context.
pub fn get_color_texture(&self) -> Rid
pub fn get_color_texture(&self) -> Rid
To set the default parameters, use get_color_texture_ex and its builder methods. See the book for detailed usage instructions.
Returns the color texture we are rendering 3D content to. If multiview is used this will be a texture array with all views.
If msaa is true and MSAA is enabled, this returns the MSAA variant of the buffer.
pub fn get_color_texture_ex<'ex>(&'ex self) -> ExGetColorTexture<'ex>
pub fn get_color_texture_ex<'ex>(&'ex self) -> ExGetColorTexture<'ex>
Returns the color texture we are rendering 3D content to. If multiview is used this will be a texture array with all views.
If msaa is true and MSAA is enabled, this returns the MSAA variant of the buffer.
pub fn get_color_layer(&self, layer: u32) -> Rid
pub fn get_color_layer(&self, layer: u32) -> Rid
To set the default parameters, use get_color_layer_ex and its builder methods. See the book for detailed usage instructions.
Returns the specified layer from the color texture we are rendering 3D content to.
If msaa is true and MSAA is enabled, this returns the MSAA variant of the buffer.
pub fn get_color_layer_ex<'ex>(&'ex self, layer: u32) -> ExGetColorLayer<'ex>
pub fn get_color_layer_ex<'ex>(&'ex self, layer: u32) -> ExGetColorLayer<'ex>
Returns the specified layer from the color texture we are rendering 3D content to.
If msaa is true and MSAA is enabled, this returns the MSAA variant of the buffer.
pub fn get_depth_texture(&self) -> Rid
pub fn get_depth_texture(&self) -> Rid
To set the default parameters, use get_depth_texture_ex and its builder methods. See the book for detailed usage instructions.
Returns the depth texture we are rendering 3D content to. If multiview is used this will be a texture array with all views.
If msaa is true and MSAA is enabled, this returns the MSAA variant of the buffer.
pub fn get_depth_texture_ex<'ex>(&'ex self) -> ExGetDepthTexture<'ex>
pub fn get_depth_texture_ex<'ex>(&'ex self) -> ExGetDepthTexture<'ex>
Returns the depth texture we are rendering 3D content to. If multiview is used this will be a texture array with all views.
If msaa is true and MSAA is enabled, this returns the MSAA variant of the buffer.
pub fn get_depth_layer(&self, layer: u32) -> Rid
pub fn get_depth_layer(&self, layer: u32) -> Rid
To set the default parameters, use get_depth_layer_ex and its builder methods. See the book for detailed usage instructions.
Returns the specified layer from the depth texture we are rendering 3D content to.
If msaa is true and MSAA is enabled, this returns the MSAA variant of the buffer.
pub fn get_depth_layer_ex<'ex>(&'ex self, layer: u32) -> ExGetDepthLayer<'ex>
pub fn get_depth_layer_ex<'ex>(&'ex self, layer: u32) -> ExGetDepthLayer<'ex>
Returns the specified layer from the depth texture we are rendering 3D content to.
If msaa is true and MSAA is enabled, this returns the MSAA variant of the buffer.
pub fn get_velocity_texture(&self) -> Rid
pub fn get_velocity_texture(&self) -> Rid
To set the default parameters, use get_velocity_texture_ex and its builder methods. See the book for detailed usage instructions.
Returns the velocity texture we are rendering 3D content to. If multiview is used this will be a texture array with all views.
If msaa is true and MSAA is enabled, this returns the MSAA variant of the buffer.
pub fn get_velocity_texture_ex<'ex>(&'ex self) -> ExGetVelocityTexture<'ex>
pub fn get_velocity_texture_ex<'ex>(&'ex self) -> ExGetVelocityTexture<'ex>
Returns the velocity texture we are rendering 3D content to. If multiview is used this will be a texture array with all views.
If msaa is true and MSAA is enabled, this returns the MSAA variant of the buffer.
pub fn get_velocity_layer(&self, layer: u32) -> Rid
pub fn get_velocity_layer(&self, layer: u32) -> Rid
To set the default parameters, use get_velocity_layer_ex and its builder methods. See the book for detailed usage instructions.
Returns the specified layer from the velocity texture we are rendering 3D content to.
pub fn get_velocity_layer_ex<'ex>(
&'ex self,
layer: u32,
) -> ExGetVelocityLayer<'ex>
pub fn get_velocity_layer_ex<'ex>( &'ex self, layer: u32, ) -> ExGetVelocityLayer<'ex>
Returns the specified layer from the velocity texture we are rendering 3D content to.
pub fn get_render_target(&self) -> Rid
pub fn get_render_target(&self) -> Rid
Returns the render target associated with this buffers object.
pub fn get_view_count(&self) -> u32
pub fn get_view_count(&self) -> u32
Returns the view count for the associated viewport.
pub fn get_internal_size(&self) -> Vector2i
pub fn get_internal_size(&self) -> Vector2i
Returns the internal size of the render buffer (size before upscaling) with which textures are created by default.
pub fn get_target_size(&self) -> Vector2i
pub fn get_target_size(&self) -> Vector2i
Returns the target size of the render buffer (size after upscaling).
pub fn get_scaling_3d_mode(&self) -> ViewportScaling3DMode
pub fn get_scaling_3d_mode(&self) -> ViewportScaling3DMode
Returns the scaling mode used for upscaling.
pub fn get_fsr_sharpness(&self) -> f32
pub fn get_fsr_sharpness(&self) -> f32
Returns the FSR sharpness value used while rendering the 3D content (if get_scaling_3d_mode is an FSR mode).
pub fn get_msaa_3d(&self) -> ViewportMsaa
pub fn get_msaa_3d(&self) -> ViewportMsaa
Returns the applied 3D MSAA mode for this viewport.
pub fn get_texture_samples(&self) -> TextureSamples
pub fn get_texture_samples(&self) -> TextureSamples
Returns the number of MSAA samples used.
pub fn get_screen_space_aa(&self) -> ViewportScreenSpaceAa
pub fn get_screen_space_aa(&self) -> ViewportScreenSpaceAa
Returns the screen-space antialiasing method applied.
pub fn get_use_taa(&self) -> bool
pub fn get_use_taa(&self) -> bool
Returns true if TAA is enabled.
pub fn get_use_debanding(&self) -> bool
pub fn get_use_debanding(&self) -> bool
Returns true if debanding is enabled.
Methods from Deref<Target = RenderSceneBuffers>
pub fn configure(
&mut self,
config: impl AsArg<Option<Gd<RenderSceneBuffersConfiguration>>>,
)
pub fn configure( &mut self, config: impl AsArg<Option<Gd<RenderSceneBuffersConfiguration>>>, )
This method is called by the rendering server when the associated viewport’s configuration is changed. It will discard the old buffers and recreate the internal buffers used.
Methods from Deref<Target = RefCounted>
pub fn get_reference_count(&self) -> i32
pub fn get_reference_count(&self) -> i32
Returns the current reference count.
Methods from Deref<Target = Object>
pub fn get_script(&self) -> Option<Gd<Script>>
pub fn set_script(&mut self, script: impl AsArg<Option<Gd<Script>>>)
pub fn connect( &mut self, signal: impl AsArg<StringName>, callable: &Callable, ) -> Error
pub fn connect_flags( &mut self, signal: impl AsArg<StringName>, callable: &Callable, flags: ConnectFlags, ) -> Error
pub fn is_class(&self, class: impl AsArg<GString>) -> bool
pub fn is_class(&self, class: impl AsArg<GString>) -> bool
Returns true if the object inherits from the given class. See also get_class.
var sprite2d = Sprite2D.new()
sprite2d.is_class("Sprite2D") # Returns true
sprite2d.is_class("Node") # Returns true
sprite2d.is_class("Node3D") # Returns falseNote: This method ignores class_name declarations in the object’s script.
pub fn set(&mut self, property: impl AsArg<StringName>, value: &Variant)
pub fn set(&mut self, property: impl AsArg<StringName>, value: &Variant)
Assigns value to the given property. If the property does not exist or the given value’s type doesn’t match, nothing happens.
var node = Node2D.new()
node.set("global_scale", Vector2(8, 2.5))
print(node.global_scale) # Prints (8.0, 2.5)Note: In C#, property must be in snake_case when referring to built-in Godot properties. Prefer using the names exposed in the PropertyName class to avoid allocating a new StringName on each call.
pub fn get(&self, property: impl AsArg<StringName>) -> Variant
pub fn get(&self, property: impl AsArg<StringName>) -> Variant
Returns the Variant value of the given property. If the property does not exist, this method returns null.
var node = Node2D.new()
node.rotation = 1.5
var a = node.get("rotation") # a is 1.5Note: In C#, property must be in snake_case when referring to built-in Godot properties. Prefer using the names exposed in the PropertyName class to avoid allocating a new StringName on each call.
pub fn set_indexed(
&mut self,
property_path: impl AsArg<NodePath>,
value: &Variant,
)
pub fn set_indexed( &mut self, property_path: impl AsArg<NodePath>, value: &Variant, )
Assigns a new value to the property identified by the property_path. The path should be a NodePath relative to this object, and can use the colon character (:) to access nested properties.
var node = Node2D.new()
node.set_indexed("position", Vector2(42, 0))
node.set_indexed("position:y", -10)
print(node.position) # Prints (42.0, -10.0)Note: In C#, property_path must be in snake_case when referring to built-in Godot properties. Prefer using the names exposed in the PropertyName class to avoid allocating a new StringName on each call.
pub fn get_indexed(&self, property_path: impl AsArg<NodePath>) -> Variant
pub fn get_indexed(&self, property_path: impl AsArg<NodePath>) -> Variant
Gets the object’s property indexed by the given property_path. The path should be a NodePath relative to the current object and can use the colon character (:) to access nested properties.
Examples: "position:x" or "material:next_pass:blend_mode".
var node = Node2D.new()
node.position = Vector2(5, -10)
var a = node.get_indexed("position") # a is Vector2(5, -10)
var b = node.get_indexed("position:y") # b is -10Note: In C#, property_path must be in snake_case when referring to built-in Godot properties. Prefer using the names exposed in the PropertyName class to avoid allocating a new StringName on each call.
Note: This method does not support actual paths to nodes in the SceneTree, only sub-property paths. In the context of nodes, use get_node_and_resource instead.
pub fn get_property_list(&self) -> Array<Dictionary<Variant, Variant>>
pub fn get_property_list(&self) -> Array<Dictionary<Variant, Variant>>
Returns the object’s property list as an Array of dictionaries. Each Dictionary contains the following entries:
-
nameis the property’s name, as aString; -
class_nameis an emptyStringName, unless the property isVariantType::OBJECTand it inherits from a class; -
typeis the property’s type, as anint(see [enum Variant.Type]); -
hintis how the property is meant to be edited (see [enum PropertyHint]); -
hint_stringdepends on the hint (see [enum PropertyHint]); -
usageis a combination of [enum PropertyUsageFlags].
Note: In GDScript, all class members are treated as properties. In C# and GDExtension, it may be necessary to explicitly mark class members as Godot properties using decorators or attributes.
pub fn get_method_list(&self) -> Array<Dictionary<Variant, Variant>>
pub fn get_method_list(&self) -> Array<Dictionary<Variant, Variant>>
Returns this object’s methods and their signatures as an Array of dictionaries. Each Dictionary contains the following entries:
-
nameis the name of the method, as aString; -
argsis anArrayof dictionaries representing the arguments; -
default_argsis the default arguments as anArrayof variants; -
flagsis a combination of [enum MethodFlags]; -
idis the method’s internal identifierint; -
returnis the returned value, as aDictionary;
Note: The dictionaries of args and return are formatted identically to the results of get_property_list, although not all entries are used.
pub fn property_can_revert(&self, property: impl AsArg<StringName>) -> bool
pub fn property_can_revert(&self, property: impl AsArg<StringName>) -> bool
Returns true if the given property has a custom default value. Use property_get_revert to get the property’s default value.
Note: This method is used by the Inspector dock to display a revert icon. The object must implement [method _property_can_revert] to customize the default value. If [method _property_can_revert] is not implemented, this method returns false.
pub fn property_get_revert(&self, property: impl AsArg<StringName>) -> Variant
pub fn property_get_revert(&self, property: impl AsArg<StringName>) -> Variant
Returns the custom default value of the given property. Use property_can_revert to check if the property has a custom default value.
Note: This method is used by the Inspector dock to display a revert icon. The object must implement [method _property_get_revert] to customize the default value. If [method _property_get_revert] is not implemented, this method returns null.
pub fn set_meta(&mut self, name: impl AsArg<StringName>, value: &Variant)
pub fn set_meta(&mut self, name: impl AsArg<StringName>, value: &Variant)
Adds or changes the entry name inside the object’s metadata. The metadata value can be any Variant, although some types cannot be serialized correctly.
If value is null, the entry is removed. This is the equivalent of using remove_meta. See also has_meta and get_meta.
Note: A metadata’s name must be a valid identifier as per is_valid_identifier method.
Note: Metadata that has a name starting with an underscore (_) is considered editor-only. Editor-only metadata is not displayed in the Inspector and should not be edited, although it can still be found by this method.
pub fn remove_meta(&mut self, name: impl AsArg<StringName>)
pub fn remove_meta(&mut self, name: impl AsArg<StringName>)
Removes the given entry name from the object’s metadata. See also has_meta, get_meta and set_meta.
Note: A metadata’s name must be a valid identifier as per is_valid_identifier method.
Note: Metadata that has a name starting with an underscore (_) is considered editor-only. Editor-only metadata is not displayed in the Inspector and should not be edited, although it can still be found by this method.
pub fn get_meta(&self, name: impl AsArg<StringName>) -> Variant
pub fn get_meta(&self, name: impl AsArg<StringName>) -> Variant
To set the default parameters, use get_meta_ex and its builder methods. See the book for detailed usage instructions.
Returns the object’s metadata value for the given entry name. If the entry does not exist, returns default. If default is null, an error is also generated.
Note: A metadata’s name must be a valid identifier as per is_valid_identifier method.
Note: Metadata that has a name starting with an underscore (_) is considered editor-only. Editor-only metadata is not displayed in the Inspector and should not be edited, although it can still be found by this method.
pub fn get_meta_ex<'ex>(
&'ex self,
name: impl AsArg<StringName> + 'ex,
) -> ExGetMeta<'ex>
pub fn get_meta_ex<'ex>( &'ex self, name: impl AsArg<StringName> + 'ex, ) -> ExGetMeta<'ex>
Returns the object’s metadata value for the given entry name. If the entry does not exist, returns default. If default is null, an error is also generated.
Note: A metadata’s name must be a valid identifier as per is_valid_identifier method.
Note: Metadata that has a name starting with an underscore (_) is considered editor-only. Editor-only metadata is not displayed in the Inspector and should not be edited, although it can still be found by this method.
pub fn has_meta(&self, name: impl AsArg<StringName>) -> bool
pub fn has_meta(&self, name: impl AsArg<StringName>) -> bool
Returns true if a metadata entry is found with the given name. See also get_meta, set_meta and remove_meta.
Note: A metadata’s name must be a valid identifier as per is_valid_identifier method.
Note: Metadata that has a name starting with an underscore (_) is considered editor-only. Editor-only metadata is not displayed in the Inspector and should not be edited, although it can still be found by this method.
pub fn get_meta_list(&self) -> Array<StringName>
pub fn get_meta_list(&self) -> Array<StringName>
Returns the object’s metadata entry names as an Array of StringNames.
pub fn add_user_signal(&mut self, signal: impl AsArg<GString>)
pub fn add_user_signal(&mut self, signal: impl AsArg<GString>)
To set the default parameters, use add_user_signal_ex and its builder methods. See the book for detailed usage instructions.
Adds a user-defined signal named signal. Optional arguments for the signal can be added as an Array of dictionaries, each defining a name String and a type int (see [enum Variant.Type]). See also has_user_signal and remove_user_signal.
add_user_signal("hurt", [
{ "name": "damage", "type": TYPE_INT },
{ "name": "source", "type": TYPE_OBJECT }
])pub fn add_user_signal_ex<'ex>(
&'ex mut self,
signal: impl AsArg<GString> + 'ex,
) -> ExAddUserSignal<'ex>
pub fn add_user_signal_ex<'ex>( &'ex mut self, signal: impl AsArg<GString> + 'ex, ) -> ExAddUserSignal<'ex>
Adds a user-defined signal named signal. Optional arguments for the signal can be added as an Array of dictionaries, each defining a name String and a type int (see [enum Variant.Type]). See also has_user_signal and remove_user_signal.
add_user_signal("hurt", [
{ "name": "damage", "type": TYPE_INT },
{ "name": "source", "type": TYPE_OBJECT }
])pub fn has_user_signal(&self, signal: impl AsArg<StringName>) -> bool
pub fn has_user_signal(&self, signal: impl AsArg<StringName>) -> bool
Returns true if the given user-defined signal name exists. Only signals added with add_user_signal are included. See also remove_user_signal.
pub fn remove_user_signal(&mut self, signal: impl AsArg<StringName>)
pub fn remove_user_signal(&mut self, signal: impl AsArg<StringName>)
Removes the given user signal signal from the object. See also add_user_signal and has_user_signal.
pub fn emit_signal(
&mut self,
signal: impl AsArg<StringName>,
varargs: &[Variant],
) -> Error
pub fn emit_signal( &mut self, signal: impl AsArg<StringName>, varargs: &[Variant], ) -> Error
Emits the given signal by name. The signal must exist, so it should be a built-in signal of this class or one of its inherited classes, or a user-defined signal (see add_user_signal). This method supports a variable number of arguments, so parameters can be passed as a comma separated list.
Returns Error::ERR_UNAVAILABLE if signal does not exist or the parameters are invalid.
emit_signal("hit", "sword", 100)
emit_signal("game_over")Note: In C#, signal must be in snake_case when referring to built-in Godot signals. Prefer using the names exposed in the SignalName class to avoid allocating a new StringName on each call.
Panics
This is a varcall method, meaning parameters and return values are passed as Variant.
It can detect call failures and will panic in such a case.
pub fn try_emit_signal(
&mut self,
signal: impl AsArg<StringName>,
varargs: &[Variant],
) -> Result<Error, CallError>
pub fn try_emit_signal( &mut self, signal: impl AsArg<StringName>, varargs: &[Variant], ) -> Result<Error, CallError>
Return type
This is a varcall method, meaning parameters and return values are passed as Variant.
It can detect call failures and will return Err in such a case.
pub fn call(
&mut self,
method: impl AsArg<StringName>,
varargs: &[Variant],
) -> Variant
pub fn call( &mut self, method: impl AsArg<StringName>, varargs: &[Variant], ) -> Variant
Calls the method on the object and returns the result. This method supports a variable number of arguments, so parameters can be passed as a comma separated list.
var node = Node3D.new()
node.call("rotate", Vector3(1.0, 0.0, 0.0), 1.571)Note: In C#, method must be in snake_case when referring to built-in Godot methods. Prefer using the names exposed in the MethodName class to avoid allocating a new StringName on each call.
Panics
This is a varcall method, meaning parameters and return values are passed as Variant.
It can detect call failures and will panic in such a case.
pub fn try_call(
&mut self,
method: impl AsArg<StringName>,
varargs: &[Variant],
) -> Result<Variant, CallError>
pub fn try_call( &mut self, method: impl AsArg<StringName>, varargs: &[Variant], ) -> Result<Variant, CallError>
Return type
This is a varcall method, meaning parameters and return values are passed as Variant.
It can detect call failures and will return Err in such a case.
pub fn call_deferred(
&mut self,
method: impl AsArg<StringName>,
varargs: &[Variant],
) -> Variant
pub fn call_deferred( &mut self, method: impl AsArg<StringName>, varargs: &[Variant], ) -> Variant
Calls the method on the object during idle time. Always returns null, not the method’s result.
Idle time happens mainly at the end of process and physics frames. In it, deferred calls will be run until there are none left, which means you can defer calls from other deferred calls and they’ll still be run in the current idle time cycle. This means you should not call a method deferred from itself (or from a method called by it), as this causes infinite recursion the same way as if you had called the method directly.
This method supports a variable number of arguments, so parameters can be passed as a comma separated list.
var node = Node3D.new()
node.call_deferred("rotate", Vector3(1.0, 0.0, 0.0), 1.571)For methods that are deferred from the same thread, the order of execution at idle time is identical to the order in which call_deferred was called.
See also call_deferred.
Note: In C#, method must be in snake_case when referring to built-in Godot methods. Prefer using the names exposed in the MethodName class to avoid allocating a new StringName on each call.
Note: If you’re looking to delay the function call by a frame, refer to the SceneTree.process_frame and SceneTree.physics_frame signals.
var node = Node3D.new()
# Make a Callable and bind the arguments to the node's rotate() call.
var callable = node.rotate.bind(Vector3(1.0, 0.0, 0.0), 1.571)
# Connect the callable to the process_frame signal, so it gets called in the next process frame.
# CONNECT_ONE_SHOT makes sure it only gets called once instead of every frame.
get_tree().process_frame.connect(callable, CONNECT_ONE_SHOT)Panics
This is a varcall method, meaning parameters and return values are passed as Variant.
It can detect call failures and will panic in such a case.
pub fn try_call_deferred(
&mut self,
method: impl AsArg<StringName>,
varargs: &[Variant],
) -> Result<Variant, CallError>
pub fn try_call_deferred( &mut self, method: impl AsArg<StringName>, varargs: &[Variant], ) -> Result<Variant, CallError>
Return type
This is a varcall method, meaning parameters and return values are passed as Variant.
It can detect call failures and will return Err in such a case.
pub fn set_deferred(
&mut self,
property: impl AsArg<StringName>,
value: &Variant,
)
pub fn set_deferred( &mut self, property: impl AsArg<StringName>, value: &Variant, )
Assigns value to the given property, at the end of the current frame. This is equivalent to calling set through call_deferred.
var node = Node2D.new()
add_child(node)
node.rotation = 1.5
node.set_deferred("rotation", 3.0)
print(node.rotation) # Prints 1.5
await get_tree().process_frame
print(node.rotation) # Prints 3.0Note: In C#, property must be in snake_case when referring to built-in Godot properties. Prefer using the names exposed in the PropertyName class to avoid allocating a new StringName on each call.
pub fn callv(
&mut self,
method: impl AsArg<StringName>,
arg_array: &AnyArray,
) -> Variant
pub fn callv( &mut self, method: impl AsArg<StringName>, arg_array: &AnyArray, ) -> Variant
Calls the method on the object and returns the result. Unlike call, this method expects all parameters to be contained inside arg_array.
var node = Node3D.new()
node.callv("rotate", [Vector3(1.0, 0.0, 0.0), 1.571])Note: In C#, method must be in snake_case when referring to built-in Godot methods. Prefer using the names exposed in the MethodName class to avoid allocating a new StringName on each call.
pub fn has_method(&self, method: impl AsArg<StringName>) -> bool
pub fn has_method(&self, method: impl AsArg<StringName>) -> bool
Returns true if the given method name exists in the object.
Note: In C#, method must be in snake_case when referring to built-in Godot methods. Prefer using the names exposed in the MethodName class to avoid allocating a new StringName on each call.
pub fn get_method_argument_count(&self, method: impl AsArg<StringName>) -> i32
pub fn get_method_argument_count(&self, method: impl AsArg<StringName>) -> i32
Returns the number of arguments of the given method by name.
Note: In C#, method must be in snake_case when referring to built-in Godot methods. Prefer using the names exposed in the MethodName class to avoid allocating a new StringName on each call.
pub fn has_signal(&self, signal: impl AsArg<StringName>) -> bool
pub fn has_signal(&self, signal: impl AsArg<StringName>) -> bool
Returns true if the given signal name exists in the object.
Note: In C#, signal must be in snake_case when referring to built-in Godot signals. Prefer using the names exposed in the SignalName class to avoid allocating a new StringName on each call.
pub fn get_signal_list(&self) -> Array<Dictionary<Variant, Variant>>
pub fn get_signal_list(&self) -> Array<Dictionary<Variant, Variant>>
Returns the list of existing signals as an Array of dictionaries.
Note: Due to the implementation, each Dictionary is formatted very similarly to the returned values of get_method_list.
pub fn get_signal_connection_list(
&self,
signal: impl AsArg<StringName>,
) -> Array<Dictionary<Variant, Variant>>
pub fn get_signal_connection_list( &self, signal: impl AsArg<StringName>, ) -> Array<Dictionary<Variant, Variant>>
Returns an Array of connections for the given signal name. Each connection is represented as a Dictionary that contains three entries:
pub fn get_incoming_connections(&self) -> Array<Dictionary<Variant, Variant>>
pub fn get_incoming_connections(&self) -> Array<Dictionary<Variant, Variant>>
Returns an Array of signal connections received by this object. Each connection is represented as a Dictionary that contains three entries:
pub fn disconnect(
&mut self,
signal: impl AsArg<StringName>,
callable: &Callable,
)
pub fn disconnect( &mut self, signal: impl AsArg<StringName>, callable: &Callable, )
Disconnects a signal by name from a given callable. If the connection does not exist, generates an error. Use is_connected to make sure that the connection exists.
pub fn is_connected(
&self,
signal: impl AsArg<StringName>,
callable: &Callable,
) -> bool
pub fn is_connected( &self, signal: impl AsArg<StringName>, callable: &Callable, ) -> bool
Returns true if a connection exists between the given signal name and callable.
Note: In C#, signal must be in snake_case when referring to built-in Godot signals. Prefer using the names exposed in the SignalName class to avoid allocating a new StringName on each call.
pub fn has_connections(&self, signal: impl AsArg<StringName>) -> bool
pub fn has_connections(&self, signal: impl AsArg<StringName>) -> bool
Returns true if any connection exists on the given signal name.
Note: In C#, signal must be in snake_case when referring to built-in Godot methods. Prefer using the names exposed in the SignalName class to avoid allocating a new StringName on each call.
pub fn set_block_signals(&mut self, enable: bool)
pub fn set_block_signals(&mut self, enable: bool)
If set to true, the object becomes unable to emit signals. As such, emit_signal and signal connections will not work, until it is set to false.
pub fn is_blocking_signals(&self) -> bool
pub fn is_blocking_signals(&self) -> bool
Returns true if the object is blocking its signals from being emitted. See set_block_signals.
pub fn notify_property_list_changed(&mut self)
pub fn notify_property_list_changed(&mut self)
Emits the property_list_changed signal. This is mainly used to refresh the editor, so that the Inspector and editor plugins are properly updated.
pub fn set_message_translation(&mut self, enable: bool)
pub fn set_message_translation(&mut self, enable: bool)
If set to true, allows the object to translate messages with tr and tr_n. Enabled by default. See also can_translate_messages.
pub fn can_translate_messages(&self) -> bool
pub fn can_translate_messages(&self) -> bool
Returns true if the object is allowed to translate messages with tr and tr_n. See also set_message_translation.
pub fn tr(&self, message: impl AsArg<StringName>) -> GString
pub fn tr(&self, message: impl AsArg<StringName>) -> GString
To set the default parameters, use tr_ex and its builder methods. See the book for detailed usage instructions.
Translates a message, using the translation catalogs configured in the Project Settings. Further context can be specified to help with the translation. Note that most Control nodes automatically translate their strings, so this method is mostly useful for formatted strings or custom drawn text.
If can_translate_messages is false, or no translation is available, this method returns the message without changes. See set_message_translation.
For detailed examples, see Internationalizing games.
Note: This method can’t be used without an Object instance, as it requires the can_translate_messages method. To translate strings in a static context, use translate.
pub fn tr_ex<'ex>(&'ex self, message: impl AsArg<StringName> + 'ex) -> ExTr<'ex>
pub fn tr_ex<'ex>(&'ex self, message: impl AsArg<StringName> + 'ex) -> ExTr<'ex>
Translates a message, using the translation catalogs configured in the Project Settings. Further context can be specified to help with the translation. Note that most Control nodes automatically translate their strings, so this method is mostly useful for formatted strings or custom drawn text.
If can_translate_messages is false, or no translation is available, this method returns the message without changes. See set_message_translation.
For detailed examples, see Internationalizing games.
Note: This method can’t be used without an Object instance, as it requires the can_translate_messages method. To translate strings in a static context, use translate.
pub fn tr_n(
&self,
message: impl AsArg<StringName>,
plural_message: impl AsArg<StringName>,
n: i32,
) -> GString
pub fn tr_n( &self, message: impl AsArg<StringName>, plural_message: impl AsArg<StringName>, n: i32, ) -> GString
To set the default parameters, use tr_n_ex and its builder methods. See the book for detailed usage instructions.
Translates a message or plural_message, using the translation catalogs configured in the Project Settings. Further context can be specified to help with the translation.
If can_translate_messages is false, or no translation is available, this method returns message or plural_message, without changes. See set_message_translation.
The n is the number, or amount, of the message’s subject. It is used by the translation system to fetch the correct plural form for the current language.
For detailed examples, see Localization using gettext.
Note: Negative and float numbers may not properly apply to some countable subjects. It’s recommended to handle these cases with tr.
Note: This method can’t be used without an Object instance, as it requires the can_translate_messages method. To translate strings in a static context, use translate_plural.
pub fn tr_n_ex<'ex>(
&'ex self,
message: impl AsArg<StringName> + 'ex,
plural_message: impl AsArg<StringName> + 'ex,
n: i32,
) -> ExTrN<'ex>
pub fn tr_n_ex<'ex>( &'ex self, message: impl AsArg<StringName> + 'ex, plural_message: impl AsArg<StringName> + 'ex, n: i32, ) -> ExTrN<'ex>
Translates a message or plural_message, using the translation catalogs configured in the Project Settings. Further context can be specified to help with the translation.
If can_translate_messages is false, or no translation is available, this method returns message or plural_message, without changes. See set_message_translation.
The n is the number, or amount, of the message’s subject. It is used by the translation system to fetch the correct plural form for the current language.
For detailed examples, see Localization using gettext.
Note: Negative and float numbers may not properly apply to some countable subjects. It’s recommended to handle these cases with tr.
Note: This method can’t be used without an Object instance, as it requires the can_translate_messages method. To translate strings in a static context, use translate_plural.
pub fn get_translation_domain(&self) -> StringName
pub fn get_translation_domain(&self) -> StringName
Returns the name of the translation domain used by tr and tr_n. See also TranslationServer.
pub fn set_translation_domain(&mut self, domain: impl AsArg<StringName>)
pub fn set_translation_domain(&mut self, domain: impl AsArg<StringName>)
Sets the name of the translation domain used by tr and tr_n. See also TranslationServer.
pub fn is_queued_for_deletion(&self) -> bool
pub fn is_queued_for_deletion(&self) -> bool
Returns true if the queue_free method was called for the object.
pub fn cancel_free(&mut self)
pub fn cancel_free(&mut self)
If this method is called during ObjectNotification::PREDELETE, this object will reject being freed and will remain allocated. This is mostly an internal function used for error handling to avoid the user from freeing objects when they are not intended to.
pub fn notify(&mut self, what: ObjectNotification)
pub fn notify(&mut self, what: ObjectNotification)
⚠️ Sends a Godot notification to all classes inherited by the object.
Triggers calls to on_notification(), and depending on the notification, also to Godot’s lifecycle callbacks such as ready().
Starts from the highest ancestor (the Object class) and goes down the hierarchy.
See also Godot docs for Object::notification().
Panics
If you call this method on a user-defined object while holding a GdRef or GdMut guard on the instance, you will encounter
a panic. The reason is that the receiving virtual method on_notification() acquires a GdMut lock dynamically, which must
be exclusive.
pub fn notify_reversed(&mut self, what: ObjectNotification)
pub fn notify_reversed(&mut self, what: ObjectNotification)
⚠️ Like Self::notify(), but starts at the most-derived class and goes up the hierarchy.
See docs of that method, including the panics.