TreeItem

Struct TreeItem 

pub struct TreeItem { /* private fields */ }
Godot class TreeItem.

Inherits Object.

Related symbols:

  • tree_item: sidecar module with related enum/flag types

See also Godot docs for TreeItem.

Not instantiable

This class cannot be constructed. Obtain Gd<TreeItem> instances via Godot APIs.

Final class

This class is final, meaning you cannot inherit from it, and it comes without I* interface trait. It is still possible that other Godot classes inherit from it, but that is limited to the engine itself.

Godot docs

A single item of a Tree control. It can contain other TreeItems as children, which allows it to create a hierarchy. It can also contain text and buttons. TreeItem is not a Node, it is internal to the Tree.

To create a TreeItem, use create_item or create_child. To remove a TreeItem, use free.

Note: The ID values used for buttons are 32-bit, unlike int which is always 64-bit. They go from -2147483648 to 2147483647.

Implementations



impl TreeItem

pub fn set_cell_mode(&mut self, column: i32, mode: TreeCellMode)

Sets the given column’s cell mode to mode. This determines how the cell is displayed and edited.

pub fn get_cell_mode(&self, column: i32) -> TreeCellMode

Returns the column’s cell mode.

pub fn set_auto_translate_mode(&mut self, column: i32, mode: AutoTranslateMode)

Sets the given column’s auto translate mode to mode.

All columns use AutoTranslateMode::INHERIT by default, which uses the same auto translate mode as the Tree itself.

pub fn get_auto_translate_mode(&self, column: i32) -> AutoTranslateMode

Returns the column’s auto translate mode.

pub fn set_edit_multiline(&mut self, column: i32, multiline: bool)

If multiline is true, the given column is multiline editable.

Note: This option only affects the type of control (LineEdit or TextEdit) that appears when editing the column. You can set multiline values with set_text even if the column is not multiline editable.

pub fn is_edit_multiline(&self, column: i32) -> bool

Returns true if the given column is multiline editable.

pub fn set_checked(&mut self, column: i32, checked: bool)

If checked is true, the given column is checked. Clears column’s indeterminate status.

pub fn set_indeterminate(&mut self, column: i32, indeterminate: bool)

If indeterminate is true, the given column is marked indeterminate.

Note: If set true from false, then column is cleared of checked status.

pub fn is_checked(&self, column: i32) -> bool

Returns true if the given column is checked.

pub fn is_indeterminate(&self, column: i32) -> bool

Returns true if the given column is indeterminate.

pub fn propagate_check(&mut self, column: i32)

To set the default parameters, use propagate_check_ex and its builder methods. See the book for detailed usage instructions. Propagates this item’s checked status to its children and parents for the given column. It is possible to process the items affected by this method call by connecting to Tree.check_propagated_to_item. The order that the items affected will be processed is as follows: the item invoking this method, children of that item, and finally parents of that item. If emit_signal is false, then Tree.check_propagated_to_item will not be emitted.

pub fn propagate_check_ex<'ex>( &'ex mut self, column: i32, ) -> ExPropagateCheck<'ex>

Propagates this item’s checked status to its children and parents for the given column. It is possible to process the items affected by this method call by connecting to Tree.check_propagated_to_item. The order that the items affected will be processed is as follows: the item invoking this method, children of that item, and finally parents of that item. If emit_signal is false, then Tree.check_propagated_to_item will not be emitted.

pub fn set_text(&mut self, column: i32, text: impl AsArg<GString>)

Sets the given column’s text value.

pub fn get_text(&self, column: i32) -> GString

Returns the given column’s text.

pub fn set_description(&mut self, column: i32, description: impl AsArg<GString>)

Sets the given column’s description for assistive apps.

pub fn get_description(&self, column: i32) -> GString

Returns the given column’s description for assistive apps.

pub fn set_text_direction(&mut self, column: i32, direction: TextDirection)

Sets item’s text base writing direction.

pub fn get_text_direction(&self, column: i32) -> TextDirection

Returns item’s text base writing direction.

pub fn set_autowrap_mode(&mut self, column: i32, autowrap_mode: AutowrapMode)

Sets the autowrap mode in the given column. If set to something other than AutowrapMode::OFF, the text gets wrapped inside the cell’s bounding rectangle.

pub fn get_autowrap_mode(&self, column: i32) -> AutowrapMode

Returns the text autowrap mode in the given column. By default it is AutowrapMode::OFF.

pub fn set_text_overrun_behavior( &mut self, column: i32, overrun_behavior: OverrunBehavior, )

Sets the clipping behavior when the text exceeds the item’s bounding rectangle in the given column.

pub fn get_text_overrun_behavior(&self, column: i32) -> OverrunBehavior

Returns the clipping behavior when the text exceeds the item’s bounding rectangle in the given column. By default it is OverrunBehavior::TRIM_ELLIPSIS.

pub fn set_structured_text_bidi_override( &mut self, column: i32, parser: StructuredTextParser, )

Set BiDi algorithm override for the structured text. Has effect for cells that display text.

pub fn get_structured_text_bidi_override( &self, column: i32, ) -> StructuredTextParser

Returns the BiDi algorithm override set for this cell.

pub fn set_structured_text_bidi_override_options( &mut self, column: i32, args: &AnyArray, )

Set additional options for BiDi override. Has effect for cells that display text.

pub fn get_structured_text_bidi_override_options( &self, column: i32, ) -> Array<Variant>

Returns the additional BiDi options set for this cell.

pub fn set_language(&mut self, column: i32, language: impl AsArg<GString>)

Sets the language code of the given column’s text to language. This is used for line-breaking and text shaping algorithms. If language is empty, the current locale is used.

pub fn get_language(&self, column: i32) -> GString

Returns item’s text language code.

pub fn set_suffix(&mut self, column: i32, text: impl AsArg<GString>)

Sets a string to be shown after a column’s value (for example, a unit abbreviation).

pub fn get_suffix(&self, column: i32) -> GString

Gets the suffix string shown after the column value.

pub fn set_icon( &mut self, column: i32, texture: impl AsArg<Option<Gd<Texture2D>>>, )

Sets the given cell’s icon Texture2D. If the cell is in TreeCellMode::ICON mode, the icon is displayed in the center of the cell. Otherwise, the icon is displayed before the cell’s text. TreeCellMode::RANGE does not display an icon.

pub fn get_icon(&self, column: i32) -> Option<Gd<Texture2D>>

Returns the given column’s icon Texture2D. Error if no icon is set.

pub fn set_icon_overlay( &mut self, column: i32, texture: impl AsArg<Option<Gd<Texture2D>>>, )

Sets the given cell’s icon overlay Texture2D. The cell has to be in TreeCellMode::ICON mode, and icon has to be set. Overlay is drawn on top of icon, in the bottom left corner.

pub fn get_icon_overlay(&self, column: i32) -> Option<Gd<Texture2D>>

Returns the given column’s icon overlay Texture2D.

pub fn set_icon_region(&mut self, column: i32, region: Rect2)

Sets the given column’s icon’s texture region.

pub fn get_icon_region(&self, column: i32) -> Rect2

Returns the icon Texture2D region as Rect2.

pub fn set_icon_max_width(&mut self, column: i32, width: i32)

Sets the maximum allowed width of the icon in the given column. This limit is applied on top of the default size of the icon and on top of [theme_item Tree.icon_max_width]. The height is adjusted according to the icon’s ratio.

pub fn get_icon_max_width(&self, column: i32) -> i32

Returns the maximum allowed width of the icon in the given column.

pub fn set_icon_modulate(&mut self, column: i32, modulate: Color)

Modulates the given column’s icon with modulate.

pub fn get_icon_modulate(&self, column: i32) -> Color

Returns the Color modulating the column’s icon.

pub fn set_range(&mut self, column: i32, value: f64)

Sets the value of a TreeCellMode::RANGE column.

pub fn get_range(&self, column: i32) -> f64

Returns the value of a TreeCellMode::RANGE column.

pub fn set_range_config(&mut self, column: i32, min: f64, max: f64, step: f64)

To set the default parameters, use set_range_config_ex and its builder methods. See the book for detailed usage instructions. Sets the range of accepted values for a column. The column must be in the TreeCellMode::RANGE mode.

If expr is true, the edit mode slider will use an exponential scale as with [member Range.exp_edit].

pub fn set_range_config_ex<'ex>( &'ex mut self, column: i32, min: f64, max: f64, step: f64, ) -> ExSetRangeConfig<'ex>

Sets the range of accepted values for a column. The column must be in the TreeCellMode::RANGE mode.

If expr is true, the edit mode slider will use an exponential scale as with [member Range.exp_edit].

pub fn get_range_config(&self, column: i32) -> Dictionary<Variant, Variant>

Returns a dictionary containing the range parameters for a given column. The keys are “min”, “max”, “step”, and “expr”.

pub fn set_metadata(&mut self, column: i32, meta: &Variant)

Sets the metadata value for the given column, which can be retrieved later using get_metadata. This can be used, for example, to store a reference to the original data.

pub fn get_metadata(&self, column: i32) -> Variant

Returns the metadata value that was set for the given column using set_metadata.

pub fn set_custom_draw( &mut self, column: i32, object: impl AsArg<Option<Gd<Object>>>, callback: impl AsArg<StringName>, )

Sets the given column’s custom draw callback to the callback method on object.

The method named callback should accept two arguments: the TreeItem that is drawn and its position and size as a Rect2.

pub fn set_custom_draw_callback(&mut self, column: i32, callback: &Callable)

Sets the given column’s custom draw callback. Use an empty Callable (Callable()) to clear the custom callback. The cell has to be in TreeCellMode::CUSTOM to use this feature.

The callback should accept two arguments: the TreeItem that is drawn and its position and size as a Rect2.

pub fn get_custom_draw_callback(&self, column: i32) -> Callable

Returns the custom callback of column column.

pub fn set_custom_stylebox( &mut self, column: i32, stylebox: impl AsArg<Option<Gd<StyleBox>>>, )

Sets the given column’s custom StyleBox used to draw the background.

Note: If a custom background color is set, the StyleBox will be drawn in front of it.

pub fn get_custom_stylebox(&self, column: i32) -> Option<Gd<StyleBox>>

Returns the given column’s custom StyleBox used to draw the background.

pub fn set_collapsed(&mut self, enable: bool)

pub fn is_collapsed(&self) -> bool

pub fn set_collapsed_recursive(&mut self, enable: bool)

Collapses or uncollapses this TreeItem and all the descendants of this item.

pub fn is_any_collapsed(&self) -> bool

To set the default parameters, use is_any_collapsed_ex and its builder methods. See the book for detailed usage instructions. Returns true if this TreeItem, or any of its descendants, is collapsed.

If only_visible is true it ignores non-visible TreeItems.

pub fn is_any_collapsed_ex<'ex>(&'ex self) -> ExIsAnyCollapsed<'ex>

Returns true if this TreeItem, or any of its descendants, is collapsed.

If only_visible is true it ignores non-visible TreeItems.

pub fn set_visible(&mut self, enable: bool)

pub fn is_visible(&self) -> bool

pub fn is_visible_in_tree(&self) -> bool

Returns true if [member visible] is true and all its ancestors are also visible.

pub fn uncollapse_tree(&mut self)

Uncollapses all TreeItems necessary to reveal this TreeItem, i.e. all ancestor TreeItems.

pub fn set_custom_minimum_height(&mut self, height: i32)

pub fn get_custom_minimum_height(&self) -> i32

pub fn set_selectable(&mut self, column: i32, selectable: bool)

If selectable is true, the given column is selectable.

pub fn is_selectable(&self, column: i32) -> bool

Returns true if the given column is selectable.

pub fn is_selected(&self, column: i32) -> bool

Returns true if the given column is selected.

pub fn select(&mut self, column: i32)

Selects the given column.

pub fn deselect(&mut self, column: i32)

Deselects the given column.

pub fn set_editable(&mut self, column: i32, enabled: bool)

If enabled is true, the given column is editable.

pub fn is_editable(&self, column: i32) -> bool

Returns true if the given column is editable.

pub fn set_custom_color(&mut self, column: i32, color: Color)

Sets the given column’s custom color.

pub fn get_custom_color(&self, column: i32) -> Color

Returns the custom color of column column.

pub fn clear_custom_color(&mut self, column: i32)

Resets the color for the given column to default.

pub fn set_custom_font( &mut self, column: i32, font: impl AsArg<Option<Gd<Font>>>, )

Sets custom font used to draw text in the given column.

pub fn get_custom_font(&self, column: i32) -> Option<Gd<Font>>

Returns custom font used to draw text in the column column.

pub fn set_custom_font_size(&mut self, column: i32, font_size: i32)

Sets custom font size used to draw text in the given column.

pub fn get_custom_font_size(&self, column: i32) -> i32

Returns custom font size used to draw text in the column column.

pub fn set_custom_bg_color(&mut self, column: i32, color: Color)

To set the default parameters, use set_custom_bg_color_ex and its builder methods. See the book for detailed usage instructions. Sets the given column’s custom background color and whether to just use it as an outline.

Note: If a custom StyleBox is set, the background color will be drawn behind it.

pub fn set_custom_bg_color_ex<'ex>( &'ex mut self, column: i32, color: Color, ) -> ExSetCustomBgColor<'ex>

Sets the given column’s custom background color and whether to just use it as an outline.

Note: If a custom StyleBox is set, the background color will be drawn behind it.

pub fn clear_custom_bg_color(&mut self, column: i32)

Resets the background color for the given column to default.

pub fn get_custom_bg_color(&self, column: i32) -> Color

Returns the custom background color of column column.

pub fn set_custom_as_button(&mut self, column: i32, enable: bool)

Makes a cell with TreeCellMode::CUSTOM display as a non-flat button with a StyleBox.

pub fn is_custom_set_as_button(&self, column: i32) -> bool

Returns true if the cell was made into a button with set_custom_as_button.

pub fn clear_buttons(&mut self)

Removes all buttons from all columns of this item.

pub fn add_button( &mut self, column: i32, button: impl AsArg<Option<Gd<Texture2D>>>, )

To set the default parameters, use add_button_ex and its builder methods. See the book for detailed usage instructions. Adds a button with Texture2D button to the end of the cell at column column. The id is used to identify the button in the according Tree.button_clicked signal and can be different from the buttons index. If not specified, the next available index is used, which may be retrieved by calling get_button_count immediately before this method. Optionally, the button can be disabled and have a tooltip_text. description is used as the button description for assistive apps.

pub fn add_button_ex<'ex>( &'ex mut self, column: i32, button: impl AsArg<Option<Gd<Texture2D>>> + 'ex, ) -> ExAddButton<'ex>

Adds a button with Texture2D button to the end of the cell at column column. The id is used to identify the button in the according Tree.button_clicked signal and can be different from the buttons index. If not specified, the next available index is used, which may be retrieved by calling get_button_count immediately before this method. Optionally, the button can be disabled and have a tooltip_text. description is used as the button description for assistive apps.

pub fn get_button_count(&self, column: i32) -> i32

Returns the number of buttons in column column.

pub fn get_button_tooltip_text(&self, column: i32, button_index: i32) -> GString

Returns the tooltip text for the button at index button_index in column column.

pub fn get_button_id(&self, column: i32, button_index: i32) -> i32

Returns the ID for the button at index button_index in column column.

pub fn get_button_by_id(&self, column: i32, id: i32) -> i32

Returns the button index if there is a button with ID id in column column, otherwise returns -1.

pub fn get_button_color(&self, column: i32, id: i32) -> Color

Returns the color of the button with ID id in column column. If the specified button does not exist, returns Color.BLACK.

pub fn get_button( &self, column: i32, button_index: i32, ) -> Option<Gd<Texture2D>>

Returns the Texture2D of the button at index button_index in column column.

pub fn set_button_tooltip_text( &mut self, column: i32, button_index: i32, tooltip: impl AsArg<GString>, )

Sets the tooltip text for the button at index button_index in the given column.

pub fn set_button( &mut self, column: i32, button_index: i32, button: impl AsArg<Option<Gd<Texture2D>>>, )

Sets the given column’s button Texture2D at index button_index to button.

pub fn erase_button(&mut self, column: i32, button_index: i32)

Removes the button at index button_index in column column.

pub fn set_button_description( &mut self, column: i32, button_index: i32, description: impl AsArg<GString>, )

Sets the given column’s button description at index button_index for assistive apps.

pub fn set_button_disabled( &mut self, column: i32, button_index: i32, disabled: bool, )

If true, disables the button at index button_index in the given column.

pub fn set_button_color(&mut self, column: i32, button_index: i32, color: Color)

Sets the given column’s button color at index button_index to color.

pub fn is_button_disabled(&self, column: i32, button_index: i32) -> bool

Returns true if the button at index button_index for the given column is disabled.

pub fn set_tooltip_text(&mut self, column: i32, tooltip: impl AsArg<GString>)

Sets the given column’s tooltip text.

pub fn get_tooltip_text(&self, column: i32) -> GString

Returns the given column’s tooltip text.

pub fn set_text_alignment( &mut self, column: i32, text_alignment: HorizontalAlignment, )

Sets the given column’s text alignment to text_alignment.

pub fn get_text_alignment(&self, column: i32) -> HorizontalAlignment

Returns the given column’s text alignment.

pub fn set_expand_right(&mut self, column: i32, enable: bool)

If enable is true, the given column is expanded to the right.

pub fn get_expand_right(&self, column: i32) -> bool

Returns true if expand_right is set.

pub fn set_disable_folding(&mut self, disable: bool)

pub fn is_folding_disabled(&self) -> bool

pub fn create_child(&mut self) -> Option<Gd<TreeItem>>

To set the default parameters, use create_child_ex and its builder methods. See the book for detailed usage instructions. Creates an item and adds it as a child.

The new item will be inserted as position index (the default value -1 means the last position), or it will be the last child if index is higher than the child count.

pub fn create_child_ex<'ex>(&'ex mut self) -> ExCreateChild<'ex>

Creates an item and adds it as a child.

The new item will be inserted as position index (the default value -1 means the last position), or it will be the last child if index is higher than the child count.

pub fn add_child(&mut self, child: impl AsArg<Option<Gd<TreeItem>>>)

Adds a previously unparented TreeItem as a direct child of this one. The child item must not be a part of any Tree or parented to any TreeItem. See also remove_child.

pub fn remove_child(&mut self, child: impl AsArg<Option<Gd<TreeItem>>>)

Removes the given child TreeItem and all its children from the Tree. Note that it doesn’t free the item from memory, so it can be reused later (see add_child). To completely remove a TreeItem use free.

Note: If you want to move a child from one Tree to another, then instead of removing and adding it manually you can use move_before or move_after.

pub fn get_tree(&self) -> Option<Gd<Tree>>

Returns the Tree that owns this TreeItem.

pub fn get_next(&self) -> Option<Gd<TreeItem>>

Returns the next sibling TreeItem in the tree or a null object if there is none.

pub fn get_prev(&self) -> Option<Gd<TreeItem>>

Returns the previous sibling TreeItem in the tree or a null object if there is none.

pub fn get_parent(&self) -> Option<Gd<TreeItem>>

Returns the parent TreeItem or a null object if there is none.

pub fn get_first_child(&self) -> Option<Gd<TreeItem>>

Returns the TreeItem’s first child.

pub fn get_next_in_tree(&self) -> Option<Gd<TreeItem>>

To set the default parameters, use get_next_in_tree_ex and its builder methods. See the book for detailed usage instructions. Returns the next TreeItem in the tree (in the context of a depth-first search) or a null object if there is none.

If wrap is enabled, the method will wrap around to the first element in the tree when called on the last element, otherwise it returns null.

pub fn get_next_in_tree_ex<'ex>(&'ex self) -> ExGetNextInTree<'ex>

Returns the next TreeItem in the tree (in the context of a depth-first search) or a null object if there is none.

If wrap is enabled, the method will wrap around to the first element in the tree when called on the last element, otherwise it returns null.

pub fn get_prev_in_tree(&self) -> Option<Gd<TreeItem>>

To set the default parameters, use get_prev_in_tree_ex and its builder methods. See the book for detailed usage instructions. Returns the previous TreeItem in the tree (in the context of a depth-first search) or a null object if there is none.

If wrap is enabled, the method will wrap around to the last element in the tree when called on the first visible element, otherwise it returns null.

pub fn get_prev_in_tree_ex<'ex>(&'ex self) -> ExGetPrevInTree<'ex>

Returns the previous TreeItem in the tree (in the context of a depth-first search) or a null object if there is none.

If wrap is enabled, the method will wrap around to the last element in the tree when called on the first visible element, otherwise it returns null.

pub fn get_next_visible(&self) -> Option<Gd<TreeItem>>

To set the default parameters, use get_next_visible_ex and its builder methods. See the book for detailed usage instructions. Returns the next visible TreeItem in the tree (in the context of a depth-first search) or a null object if there is none.

If wrap is enabled, the method will wrap around to the first visible element in the tree when called on the last visible element, otherwise it returns null.

pub fn get_next_visible_ex<'ex>(&'ex self) -> ExGetNextVisible<'ex>

Returns the next visible TreeItem in the tree (in the context of a depth-first search) or a null object if there is none.

If wrap is enabled, the method will wrap around to the first visible element in the tree when called on the last visible element, otherwise it returns null.

pub fn get_prev_visible(&self) -> Option<Gd<TreeItem>>

To set the default parameters, use get_prev_visible_ex and its builder methods. See the book for detailed usage instructions. Returns the previous visible sibling TreeItem in the tree (in the context of a depth-first search) or a null object if there is none.

If wrap is enabled, the method will wrap around to the last visible element in the tree when called on the first visible element, otherwise it returns null.

pub fn get_prev_visible_ex<'ex>(&'ex self) -> ExGetPrevVisible<'ex>

Returns the previous visible sibling TreeItem in the tree (in the context of a depth-first search) or a null object if there is none.

If wrap is enabled, the method will wrap around to the last visible element in the tree when called on the first visible element, otherwise it returns null.

pub fn get_child(&self, index: i32) -> Option<Gd<TreeItem>>

Returns a child item by its index (see get_child_count). This method is often used for iterating all children of an item.

Negative indices access the children from the last one.

pub fn get_child_count(&self) -> i32

Returns the number of child items.

pub fn get_children(&self) -> Array<Gd<TreeItem>>

Returns an array of references to the item’s children.

pub fn get_index(&self) -> i32

Returns the node’s order in the tree. For example, if called on the first child item the position is 0.

pub fn move_before(&mut self, item: impl AsArg<Option<Gd<TreeItem>>>)

Moves this TreeItem right before the given item.

Note: You can’t move to the root or move the root.

pub fn move_after(&mut self, item: impl AsArg<Option<Gd<TreeItem>>>)

Moves this TreeItem right after the given item.

Note: You can’t move to the root or move the root.

pub fn call_recursive( &mut self, method: impl AsArg<StringName>, varargs: &[Variant], )

Calls the method on the actual TreeItem and its children recursively. Pass parameters as a comma separated list.

Panics

This is a varcall method, meaning parameters and return values are passed as Variant. It can detect call failures and will panic in such a case.

pub fn try_call_recursive( &mut self, method: impl AsArg<StringName>, varargs: &[Variant], ) -> Result<(), CallError>

Return type

This is a varcall method, meaning parameters and return values are passed as Variant. It can detect call failures and will return Err in such a case.

Methods from Deref<Target = Object>

pub fn get_script(&self) -> Option<Gd<Script>>

pub fn set_script(&mut self, script: impl AsArg<Option<Gd<Script>>>)

pub fn connect( &mut self, signal: impl AsArg<StringName>, callable: &Callable, ) -> Error

pub fn connect_flags( &mut self, signal: impl AsArg<StringName>, callable: &Callable, flags: ConnectFlags, ) -> Error

pub fn get_class(&self) -> GString

Returns the object’s built-in class name, as a String. See also is_class.

Note: This method ignores class_name declarations. If this object’s script has defined a class_name, the base, built-in class name is returned instead.

pub fn is_class(&self, class: impl AsArg<GString>) -> bool

Returns true if the object inherits from the given class. See also get_class.

var sprite2d = Sprite2D.new()
sprite2d.is_class("Sprite2D") # Returns true
sprite2d.is_class("Node")     # Returns true
sprite2d.is_class("Node3D")   # Returns false

Note: This method ignores class_name declarations in the object’s script.

pub fn set(&mut self, property: impl AsArg<StringName>, value: &Variant)

Assigns value to the given property. If the property does not exist or the given value’s type doesn’t match, nothing happens.

var node = Node2D.new()
node.set("global_scale", Vector2(8, 2.5))
print(node.global_scale) # Prints (8.0, 2.5)

Note: In C#, property must be in snake_case when referring to built-in Godot properties. Prefer using the names exposed in the PropertyName class to avoid allocating a new StringName on each call.

pub fn get(&self, property: impl AsArg<StringName>) -> Variant

Returns the Variant value of the given property. If the property does not exist, this method returns null.

var node = Node2D.new()
node.rotation = 1.5
var a = node.get("rotation") # a is 1.5

Note: In C#, property must be in snake_case when referring to built-in Godot properties. Prefer using the names exposed in the PropertyName class to avoid allocating a new StringName on each call.

pub fn set_indexed( &mut self, property_path: impl AsArg<NodePath>, value: &Variant, )

Assigns a new value to the property identified by the property_path. The path should be a NodePath relative to this object, and can use the colon character (:) to access nested properties.

var node = Node2D.new()
node.set_indexed("position", Vector2(42, 0))
node.set_indexed("position:y", -10)
print(node.position) # Prints (42.0, -10.0)

Note: In C#, property_path must be in snake_case when referring to built-in Godot properties. Prefer using the names exposed in the PropertyName class to avoid allocating a new StringName on each call.

pub fn get_indexed(&self, property_path: impl AsArg<NodePath>) -> Variant

Gets the object’s property indexed by the given property_path. The path should be a NodePath relative to the current object and can use the colon character (:) to access nested properties.

Examples: "position:x" or "material:next_pass:blend_mode".

var node = Node2D.new()
node.position = Vector2(5, -10)
var a = node.get_indexed("position")   # a is Vector2(5, -10)
var b = node.get_indexed("position:y") # b is -10

Note: In C#, property_path must be in snake_case when referring to built-in Godot properties. Prefer using the names exposed in the PropertyName class to avoid allocating a new StringName on each call.

Note: This method does not support actual paths to nodes in the SceneTree, only sub-property paths. In the context of nodes, use get_node_and_resource instead.

pub fn get_property_list(&self) -> Array<Dictionary<Variant, Variant>>

Returns the object’s property list as an Array of dictionaries. Each Dictionary contains the following entries:

  • name is the property’s name, as a String;

  • class_name is an empty StringName, unless the property is VariantType::OBJECT and it inherits from a class;

  • type is the property’s type, as an int (see [enum Variant.Type]);

  • hint is how the property is meant to be edited (see [enum PropertyHint]);

  • hint_string depends on the hint (see [enum PropertyHint]);

  • usage is a combination of [enum PropertyUsageFlags].

Note: In GDScript, all class members are treated as properties. In C# and GDExtension, it may be necessary to explicitly mark class members as Godot properties using decorators or attributes.

pub fn get_method_list(&self) -> Array<Dictionary<Variant, Variant>>

Returns this object’s methods and their signatures as an Array of dictionaries. Each Dictionary contains the following entries:

  • name is the name of the method, as a String;

  • args is an Array of dictionaries representing the arguments;

  • default_args is the default arguments as an Array of variants;

  • flags is a combination of [enum MethodFlags];

  • id is the method’s internal identifier int;

  • return is the returned value, as a Dictionary;

Note: The dictionaries of args and return are formatted identically to the results of get_property_list, although not all entries are used.

pub fn property_can_revert(&self, property: impl AsArg<StringName>) -> bool

Returns true if the given property has a custom default value. Use property_get_revert to get the property’s default value.

Note: This method is used by the Inspector dock to display a revert icon. The object must implement [method _property_can_revert] to customize the default value. If [method _property_can_revert] is not implemented, this method returns false.

pub fn property_get_revert(&self, property: impl AsArg<StringName>) -> Variant

Returns the custom default value of the given property. Use property_can_revert to check if the property has a custom default value.

Note: This method is used by the Inspector dock to display a revert icon. The object must implement [method _property_get_revert] to customize the default value. If [method _property_get_revert] is not implemented, this method returns null.

pub fn set_meta(&mut self, name: impl AsArg<StringName>, value: &Variant)

Adds or changes the entry name inside the object’s metadata. The metadata value can be any Variant, although some types cannot be serialized correctly.

If value is null, the entry is removed. This is the equivalent of using remove_meta. See also has_meta and get_meta.

Note: A metadata’s name must be a valid identifier as per is_valid_identifier method.

Note: Metadata that has a name starting with an underscore (_) is considered editor-only. Editor-only metadata is not displayed in the Inspector and should not be edited, although it can still be found by this method.

pub fn remove_meta(&mut self, name: impl AsArg<StringName>)

Removes the given entry name from the object’s metadata. See also has_meta, get_meta and set_meta.

Note: A metadata’s name must be a valid identifier as per is_valid_identifier method.

Note: Metadata that has a name starting with an underscore (_) is considered editor-only. Editor-only metadata is not displayed in the Inspector and should not be edited, although it can still be found by this method.

pub fn get_meta(&self, name: impl AsArg<StringName>) -> Variant

To set the default parameters, use get_meta_ex and its builder methods. See the book for detailed usage instructions. Returns the object’s metadata value for the given entry name. If the entry does not exist, returns default. If default is null, an error is also generated.

Note: A metadata’s name must be a valid identifier as per is_valid_identifier method.

Note: Metadata that has a name starting with an underscore (_) is considered editor-only. Editor-only metadata is not displayed in the Inspector and should not be edited, although it can still be found by this method.

pub fn get_meta_ex<'ex>( &'ex self, name: impl AsArg<StringName> + 'ex, ) -> ExGetMeta<'ex>

Returns the object’s metadata value for the given entry name. If the entry does not exist, returns default. If default is null, an error is also generated.

Note: A metadata’s name must be a valid identifier as per is_valid_identifier method.

Note: Metadata that has a name starting with an underscore (_) is considered editor-only. Editor-only metadata is not displayed in the Inspector and should not be edited, although it can still be found by this method.

pub fn has_meta(&self, name: impl AsArg<StringName>) -> bool

Returns true if a metadata entry is found with the given name. See also get_meta, set_meta and remove_meta.

Note: A metadata’s name must be a valid identifier as per is_valid_identifier method.

Note: Metadata that has a name starting with an underscore (_) is considered editor-only. Editor-only metadata is not displayed in the Inspector and should not be edited, although it can still be found by this method.

pub fn get_meta_list(&self) -> Array<StringName>

Returns the object’s metadata entry names as an Array of StringNames.

pub fn add_user_signal(&mut self, signal: impl AsArg<GString>)

To set the default parameters, use add_user_signal_ex and its builder methods. See the book for detailed usage instructions. Adds a user-defined signal named signal. Optional arguments for the signal can be added as an Array of dictionaries, each defining a name String and a type int (see [enum Variant.Type]). See also has_user_signal and remove_user_signal.

add_user_signal("hurt", [
	{ "name": "damage", "type": TYPE_INT },
	{ "name": "source", "type": TYPE_OBJECT }
])

pub fn add_user_signal_ex<'ex>( &'ex mut self, signal: impl AsArg<GString> + 'ex, ) -> ExAddUserSignal<'ex>

Adds a user-defined signal named signal. Optional arguments for the signal can be added as an Array of dictionaries, each defining a name String and a type int (see [enum Variant.Type]). See also has_user_signal and remove_user_signal.

add_user_signal("hurt", [
	{ "name": "damage", "type": TYPE_INT },
	{ "name": "source", "type": TYPE_OBJECT }
])

pub fn has_user_signal(&self, signal: impl AsArg<StringName>) -> bool

Returns true if the given user-defined signal name exists. Only signals added with add_user_signal are included. See also remove_user_signal.

pub fn remove_user_signal(&mut self, signal: impl AsArg<StringName>)

Removes the given user signal signal from the object. See also add_user_signal and has_user_signal.

pub fn emit_signal( &mut self, signal: impl AsArg<StringName>, varargs: &[Variant], ) -> Error

Emits the given signal by name. The signal must exist, so it should be a built-in signal of this class or one of its inherited classes, or a user-defined signal (see add_user_signal). This method supports a variable number of arguments, so parameters can be passed as a comma separated list.

Returns Error::ERR_UNAVAILABLE if signal does not exist or the parameters are invalid.

emit_signal("hit", "sword", 100)
emit_signal("game_over")

Note: In C#, signal must be in snake_case when referring to built-in Godot signals. Prefer using the names exposed in the SignalName class to avoid allocating a new StringName on each call.

Panics

This is a varcall method, meaning parameters and return values are passed as Variant. It can detect call failures and will panic in such a case.

pub fn try_emit_signal( &mut self, signal: impl AsArg<StringName>, varargs: &[Variant], ) -> Result<Error, CallError>

Return type

This is a varcall method, meaning parameters and return values are passed as Variant. It can detect call failures and will return Err in such a case.

pub fn call( &mut self, method: impl AsArg<StringName>, varargs: &[Variant], ) -> Variant

Calls the method on the object and returns the result. This method supports a variable number of arguments, so parameters can be passed as a comma separated list.

var node = Node3D.new()
node.call("rotate", Vector3(1.0, 0.0, 0.0), 1.571)

Note: In C#, method must be in snake_case when referring to built-in Godot methods. Prefer using the names exposed in the MethodName class to avoid allocating a new StringName on each call.

Panics

This is a varcall method, meaning parameters and return values are passed as Variant. It can detect call failures and will panic in such a case.

pub fn try_call( &mut self, method: impl AsArg<StringName>, varargs: &[Variant], ) -> Result<Variant, CallError>

Return type

This is a varcall method, meaning parameters and return values are passed as Variant. It can detect call failures and will return Err in such a case.

pub fn call_deferred( &mut self, method: impl AsArg<StringName>, varargs: &[Variant], ) -> Variant

Calls the method on the object during idle time. Always returns null, not the method’s result.

Idle time happens mainly at the end of process and physics frames. In it, deferred calls will be run until there are none left, which means you can defer calls from other deferred calls and they’ll still be run in the current idle time cycle. This means you should not call a method deferred from itself (or from a method called by it), as this causes infinite recursion the same way as if you had called the method directly.

This method supports a variable number of arguments, so parameters can be passed as a comma separated list.

var node = Node3D.new()
node.call_deferred("rotate", Vector3(1.0, 0.0, 0.0), 1.571)

For methods that are deferred from the same thread, the order of execution at idle time is identical to the order in which call_deferred was called.

See also call_deferred.

Note: In C#, method must be in snake_case when referring to built-in Godot methods. Prefer using the names exposed in the MethodName class to avoid allocating a new StringName on each call.

Note: If you’re looking to delay the function call by a frame, refer to the SceneTree.process_frame and SceneTree.physics_frame signals.

var node = Node3D.new()
# Make a Callable and bind the arguments to the node's rotate() call.
var callable = node.rotate.bind(Vector3(1.0, 0.0, 0.0), 1.571)
# Connect the callable to the process_frame signal, so it gets called in the next process frame.
# CONNECT_ONE_SHOT makes sure it only gets called once instead of every frame.
get_tree().process_frame.connect(callable, CONNECT_ONE_SHOT)
Panics

This is a varcall method, meaning parameters and return values are passed as Variant. It can detect call failures and will panic in such a case.

pub fn try_call_deferred( &mut self, method: impl AsArg<StringName>, varargs: &[Variant], ) -> Result<Variant, CallError>

Return type

This is a varcall method, meaning parameters and return values are passed as Variant. It can detect call failures and will return Err in such a case.

pub fn set_deferred( &mut self, property: impl AsArg<StringName>, value: &Variant, )

Assigns value to the given property, at the end of the current frame. This is equivalent to calling set through call_deferred.

var node = Node2D.new()
add_child(node)

node.rotation = 1.5
node.set_deferred("rotation", 3.0)
print(node.rotation) # Prints 1.5

await get_tree().process_frame
print(node.rotation) # Prints 3.0

Note: In C#, property must be in snake_case when referring to built-in Godot properties. Prefer using the names exposed in the PropertyName class to avoid allocating a new StringName on each call.

pub fn callv( &mut self, method: impl AsArg<StringName>, arg_array: &AnyArray, ) -> Variant

Calls the method on the object and returns the result. Unlike call, this method expects all parameters to be contained inside arg_array.

var node = Node3D.new()
node.callv("rotate", [Vector3(1.0, 0.0, 0.0), 1.571])

Note: In C#, method must be in snake_case when referring to built-in Godot methods. Prefer using the names exposed in the MethodName class to avoid allocating a new StringName on each call.

pub fn has_method(&self, method: impl AsArg<StringName>) -> bool

Returns true if the given method name exists in the object.

Note: In C#, method must be in snake_case when referring to built-in Godot methods. Prefer using the names exposed in the MethodName class to avoid allocating a new StringName on each call.

pub fn get_method_argument_count(&self, method: impl AsArg<StringName>) -> i32

Returns the number of arguments of the given method by name.

Note: In C#, method must be in snake_case when referring to built-in Godot methods. Prefer using the names exposed in the MethodName class to avoid allocating a new StringName on each call.

pub fn has_signal(&self, signal: impl AsArg<StringName>) -> bool

Returns true if the given signal name exists in the object.

Note: In C#, signal must be in snake_case when referring to built-in Godot signals. Prefer using the names exposed in the SignalName class to avoid allocating a new StringName on each call.

pub fn get_signal_list(&self) -> Array<Dictionary<Variant, Variant>>

Returns the list of existing signals as an Array of dictionaries.

Note: Due to the implementation, each Dictionary is formatted very similarly to the returned values of get_method_list.

pub fn get_signal_connection_list( &self, signal: impl AsArg<StringName>, ) -> Array<Dictionary<Variant, Variant>>

Returns an Array of connections for the given signal name. Each connection is represented as a Dictionary that contains three entries:

  • signal is a reference to the Signal;

  • callable is a reference to the connected Callable;

  • flags is a combination of [enum ConnectFlags].

pub fn get_incoming_connections(&self) -> Array<Dictionary<Variant, Variant>>

Returns an Array of signal connections received by this object. Each connection is represented as a Dictionary that contains three entries:

  • signal is a reference to the Signal;

  • callable is a reference to the Callable;

  • flags is a combination of [enum ConnectFlags].

pub fn disconnect( &mut self, signal: impl AsArg<StringName>, callable: &Callable, )

Disconnects a signal by name from a given callable. If the connection does not exist, generates an error. Use is_connected to make sure that the connection exists.

pub fn is_connected( &self, signal: impl AsArg<StringName>, callable: &Callable, ) -> bool

Returns true if a connection exists between the given signal name and callable.

Note: In C#, signal must be in snake_case when referring to built-in Godot signals. Prefer using the names exposed in the SignalName class to avoid allocating a new StringName on each call.

pub fn has_connections(&self, signal: impl AsArg<StringName>) -> bool

Returns true if any connection exists on the given signal name.

Note: In C#, signal must be in snake_case when referring to built-in Godot methods. Prefer using the names exposed in the SignalName class to avoid allocating a new StringName on each call.

pub fn set_block_signals(&mut self, enable: bool)

If set to true, the object becomes unable to emit signals. As such, emit_signal and signal connections will not work, until it is set to false.

pub fn is_blocking_signals(&self) -> bool

Returns true if the object is blocking its signals from being emitted. See set_block_signals.

pub fn notify_property_list_changed(&mut self)

Emits the property_list_changed signal. This is mainly used to refresh the editor, so that the Inspector and editor plugins are properly updated.

pub fn set_message_translation(&mut self, enable: bool)

If set to true, allows the object to translate messages with tr and tr_n. Enabled by default. See also can_translate_messages.

pub fn can_translate_messages(&self) -> bool

Returns true if the object is allowed to translate messages with tr and tr_n. See also set_message_translation.

pub fn tr(&self, message: impl AsArg<StringName>) -> GString

To set the default parameters, use tr_ex and its builder methods. See the book for detailed usage instructions. Translates a message, using the translation catalogs configured in the Project Settings. Further context can be specified to help with the translation. Note that most Control nodes automatically translate their strings, so this method is mostly useful for formatted strings or custom drawn text.

If can_translate_messages is false, or no translation is available, this method returns the message without changes. See set_message_translation.

For detailed examples, see Internationalizing games.

Note: This method can’t be used without an Object instance, as it requires the can_translate_messages method. To translate strings in a static context, use translate.

pub fn tr_ex<'ex>(&'ex self, message: impl AsArg<StringName> + 'ex) -> ExTr<'ex>

Translates a message, using the translation catalogs configured in the Project Settings. Further context can be specified to help with the translation. Note that most Control nodes automatically translate their strings, so this method is mostly useful for formatted strings or custom drawn text.

If can_translate_messages is false, or no translation is available, this method returns the message without changes. See set_message_translation.

For detailed examples, see Internationalizing games.

Note: This method can’t be used without an Object instance, as it requires the can_translate_messages method. To translate strings in a static context, use translate.

pub fn tr_n( &self, message: impl AsArg<StringName>, plural_message: impl AsArg<StringName>, n: i32, ) -> GString

To set the default parameters, use tr_n_ex and its builder methods. See the book for detailed usage instructions. Translates a message or plural_message, using the translation catalogs configured in the Project Settings. Further context can be specified to help with the translation.

If can_translate_messages is false, or no translation is available, this method returns message or plural_message, without changes. See set_message_translation.

The n is the number, or amount, of the message’s subject. It is used by the translation system to fetch the correct plural form for the current language.

For detailed examples, see Localization using gettext.

Note: Negative and float numbers may not properly apply to some countable subjects. It’s recommended to handle these cases with tr.

Note: This method can’t be used without an Object instance, as it requires the can_translate_messages method. To translate strings in a static context, use translate_plural.

pub fn tr_n_ex<'ex>( &'ex self, message: impl AsArg<StringName> + 'ex, plural_message: impl AsArg<StringName> + 'ex, n: i32, ) -> ExTrN<'ex>

Translates a message or plural_message, using the translation catalogs configured in the Project Settings. Further context can be specified to help with the translation.

If can_translate_messages is false, or no translation is available, this method returns message or plural_message, without changes. See set_message_translation.

The n is the number, or amount, of the message’s subject. It is used by the translation system to fetch the correct plural form for the current language.

For detailed examples, see Localization using gettext.

Note: Negative and float numbers may not properly apply to some countable subjects. It’s recommended to handle these cases with tr.

Note: This method can’t be used without an Object instance, as it requires the can_translate_messages method. To translate strings in a static context, use translate_plural.

pub fn get_translation_domain(&self) -> StringName

Returns the name of the translation domain used by tr and tr_n. See also TranslationServer.

pub fn set_translation_domain(&mut self, domain: impl AsArg<StringName>)

Sets the name of the translation domain used by tr and tr_n. See also TranslationServer.

pub fn is_queued_for_deletion(&self) -> bool

Returns true if the queue_free method was called for the object.

pub fn cancel_free(&mut self)

If this method is called during ObjectNotification::PREDELETE, this object will reject being freed and will remain allocated. This is mostly an internal function used for error handling to avoid the user from freeing objects when they are not intended to.

pub fn notify(&mut self, what: ObjectNotification)

⚠️ Sends a Godot notification to all classes inherited by the object.

Triggers calls to on_notification(), and depending on the notification, also to Godot’s lifecycle callbacks such as ready().

Starts from the highest ancestor (the Object class) and goes down the hierarchy. See also Godot docs for Object::notification().

Panics

If you call this method on a user-defined object while holding a GdRef or GdMut guard on the instance, you will encounter a panic. The reason is that the receiving virtual method on_notification() acquires a GdMut lock dynamically, which must be exclusive.

pub fn notify_reversed(&mut self, what: ObjectNotification)

⚠️ Like Self::notify(), but starts at the most-derived class and goes up the hierarchy.

See docs of that method, including the panics.