is_equal_approx

Function is_equal_approx 

pub fn is_equal_approx(a: f64, b: f64) -> bool
Returns true if a and b are approximately equal to each other.

Here, “approximately equal” means that a and b are within a small internal epsilon of each other, which scales with the magnitude of the numbers.

Infinity values of the same sign are considered equal.