min

Function min 

pub fn min(arg1: &Variant, arg2: &Variant, varargs: &[Variant]) -> Variant
Returns the minimum of the given numeric values. This function can take any number of arguments.

min(1, 7, 3, -6, 5) # Returns -6

Note: When using this on vectors it will not perform component-wise minimum, and will pick the smallest value when compared using x < y. To perform component-wise minimum, use coord_min, min, coord_min, min, coord_min, and min.