print_verbose

Function print_verbose 

pub fn print_verbose(varargs: &[Variant])
If verbose mode is enabled (is_stdout_verbose returning true), converts one or more arguments of any type to string in the best way possible and prints them to the console.