rid_allocate_id

Function rid_allocate_id 

pub fn rid_allocate_id() -> i64
Allocates a unique ID which can be used by the implementation to construct an RID. This is used mainly from native extensions to implement servers.