Function var_to_bytes
pub fn var_to_bytes(variable: &Variant) -> PackedArray<u8>Expand description
Encodes a Variant value to a byte array, without encoding objects. Deserialization can be done with [method bytes_to_var].
Note: If you need object serialization, see [method var_to_bytes_with_objects].
Note: Encoding Callable is not supported and will result in an empty value, regardless of the data.