Enum RpcError
#[non_exhaustive]pub enum RpcError {
NotConnected,
InvalidArguments,
Unconfigured,
Unrelated(Error),
}Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
NotConnected
The callee node was not connected to a server.
InvalidArguments
The RPC was called with incorrect arguments.
If this error occurs through the type-safe API, it is probably a bug.
Unconfigured
The callee node’s multiplayer could not be fetched. This is likely to happen when the node has yet to be added to the tree.
An error that is unlikely to come from interacting with RPCs.