Struct RpcBuilder
pub struct RpcBuilder<'c, C>where
C: GodotClass,{ /* private fields */ }Expand description
Represents an RPC, and the object that it can be called on, and is usually obtained through the type-safe RPC API. See the relevant section in the book for more information about type-safe RPC calls.
Implementations
impl<'c, C> RpcBuilder<'c, C>where
C: GodotClass,
impl<'c, C> RpcBuilder<'c, C>where
C: GodotClass,
pub fn new( object: UserRpcObject<'c, C>, rpc_name: &'c str, parameters: Vec<Variant>, ) -> RpcBuilder<'c, C>