ParamMetadata

Enum ParamMetadata 

#[non_exhaustive]
pub enum ParamMetadata {
Show 14 variants NONE, INT_IS_INT8, INT_IS_INT16, INT_IS_INT32, INT_IS_INT64, INT_IS_UINT8, INT_IS_UINT16, INT_IS_UINT32, INT_IS_UINT64, INT_IS_CHAR16, INT_IS_CHAR32, REAL_IS_FLOAT, REAL_IS_DOUBLE, OBJECT_IS_REQUIRED,
}
Metadata for a method parameter or return value, describing the precise numeric type.

Used in method registration to convey extra type information beyond the basic VariantType. For example, distinguishing i8 from i64 even though both are represented as INT in Godot’s type system. While irrelevant for GDScript, this can be helpful for other languages. The FFI representation is not affected by this, underlying types are always i64, f64 or object pointers.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


NONE

No special metadata; use the default representation.



INT_IS_INT8

Rust i8.



INT_IS_INT16

Rust i16.



INT_IS_INT32

Rust i32.



INT_IS_INT64

Rust i64.



INT_IS_UINT8

Rust u8.



INT_IS_UINT16

Rust u16.



INT_IS_UINT32

Rust u32.



INT_IS_UINT64

Rust u64.



INT_IS_CHAR16

16-bit character (UTF-16).



INT_IS_CHAR32

32-bit character (UTF-32).



REAL_IS_FLOAT

Rust f32 single-precision float.



REAL_IS_DOUBLE

Rust f64 double-precision float.



OBJECT_IS_REQUIRED

Object that must not be null (non-nullable Gd<T> parameter).

Compatibility: Only has an effect in Godot 4.6+. In earlier versions, this behaves like NONE, effectively allowing null objects.

Implementations



impl ParamMetadata

pub fn to_sys(self) -> u32

Converts to the raw GDExtension constant.