CallOutcome

Enum CallOutcome 

pub enum CallOutcome<R> {
    Return(R),
    CallFailed(String),
}
Outcome of mapping a Result<T, E> for a #[func] return value.

Returned by ErrorToGodot::result_to_godot(). Decides how Godot handles the result of a user-defined #[func].

Variants



Return(R)

Pass this value back to GDScript; the call succeeds.



CallFailed(String)

The call encounters an unexpected error; log provided message and perform best-effort failure handling.

This either stops the calling GDScript function or results in a default value of R on Godot side. Rust callers using Object::try_call() always receive Err. For detailed Godot-side semantics and an example, see strat::Unexpected.