Struct Font
pub struct Font { /* private fields */ }Expand description
Godot class Font.
Inherits Resource.
Related symbols:
font: sidecar module with related enum/flag types
See also Godot docs for Font.
Not instantiable
This class cannot be constructed. Obtain Gd<Font> instances via Godot APIs.
Final class
This class is final, meaning you cannot inherit from it, and it comes without I* interface trait. It is still possible that other Godot classes inherit from it, but that is limited to the engine itself.
Godot docs
Abstract base class for different font types. It has methods for drawing text and font character introspection.
Implementations
impl Font
impl Font
pub fn set_fallbacks(&mut self, fallbacks: &Array<Gd<Font>>)
pub fn get_fallbacks(&self) -> Array<Gd<Font>>
pub fn find_variation(&self, variation_coordinates: &AnyDictionary) -> Rid
pub fn find_variation(&self, variation_coordinates: &AnyDictionary) -> Rid
To set the default parameters, use find_variation_ex and its builder methods. See the book for detailed usage instructions.
Returns TextServer RID of the font cache for specific variation.
pub fn find_variation_ex<'ex>(
&'ex self,
variation_coordinates: &'ex AnyDictionary,
) -> ExFindVariation<'ex>
pub fn find_variation_ex<'ex>( &'ex self, variation_coordinates: &'ex AnyDictionary, ) -> ExFindVariation<'ex>
Returns TextServer RID of the font cache for specific variation.
pub fn get_rids(&self) -> Array<Rid>
pub fn get_rids(&self) -> Array<Rid>
Returns Array of valid Font RIDs, which can be passed to the TextServer methods.
pub fn get_height(&self) -> f32
pub fn get_height(&self) -> f32
To set the default parameters, use get_height_ex and its builder methods. See the book for detailed usage instructions.
Returns the total average font height (ascent plus descent) in pixels.
Note: Real height of the string is context-dependent and can be significantly different from the value returned by this function. Use it only as rough estimate (e.g. as the height of empty line).
pub fn get_height_ex<'ex>(&'ex self) -> ExGetHeight<'ex>
pub fn get_height_ex<'ex>(&'ex self) -> ExGetHeight<'ex>
Returns the total average font height (ascent plus descent) in pixels.
Note: Real height of the string is context-dependent and can be significantly different from the value returned by this function. Use it only as rough estimate (e.g. as the height of empty line).
pub fn get_ascent(&self) -> f32
pub fn get_ascent(&self) -> f32
To set the default parameters, use get_ascent_ex and its builder methods. See the book for detailed usage instructions.
Returns the average font ascent (number of pixels above the baseline).
Note: Real ascent of the string is context-dependent and can be significantly different from the value returned by this function. Use it only as rough estimate (e.g. as the ascent of empty line).
pub fn get_ascent_ex<'ex>(&'ex self) -> ExGetAscent<'ex>
pub fn get_ascent_ex<'ex>(&'ex self) -> ExGetAscent<'ex>
Returns the average font ascent (number of pixels above the baseline).
Note: Real ascent of the string is context-dependent and can be significantly different from the value returned by this function. Use it only as rough estimate (e.g. as the ascent of empty line).
pub fn get_descent(&self) -> f32
pub fn get_descent(&self) -> f32
To set the default parameters, use get_descent_ex and its builder methods. See the book for detailed usage instructions.
Returns the average font descent (number of pixels below the baseline).
Note: Real descent of the string is context-dependent and can be significantly different from the value returned by this function. Use it only as rough estimate (e.g. as the descent of empty line).
pub fn get_descent_ex<'ex>(&'ex self) -> ExGetDescent<'ex>
pub fn get_descent_ex<'ex>(&'ex self) -> ExGetDescent<'ex>
Returns the average font descent (number of pixels below the baseline).
Note: Real descent of the string is context-dependent and can be significantly different from the value returned by this function. Use it only as rough estimate (e.g. as the descent of empty line).
pub fn get_underline_position(&self) -> f32
pub fn get_underline_position(&self) -> f32
To set the default parameters, use get_underline_position_ex and its builder methods. See the book for detailed usage instructions.
Returns average pixel offset of the underline below the baseline.
Note: Real underline position of the string is context-dependent and can be significantly different from the value returned by this function. Use it only as rough estimate.
pub fn get_underline_position_ex<'ex>(&'ex self) -> ExGetUnderlinePosition<'ex>
pub fn get_underline_position_ex<'ex>(&'ex self) -> ExGetUnderlinePosition<'ex>
Returns average pixel offset of the underline below the baseline.
Note: Real underline position of the string is context-dependent and can be significantly different from the value returned by this function. Use it only as rough estimate.
pub fn get_underline_thickness(&self) -> f32
pub fn get_underline_thickness(&self) -> f32
To set the default parameters, use get_underline_thickness_ex and its builder methods. See the book for detailed usage instructions.
Returns average thickness of the underline.
Note: Real underline thickness of the string is context-dependent and can be significantly different from the value returned by this function. Use it only as rough estimate.
pub fn get_underline_thickness_ex<'ex>(
&'ex self,
) -> ExGetUnderlineThickness<'ex>
pub fn get_underline_thickness_ex<'ex>( &'ex self, ) -> ExGetUnderlineThickness<'ex>
Returns average thickness of the underline.
Note: Real underline thickness of the string is context-dependent and can be significantly different from the value returned by this function. Use it only as rough estimate.
pub fn get_font_name(&self) -> GString
pub fn get_font_name(&self) -> GString
Returns font family name.
pub fn get_font_style_name(&self) -> GString
pub fn get_font_style_name(&self) -> GString
Returns font style name.
pub fn get_ot_name_strings(&self) -> Dictionary<Variant, Variant>
pub fn get_ot_name_strings(&self) -> Dictionary<Variant, Variant>
Returns Dictionary with OpenType font name strings (localized font names, version, description, license information, sample text, etc.).
pub fn get_font_style(&self) -> FontStyle
pub fn get_font_style(&self) -> FontStyle
Returns font style flags.
pub fn get_font_weight(&self) -> i32
pub fn get_font_weight(&self) -> i32
Returns weight (boldness) of the font. A value in the 100...999 range, normal font weight is 400, bold font weight is 700.
pub fn get_font_stretch(&self) -> i32
pub fn get_font_stretch(&self) -> i32
Returns font stretch amount, compared to a normal width. A percentage value between 50% and 200%.
pub fn get_spacing(&self, spacing: SpacingType) -> i32
pub fn get_spacing(&self, spacing: SpacingType) -> i32
Returns the amount of spacing for the given spacing type.
pub fn get_opentype_features(&self) -> Dictionary<Variant, Variant>
pub fn get_opentype_features(&self) -> Dictionary<Variant, Variant>
Returns a set of OpenType feature tags. More info: OpenType feature tags.
pub fn set_cache_capacity(&mut self, single_line: i32, multi_line: i32)
pub fn set_cache_capacity(&mut self, single_line: i32, multi_line: i32)
Sets LRU cache capacity for draw_* methods.
pub fn get_string_size(&self, text: impl AsArg<GString>) -> Vector2
pub fn get_string_size(&self, text: impl AsArg<GString>) -> Vector2
To set the default parameters, use get_string_size_ex and its builder methods. See the book for detailed usage instructions.
Returns the size of a bounding box of a single-line string, taking kerning, advance and subpixel positioning into account. See also get_multiline_string_size and draw_string.
For example, to get the string size as displayed by a single-line Label, use:
var string_size = $Label.get_theme_font("font").get_string_size($Label.text, HORIZONTAL_ALIGNMENT_LEFT, -1, $Label.get_theme_font_size("font_size"))Note: Since kerning, advance and subpixel positioning are taken into account by get_string_size, using separate get_string_size calls on substrings of a string then adding the results together will return a different result compared to using a single get_string_size call on the full string.
Note: Real height of the string is context-dependent and can be significantly different from the value returned by get_height.
pub fn get_string_size_ex<'ex>(
&'ex self,
text: impl AsArg<GString> + 'ex,
) -> ExGetStringSize<'ex>
pub fn get_string_size_ex<'ex>( &'ex self, text: impl AsArg<GString> + 'ex, ) -> ExGetStringSize<'ex>
Returns the size of a bounding box of a single-line string, taking kerning, advance and subpixel positioning into account. See also get_multiline_string_size and draw_string.
For example, to get the string size as displayed by a single-line Label, use:
var string_size = $Label.get_theme_font("font").get_string_size($Label.text, HORIZONTAL_ALIGNMENT_LEFT, -1, $Label.get_theme_font_size("font_size"))Note: Since kerning, advance and subpixel positioning are taken into account by get_string_size, using separate get_string_size calls on substrings of a string then adding the results together will return a different result compared to using a single get_string_size call on the full string.
Note: Real height of the string is context-dependent and can be significantly different from the value returned by get_height.
pub fn get_multiline_string_size(&self, text: impl AsArg<GString>) -> Vector2
pub fn get_multiline_string_size(&self, text: impl AsArg<GString>) -> Vector2
To set the default parameters, use get_multiline_string_size_ex and its builder methods. See the book for detailed usage instructions.
Returns the size of a bounding box of a string broken into the lines, taking kerning and advance into account.
See also draw_multiline_string.
pub fn get_multiline_string_size_ex<'ex>(
&'ex self,
text: impl AsArg<GString> + 'ex,
) -> ExGetMultilineStringSize<'ex>
pub fn get_multiline_string_size_ex<'ex>( &'ex self, text: impl AsArg<GString> + 'ex, ) -> ExGetMultilineStringSize<'ex>
Returns the size of a bounding box of a string broken into the lines, taking kerning and advance into account.
See also draw_multiline_string.
pub fn draw_string(
&self,
canvas_item: Rid,
pos: Vector2,
text: impl AsArg<GString>,
)
pub fn draw_string( &self, canvas_item: Rid, pos: Vector2, text: impl AsArg<GString>, )
To set the default parameters, use draw_string_ex and its builder methods. See the book for detailed usage instructions.
Draw text into a canvas item using the font, at a given position, with modulate color, optionally clipping the width and aligning horizontally. pos specifies the baseline, not the top. To draw from the top, ascent must be added to the Y axis. If oversampling is greater than zero, it is used as font oversampling factor, otherwise viewport oversampling settings are used.
See also draw_string.
pub fn draw_string_ex<'ex>(
&'ex self,
canvas_item: Rid,
pos: Vector2,
text: impl AsArg<GString> + 'ex,
) -> ExDrawString<'ex>
pub fn draw_string_ex<'ex>( &'ex self, canvas_item: Rid, pos: Vector2, text: impl AsArg<GString> + 'ex, ) -> ExDrawString<'ex>
Draw text into a canvas item using the font, at a given position, with modulate color, optionally clipping the width and aligning horizontally. pos specifies the baseline, not the top. To draw from the top, ascent must be added to the Y axis. If oversampling is greater than zero, it is used as font oversampling factor, otherwise viewport oversampling settings are used.
See also draw_string.
pub fn draw_multiline_string(
&self,
canvas_item: Rid,
pos: Vector2,
text: impl AsArg<GString>,
)
pub fn draw_multiline_string( &self, canvas_item: Rid, pos: Vector2, text: impl AsArg<GString>, )
To set the default parameters, use draw_multiline_string_ex and its builder methods. See the book for detailed usage instructions.
Breaks text into lines using rules specified by brk_flags and draws it into a canvas item using the font, at a given position, with modulate color, optionally clipping the width and aligning horizontally. pos specifies the baseline of the first line, not the top. To draw from the top, ascent must be added to the Y axis. If oversampling is greater than zero, it is used as font oversampling factor, otherwise viewport oversampling settings are used.
See also draw_multiline_string.
pub fn draw_multiline_string_ex<'ex>(
&'ex self,
canvas_item: Rid,
pos: Vector2,
text: impl AsArg<GString> + 'ex,
) -> ExDrawMultilineString<'ex>
pub fn draw_multiline_string_ex<'ex>( &'ex self, canvas_item: Rid, pos: Vector2, text: impl AsArg<GString> + 'ex, ) -> ExDrawMultilineString<'ex>
Breaks text into lines using rules specified by brk_flags and draws it into a canvas item using the font, at a given position, with modulate color, optionally clipping the width and aligning horizontally. pos specifies the baseline of the first line, not the top. To draw from the top, ascent must be added to the Y axis. If oversampling is greater than zero, it is used as font oversampling factor, otherwise viewport oversampling settings are used.
See also draw_multiline_string.
pub fn draw_string_outline(
&self,
canvas_item: Rid,
pos: Vector2,
text: impl AsArg<GString>,
)
pub fn draw_string_outline( &self, canvas_item: Rid, pos: Vector2, text: impl AsArg<GString>, )
To set the default parameters, use draw_string_outline_ex and its builder methods. See the book for detailed usage instructions.
Draw text outline into a canvas item using the font, at a given position, with modulate color and size outline size, optionally clipping the width and aligning horizontally. pos specifies the baseline, not the top. To draw from the top, ascent must be added to the Y axis. If oversampling is greater than zero, it is used as font oversampling factor, otherwise viewport oversampling settings are used.
See also draw_string_outline.
pub fn draw_string_outline_ex<'ex>(
&'ex self,
canvas_item: Rid,
pos: Vector2,
text: impl AsArg<GString> + 'ex,
) -> ExDrawStringOutline<'ex>
pub fn draw_string_outline_ex<'ex>( &'ex self, canvas_item: Rid, pos: Vector2, text: impl AsArg<GString> + 'ex, ) -> ExDrawStringOutline<'ex>
Draw text outline into a canvas item using the font, at a given position, with modulate color and size outline size, optionally clipping the width and aligning horizontally. pos specifies the baseline, not the top. To draw from the top, ascent must be added to the Y axis. If oversampling is greater than zero, it is used as font oversampling factor, otherwise viewport oversampling settings are used.
See also draw_string_outline.
pub fn draw_multiline_string_outline(
&self,
canvas_item: Rid,
pos: Vector2,
text: impl AsArg<GString>,
)
pub fn draw_multiline_string_outline( &self, canvas_item: Rid, pos: Vector2, text: impl AsArg<GString>, )
To set the default parameters, use draw_multiline_string_outline_ex and its builder methods. See the book for detailed usage instructions.
Breaks text to the lines using rules specified by brk_flags and draws text outline into a canvas item using the font, at a given position, with modulate color and size outline size, optionally clipping the width and aligning horizontally. pos specifies the baseline of the first line, not the top. To draw from the top, ascent must be added to the Y axis. If oversampling is greater than zero, it is used as font oversampling factor, otherwise viewport oversampling settings are used.
See also draw_multiline_string_outline.
pub fn draw_multiline_string_outline_ex<'ex>(
&'ex self,
canvas_item: Rid,
pos: Vector2,
text: impl AsArg<GString> + 'ex,
) -> ExDrawMultilineStringOutline<'ex>
pub fn draw_multiline_string_outline_ex<'ex>( &'ex self, canvas_item: Rid, pos: Vector2, text: impl AsArg<GString> + 'ex, ) -> ExDrawMultilineStringOutline<'ex>
Breaks text to the lines using rules specified by brk_flags and draws text outline into a canvas item using the font, at a given position, with modulate color and size outline size, optionally clipping the width and aligning horizontally. pos specifies the baseline of the first line, not the top. To draw from the top, ascent must be added to the Y axis. If oversampling is greater than zero, it is used as font oversampling factor, otherwise viewport oversampling settings are used.
See also draw_multiline_string_outline.
pub fn get_char_size(&self, char: u32, font_size: i32) -> Vector2
pub fn get_char_size(&self, char: u32, font_size: i32) -> Vector2
Returns the size of a character. Does not take kerning into account.
Note: Do not use this function to calculate width of the string character by character, use get_string_size or TextLine instead. The height returned is the font height (see also get_height) and has no relation to the glyph height.
pub fn draw_char(
&self,
canvas_item: Rid,
pos: Vector2,
char: u32,
font_size: i32,
) -> f32
pub fn draw_char( &self, canvas_item: Rid, pos: Vector2, char: u32, font_size: i32, ) -> f32
To set the default parameters, use draw_char_ex and its builder methods. See the book for detailed usage instructions.
Draw a single Unicode character char into a canvas item using the font, at a given position, with modulate color. pos specifies the baseline, not the top. To draw from the top, ascent must be added to the Y axis. If oversampling is greater than zero, it is used as font oversampling factor, otherwise viewport oversampling settings are used.
Note: Do not use this function to draw strings character by character, use draw_string or TextLine instead.
pub fn draw_char_ex<'ex>(
&'ex self,
canvas_item: Rid,
pos: Vector2,
char: u32,
font_size: i32,
) -> ExDrawChar<'ex>
pub fn draw_char_ex<'ex>( &'ex self, canvas_item: Rid, pos: Vector2, char: u32, font_size: i32, ) -> ExDrawChar<'ex>
Draw a single Unicode character char into a canvas item using the font, at a given position, with modulate color. pos specifies the baseline, not the top. To draw from the top, ascent must be added to the Y axis. If oversampling is greater than zero, it is used as font oversampling factor, otherwise viewport oversampling settings are used.
Note: Do not use this function to draw strings character by character, use draw_string or TextLine instead.
pub fn draw_char_outline(
&self,
canvas_item: Rid,
pos: Vector2,
char: u32,
font_size: i32,
) -> f32
pub fn draw_char_outline( &self, canvas_item: Rid, pos: Vector2, char: u32, font_size: i32, ) -> f32
To set the default parameters, use draw_char_outline_ex and its builder methods. See the book for detailed usage instructions.
Draw a single Unicode character char outline into a canvas item using the font, at a given position, with modulate color and size outline size. pos specifies the baseline, not the top. To draw from the top, ascent must be added to the Y axis. If oversampling is greater than zero, it is used as font oversampling factor, otherwise viewport oversampling settings are used.
Note: Do not use this function to draw strings character by character, use draw_string or TextLine instead.
pub fn draw_char_outline_ex<'ex>(
&'ex self,
canvas_item: Rid,
pos: Vector2,
char: u32,
font_size: i32,
) -> ExDrawCharOutline<'ex>
pub fn draw_char_outline_ex<'ex>( &'ex self, canvas_item: Rid, pos: Vector2, char: u32, font_size: i32, ) -> ExDrawCharOutline<'ex>
Draw a single Unicode character char outline into a canvas item using the font, at a given position, with modulate color and size outline size. pos specifies the baseline, not the top. To draw from the top, ascent must be added to the Y axis. If oversampling is greater than zero, it is used as font oversampling factor, otherwise viewport oversampling settings are used.
Note: Do not use this function to draw strings character by character, use draw_string or TextLine instead.
pub fn get_supported_chars(&self) -> GString
pub fn get_supported_chars(&self) -> GString
Returns a string containing all the characters available in the font.
If a given character is included in more than one font data source, it appears only once in the returned string.
pub fn is_language_supported(&self, language: impl AsArg<GString>) -> bool
pub fn is_language_supported(&self, language: impl AsArg<GString>) -> bool
Returns true if the font supports the given language (as a ISO 639 code).
pub fn is_script_supported(&self, script: impl AsArg<GString>) -> bool
pub fn is_script_supported(&self, script: impl AsArg<GString>) -> bool
Returns true if the font supports the given script (as a ISO 15924 code).
pub fn get_supported_feature_list(&self) -> Dictionary<Variant, Variant>
pub fn get_supported_feature_list(&self) -> Dictionary<Variant, Variant>
Returns list of OpenType features supported by font.
pub fn get_supported_variation_list(&self) -> Dictionary<Variant, Variant>
pub fn get_supported_variation_list(&self) -> Dictionary<Variant, Variant>
Returns list of supported variation coordinates, each coordinate is returned as tag: Vector3i(min_value,max_value,default_value).
Font variations allow for continuous change of glyph characteristics along some given design axis, such as weight, width or slant.
To print available variation axes of a variable font:
var fv = FontVariation.new()
fv.base_font = load("res://RobotoFlex.ttf")
var variation_list = fv.get_supported_variation_list()
for tag in variation_list:
var name = TextServerManager.get_primary_interface().tag_to_name(tag)
var values = variation_list[tag]
print("variation axis: %s (%d)\n\tmin, max, default: %s" % [name, tag, values])Note: To set and get variation coordinates of a FontVariation, use [member FontVariation.variation_opentype].
pub fn get_face_count(&self) -> i64
pub fn get_face_count(&self) -> i64
Returns number of faces in the TrueType / OpenType collection.
Methods from Deref<Target = Resource>
pub fn set_path(&mut self, path: impl AsArg<GString>)
pub fn take_over_path(&mut self, path: impl AsArg<GString>)
pub fn take_over_path(&mut self, path: impl AsArg<GString>)
Sets the [member resource_path] to path, potentially overriding an existing cache entry for this path. Further attempts to load an overridden resource by path will instead return this resource.
pub fn get_path(&self) -> GString
pub fn set_path_cache(&mut self, path: impl AsArg<GString>)
pub fn set_path_cache(&mut self, path: impl AsArg<GString>)
Sets the resource’s path to path without involving the resource cache. Useful for handling [enum ResourceFormatLoader.CacheMode] values when implementing a custom resource format by extending ResourceFormatLoader and ResourceFormatSaver.
pub fn set_name(&mut self, name: impl AsArg<GString>)
pub fn get_name(&self) -> GString
pub fn get_rid(&self) -> Rid
pub fn get_rid(&self) -> Rid
Returns the RID of this resource (or an empty RID). Many resources (such as Texture2D, Mesh, and so on) are high-level abstractions of resources stored in a specialized server (DisplayServer, RenderingServer, etc.), so this function will return the original RID.
pub fn set_local_to_scene(&mut self, enable: bool)
pub fn is_local_to_scene(&self) -> bool
pub fn get_local_scene(&self) -> Option<Gd<Node>>
pub fn get_local_scene(&self) -> Option<Gd<Node>>
If [member resource_local_to_scene] is set to true and the resource has been loaded from a PackedScene instantiation, returns the root Node of the scene where this resource is used. Otherwise, returns null.
pub fn setup_local_to_scene(&mut self)
pub fn setup_local_to_scene(&mut self)
Calls setup_local_to_scene. If [member resource_local_to_scene] is set to true, this method is automatically called from instantiate by the newly duplicated resource within the scene instance.
pub fn reset_state(&mut self)
pub fn reset_state(&mut self)
Makes the resource clear its non-exported properties. See also reset_state. Useful when implementing a custom resource format by extending ResourceFormatLoader and ResourceFormatSaver.
pub fn set_id_for_path(
&mut self,
path: impl AsArg<GString>,
id: impl AsArg<GString>,
)
pub fn set_id_for_path( &mut self, path: impl AsArg<GString>, id: impl AsArg<GString>, )
In the internal cache for scene-unique IDs, sets the ID of this resource to id for the scene at path. If id is empty, the cache entry for path is cleared. Useful to keep scene-unique IDs the same when implementing a VCS-friendly custom resource format by extending ResourceFormatLoader and ResourceFormatSaver.
Note: This method is only implemented when running in an editor context.
pub fn get_id_for_path(&self, path: impl AsArg<GString>) -> GString
pub fn get_id_for_path(&self, path: impl AsArg<GString>) -> GString
From the internal cache for scene-unique IDs, returns the ID of this resource for the scene at path. If there is no entry, an empty string is returned. Useful to keep scene-unique IDs the same when implementing a VCS-friendly custom resource format by extending ResourceFormatLoader and ResourceFormatSaver.
Note: This method is only implemented when running in an editor context. At runtime, it returns an empty string.
pub fn is_built_in(&self) -> bool
pub fn is_built_in(&self) -> bool
Returns true if the resource is saved on disk as a part of another resource’s file.
pub fn set_scene_unique_id(&mut self, id: impl AsArg<GString>)
pub fn get_scene_unique_id(&self) -> GString
pub fn emit_changed(&mut self)
pub fn emit_changed(&mut self)
Emits the changed signal. This method is called automatically for some built-in resources.
Note: For custom resources, it’s recommended to call this method whenever a meaningful change occurs, such as a modified property. This ensures that custom Objects depending on the resource are properly updated.
var damage:
set(new_value):
if damage != new_value:
damage = new_value
emit_changed()pub fn duplicate(&self) -> Option<Gd<Resource>>
👎Deprecated: Use Gd::duplicate_resource() or Gd::duplicate_resource_ex().
pub fn duplicate(&self) -> Option<Gd<Resource>>
Use Gd::duplicate_resource() or Gd::duplicate_resource_ex().
To set the default parameters, use duplicate_ex and its builder methods. See the book for detailed usage instructions.
Duplicates this resource, returning a new resource with its exported or PropertyUsageFlags::STORAGE properties copied from the original.
If deep is false, a shallow copy is returned: nested Array, Dictionary, and Resource properties are not duplicated and are shared with the original resource.
If deep is true, a deep copy is returned: all nested arrays, dictionaries, and packed arrays are also duplicated (recursively). Any Resource found inside will only be duplicated if it’s local, like DeepDuplicateMode::INTERNAL used with duplicate_deep.
The following exceptions apply:
-
Subresource properties with the
PropertyUsageFlags::ALWAYS_DUPLICATEflag are always duplicated (recursively or not, depending ondeep). -
Subresource properties with the
PropertyUsageFlags::NEVER_DUPLICATEflag are never duplicated.
Note: For custom resources, this method will fail if init has been defined with required parameters.
Note: When duplicating with deep set to true, each resource found, including the one on which this method is called, will be only duplicated once and referenced as many times as needed in the duplicate. For instance, if you are duplicating resource A that happens to have resource B referenced twice, you’ll get a new resource A’ referencing a new resource B’ twice.
pub fn duplicate_ex<'ex>(&'ex self) -> ExDuplicate<'ex>
👎Deprecated: Use Gd::duplicate_resource() or Gd::duplicate_resource_ex().
pub fn duplicate_ex<'ex>(&'ex self) -> ExDuplicate<'ex>
Use Gd::duplicate_resource() or Gd::duplicate_resource_ex().
Duplicates this resource, returning a new resource with its exported or PropertyUsageFlags::STORAGE properties copied from the original.
If deep is false, a shallow copy is returned: nested Array, Dictionary, and Resource properties are not duplicated and are shared with the original resource.
If deep is true, a deep copy is returned: all nested arrays, dictionaries, and packed arrays are also duplicated (recursively). Any Resource found inside will only be duplicated if it’s local, like DeepDuplicateMode::INTERNAL used with duplicate_deep.
The following exceptions apply:
-
Subresource properties with the
PropertyUsageFlags::ALWAYS_DUPLICATEflag are always duplicated (recursively or not, depending ondeep). -
Subresource properties with the
PropertyUsageFlags::NEVER_DUPLICATEflag are never duplicated.
Note: For custom resources, this method will fail if init has been defined with required parameters.
Note: When duplicating with deep set to true, each resource found, including the one on which this method is called, will be only duplicated once and referenced as many times as needed in the duplicate. For instance, if you are duplicating resource A that happens to have resource B referenced twice, you’ll get a new resource A’ referencing a new resource B’ twice.
pub fn duplicate_deep(&self) -> Option<Gd<Resource>>
👎Deprecated: Use Gd::duplicate_resource() or Gd::duplicate_resource_ex().
pub fn duplicate_deep(&self) -> Option<Gd<Resource>>
Use Gd::duplicate_resource() or Gd::duplicate_resource_ex().
To set the default parameters, use duplicate_deep_ex and its builder methods. See the book for detailed usage instructions.
Duplicates this resource, deeply, like duplicate when passing true, with extra control over how subresources are handled.
pub fn duplicate_deep_ex<'ex>(&'ex self) -> ExDuplicateDeep<'ex>
👎Deprecated: Use Gd::duplicate_resource() or Gd::duplicate_resource_ex().
pub fn duplicate_deep_ex<'ex>(&'ex self) -> ExDuplicateDeep<'ex>
Use Gd::duplicate_resource() or Gd::duplicate_resource_ex().
Duplicates this resource, deeply, like duplicate when passing true, with extra control over how subresources are handled.
Methods from Deref<Target = RefCounted>
pub fn get_reference_count(&self) -> i32
pub fn get_reference_count(&self) -> i32
Returns the current reference count.
Methods from Deref<Target = Object>
pub fn get_script(&self) -> Option<Gd<Script>>
pub fn set_script(&mut self, script: impl AsArg<Option<Gd<Script>>>)
pub fn connect( &mut self, signal: impl AsArg<StringName>, callable: &Callable, ) -> Error
pub fn connect_flags( &mut self, signal: impl AsArg<StringName>, callable: &Callable, flags: ConnectFlags, ) -> Error
pub fn is_class(&self, class: impl AsArg<GString>) -> bool
pub fn is_class(&self, class: impl AsArg<GString>) -> bool
Returns true if the object inherits from the given class. See also get_class.
var sprite2d = Sprite2D.new()
sprite2d.is_class("Sprite2D") # Returns true
sprite2d.is_class("Node") # Returns true
sprite2d.is_class("Node3D") # Returns falseNote: This method ignores class_name declarations in the object’s script.
pub fn set(&mut self, property: impl AsArg<StringName>, value: &Variant)
pub fn set(&mut self, property: impl AsArg<StringName>, value: &Variant)
Assigns value to the given property. If the property does not exist or the given value’s type doesn’t match, nothing happens.
var node = Node2D.new()
node.set("global_scale", Vector2(8, 2.5))
print(node.global_scale) # Prints (8.0, 2.5)Note: In C#, property must be in snake_case when referring to built-in Godot properties. Prefer using the names exposed in the PropertyName class to avoid allocating a new StringName on each call.
pub fn get(&self, property: impl AsArg<StringName>) -> Variant
pub fn get(&self, property: impl AsArg<StringName>) -> Variant
Returns the Variant value of the given property. If the property does not exist, this method returns null.
var node = Node2D.new()
node.rotation = 1.5
var a = node.get("rotation") # a is 1.5Note: In C#, property must be in snake_case when referring to built-in Godot properties. Prefer using the names exposed in the PropertyName class to avoid allocating a new StringName on each call.
pub fn set_indexed(
&mut self,
property_path: impl AsArg<NodePath>,
value: &Variant,
)
pub fn set_indexed( &mut self, property_path: impl AsArg<NodePath>, value: &Variant, )
Assigns a new value to the property identified by the property_path. The path should be a NodePath relative to this object, and can use the colon character (:) to access nested properties.
var node = Node2D.new()
node.set_indexed("position", Vector2(42, 0))
node.set_indexed("position:y", -10)
print(node.position) # Prints (42.0, -10.0)Note: In C#, property_path must be in snake_case when referring to built-in Godot properties. Prefer using the names exposed in the PropertyName class to avoid allocating a new StringName on each call.
pub fn get_indexed(&self, property_path: impl AsArg<NodePath>) -> Variant
pub fn get_indexed(&self, property_path: impl AsArg<NodePath>) -> Variant
Gets the object’s property indexed by the given property_path. The path should be a NodePath relative to the current object and can use the colon character (:) to access nested properties.
Examples: "position:x" or "material:next_pass:blend_mode".
var node = Node2D.new()
node.position = Vector2(5, -10)
var a = node.get_indexed("position") # a is Vector2(5, -10)
var b = node.get_indexed("position:y") # b is -10Note: In C#, property_path must be in snake_case when referring to built-in Godot properties. Prefer using the names exposed in the PropertyName class to avoid allocating a new StringName on each call.
Note: This method does not support actual paths to nodes in the SceneTree, only sub-property paths. In the context of nodes, use get_node_and_resource instead.
pub fn get_property_list(&self) -> Array<Dictionary<Variant, Variant>>
pub fn get_property_list(&self) -> Array<Dictionary<Variant, Variant>>
Returns the object’s property list as an Array of dictionaries. Each Dictionary contains the following entries:
-
nameis the property’s name, as aString; -
class_nameis an emptyStringName, unless the property isVariantType::OBJECTand it inherits from a class; -
typeis the property’s type, as anint(see [enum Variant.Type]); -
hintis how the property is meant to be edited (see [enum PropertyHint]); -
hint_stringdepends on the hint (see [enum PropertyHint]); -
usageis a combination of [enum PropertyUsageFlags].
Note: In GDScript, all class members are treated as properties. In C# and GDExtension, it may be necessary to explicitly mark class members as Godot properties using decorators or attributes.
pub fn get_method_list(&self) -> Array<Dictionary<Variant, Variant>>
pub fn get_method_list(&self) -> Array<Dictionary<Variant, Variant>>
Returns this object’s methods and their signatures as an Array of dictionaries. Each Dictionary contains the following entries:
-
nameis the name of the method, as aString; -
argsis anArrayof dictionaries representing the arguments; -
default_argsis the default arguments as anArrayof variants; -
flagsis a combination of [enum MethodFlags]; -
idis the method’s internal identifierint; -
returnis the returned value, as aDictionary;
Note: The dictionaries of args and return are formatted identically to the results of get_property_list, although not all entries are used.
pub fn property_can_revert(&self, property: impl AsArg<StringName>) -> bool
pub fn property_can_revert(&self, property: impl AsArg<StringName>) -> bool
Returns true if the given property has a custom default value. Use property_get_revert to get the property’s default value.
Note: This method is used by the Inspector dock to display a revert icon. The object must implement [method _property_can_revert] to customize the default value. If [method _property_can_revert] is not implemented, this method returns false.
pub fn property_get_revert(&self, property: impl AsArg<StringName>) -> Variant
pub fn property_get_revert(&self, property: impl AsArg<StringName>) -> Variant
Returns the custom default value of the given property. Use property_can_revert to check if the property has a custom default value.
Note: This method is used by the Inspector dock to display a revert icon. The object must implement [method _property_get_revert] to customize the default value. If [method _property_get_revert] is not implemented, this method returns null.
pub fn set_meta(&mut self, name: impl AsArg<StringName>, value: &Variant)
pub fn set_meta(&mut self, name: impl AsArg<StringName>, value: &Variant)
Adds or changes the entry name inside the object’s metadata. The metadata value can be any Variant, although some types cannot be serialized correctly.
If value is null, the entry is removed. This is the equivalent of using remove_meta. See also has_meta and get_meta.
Note: A metadata’s name must be a valid identifier as per is_valid_identifier method.
Note: Metadata that has a name starting with an underscore (_) is considered editor-only. Editor-only metadata is not displayed in the Inspector and should not be edited, although it can still be found by this method.
pub fn remove_meta(&mut self, name: impl AsArg<StringName>)
pub fn remove_meta(&mut self, name: impl AsArg<StringName>)
Removes the given entry name from the object’s metadata. See also has_meta, get_meta and set_meta.
Note: A metadata’s name must be a valid identifier as per is_valid_identifier method.
Note: Metadata that has a name starting with an underscore (_) is considered editor-only. Editor-only metadata is not displayed in the Inspector and should not be edited, although it can still be found by this method.
pub fn get_meta(&self, name: impl AsArg<StringName>) -> Variant
pub fn get_meta(&self, name: impl AsArg<StringName>) -> Variant
To set the default parameters, use get_meta_ex and its builder methods. See the book for detailed usage instructions.
Returns the object’s metadata value for the given entry name. If the entry does not exist, returns default. If default is null, an error is also generated.
Note: A metadata’s name must be a valid identifier as per is_valid_identifier method.
Note: Metadata that has a name starting with an underscore (_) is considered editor-only. Editor-only metadata is not displayed in the Inspector and should not be edited, although it can still be found by this method.
pub fn get_meta_ex<'ex>(
&'ex self,
name: impl AsArg<StringName> + 'ex,
) -> ExGetMeta<'ex>
pub fn get_meta_ex<'ex>( &'ex self, name: impl AsArg<StringName> + 'ex, ) -> ExGetMeta<'ex>
Returns the object’s metadata value for the given entry name. If the entry does not exist, returns default. If default is null, an error is also generated.
Note: A metadata’s name must be a valid identifier as per is_valid_identifier method.
Note: Metadata that has a name starting with an underscore (_) is considered editor-only. Editor-only metadata is not displayed in the Inspector and should not be edited, although it can still be found by this method.
pub fn has_meta(&self, name: impl AsArg<StringName>) -> bool
pub fn has_meta(&self, name: impl AsArg<StringName>) -> bool
Returns true if a metadata entry is found with the given name. See also get_meta, set_meta and remove_meta.
Note: A metadata’s name must be a valid identifier as per is_valid_identifier method.
Note: Metadata that has a name starting with an underscore (_) is considered editor-only. Editor-only metadata is not displayed in the Inspector and should not be edited, although it can still be found by this method.
pub fn get_meta_list(&self) -> Array<StringName>
pub fn get_meta_list(&self) -> Array<StringName>
Returns the object’s metadata entry names as an Array of StringNames.
pub fn add_user_signal(&mut self, signal: impl AsArg<GString>)
pub fn add_user_signal(&mut self, signal: impl AsArg<GString>)
To set the default parameters, use add_user_signal_ex and its builder methods. See the book for detailed usage instructions.
Adds a user-defined signal named signal. Optional arguments for the signal can be added as an Array of dictionaries, each defining a name String and a type int (see [enum Variant.Type]). See also has_user_signal and remove_user_signal.
add_user_signal("hurt", [
{ "name": "damage", "type": TYPE_INT },
{ "name": "source", "type": TYPE_OBJECT }
])pub fn add_user_signal_ex<'ex>(
&'ex mut self,
signal: impl AsArg<GString> + 'ex,
) -> ExAddUserSignal<'ex>
pub fn add_user_signal_ex<'ex>( &'ex mut self, signal: impl AsArg<GString> + 'ex, ) -> ExAddUserSignal<'ex>
Adds a user-defined signal named signal. Optional arguments for the signal can be added as an Array of dictionaries, each defining a name String and a type int (see [enum Variant.Type]). See also has_user_signal and remove_user_signal.
add_user_signal("hurt", [
{ "name": "damage", "type": TYPE_INT },
{ "name": "source", "type": TYPE_OBJECT }
])pub fn has_user_signal(&self, signal: impl AsArg<StringName>) -> bool
pub fn has_user_signal(&self, signal: impl AsArg<StringName>) -> bool
Returns true if the given user-defined signal name exists. Only signals added with add_user_signal are included. See also remove_user_signal.
pub fn remove_user_signal(&mut self, signal: impl AsArg<StringName>)
pub fn remove_user_signal(&mut self, signal: impl AsArg<StringName>)
Removes the given user signal signal from the object. See also add_user_signal and has_user_signal.
pub fn emit_signal(
&mut self,
signal: impl AsArg<StringName>,
varargs: &[Variant],
) -> Error
pub fn emit_signal( &mut self, signal: impl AsArg<StringName>, varargs: &[Variant], ) -> Error
Emits the given signal by name. The signal must exist, so it should be a built-in signal of this class or one of its inherited classes, or a user-defined signal (see add_user_signal). This method supports a variable number of arguments, so parameters can be passed as a comma separated list.
Returns Error::ERR_UNAVAILABLE if signal does not exist or the parameters are invalid.
emit_signal("hit", "sword", 100)
emit_signal("game_over")Note: In C#, signal must be in snake_case when referring to built-in Godot signals. Prefer using the names exposed in the SignalName class to avoid allocating a new StringName on each call.
Panics
This is a varcall method, meaning parameters and return values are passed as Variant.
It can detect call failures and will panic in such a case.
pub fn try_emit_signal(
&mut self,
signal: impl AsArg<StringName>,
varargs: &[Variant],
) -> Result<Error, CallError>
pub fn try_emit_signal( &mut self, signal: impl AsArg<StringName>, varargs: &[Variant], ) -> Result<Error, CallError>
Return type
This is a varcall method, meaning parameters and return values are passed as Variant.
It can detect call failures and will return Err in such a case.
pub fn call(
&mut self,
method: impl AsArg<StringName>,
varargs: &[Variant],
) -> Variant
pub fn call( &mut self, method: impl AsArg<StringName>, varargs: &[Variant], ) -> Variant
Calls the method on the object and returns the result. This method supports a variable number of arguments, so parameters can be passed as a comma separated list.
var node = Node3D.new()
node.call("rotate", Vector3(1.0, 0.0, 0.0), 1.571)Note: In C#, method must be in snake_case when referring to built-in Godot methods. Prefer using the names exposed in the MethodName class to avoid allocating a new StringName on each call.
Panics
This is a varcall method, meaning parameters and return values are passed as Variant.
It can detect call failures and will panic in such a case.
pub fn try_call(
&mut self,
method: impl AsArg<StringName>,
varargs: &[Variant],
) -> Result<Variant, CallError>
pub fn try_call( &mut self, method: impl AsArg<StringName>, varargs: &[Variant], ) -> Result<Variant, CallError>
Return type
This is a varcall method, meaning parameters and return values are passed as Variant.
It can detect call failures and will return Err in such a case.
pub fn call_deferred(
&mut self,
method: impl AsArg<StringName>,
varargs: &[Variant],
) -> Variant
pub fn call_deferred( &mut self, method: impl AsArg<StringName>, varargs: &[Variant], ) -> Variant
Calls the method on the object during idle time. Always returns null, not the method’s result.
Idle time happens mainly at the end of process and physics frames. In it, deferred calls will be run until there are none left, which means you can defer calls from other deferred calls and they’ll still be run in the current idle time cycle. This means you should not call a method deferred from itself (or from a method called by it), as this causes infinite recursion the same way as if you had called the method directly.
This method supports a variable number of arguments, so parameters can be passed as a comma separated list.
var node = Node3D.new()
node.call_deferred("rotate", Vector3(1.0, 0.0, 0.0), 1.571)For methods that are deferred from the same thread, the order of execution at idle time is identical to the order in which call_deferred was called.
See also call_deferred.
Note: In C#, method must be in snake_case when referring to built-in Godot methods. Prefer using the names exposed in the MethodName class to avoid allocating a new StringName on each call.
Note: If you’re looking to delay the function call by a frame, refer to the SceneTree.process_frame and SceneTree.physics_frame signals.
var node = Node3D.new()
# Make a Callable and bind the arguments to the node's rotate() call.
var callable = node.rotate.bind(Vector3(1.0, 0.0, 0.0), 1.571)
# Connect the callable to the process_frame signal, so it gets called in the next process frame.
# CONNECT_ONE_SHOT makes sure it only gets called once instead of every frame.
get_tree().process_frame.connect(callable, CONNECT_ONE_SHOT)Panics
This is a varcall method, meaning parameters and return values are passed as Variant.
It can detect call failures and will panic in such a case.
pub fn try_call_deferred(
&mut self,
method: impl AsArg<StringName>,
varargs: &[Variant],
) -> Result<Variant, CallError>
pub fn try_call_deferred( &mut self, method: impl AsArg<StringName>, varargs: &[Variant], ) -> Result<Variant, CallError>
Return type
This is a varcall method, meaning parameters and return values are passed as Variant.
It can detect call failures and will return Err in such a case.
pub fn set_deferred(
&mut self,
property: impl AsArg<StringName>,
value: &Variant,
)
pub fn set_deferred( &mut self, property: impl AsArg<StringName>, value: &Variant, )
Assigns value to the given property, at the end of the current frame. This is equivalent to calling set through call_deferred.
var node = Node2D.new()
add_child(node)
node.rotation = 1.5
node.set_deferred("rotation", 3.0)
print(node.rotation) # Prints 1.5
await get_tree().process_frame
print(node.rotation) # Prints 3.0Note: In C#, property must be in snake_case when referring to built-in Godot properties. Prefer using the names exposed in the PropertyName class to avoid allocating a new StringName on each call.
pub fn callv(
&mut self,
method: impl AsArg<StringName>,
arg_array: &AnyArray,
) -> Variant
pub fn callv( &mut self, method: impl AsArg<StringName>, arg_array: &AnyArray, ) -> Variant
Calls the method on the object and returns the result. Unlike call, this method expects all parameters to be contained inside arg_array.
var node = Node3D.new()
node.callv("rotate", [Vector3(1.0, 0.0, 0.0), 1.571])Note: In C#, method must be in snake_case when referring to built-in Godot methods. Prefer using the names exposed in the MethodName class to avoid allocating a new StringName on each call.
pub fn has_method(&self, method: impl AsArg<StringName>) -> bool
pub fn has_method(&self, method: impl AsArg<StringName>) -> bool
Returns true if the given method name exists in the object.
Note: In C#, method must be in snake_case when referring to built-in Godot methods. Prefer using the names exposed in the MethodName class to avoid allocating a new StringName on each call.
pub fn get_method_argument_count(&self, method: impl AsArg<StringName>) -> i32
pub fn get_method_argument_count(&self, method: impl AsArg<StringName>) -> i32
Returns the number of arguments of the given method by name.
Note: In C#, method must be in snake_case when referring to built-in Godot methods. Prefer using the names exposed in the MethodName class to avoid allocating a new StringName on each call.
pub fn has_signal(&self, signal: impl AsArg<StringName>) -> bool
pub fn has_signal(&self, signal: impl AsArg<StringName>) -> bool
Returns true if the given signal name exists in the object.
Note: In C#, signal must be in snake_case when referring to built-in Godot signals. Prefer using the names exposed in the SignalName class to avoid allocating a new StringName on each call.
pub fn get_signal_list(&self) -> Array<Dictionary<Variant, Variant>>
pub fn get_signal_list(&self) -> Array<Dictionary<Variant, Variant>>
Returns the list of existing signals as an Array of dictionaries.
Note: Due to the implementation, each Dictionary is formatted very similarly to the returned values of get_method_list.
pub fn get_signal_connection_list(
&self,
signal: impl AsArg<StringName>,
) -> Array<Dictionary<Variant, Variant>>
pub fn get_signal_connection_list( &self, signal: impl AsArg<StringName>, ) -> Array<Dictionary<Variant, Variant>>
Returns an Array of connections for the given signal name. Each connection is represented as a Dictionary that contains three entries:
pub fn get_incoming_connections(&self) -> Array<Dictionary<Variant, Variant>>
pub fn get_incoming_connections(&self) -> Array<Dictionary<Variant, Variant>>
Returns an Array of signal connections received by this object. Each connection is represented as a Dictionary that contains three entries:
pub fn disconnect(
&mut self,
signal: impl AsArg<StringName>,
callable: &Callable,
)
pub fn disconnect( &mut self, signal: impl AsArg<StringName>, callable: &Callable, )
Disconnects a signal by name from a given callable. If the connection does not exist, generates an error. Use is_connected to make sure that the connection exists.
pub fn is_connected(
&self,
signal: impl AsArg<StringName>,
callable: &Callable,
) -> bool
pub fn is_connected( &self, signal: impl AsArg<StringName>, callable: &Callable, ) -> bool
Returns true if a connection exists between the given signal name and callable.
Note: In C#, signal must be in snake_case when referring to built-in Godot signals. Prefer using the names exposed in the SignalName class to avoid allocating a new StringName on each call.
pub fn has_connections(&self, signal: impl AsArg<StringName>) -> bool
pub fn has_connections(&self, signal: impl AsArg<StringName>) -> bool
Returns true if any connection exists on the given signal name.
Note: In C#, signal must be in snake_case when referring to built-in Godot methods. Prefer using the names exposed in the SignalName class to avoid allocating a new StringName on each call.
pub fn set_block_signals(&mut self, enable: bool)
pub fn set_block_signals(&mut self, enable: bool)
If set to true, the object becomes unable to emit signals. As such, emit_signal and signal connections will not work, until it is set to false.
pub fn is_blocking_signals(&self) -> bool
pub fn is_blocking_signals(&self) -> bool
Returns true if the object is blocking its signals from being emitted. See set_block_signals.
pub fn notify_property_list_changed(&mut self)
pub fn notify_property_list_changed(&mut self)
Emits the property_list_changed signal. This is mainly used to refresh the editor, so that the Inspector and editor plugins are properly updated.
pub fn set_message_translation(&mut self, enable: bool)
pub fn set_message_translation(&mut self, enable: bool)
If set to true, allows the object to translate messages with tr and tr_n. Enabled by default. See also can_translate_messages.
pub fn can_translate_messages(&self) -> bool
pub fn can_translate_messages(&self) -> bool
Returns true if the object is allowed to translate messages with tr and tr_n. See also set_message_translation.
pub fn tr(&self, message: impl AsArg<StringName>) -> GString
pub fn tr(&self, message: impl AsArg<StringName>) -> GString
To set the default parameters, use tr_ex and its builder methods. See the book for detailed usage instructions.
Translates a message, using the translation catalogs configured in the Project Settings. Further context can be specified to help with the translation. Note that most Control nodes automatically translate their strings, so this method is mostly useful for formatted strings or custom drawn text.
If can_translate_messages is false, or no translation is available, this method returns the message without changes. See set_message_translation.
For detailed examples, see Internationalizing games.
Note: This method can’t be used without an Object instance, as it requires the can_translate_messages method. To translate strings in a static context, use translate.
pub fn tr_ex<'ex>(&'ex self, message: impl AsArg<StringName> + 'ex) -> ExTr<'ex>
pub fn tr_ex<'ex>(&'ex self, message: impl AsArg<StringName> + 'ex) -> ExTr<'ex>
Translates a message, using the translation catalogs configured in the Project Settings. Further context can be specified to help with the translation. Note that most Control nodes automatically translate their strings, so this method is mostly useful for formatted strings or custom drawn text.
If can_translate_messages is false, or no translation is available, this method returns the message without changes. See set_message_translation.
For detailed examples, see Internationalizing games.
Note: This method can’t be used without an Object instance, as it requires the can_translate_messages method. To translate strings in a static context, use translate.
pub fn tr_n(
&self,
message: impl AsArg<StringName>,
plural_message: impl AsArg<StringName>,
n: i32,
) -> GString
pub fn tr_n( &self, message: impl AsArg<StringName>, plural_message: impl AsArg<StringName>, n: i32, ) -> GString
To set the default parameters, use tr_n_ex and its builder methods. See the book for detailed usage instructions.
Translates a message or plural_message, using the translation catalogs configured in the Project Settings. Further context can be specified to help with the translation.
If can_translate_messages is false, or no translation is available, this method returns message or plural_message, without changes. See set_message_translation.
The n is the number, or amount, of the message’s subject. It is used by the translation system to fetch the correct plural form for the current language.
For detailed examples, see Localization using gettext.
Note: Negative and float numbers may not properly apply to some countable subjects. It’s recommended to handle these cases with tr.
Note: This method can’t be used without an Object instance, as it requires the can_translate_messages method. To translate strings in a static context, use translate_plural.
pub fn tr_n_ex<'ex>(
&'ex self,
message: impl AsArg<StringName> + 'ex,
plural_message: impl AsArg<StringName> + 'ex,
n: i32,
) -> ExTrN<'ex>
pub fn tr_n_ex<'ex>( &'ex self, message: impl AsArg<StringName> + 'ex, plural_message: impl AsArg<StringName> + 'ex, n: i32, ) -> ExTrN<'ex>
Translates a message or plural_message, using the translation catalogs configured in the Project Settings. Further context can be specified to help with the translation.
If can_translate_messages is false, or no translation is available, this method returns message or plural_message, without changes. See set_message_translation.
The n is the number, or amount, of the message’s subject. It is used by the translation system to fetch the correct plural form for the current language.
For detailed examples, see Localization using gettext.
Note: Negative and float numbers may not properly apply to some countable subjects. It’s recommended to handle these cases with tr.
Note: This method can’t be used without an Object instance, as it requires the can_translate_messages method. To translate strings in a static context, use translate_plural.
pub fn get_translation_domain(&self) -> StringName
pub fn get_translation_domain(&self) -> StringName
Returns the name of the translation domain used by tr and tr_n. See also TranslationServer.
pub fn set_translation_domain(&mut self, domain: impl AsArg<StringName>)
pub fn set_translation_domain(&mut self, domain: impl AsArg<StringName>)
Sets the name of the translation domain used by tr and tr_n. See also TranslationServer.
pub fn is_queued_for_deletion(&self) -> bool
pub fn is_queued_for_deletion(&self) -> bool
Returns true if the queue_free method was called for the object.
pub fn cancel_free(&mut self)
pub fn cancel_free(&mut self)
If this method is called during ObjectNotification::PREDELETE, this object will reject being freed and will remain allocated. This is mostly an internal function used for error handling to avoid the user from freeing objects when they are not intended to.
pub fn notify(&mut self, what: ObjectNotification)
pub fn notify(&mut self, what: ObjectNotification)
⚠️ Sends a Godot notification to all classes inherited by the object.
Triggers calls to on_notification(), and depending on the notification, also to Godot’s lifecycle callbacks such as ready().
Starts from the highest ancestor (the Object class) and goes down the hierarchy.
See also Godot docs for Object::notification().
Panics
If you call this method on a user-defined object while holding a GdRef or GdMut guard on the instance, you will encounter
a panic. The reason is that the receiving virtual method on_notification() acquires a GdMut lock dynamically, which must
be exclusive.
pub fn notify_reversed(&mut self, what: ObjectNotification)
pub fn notify_reversed(&mut self, what: ObjectNotification)
⚠️ Like Self::notify(), but starts at the most-derived class and goes up the hierarchy.
See docs of that method, including the panics.