bytes_to_var_with_objects

Function bytes_to_var_with_objects 

pub fn bytes_to_var_with_objects(bytes: &PackedArray<u8>) -> Variant
Decodes a byte array back to a Variant value. Decoding objects is allowed.

Warning: Deserialized object can contain code which gets executed. Do not use this option if the serialized object comes from untrusted sources to avoid potential security threats (remote code execution).