Function print
pub fn print(varargs: &[Variant])Expand description
Converts one or more arguments of any type to string in the best way possible and prints them to the console.
var a = [1, 2, 3]
print("a", "b", a) # Prints "ab[1, 2, 3]"Note: Consider using [method push_error] and [method push_warning] to print error and warning messages instead of [method print] or [method print_rich]. This distinguishes them from print messages used for debugging purposes, while also displaying a stack trace when an error or warning is printed. See also [member Engine.print_to_stdout] and [member ProjectSettings.application/run/disable_stdout].