Function printraw
pub fn printraw(varargs: &[Variant])Expand description
Prints one or more arguments to strings in the best way possible to the OS terminal. Unlike [method print], no newline is automatically added at the end.
Note: The OS terminal is not the same as the editor’s Output dock. The output sent to the OS terminal can be seen when running Godot from a terminal. On Windows, this requires using the console.exe executable.
# Prints "ABC" to terminal.
printraw("A")
printraw("B")
printraw("C")