randomize

Function randomize 

pub fn randomize()
Randomizes the seed (or the internal state) of the random number generator. The current implementation uses a number based on the device’s time.

Note: This function is called automatically when the project is run. If you need to fix the seed to have consistent, reproducible results, use [method seed] to initialize the random number generator.