is_initialized

Function is_initialized 

pub fn is_initialized() -> bool
Returns true if godot-rust bindings are initialized.

The bindings are initialized when the library is loaded and deinitialized when it is unloaded (which may happen, for example, during a hot reload).