BaseMaterial3D

Struct BaseMaterial3D 

pub struct BaseMaterial3D { /* private fields */ }
Godot class BaseMaterial3D.

Inherits Material.

Related symbols:

See also Godot docs for BaseMaterial3D.

Not instantiable

This class cannot be constructed. Obtain Gd<BaseMaterial3D> instances via Godot APIs.

Final class

This class is final, meaning you cannot inherit from it, and it comes without I* interface trait. It is still possible that other Godot classes inherit from it, but that is limited to the engine itself.

Godot docs

This class serves as a default material with a wide variety of rendering features and properties without the need to write shader code. See the tutorial below for details.

Implementations



impl BaseMaterial3D

pub fn set_albedo(&mut self, albedo: Color)

pub fn get_albedo(&self) -> Color

pub fn set_transparency(&mut self, transparency: Transparency)

pub fn get_transparency(&self) -> Transparency

pub fn set_alpha_antialiasing(&mut self, alpha_aa: AlphaAntiAliasing)

pub fn get_alpha_antialiasing(&self) -> AlphaAntiAliasing

pub fn set_alpha_antialiasing_edge(&mut self, edge: f32)

pub fn get_alpha_antialiasing_edge(&self) -> f32

pub fn set_shading_mode(&mut self, shading_mode: ShadingMode)

pub fn get_shading_mode(&self) -> ShadingMode

pub fn set_specular(&mut self, specular: f32)

pub fn get_specular(&self) -> f32

pub fn set_metallic(&mut self, metallic: f32)

pub fn get_metallic(&self) -> f32

pub fn set_roughness(&mut self, roughness: f32)

pub fn get_roughness(&self) -> f32

pub fn set_emission(&mut self, emission: Color)

pub fn get_emission(&self) -> Color

pub fn set_emission_energy_multiplier( &mut self, emission_energy_multiplier: f32, )

pub fn get_emission_energy_multiplier(&self) -> f32

pub fn set_emission_intensity(&mut self, emission_energy_multiplier: f32)

pub fn get_emission_intensity(&self) -> f32

pub fn set_normal_scale(&mut self, normal_scale: f32)

pub fn get_normal_scale(&self) -> f32

pub fn set_rim(&mut self, rim: f32)

pub fn get_rim(&self) -> f32

pub fn set_rim_tint(&mut self, rim_tint: f32)

pub fn get_rim_tint(&self) -> f32

pub fn set_clearcoat(&mut self, clearcoat: f32)

pub fn get_clearcoat(&self) -> f32

pub fn set_clearcoat_roughness(&mut self, clearcoat_roughness: f32)

pub fn get_clearcoat_roughness(&self) -> f32

pub fn set_anisotropy(&mut self, anisotropy: f32)

pub fn get_anisotropy(&self) -> f32

pub fn set_heightmap_scale(&mut self, heightmap_scale: f32)

pub fn get_heightmap_scale(&self) -> f32

pub fn set_subsurface_scattering_strength(&mut self, strength: f32)

pub fn get_subsurface_scattering_strength(&self) -> f32

pub fn set_transmittance_color(&mut self, color: Color)

pub fn get_transmittance_color(&self) -> Color

pub fn set_transmittance_depth(&mut self, depth: f32)

pub fn get_transmittance_depth(&self) -> f32

pub fn set_transmittance_boost(&mut self, boost: f32)

pub fn get_transmittance_boost(&self) -> f32

pub fn set_backlight(&mut self, backlight: Color)

pub fn get_backlight(&self) -> Color

pub fn set_refraction(&mut self, refraction: f32)

pub fn get_refraction(&self) -> f32

pub fn set_point_size(&mut self, point_size: f32)

pub fn get_point_size(&self) -> f32

pub fn set_detail_uv(&mut self, detail_uv: DetailUv)

pub fn get_detail_uv(&self) -> DetailUv

pub fn set_blend_mode(&mut self, blend_mode: BlendMode)

pub fn get_blend_mode(&self) -> BlendMode

pub fn set_depth_draw_mode(&mut self, depth_draw_mode: DepthDrawMode)

pub fn get_depth_draw_mode(&self) -> DepthDrawMode

pub fn set_depth_test(&mut self, depth_test: DepthTest)

pub fn get_depth_test(&self) -> DepthTest

pub fn set_cull_mode(&mut self, cull_mode: CullMode)

pub fn get_cull_mode(&self) -> CullMode

pub fn set_diffuse_mode(&mut self, diffuse_mode: DiffuseMode)

pub fn get_diffuse_mode(&self) -> DiffuseMode

pub fn set_specular_mode(&mut self, specular_mode: SpecularMode)

pub fn get_specular_mode(&self) -> SpecularMode

pub fn set_flag(&mut self, flag: Flags, enable: bool)

If enable is true, enables the specified flag. Flags are optional behavior that can be turned on and off. Only one flag can be enabled at a time with this function, the flag enumerators cannot be bit-masked together to enable or disable multiple flags at once. Flags can also be enabled by setting their corresponding property to true.

pub fn get_flag(&self, flag: Flags) -> bool

Returns true if the specified flag is enabled.

pub fn set_texture_filter(&mut self, mode: TextureFilter)

pub fn get_texture_filter(&self) -> TextureFilter

pub fn set_feature(&mut self, feature: Feature, enable: bool)

If enable is true, enables the specified feature. Many features that are available in BaseMaterial3D need to be enabled before use. This way, the cost for using the feature is only incurred when specified. Features can also be enabled by setting their corresponding property to true.

pub fn get_feature(&self, feature: Feature) -> bool

Returns true if the specified feature is enabled.

pub fn set_texture( &mut self, param: TextureParam, texture: impl AsArg<Option<Gd<Texture2D>>>, )

Sets the texture for the slot specified by param.

pub fn get_texture(&self, param: TextureParam) -> Option<Gd<Texture2D>>

Returns the Texture2D associated with the specified texture param.

pub fn set_detail_blend_mode(&mut self, detail_blend_mode: BlendMode)

pub fn get_detail_blend_mode(&self) -> BlendMode

pub fn set_uv1_scale(&mut self, scale: Vector3)

pub fn get_uv1_scale(&self) -> Vector3

pub fn set_uv1_offset(&mut self, offset: Vector3)

pub fn get_uv1_offset(&self) -> Vector3

pub fn set_uv1_triplanar_blend_sharpness(&mut self, sharpness: f32)

pub fn get_uv1_triplanar_blend_sharpness(&self) -> f32

pub fn set_uv2_scale(&mut self, scale: Vector3)

pub fn get_uv2_scale(&self) -> Vector3

pub fn set_uv2_offset(&mut self, offset: Vector3)

pub fn get_uv2_offset(&self) -> Vector3

pub fn set_uv2_triplanar_blend_sharpness(&mut self, sharpness: f32)

pub fn get_uv2_triplanar_blend_sharpness(&self) -> f32

pub fn set_billboard_mode(&mut self, mode: BillboardMode)

pub fn get_billboard_mode(&self) -> BillboardMode

pub fn set_particles_anim_h_frames(&mut self, frames: i32)

pub fn get_particles_anim_h_frames(&self) -> i32

pub fn set_particles_anim_v_frames(&mut self, frames: i32)

pub fn get_particles_anim_v_frames(&self) -> i32

pub fn set_particles_anim_loop(&mut self, loop_: bool)

pub fn get_particles_anim_loop(&self) -> bool

pub fn set_heightmap_deep_parallax(&mut self, enable: bool)

pub fn is_heightmap_deep_parallax_enabled(&self) -> bool

pub fn set_heightmap_deep_parallax_min_layers(&mut self, layer: i32)

pub fn get_heightmap_deep_parallax_min_layers(&self) -> i32

pub fn set_heightmap_deep_parallax_max_layers(&mut self, layer: i32)

pub fn get_heightmap_deep_parallax_max_layers(&self) -> i32

pub fn set_heightmap_deep_parallax_flip_tangent(&mut self, flip: bool)

pub fn get_heightmap_deep_parallax_flip_tangent(&self) -> bool

pub fn set_heightmap_deep_parallax_flip_binormal(&mut self, flip: bool)

pub fn get_heightmap_deep_parallax_flip_binormal(&self) -> bool

pub fn set_grow(&mut self, amount: f32)

pub fn get_grow(&self) -> f32

pub fn set_emission_operator(&mut self, operator: EmissionOperator)

pub fn get_emission_operator(&self) -> EmissionOperator

pub fn set_ao_light_affect(&mut self, amount: f32)

pub fn get_ao_light_affect(&self) -> f32

pub fn set_alpha_scissor_threshold(&mut self, threshold: f32)

pub fn get_alpha_scissor_threshold(&self) -> f32

pub fn set_alpha_hash_scale(&mut self, threshold: f32)

pub fn get_alpha_hash_scale(&self) -> f32

pub fn set_grow_enabled(&mut self, enable: bool)

pub fn is_grow_enabled(&self) -> bool

pub fn set_metallic_texture_channel(&mut self, channel: TextureChannel)

pub fn get_metallic_texture_channel(&self) -> TextureChannel

pub fn set_roughness_texture_channel(&mut self, channel: TextureChannel)

pub fn get_roughness_texture_channel(&self) -> TextureChannel

pub fn set_ao_texture_channel(&mut self, channel: TextureChannel)

pub fn get_ao_texture_channel(&self) -> TextureChannel

pub fn set_refraction_texture_channel(&mut self, channel: TextureChannel)

pub fn get_refraction_texture_channel(&self) -> TextureChannel

pub fn set_proximity_fade_enabled(&mut self, enabled: bool)

pub fn is_proximity_fade_enabled(&self) -> bool

pub fn set_proximity_fade_distance(&mut self, distance: f32)

pub fn get_proximity_fade_distance(&self) -> f32

pub fn set_msdf_pixel_range(&mut self, range: f32)

pub fn get_msdf_pixel_range(&self) -> f32

pub fn set_msdf_outline_size(&mut self, size: f32)

pub fn get_msdf_outline_size(&self) -> f32

pub fn set_distance_fade(&mut self, mode: DistanceFadeMode)

pub fn get_distance_fade(&self) -> DistanceFadeMode

pub fn set_distance_fade_max_distance(&mut self, distance: f32)

pub fn get_distance_fade_max_distance(&self) -> f32

pub fn set_distance_fade_min_distance(&mut self, distance: f32)

pub fn get_distance_fade_min_distance(&self) -> f32

pub fn set_z_clip_scale(&mut self, scale: f32)

pub fn get_z_clip_scale(&self) -> f32

pub fn set_fov_override(&mut self, scale: f32)

pub fn get_fov_override(&self) -> f32

pub fn set_stencil_mode(&mut self, stencil_mode: StencilMode)

pub fn get_stencil_mode(&self) -> StencilMode

pub fn set_stencil_flags(&mut self, stencil_flags: i32)

pub fn get_stencil_flags(&self) -> i32

pub fn set_stencil_compare(&mut self, stencil_compare: StencilCompare)

pub fn get_stencil_compare(&self) -> StencilCompare

pub fn set_stencil_reference(&mut self, stencil_reference: i32)

pub fn get_stencil_reference(&self) -> i32

pub fn set_stencil_effect_color(&mut self, stencil_color: Color)

pub fn get_stencil_effect_color(&self) -> Color

pub fn set_stencil_effect_outline_thickness( &mut self, stencil_outline_thickness: f32, )

pub fn get_stencil_effect_outline_thickness(&self) -> f32

Methods from Deref<Target = Material>

pub const RENDER_PRIORITY_MAX: i32 = 127i32

pub const RENDER_PRIORITY_MIN: i32 = - 128i32

pub fn set_next_pass(&mut self, next_pass: impl AsArg<Option<Gd<Material>>>)

pub fn get_next_pass(&self) -> Option<Gd<Material>>

pub fn set_render_priority(&mut self, priority: i32)

pub fn get_render_priority(&self) -> i32

pub fn inspect_native_shader_code(&mut self)

Only available when running in the editor. Opens a popup that visualizes the generated shader code, including all variants and internal shader code. See also inspect_native_shader_code.

pub fn create_placeholder(&self) -> Option<Gd<Resource>>

Creates a placeholder version of this resource (PlaceholderMaterial).

Methods from Deref<Target = Resource>

pub fn set_path(&mut self, path: impl AsArg<GString>)

pub fn take_over_path(&mut self, path: impl AsArg<GString>)

Sets the [member resource_path] to path, potentially overriding an existing cache entry for this path. Further attempts to load an overridden resource by path will instead return this resource.

pub fn get_path(&self) -> GString

pub fn set_path_cache(&mut self, path: impl AsArg<GString>)

Sets the resource’s path to path without involving the resource cache. Useful for handling [enum ResourceFormatLoader.CacheMode] values when implementing a custom resource format by extending ResourceFormatLoader and ResourceFormatSaver.

pub fn set_name(&mut self, name: impl AsArg<GString>)

pub fn get_name(&self) -> GString

pub fn get_rid(&self) -> Rid

Returns the RID of this resource (or an empty RID). Many resources (such as Texture2D, Mesh, and so on) are high-level abstractions of resources stored in a specialized server (DisplayServer, RenderingServer, etc.), so this function will return the original RID.

pub fn set_local_to_scene(&mut self, enable: bool)

pub fn is_local_to_scene(&self) -> bool

pub fn get_local_scene(&self) -> Option<Gd<Node>>

If [member resource_local_to_scene] is set to true and the resource has been loaded from a PackedScene instantiation, returns the root Node of the scene where this resource is used. Otherwise, returns null.

pub fn setup_local_to_scene(&mut self)

Calls setup_local_to_scene. If [member resource_local_to_scene] is set to true, this method is automatically called from instantiate by the newly duplicated resource within the scene instance.

pub fn reset_state(&mut self)

Makes the resource clear its non-exported properties. See also reset_state. Useful when implementing a custom resource format by extending ResourceFormatLoader and ResourceFormatSaver.

pub fn set_id_for_path( &mut self, path: impl AsArg<GString>, id: impl AsArg<GString>, )

In the internal cache for scene-unique IDs, sets the ID of this resource to id for the scene at path. If id is empty, the cache entry for path is cleared. Useful to keep scene-unique IDs the same when implementing a VCS-friendly custom resource format by extending ResourceFormatLoader and ResourceFormatSaver.

Note: This method is only implemented when running in an editor context.

pub fn get_id_for_path(&self, path: impl AsArg<GString>) -> GString

From the internal cache for scene-unique IDs, returns the ID of this resource for the scene at path. If there is no entry, an empty string is returned. Useful to keep scene-unique IDs the same when implementing a VCS-friendly custom resource format by extending ResourceFormatLoader and ResourceFormatSaver.

Note: This method is only implemented when running in an editor context. At runtime, it returns an empty string.

pub fn is_built_in(&self) -> bool

Returns true if the resource is saved on disk as a part of another resource’s file.

pub fn set_scene_unique_id(&mut self, id: impl AsArg<GString>)

pub fn get_scene_unique_id(&self) -> GString

pub fn emit_changed(&mut self)

Emits the changed signal. This method is called automatically for some built-in resources.

Note: For custom resources, it’s recommended to call this method whenever a meaningful change occurs, such as a modified property. This ensures that custom Objects depending on the resource are properly updated.

var damage:
	set(new_value):
		if damage != new_value:
			damage = new_value
			emit_changed()

pub fn duplicate(&self) -> Option<Gd<Resource>>

👎Deprecated:

Use Gd::duplicate_resource() or Gd::duplicate_resource_ex().

To set the default parameters, use duplicate_ex and its builder methods. See the book for detailed usage instructions. Duplicates this resource, returning a new resource with its exported or PropertyUsageFlags::STORAGE properties copied from the original.

If deep is false, a shallow copy is returned: nested Array, Dictionary, and Resource properties are not duplicated and are shared with the original resource.

If deep is true, a deep copy is returned: all nested arrays, dictionaries, and packed arrays are also duplicated (recursively). Any Resource found inside will only be duplicated if it’s local, like DeepDuplicateMode::INTERNAL used with duplicate_deep.

The following exceptions apply:

Note: For custom resources, this method will fail if init has been defined with required parameters.

Note: When duplicating with deep set to true, each resource found, including the one on which this method is called, will be only duplicated once and referenced as many times as needed in the duplicate. For instance, if you are duplicating resource A that happens to have resource B referenced twice, you’ll get a new resource A’ referencing a new resource B’ twice.

pub fn duplicate_ex<'ex>(&'ex self) -> ExDuplicate<'ex>

👎Deprecated:

Use Gd::duplicate_resource() or Gd::duplicate_resource_ex().

Duplicates this resource, returning a new resource with its exported or PropertyUsageFlags::STORAGE properties copied from the original.

If deep is false, a shallow copy is returned: nested Array, Dictionary, and Resource properties are not duplicated and are shared with the original resource.

If deep is true, a deep copy is returned: all nested arrays, dictionaries, and packed arrays are also duplicated (recursively). Any Resource found inside will only be duplicated if it’s local, like DeepDuplicateMode::INTERNAL used with duplicate_deep.

The following exceptions apply:

Note: For custom resources, this method will fail if init has been defined with required parameters.

Note: When duplicating with deep set to true, each resource found, including the one on which this method is called, will be only duplicated once and referenced as many times as needed in the duplicate. For instance, if you are duplicating resource A that happens to have resource B referenced twice, you’ll get a new resource A’ referencing a new resource B’ twice.

pub fn duplicate_deep(&self) -> Option<Gd<Resource>>

👎Deprecated:

Use Gd::duplicate_resource() or Gd::duplicate_resource_ex().

To set the default parameters, use duplicate_deep_ex and its builder methods. See the book for detailed usage instructions. Duplicates this resource, deeply, like duplicate when passing true, with extra control over how subresources are handled.

pub fn duplicate_deep_ex<'ex>(&'ex self) -> ExDuplicateDeep<'ex>

👎Deprecated:

Use Gd::duplicate_resource() or Gd::duplicate_resource_ex().

Duplicates this resource, deeply, like duplicate when passing true, with extra control over how subresources are handled.

Methods from Deref<Target = RefCounted>

pub fn get_reference_count(&self) -> i32

Returns the current reference count.

Methods from Deref<Target = Object>

pub fn get_script(&self) -> Option<Gd<Script>>

pub fn set_script(&mut self, script: impl AsArg<Option<Gd<Script>>>)

pub fn connect( &mut self, signal: impl AsArg<StringName>, callable: &Callable, ) -> Error

pub fn connect_flags( &mut self, signal: impl AsArg<StringName>, callable: &Callable, flags: ConnectFlags, ) -> Error

pub fn get_class(&self) -> GString

Returns the object’s built-in class name, as a String. See also is_class.

Note: This method ignores class_name declarations. If this object’s script has defined a class_name, the base, built-in class name is returned instead.

pub fn is_class(&self, class: impl AsArg<GString>) -> bool

Returns true if the object inherits from the given class. See also get_class.

var sprite2d = Sprite2D.new()
sprite2d.is_class("Sprite2D") # Returns true
sprite2d.is_class("Node")     # Returns true
sprite2d.is_class("Node3D")   # Returns false

Note: This method ignores class_name declarations in the object’s script.

pub fn set(&mut self, property: impl AsArg<StringName>, value: &Variant)

Assigns value to the given property. If the property does not exist or the given value’s type doesn’t match, nothing happens.

var node = Node2D.new()
node.set("global_scale", Vector2(8, 2.5))
print(node.global_scale) # Prints (8.0, 2.5)

Note: In C#, property must be in snake_case when referring to built-in Godot properties. Prefer using the names exposed in the PropertyName class to avoid allocating a new StringName on each call.

pub fn get(&self, property: impl AsArg<StringName>) -> Variant

Returns the Variant value of the given property. If the property does not exist, this method returns null.

var node = Node2D.new()
node.rotation = 1.5
var a = node.get("rotation") # a is 1.5

Note: In C#, property must be in snake_case when referring to built-in Godot properties. Prefer using the names exposed in the PropertyName class to avoid allocating a new StringName on each call.

pub fn set_indexed( &mut self, property_path: impl AsArg<NodePath>, value: &Variant, )

Assigns a new value to the property identified by the property_path. The path should be a NodePath relative to this object, and can use the colon character (:) to access nested properties.

var node = Node2D.new()
node.set_indexed("position", Vector2(42, 0))
node.set_indexed("position:y", -10)
print(node.position) # Prints (42.0, -10.0)

Note: In C#, property_path must be in snake_case when referring to built-in Godot properties. Prefer using the names exposed in the PropertyName class to avoid allocating a new StringName on each call.

pub fn get_indexed(&self, property_path: impl AsArg<NodePath>) -> Variant

Gets the object’s property indexed by the given property_path. The path should be a NodePath relative to the current object and can use the colon character (:) to access nested properties.

Examples: "position:x" or "material:next_pass:blend_mode".

var node = Node2D.new()
node.position = Vector2(5, -10)
var a = node.get_indexed("position")   # a is Vector2(5, -10)
var b = node.get_indexed("position:y") # b is -10

Note: In C#, property_path must be in snake_case when referring to built-in Godot properties. Prefer using the names exposed in the PropertyName class to avoid allocating a new StringName on each call.

Note: This method does not support actual paths to nodes in the SceneTree, only sub-property paths. In the context of nodes, use get_node_and_resource instead.

pub fn get_property_list(&self) -> Array<Dictionary<Variant, Variant>>

Returns the object’s property list as an Array of dictionaries. Each Dictionary contains the following entries:

  • name is the property’s name, as a String;

  • class_name is an empty StringName, unless the property is VariantType::OBJECT and it inherits from a class;

  • type is the property’s type, as an int (see [enum Variant.Type]);

  • hint is how the property is meant to be edited (see [enum PropertyHint]);

  • hint_string depends on the hint (see [enum PropertyHint]);

  • usage is a combination of [enum PropertyUsageFlags].

Note: In GDScript, all class members are treated as properties. In C# and GDExtension, it may be necessary to explicitly mark class members as Godot properties using decorators or attributes.

pub fn get_method_list(&self) -> Array<Dictionary<Variant, Variant>>

Returns this object’s methods and their signatures as an Array of dictionaries. Each Dictionary contains the following entries:

  • name is the name of the method, as a String;

  • args is an Array of dictionaries representing the arguments;

  • default_args is the default arguments as an Array of variants;

  • flags is a combination of [enum MethodFlags];

  • id is the method’s internal identifier int;

  • return is the returned value, as a Dictionary;

Note: The dictionaries of args and return are formatted identically to the results of get_property_list, although not all entries are used.

pub fn property_can_revert(&self, property: impl AsArg<StringName>) -> bool

Returns true if the given property has a custom default value. Use property_get_revert to get the property’s default value.

Note: This method is used by the Inspector dock to display a revert icon. The object must implement [method _property_can_revert] to customize the default value. If [method _property_can_revert] is not implemented, this method returns false.

pub fn property_get_revert(&self, property: impl AsArg<StringName>) -> Variant

Returns the custom default value of the given property. Use property_can_revert to check if the property has a custom default value.

Note: This method is used by the Inspector dock to display a revert icon. The object must implement [method _property_get_revert] to customize the default value. If [method _property_get_revert] is not implemented, this method returns null.

pub fn set_meta(&mut self, name: impl AsArg<StringName>, value: &Variant)

Adds or changes the entry name inside the object’s metadata. The metadata value can be any Variant, although some types cannot be serialized correctly.

If value is null, the entry is removed. This is the equivalent of using remove_meta. See also has_meta and get_meta.

Note: A metadata’s name must be a valid identifier as per is_valid_identifier method.

Note: Metadata that has a name starting with an underscore (_) is considered editor-only. Editor-only metadata is not displayed in the Inspector and should not be edited, although it can still be found by this method.

pub fn remove_meta(&mut self, name: impl AsArg<StringName>)

Removes the given entry name from the object’s metadata. See also has_meta, get_meta and set_meta.

Note: A metadata’s name must be a valid identifier as per is_valid_identifier method.

Note: Metadata that has a name starting with an underscore (_) is considered editor-only. Editor-only metadata is not displayed in the Inspector and should not be edited, although it can still be found by this method.

pub fn get_meta(&self, name: impl AsArg<StringName>) -> Variant

To set the default parameters, use get_meta_ex and its builder methods. See the book for detailed usage instructions. Returns the object’s metadata value for the given entry name. If the entry does not exist, returns default. If default is null, an error is also generated.

Note: A metadata’s name must be a valid identifier as per is_valid_identifier method.

Note: Metadata that has a name starting with an underscore (_) is considered editor-only. Editor-only metadata is not displayed in the Inspector and should not be edited, although it can still be found by this method.

pub fn get_meta_ex<'ex>( &'ex self, name: impl AsArg<StringName> + 'ex, ) -> ExGetMeta<'ex>

Returns the object’s metadata value for the given entry name. If the entry does not exist, returns default. If default is null, an error is also generated.

Note: A metadata’s name must be a valid identifier as per is_valid_identifier method.

Note: Metadata that has a name starting with an underscore (_) is considered editor-only. Editor-only metadata is not displayed in the Inspector and should not be edited, although it can still be found by this method.

pub fn has_meta(&self, name: impl AsArg<StringName>) -> bool

Returns true if a metadata entry is found with the given name. See also get_meta, set_meta and remove_meta.

Note: A metadata’s name must be a valid identifier as per is_valid_identifier method.

Note: Metadata that has a name starting with an underscore (_) is considered editor-only. Editor-only metadata is not displayed in the Inspector and should not be edited, although it can still be found by this method.

pub fn get_meta_list(&self) -> Array<StringName>

Returns the object’s metadata entry names as an Array of StringNames.

pub fn add_user_signal(&mut self, signal: impl AsArg<GString>)

To set the default parameters, use add_user_signal_ex and its builder methods. See the book for detailed usage instructions. Adds a user-defined signal named signal. Optional arguments for the signal can be added as an Array of dictionaries, each defining a name String and a type int (see [enum Variant.Type]). See also has_user_signal and remove_user_signal.

add_user_signal("hurt", [
	{ "name": "damage", "type": TYPE_INT },
	{ "name": "source", "type": TYPE_OBJECT }
])

pub fn add_user_signal_ex<'ex>( &'ex mut self, signal: impl AsArg<GString> + 'ex, ) -> ExAddUserSignal<'ex>

Adds a user-defined signal named signal. Optional arguments for the signal can be added as an Array of dictionaries, each defining a name String and a type int (see [enum Variant.Type]). See also has_user_signal and remove_user_signal.

add_user_signal("hurt", [
	{ "name": "damage", "type": TYPE_INT },
	{ "name": "source", "type": TYPE_OBJECT }
])

pub fn has_user_signal(&self, signal: impl AsArg<StringName>) -> bool

Returns true if the given user-defined signal name exists. Only signals added with add_user_signal are included. See also remove_user_signal.

pub fn remove_user_signal(&mut self, signal: impl AsArg<StringName>)

Removes the given user signal signal from the object. See also add_user_signal and has_user_signal.

pub fn emit_signal( &mut self, signal: impl AsArg<StringName>, varargs: &[Variant], ) -> Error

Emits the given signal by name. The signal must exist, so it should be a built-in signal of this class or one of its inherited classes, or a user-defined signal (see add_user_signal). This method supports a variable number of arguments, so parameters can be passed as a comma separated list.

Returns Error::ERR_UNAVAILABLE if signal does not exist or the parameters are invalid.

emit_signal("hit", "sword", 100)
emit_signal("game_over")

Note: In C#, signal must be in snake_case when referring to built-in Godot signals. Prefer using the names exposed in the SignalName class to avoid allocating a new StringName on each call.

Panics

This is a varcall method, meaning parameters and return values are passed as Variant. It can detect call failures and will panic in such a case.

pub fn try_emit_signal( &mut self, signal: impl AsArg<StringName>, varargs: &[Variant], ) -> Result<Error, CallError>

Return type

This is a varcall method, meaning parameters and return values are passed as Variant. It can detect call failures and will return Err in such a case.

pub fn call( &mut self, method: impl AsArg<StringName>, varargs: &[Variant], ) -> Variant

Calls the method on the object and returns the result. This method supports a variable number of arguments, so parameters can be passed as a comma separated list.

var node = Node3D.new()
node.call("rotate", Vector3(1.0, 0.0, 0.0), 1.571)

Note: In C#, method must be in snake_case when referring to built-in Godot methods. Prefer using the names exposed in the MethodName class to avoid allocating a new StringName on each call.

Panics

This is a varcall method, meaning parameters and return values are passed as Variant. It can detect call failures and will panic in such a case.

pub fn try_call( &mut self, method: impl AsArg<StringName>, varargs: &[Variant], ) -> Result<Variant, CallError>

Return type

This is a varcall method, meaning parameters and return values are passed as Variant. It can detect call failures and will return Err in such a case.

pub fn call_deferred( &mut self, method: impl AsArg<StringName>, varargs: &[Variant], ) -> Variant

Calls the method on the object during idle time. Always returns null, not the method’s result.

Idle time happens mainly at the end of process and physics frames. In it, deferred calls will be run until there are none left, which means you can defer calls from other deferred calls and they’ll still be run in the current idle time cycle. This means you should not call a method deferred from itself (or from a method called by it), as this causes infinite recursion the same way as if you had called the method directly.

This method supports a variable number of arguments, so parameters can be passed as a comma separated list.

var node = Node3D.new()
node.call_deferred("rotate", Vector3(1.0, 0.0, 0.0), 1.571)

For methods that are deferred from the same thread, the order of execution at idle time is identical to the order in which call_deferred was called.

See also call_deferred.

Note: In C#, method must be in snake_case when referring to built-in Godot methods. Prefer using the names exposed in the MethodName class to avoid allocating a new StringName on each call.

Note: If you’re looking to delay the function call by a frame, refer to the SceneTree.process_frame and SceneTree.physics_frame signals.

var node = Node3D.new()
# Make a Callable and bind the arguments to the node's rotate() call.
var callable = node.rotate.bind(Vector3(1.0, 0.0, 0.0), 1.571)
# Connect the callable to the process_frame signal, so it gets called in the next process frame.
# CONNECT_ONE_SHOT makes sure it only gets called once instead of every frame.
get_tree().process_frame.connect(callable, CONNECT_ONE_SHOT)
Panics

This is a varcall method, meaning parameters and return values are passed as Variant. It can detect call failures and will panic in such a case.

pub fn try_call_deferred( &mut self, method: impl AsArg<StringName>, varargs: &[Variant], ) -> Result<Variant, CallError>

Return type

This is a varcall method, meaning parameters and return values are passed as Variant. It can detect call failures and will return Err in such a case.

pub fn set_deferred( &mut self, property: impl AsArg<StringName>, value: &Variant, )

Assigns value to the given property, at the end of the current frame. This is equivalent to calling set through call_deferred.

var node = Node2D.new()
add_child(node)

node.rotation = 1.5
node.set_deferred("rotation", 3.0)
print(node.rotation) # Prints 1.5

await get_tree().process_frame
print(node.rotation) # Prints 3.0

Note: In C#, property must be in snake_case when referring to built-in Godot properties. Prefer using the names exposed in the PropertyName class to avoid allocating a new StringName on each call.

pub fn callv( &mut self, method: impl AsArg<StringName>, arg_array: &AnyArray, ) -> Variant

Calls the method on the object and returns the result. Unlike call, this method expects all parameters to be contained inside arg_array.

var node = Node3D.new()
node.callv("rotate", [Vector3(1.0, 0.0, 0.0), 1.571])

Note: In C#, method must be in snake_case when referring to built-in Godot methods. Prefer using the names exposed in the MethodName class to avoid allocating a new StringName on each call.

pub fn has_method(&self, method: impl AsArg<StringName>) -> bool

Returns true if the given method name exists in the object.

Note: In C#, method must be in snake_case when referring to built-in Godot methods. Prefer using the names exposed in the MethodName class to avoid allocating a new StringName on each call.

pub fn get_method_argument_count(&self, method: impl AsArg<StringName>) -> i32

Returns the number of arguments of the given method by name.

Note: In C#, method must be in snake_case when referring to built-in Godot methods. Prefer using the names exposed in the MethodName class to avoid allocating a new StringName on each call.

pub fn has_signal(&self, signal: impl AsArg<StringName>) -> bool

Returns true if the given signal name exists in the object.

Note: In C#, signal must be in snake_case when referring to built-in Godot signals. Prefer using the names exposed in the SignalName class to avoid allocating a new StringName on each call.

pub fn get_signal_list(&self) -> Array<Dictionary<Variant, Variant>>

Returns the list of existing signals as an Array of dictionaries.

Note: Due to the implementation, each Dictionary is formatted very similarly to the returned values of get_method_list.

pub fn get_signal_connection_list( &self, signal: impl AsArg<StringName>, ) -> Array<Dictionary<Variant, Variant>>

Returns an Array of connections for the given signal name. Each connection is represented as a Dictionary that contains three entries:

  • signal is a reference to the Signal;

  • callable is a reference to the connected Callable;

  • flags is a combination of [enum ConnectFlags].

pub fn get_incoming_connections(&self) -> Array<Dictionary<Variant, Variant>>

Returns an Array of signal connections received by this object. Each connection is represented as a Dictionary that contains three entries:

  • signal is a reference to the Signal;

  • callable is a reference to the Callable;

  • flags is a combination of [enum ConnectFlags].

pub fn disconnect( &mut self, signal: impl AsArg<StringName>, callable: &Callable, )

Disconnects a signal by name from a given callable. If the connection does not exist, generates an error. Use is_connected to make sure that the connection exists.

pub fn is_connected( &self, signal: impl AsArg<StringName>, callable: &Callable, ) -> bool

Returns true if a connection exists between the given signal name and callable.

Note: In C#, signal must be in snake_case when referring to built-in Godot signals. Prefer using the names exposed in the SignalName class to avoid allocating a new StringName on each call.

pub fn has_connections(&self, signal: impl AsArg<StringName>) -> bool

Returns true if any connection exists on the given signal name.

Note: In C#, signal must be in snake_case when referring to built-in Godot methods. Prefer using the names exposed in the SignalName class to avoid allocating a new StringName on each call.

pub fn set_block_signals(&mut self, enable: bool)

If set to true, the object becomes unable to emit signals. As such, emit_signal and signal connections will not work, until it is set to false.

pub fn is_blocking_signals(&self) -> bool

Returns true if the object is blocking its signals from being emitted. See set_block_signals.

pub fn notify_property_list_changed(&mut self)

Emits the property_list_changed signal. This is mainly used to refresh the editor, so that the Inspector and editor plugins are properly updated.

pub fn set_message_translation(&mut self, enable: bool)

If set to true, allows the object to translate messages with tr and tr_n. Enabled by default. See also can_translate_messages.

pub fn can_translate_messages(&self) -> bool

Returns true if the object is allowed to translate messages with tr and tr_n. See also set_message_translation.

pub fn tr(&self, message: impl AsArg<StringName>) -> GString

To set the default parameters, use tr_ex and its builder methods. See the book for detailed usage instructions. Translates a message, using the translation catalogs configured in the Project Settings. Further context can be specified to help with the translation. Note that most Control nodes automatically translate their strings, so this method is mostly useful for formatted strings or custom drawn text.

If can_translate_messages is false, or no translation is available, this method returns the message without changes. See set_message_translation.

For detailed examples, see Internationalizing games.

Note: This method can’t be used without an Object instance, as it requires the can_translate_messages method. To translate strings in a static context, use translate.

pub fn tr_ex<'ex>(&'ex self, message: impl AsArg<StringName> + 'ex) -> ExTr<'ex>

Translates a message, using the translation catalogs configured in the Project Settings. Further context can be specified to help with the translation. Note that most Control nodes automatically translate their strings, so this method is mostly useful for formatted strings or custom drawn text.

If can_translate_messages is false, or no translation is available, this method returns the message without changes. See set_message_translation.

For detailed examples, see Internationalizing games.

Note: This method can’t be used without an Object instance, as it requires the can_translate_messages method. To translate strings in a static context, use translate.

pub fn tr_n( &self, message: impl AsArg<StringName>, plural_message: impl AsArg<StringName>, n: i32, ) -> GString

To set the default parameters, use tr_n_ex and its builder methods. See the book for detailed usage instructions. Translates a message or plural_message, using the translation catalogs configured in the Project Settings. Further context can be specified to help with the translation.

If can_translate_messages is false, or no translation is available, this method returns message or plural_message, without changes. See set_message_translation.

The n is the number, or amount, of the message’s subject. It is used by the translation system to fetch the correct plural form for the current language.

For detailed examples, see Localization using gettext.

Note: Negative and float numbers may not properly apply to some countable subjects. It’s recommended to handle these cases with tr.

Note: This method can’t be used without an Object instance, as it requires the can_translate_messages method. To translate strings in a static context, use translate_plural.

pub fn tr_n_ex<'ex>( &'ex self, message: impl AsArg<StringName> + 'ex, plural_message: impl AsArg<StringName> + 'ex, n: i32, ) -> ExTrN<'ex>

Translates a message or plural_message, using the translation catalogs configured in the Project Settings. Further context can be specified to help with the translation.

If can_translate_messages is false, or no translation is available, this method returns message or plural_message, without changes. See set_message_translation.

The n is the number, or amount, of the message’s subject. It is used by the translation system to fetch the correct plural form for the current language.

For detailed examples, see Localization using gettext.

Note: Negative and float numbers may not properly apply to some countable subjects. It’s recommended to handle these cases with tr.

Note: This method can’t be used without an Object instance, as it requires the can_translate_messages method. To translate strings in a static context, use translate_plural.

pub fn get_translation_domain(&self) -> StringName

Returns the name of the translation domain used by tr and tr_n. See also TranslationServer.

pub fn set_translation_domain(&mut self, domain: impl AsArg<StringName>)

Sets the name of the translation domain used by tr and tr_n. See also TranslationServer.

pub fn is_queued_for_deletion(&self) -> bool

Returns true if the queue_free method was called for the object.

pub fn cancel_free(&mut self)

If this method is called during ObjectNotification::PREDELETE, this object will reject being freed and will remain allocated. This is mostly an internal function used for error handling to avoid the user from freeing objects when they are not intended to.

pub fn notify(&mut self, what: ObjectNotification)

⚠️ Sends a Godot notification to all classes inherited by the object.

Triggers calls to on_notification(), and depending on the notification, also to Godot’s lifecycle callbacks such as ready().

Starts from the highest ancestor (the Object class) and goes down the hierarchy. See also Godot docs for Object::notification().

Panics

If you call this method on a user-defined object while holding a GdRef or GdMut guard on the instance, you will encounter a panic. The reason is that the receiving virtual method on_notification() acquires a GdMut lock dynamically, which must be exclusive.

pub fn notify_reversed(&mut self, what: ObjectNotification)

⚠️ Like Self::notify(), but starts at the most-derived class and goes up the hierarchy.

See docs of that method, including the panics.