Struct EditorInterface
pub struct EditorInterface { /* private fields */ }Expand description
Godot class EditorInterface.
Inherits Object.
Related symbols:
editor_interface: sidecar module with related enum/flag types
See also Godot docs for EditorInterface.
Singleton
This class is a singleton. You can get the one instance using Singleton::singleton().
Final class
This class is final, meaning you cannot inherit from it, and it comes without I* interface trait. It is still possible that other Godot classes inherit from it, but that is limited to the engine itself.
Godot docs
EditorInterface gives you control over Godot editor’s window. It allows customizing the window, saving and (re-)loading scenes, rendering mesh previews, inspecting and editing resources and objects, and provides access to EditorSettings, EditorFileSystem, EditorResourcePreview, ScriptEditor, the editor viewport, and information about scenes.
Note: This class shouldn’t be instantiated directly. Instead, access the singleton directly by its name.
var editor_settings = EditorInterface.get_editor_settings()Implementations
impl EditorInterface
impl EditorInterface
pub fn restart_editor(&mut self)
pub fn restart_editor(&mut self)
To set the default parameters, use restart_editor_ex and its builder methods. See the book for detailed usage instructions.
Restarts the editor. This closes the editor and then opens the same project. If save is true, the project will be saved before restarting.
pub fn restart_editor_ex<'ex>(&'ex mut self) -> ExRestartEditor<'ex>
pub fn restart_editor_ex<'ex>(&'ex mut self) -> ExRestartEditor<'ex>
Restarts the editor. This closes the editor and then opens the same project. If save is true, the project will be saved before restarting.
pub fn get_command_palette(&self) -> Option<Gd<EditorCommandPalette>>
pub fn get_command_palette(&self) -> Option<Gd<EditorCommandPalette>>
Returns the editor’s EditorCommandPalette instance.
Warning: Removing and freeing this node will render a part of the editor useless and may cause a crash.
pub fn get_resource_filesystem(&self) -> Option<Gd<EditorFileSystem>>
pub fn get_resource_filesystem(&self) -> Option<Gd<EditorFileSystem>>
Returns the editor’s EditorFileSystem instance.
pub fn get_editor_paths(&self) -> Option<Gd<EditorPaths>>
pub fn get_editor_paths(&self) -> Option<Gd<EditorPaths>>
Returns the EditorPaths singleton.
pub fn get_resource_previewer(&self) -> Option<Gd<EditorResourcePreview>>
pub fn get_resource_previewer(&self) -> Option<Gd<EditorResourcePreview>>
Returns the editor’s EditorResourcePreview instance.
pub fn get_selection(&self) -> Option<Gd<EditorSelection>>
pub fn get_selection(&self) -> Option<Gd<EditorSelection>>
Returns the editor’s EditorSelection instance.
pub fn get_editor_settings(&self) -> Option<Gd<EditorSettings>>
pub fn get_editor_settings(&self) -> Option<Gd<EditorSettings>>
Returns the editor’s EditorSettings instance.
pub fn get_editor_toaster(&self) -> Option<Gd<EditorToaster>>
pub fn get_editor_toaster(&self) -> Option<Gd<EditorToaster>>
Returns the editor’s EditorToaster.
pub fn get_editor_undo_redo(&self) -> Option<Gd<EditorUndoRedoManager>>
pub fn get_editor_undo_redo(&self) -> Option<Gd<EditorUndoRedoManager>>
Returns the editor’s EditorUndoRedoManager.
pub fn make_mesh_previews(
&mut self,
meshes: &Array<Gd<Mesh>>,
preview_size: i32,
) -> Array<Gd<Texture2D>>
pub fn make_mesh_previews( &mut self, meshes: &Array<Gd<Mesh>>, preview_size: i32, ) -> Array<Gd<Texture2D>>
pub fn set_plugin_enabled(&mut self, plugin: impl AsArg<GString>, enabled: bool)
pub fn set_plugin_enabled(&mut self, plugin: impl AsArg<GString>, enabled: bool)
Sets the enabled status of a plugin. The plugin name is the same as its directory name.
pub fn is_plugin_enabled(&self, plugin: impl AsArg<GString>) -> bool
pub fn is_plugin_enabled(&self, plugin: impl AsArg<GString>) -> bool
Returns true if the specified plugin is enabled. The plugin name is the same as its directory name.
pub fn get_editor_theme(&self) -> Option<Gd<Theme>>
pub fn get_editor_theme(&self) -> Option<Gd<Theme>>
Returns the editor’s Theme.
Note: When creating custom editor UI, prefer accessing theme items directly from your GUI nodes using the get_theme_* methods.
pub fn get_base_control(&self) -> Option<Gd<Control>>
pub fn get_base_control(&self) -> Option<Gd<Control>>
Returns the main container of Godot editor’s window. For example, you can use it to retrieve the size of the container and place your controls accordingly.
Warning: Removing and freeing this node will render the editor useless and may cause a crash.
pub fn get_editor_main_screen(&self) -> Option<Gd<VBoxContainer>>
pub fn get_editor_main_screen(&self) -> Option<Gd<VBoxContainer>>
Returns the editor control responsible for main screen plugins and tools. Use it with plugins that implement has_main_screen.
Note: This node is a VBoxContainer, which means that if you add a Control child to it, you need to set the child’s [member Control.size_flags_vertical] to SizeFlags::EXPAND_FILL to make it use the full available space.
Warning: Removing and freeing this node will render a part of the editor useless and may cause a crash.
pub fn get_script_editor(&self) -> Option<Gd<ScriptEditor>>
pub fn get_script_editor(&self) -> Option<Gd<ScriptEditor>>
Returns the editor’s ScriptEditor instance.
Warning: Removing and freeing this node will render a part of the editor useless and may cause a crash.
pub fn get_editor_viewport_2d(&self) -> Option<Gd<SubViewport>>
pub fn get_editor_viewport_2d(&self) -> Option<Gd<SubViewport>>
Returns the 2D editor SubViewport. It does not have a camera. Instead, the view transforms are done directly and can be accessed with [member Viewport.global_canvas_transform].
pub fn get_editor_viewport_3d(&self) -> Option<Gd<SubViewport>>
pub fn get_editor_viewport_3d(&self) -> Option<Gd<SubViewport>>
To set the default parameters, use get_editor_viewport_3d_ex and its builder methods. See the book for detailed usage instructions.
Returns the specified 3D editor SubViewport, from 0 to 3. The viewport can be used to access the active editor cameras with get_camera_3d.
pub fn get_editor_viewport_3d_ex<'ex>(&'ex self) -> ExGetEditorViewport3d<'ex>
pub fn get_editor_viewport_3d_ex<'ex>(&'ex self) -> ExGetEditorViewport3d<'ex>
Returns the specified 3D editor SubViewport, from 0 to 3. The viewport can be used to access the active editor cameras with get_camera_3d.
pub fn set_main_screen_editor(&mut self, name: impl AsArg<GString>)
pub fn set_main_screen_editor(&mut self, name: impl AsArg<GString>)
Sets the editor’s current main screen to the one specified in name. name must match the title of the tab in question exactly (e.g. 2D, 3D, Script, Game, or AssetLib for default tabs).
pub fn set_distraction_free_mode(&mut self, enter: bool)
pub fn is_distraction_free_mode_enabled(&self) -> bool
pub fn is_multi_window_enabled(&self) -> bool
pub fn is_multi_window_enabled(&self) -> bool
Returns true if multiple window support is enabled in the editor. Multiple window support is enabled if all of these statements are true:
-
[member EditorSettings.interface/multi_window/enable] is
true. -
[member EditorSettings.interface/editor/single_window_mode] is
false. -
[member Viewport.gui_embed_subwindows] is
false. This is forced totrueon platforms that don’t support multiple windows such as Web, or when the--single-windowcommand line argument is used.
pub fn get_editor_scale(&self) -> f32
pub fn get_editor_scale(&self) -> f32
Returns the actual scale of the editor UI (1.0 being 100% scale). This can be used to adjust position and dimensions of the UI added by plugins.
Note: This value is set via the [member EditorSettings.interface/editor/display_scale] and [member EditorSettings.interface/editor/custom_display_scale] settings. The editor must be restarted for changes to be properly applied.
pub fn get_editor_language(&self) -> GString
pub fn get_editor_language(&self) -> GString
Returns the language currently used for the editor interface.
pub fn is_node_3d_snap_enabled(&self) -> bool
pub fn is_node_3d_snap_enabled(&self) -> bool
Returns true if the 3D editor currently has snapping mode enabled, and false otherwise.
pub fn get_node_3d_translate_snap(&self) -> f32
pub fn get_node_3d_translate_snap(&self) -> f32
Returns the amount of units the 3D editor’s translation snapping is set to.
pub fn get_node_3d_rotate_snap(&self) -> f32
pub fn get_node_3d_rotate_snap(&self) -> f32
Returns the amount of degrees the 3D editor’s rotational snapping is set to.
pub fn get_node_3d_scale_snap(&self) -> f32
pub fn get_node_3d_scale_snap(&self) -> f32
Returns the amount of units the 3D editor’s scale snapping is set to.
pub fn popup_dialog(&mut self, dialog: impl AsArg<Option<Gd<Window>>>)
pub fn popup_dialog(&mut self, dialog: impl AsArg<Option<Gd<Window>>>)
To set the default parameters, use popup_dialog_ex and its builder methods. See the book for detailed usage instructions.
Pops up the dialog in the editor UI with popup_exclusive. The dialog must have no current parent, otherwise the method fails.
See also set_unparent_when_invisible.
pub fn popup_dialog_ex<'ex>(
&'ex mut self,
dialog: impl AsArg<Option<Gd<Window>>> + 'ex,
) -> ExPopupDialog<'ex>
pub fn popup_dialog_ex<'ex>( &'ex mut self, dialog: impl AsArg<Option<Gd<Window>>> + 'ex, ) -> ExPopupDialog<'ex>
Pops up the dialog in the editor UI with popup_exclusive. The dialog must have no current parent, otherwise the method fails.
See also set_unparent_when_invisible.
pub fn popup_dialog_centered(&mut self, dialog: impl AsArg<Option<Gd<Window>>>)
pub fn popup_dialog_centered(&mut self, dialog: impl AsArg<Option<Gd<Window>>>)
To set the default parameters, use popup_dialog_centered_ex and its builder methods. See the book for detailed usage instructions.
Pops up the dialog in the editor UI with popup_exclusive_centered. The dialog must have no current parent, otherwise the method fails.
See also set_unparent_when_invisible.
pub fn popup_dialog_centered_ex<'ex>(
&'ex mut self,
dialog: impl AsArg<Option<Gd<Window>>> + 'ex,
) -> ExPopupDialogCentered<'ex>
pub fn popup_dialog_centered_ex<'ex>( &'ex mut self, dialog: impl AsArg<Option<Gd<Window>>> + 'ex, ) -> ExPopupDialogCentered<'ex>
Pops up the dialog in the editor UI with popup_exclusive_centered. The dialog must have no current parent, otherwise the method fails.
See also set_unparent_when_invisible.
pub fn popup_dialog_centered_ratio(
&mut self,
dialog: impl AsArg<Option<Gd<Window>>>,
)
pub fn popup_dialog_centered_ratio( &mut self, dialog: impl AsArg<Option<Gd<Window>>>, )
To set the default parameters, use popup_dialog_centered_ratio_ex and its builder methods. See the book for detailed usage instructions.
Pops up the dialog in the editor UI with popup_exclusive_centered_ratio. The dialog must have no current parent, otherwise the method fails.
See also set_unparent_when_invisible.
pub fn popup_dialog_centered_ratio_ex<'ex>(
&'ex mut self,
dialog: impl AsArg<Option<Gd<Window>>> + 'ex,
) -> ExPopupDialogCenteredRatio<'ex>
pub fn popup_dialog_centered_ratio_ex<'ex>( &'ex mut self, dialog: impl AsArg<Option<Gd<Window>>> + 'ex, ) -> ExPopupDialogCenteredRatio<'ex>
Pops up the dialog in the editor UI with popup_exclusive_centered_ratio. The dialog must have no current parent, otherwise the method fails.
See also set_unparent_when_invisible.
pub fn popup_dialog_centered_clamped(
&mut self,
dialog: impl AsArg<Option<Gd<Window>>>,
)
pub fn popup_dialog_centered_clamped( &mut self, dialog: impl AsArg<Option<Gd<Window>>>, )
To set the default parameters, use popup_dialog_centered_clamped_ex and its builder methods. See the book for detailed usage instructions.
Pops up the dialog in the editor UI with popup_exclusive_centered_clamped. The dialog must have no current parent, otherwise the method fails.
See also set_unparent_when_invisible.
pub fn popup_dialog_centered_clamped_ex<'ex>(
&'ex mut self,
dialog: impl AsArg<Option<Gd<Window>>> + 'ex,
) -> ExPopupDialogCenteredClamped<'ex>
pub fn popup_dialog_centered_clamped_ex<'ex>( &'ex mut self, dialog: impl AsArg<Option<Gd<Window>>> + 'ex, ) -> ExPopupDialogCenteredClamped<'ex>
Pops up the dialog in the editor UI with popup_exclusive_centered_clamped. The dialog must have no current parent, otherwise the method fails.
See also set_unparent_when_invisible.
pub fn get_current_feature_profile(&self) -> GString
pub fn get_current_feature_profile(&self) -> GString
Returns the name of the currently activated feature profile. If the default profile is currently active, an empty string is returned instead.
In order to get a reference to the EditorFeatureProfile, you must load the feature profile using load_from_file.
Note: Feature profiles created via the user interface are loaded from the feature_profiles directory, as a file with the .profile extension. The editor configuration folder can be found by using get_config_dir.
pub fn set_current_feature_profile(&mut self, profile_name: impl AsArg<GString>)
pub fn set_current_feature_profile(&mut self, profile_name: impl AsArg<GString>)
Selects and activates the specified feature profile with the given profile_name. Set profile_name to an empty string to reset to the default feature profile.
A feature profile can be created programmatically using the EditorFeatureProfile class.
Note: The feature profile that gets activated must be located in the feature_profiles directory, as a file with the .profile extension. If a profile could not be found, an error occurs. The editor configuration folder can be found by using get_config_dir.
pub fn popup_node_selector(&mut self, callback: &Callable)
pub fn popup_node_selector(&mut self, callback: &Callable)
To set the default parameters, use popup_node_selector_ex and its builder methods. See the book for detailed usage instructions.
Pops up an editor dialog for selecting a Node from the edited scene. The callback must take a single argument of type NodePath. It is called on the selected NodePath or the empty path ^"" if the dialog is canceled. If valid_types is provided, the dialog will only show Nodes that match one of the listed Node types. If current_value is provided, the Node will be automatically selected in the tree, if it exists.
Example: Display the node selection dialog as soon as this node is added to the tree for the first time:
func _ready():
if Engine.is_editor_hint():
EditorInterface.popup_node_selector(_on_node_selected, ["Button"])
func _on_node_selected(node_path):
if node_path.is_empty():
print("node selection canceled")
else:
print("selected ", node_path)pub fn popup_node_selector_ex<'ex>(
&'ex mut self,
callback: &'ex Callable,
) -> ExPopupNodeSelector<'ex>
pub fn popup_node_selector_ex<'ex>( &'ex mut self, callback: &'ex Callable, ) -> ExPopupNodeSelector<'ex>
Pops up an editor dialog for selecting a Node from the edited scene. The callback must take a single argument of type NodePath. It is called on the selected NodePath or the empty path ^"" if the dialog is canceled. If valid_types is provided, the dialog will only show Nodes that match one of the listed Node types. If current_value is provided, the Node will be automatically selected in the tree, if it exists.
Example: Display the node selection dialog as soon as this node is added to the tree for the first time:
func _ready():
if Engine.is_editor_hint():
EditorInterface.popup_node_selector(_on_node_selected, ["Button"])
func _on_node_selected(node_path):
if node_path.is_empty():
print("node selection canceled")
else:
print("selected ", node_path)pub fn popup_property_selector(
&mut self,
object: impl AsArg<Option<Gd<Object>>>,
callback: &Callable,
)
pub fn popup_property_selector( &mut self, object: impl AsArg<Option<Gd<Object>>>, callback: &Callable, )
To set the default parameters, use popup_property_selector_ex and its builder methods. See the book for detailed usage instructions.
Pops up an editor dialog for selecting properties from object. The callback must take a single argument of type NodePath. It is called on the selected property path (see get_as_property_path) or the empty path ^"" if the dialog is canceled. If type_filter is provided, the dialog will only show properties that match one of the listed [enum Variant.Type] values. If current_value is provided, the property will be selected automatically in the property list, if it exists.
func _ready():
if Engine.is_editor_hint():
EditorInterface.popup_property_selector(this, _on_property_selected, [TYPE_INT])
func _on_property_selected(property_path):
if property_path.is_empty():
print("property selection canceled")
else:
print("selected ", property_path)pub fn popup_property_selector_ex<'ex>(
&'ex mut self,
object: impl AsArg<Option<Gd<Object>>> + 'ex,
callback: &'ex Callable,
) -> ExPopupPropertySelector<'ex>
pub fn popup_property_selector_ex<'ex>( &'ex mut self, object: impl AsArg<Option<Gd<Object>>> + 'ex, callback: &'ex Callable, ) -> ExPopupPropertySelector<'ex>
Pops up an editor dialog for selecting properties from object. The callback must take a single argument of type NodePath. It is called on the selected property path (see get_as_property_path) or the empty path ^"" if the dialog is canceled. If type_filter is provided, the dialog will only show properties that match one of the listed [enum Variant.Type] values. If current_value is provided, the property will be selected automatically in the property list, if it exists.
func _ready():
if Engine.is_editor_hint():
EditorInterface.popup_property_selector(this, _on_property_selected, [TYPE_INT])
func _on_property_selected(property_path):
if property_path.is_empty():
print("property selection canceled")
else:
print("selected ", property_path)pub fn popup_method_selector(
&mut self,
object: impl AsArg<Option<Gd<Object>>>,
callback: &Callable,
)
pub fn popup_method_selector( &mut self, object: impl AsArg<Option<Gd<Object>>>, callback: &Callable, )
To set the default parameters, use popup_method_selector_ex and its builder methods. See the book for detailed usage instructions.
Pops up an editor dialog for selecting a method from object. The callback must take a single argument of type String which will contain the name of the selected method or be empty if the dialog is canceled. If current_value is provided, the method will be selected automatically in the method list, if it exists.
pub fn popup_method_selector_ex<'ex>(
&'ex mut self,
object: impl AsArg<Option<Gd<Object>>> + 'ex,
callback: &'ex Callable,
) -> ExPopupMethodSelector<'ex>
pub fn popup_method_selector_ex<'ex>( &'ex mut self, object: impl AsArg<Option<Gd<Object>>> + 'ex, callback: &'ex Callable, ) -> ExPopupMethodSelector<'ex>
Pops up an editor dialog for selecting a method from object. The callback must take a single argument of type String which will contain the name of the selected method or be empty if the dialog is canceled. If current_value is provided, the method will be selected automatically in the method list, if it exists.
pub fn popup_quick_open(&mut self, callback: &Callable)
pub fn popup_quick_open(&mut self, callback: &Callable)
To set the default parameters, use popup_quick_open_ex and its builder methods. See the book for detailed usage instructions.
Pops up an editor dialog for quick selecting a resource file. The callback must take a single argument of type String which will contain the path of the selected resource or be empty if the dialog is canceled. If base_types is provided, the dialog will only show resources that match these types. Only types deriving from Resource are supported.
pub fn popup_quick_open_ex<'ex>(
&'ex mut self,
callback: &'ex Callable,
) -> ExPopupQuickOpen<'ex>
pub fn popup_quick_open_ex<'ex>( &'ex mut self, callback: &'ex Callable, ) -> ExPopupQuickOpen<'ex>
Pops up an editor dialog for quick selecting a resource file. The callback must take a single argument of type String which will contain the path of the selected resource or be empty if the dialog is canceled. If base_types is provided, the dialog will only show resources that match these types. Only types deriving from Resource are supported.
pub fn popup_create_dialog(&mut self, callback: &Callable)
pub fn popup_create_dialog(&mut self, callback: &Callable)
To set the default parameters, use popup_create_dialog_ex and its builder methods. See the book for detailed usage instructions.
Pops up an editor dialog for creating an object.
The callback must take a single argument of type String, which will contain the type name of the selected object (or the script path of the type, if the type is created from a script), or be an empty string if no item is selected.
The base_type specifies the base type of objects to display. For example, if you set this to “Resource”, all types derived from Resource will display in the create dialog.
The current_type will be passed in the search box of the create dialog, and the specified type can be immediately selected when the dialog pops up. If the current_type is not derived from base_type, there will be no result of the type in the dialog.
The dialog_title allows you to define a custom title for the dialog. This is useful if you want to accurately hint the usage of the dialog. If the dialog_title is an empty string, the dialog will use “Create New ‘Base Type’” as the default title.
The type_blocklist contains a list of type names, and the types in the blocklist will be hidden from the create dialog.
Note: Trying to list the base type in the type_blocklist will hide all types derived from the base type from the create dialog.
pub fn popup_create_dialog_ex<'ex>(
&'ex mut self,
callback: &'ex Callable,
) -> ExPopupCreateDialog<'ex>
pub fn popup_create_dialog_ex<'ex>( &'ex mut self, callback: &'ex Callable, ) -> ExPopupCreateDialog<'ex>
Pops up an editor dialog for creating an object.
The callback must take a single argument of type String, which will contain the type name of the selected object (or the script path of the type, if the type is created from a script), or be an empty string if no item is selected.
The base_type specifies the base type of objects to display. For example, if you set this to “Resource”, all types derived from Resource will display in the create dialog.
The current_type will be passed in the search box of the create dialog, and the specified type can be immediately selected when the dialog pops up. If the current_type is not derived from base_type, there will be no result of the type in the dialog.
The dialog_title allows you to define a custom title for the dialog. This is useful if you want to accurately hint the usage of the dialog. If the dialog_title is an empty string, the dialog will use “Create New ‘Base Type’” as the default title.
The type_blocklist contains a list of type names, and the types in the blocklist will be hidden from the create dialog.
Note: Trying to list the base type in the type_blocklist will hide all types derived from the base type from the create dialog.
pub fn get_file_system_dock(&self) -> Option<Gd<FileSystemDock>>
pub fn get_file_system_dock(&self) -> Option<Gd<FileSystemDock>>
Returns the editor’s FileSystemDock instance.
Warning: Removing and freeing this node will render a part of the editor useless and may cause a crash.
pub fn select_file(&mut self, file: impl AsArg<GString>)
pub fn select_file(&mut self, file: impl AsArg<GString>)
Selects the file, with the path provided by file, in the FileSystem dock.
pub fn get_selected_paths(&self) -> PackedArray<GString>
pub fn get_selected_paths(&self) -> PackedArray<GString>
Returns an array containing the paths of the currently selected files (and directories) in the FileSystemDock.
pub fn get_current_path(&self) -> GString
pub fn get_current_path(&self) -> GString
Returns the current path being viewed in the FileSystemDock.
pub fn get_current_directory(&self) -> GString
pub fn get_current_directory(&self) -> GString
Returns the current directory being viewed in the FileSystemDock. If a file is selected, its base directory will be returned using get_base_dir instead.
pub fn get_inspector(&self) -> Option<Gd<EditorInspector>>
pub fn get_inspector(&self) -> Option<Gd<EditorInspector>>
Returns the editor’s EditorInspector instance.
Warning: Removing and freeing this node will render a part of the editor useless and may cause a crash.
pub fn inspect_object(&mut self, object: impl AsArg<Option<Gd<Object>>>)
pub fn inspect_object(&mut self, object: impl AsArg<Option<Gd<Object>>>)
To set the default parameters, use inspect_object_ex and its builder methods. See the book for detailed usage instructions.
Shows the given property on the given object in the editor’s Inspector dock. If inspector_only is true, plugins will not attempt to edit object.
pub fn inspect_object_ex<'ex>(
&'ex mut self,
object: impl AsArg<Option<Gd<Object>>> + 'ex,
) -> ExInspectObject<'ex>
pub fn inspect_object_ex<'ex>( &'ex mut self, object: impl AsArg<Option<Gd<Object>>> + 'ex, ) -> ExInspectObject<'ex>
Shows the given property on the given object in the editor’s Inspector dock. If inspector_only is true, plugins will not attempt to edit object.
pub fn edit_resource(&mut self, resource: impl AsArg<Option<Gd<Resource>>>)
pub fn edit_resource(&mut self, resource: impl AsArg<Option<Gd<Resource>>>)
Edits the given Resource. If the resource is a Script you can also edit it with edit_script to specify the line and column position.
pub fn edit_node(&mut self, node: impl AsArg<Option<Gd<Node>>>)
pub fn edit_node(&mut self, node: impl AsArg<Option<Gd<Node>>>)
Edits the given Node. The node will be also selected if it’s inside the scene tree.
pub fn edit_script(&mut self, script: impl AsArg<Option<Gd<Script>>>)
pub fn edit_script(&mut self, script: impl AsArg<Option<Gd<Script>>>)
To set the default parameters, use edit_script_ex and its builder methods. See the book for detailed usage instructions.
Edits the given Script. The line and column on which to open the script can also be specified. The script will be open with the user-configured editor for the script’s language which may be an external editor.
pub fn edit_script_ex<'ex>(
&'ex mut self,
script: impl AsArg<Option<Gd<Script>>> + 'ex,
) -> ExEditScript<'ex>
pub fn edit_script_ex<'ex>( &'ex mut self, script: impl AsArg<Option<Gd<Script>>> + 'ex, ) -> ExEditScript<'ex>
Edits the given Script. The line and column on which to open the script can also be specified. The script will be open with the user-configured editor for the script’s language which may be an external editor.
pub fn open_scene_from_path(&mut self, scene_filepath: impl AsArg<GString>)
pub fn open_scene_from_path(&mut self, scene_filepath: impl AsArg<GString>)
To set the default parameters, use open_scene_from_path_ex and its builder methods. See the book for detailed usage instructions.
Opens the scene at the given path. If set_inherited is true, creates a new inherited scene.
pub fn open_scene_from_path_ex<'ex>(
&'ex mut self,
scene_filepath: impl AsArg<GString> + 'ex,
) -> ExOpenSceneFromPath<'ex>
pub fn open_scene_from_path_ex<'ex>( &'ex mut self, scene_filepath: impl AsArg<GString> + 'ex, ) -> ExOpenSceneFromPath<'ex>
Opens the scene at the given path. If set_inherited is true, creates a new inherited scene.
pub fn reload_scene_from_path(&mut self, scene_filepath: impl AsArg<GString>)
pub fn reload_scene_from_path(&mut self, scene_filepath: impl AsArg<GString>)
Reloads the scene at the given path.
pub fn set_object_edited(
&mut self,
object: impl AsArg<Option<Gd<Object>>>,
edited: bool,
)
pub fn set_object_edited( &mut self, object: impl AsArg<Option<Gd<Object>>>, edited: bool, )
If edited is true, the object is marked as edited.
Note: This is primarily used by the editor for Resource based objects to track their modified state. For example, any changes to an open scene, a resource in the inspector, or an edited script will cause this method to be called with true. Saving the scene, script, or resource resets the edited state by calling this method with false.
Note: Each call to this method increments the object’s edited version. This is used to track changes in the editor and to trigger when thumbnails should be regenerated for resources.
pub fn is_object_edited(&self, object: impl AsArg<Option<Gd<Object>>>) -> bool
pub fn is_object_edited(&self, object: impl AsArg<Option<Gd<Object>>>) -> bool
Returns true if the object has been marked as edited through set_object_edited.
pub fn get_open_scenes(&self) -> PackedArray<GString>
pub fn get_open_scenes(&self) -> PackedArray<GString>
Returns an array with the file paths of the currently opened scenes.
pub fn get_open_scene_roots(&self) -> Array<Gd<Node>>
pub fn get_open_scene_roots(&self) -> Array<Gd<Node>>
Returns an array with references to the root nodes of the currently opened scenes.
pub fn get_edited_scene_root(&self) -> Option<Gd<Node>>
pub fn get_edited_scene_root(&self) -> Option<Gd<Node>>
Returns the edited (current) scene’s root Node.
pub fn add_root_node(&mut self, node: impl AsArg<Option<Gd<Node>>>)
pub fn add_root_node(&mut self, node: impl AsArg<Option<Gd<Node>>>)
Makes node root of the currently opened scene. Only works if the scene is empty. If the node is a scene instance, an inheriting scene will be created.
pub fn save_scene(&mut self) -> Error
pub fn save_scene(&mut self) -> Error
Saves the currently active scene. Returns either Error::OK or Error::ERR_CANT_CREATE.
pub fn save_scene_as(&mut self, path: impl AsArg<GString>)
pub fn save_scene_as(&mut self, path: impl AsArg<GString>)
To set the default parameters, use save_scene_as_ex and its builder methods. See the book for detailed usage instructions.
Saves the currently active scene as a file at path.
pub fn save_scene_as_ex<'ex>(
&'ex mut self,
path: impl AsArg<GString> + 'ex,
) -> ExSaveSceneAs<'ex>
pub fn save_scene_as_ex<'ex>( &'ex mut self, path: impl AsArg<GString> + 'ex, ) -> ExSaveSceneAs<'ex>
Saves the currently active scene as a file at path.
pub fn save_all_scenes(&mut self)
pub fn save_all_scenes(&mut self)
Saves all opened scenes in the editor.
pub fn close_scene(&mut self) -> Error
pub fn close_scene(&mut self) -> Error
Closes the currently active scene, discarding any pending changes in the process. Returns Error::OK on success or Error::ERR_DOES_NOT_EXIST if there is no scene to close.
pub fn mark_scene_as_unsaved(&mut self)
pub fn mark_scene_as_unsaved(&mut self)
Marks the current scene tab as unsaved.
pub fn play_main_scene(&mut self)
pub fn play_main_scene(&mut self)
Plays the main scene.
pub fn play_current_scene(&mut self)
pub fn play_current_scene(&mut self)
Plays the currently active scene.
pub fn play_custom_scene(&mut self, scene_filepath: impl AsArg<GString>)
pub fn play_custom_scene(&mut self, scene_filepath: impl AsArg<GString>)
Plays the scene specified by its filepath.
pub fn stop_playing_scene(&mut self)
pub fn stop_playing_scene(&mut self)
Stops the scene that is currently playing.
pub fn is_playing_scene(&self) -> bool
pub fn is_playing_scene(&self) -> bool
Returns true if a scene is currently being played, false otherwise. Paused scenes are considered as being played.
pub fn get_playing_scene(&self) -> GString
pub fn get_playing_scene(&self) -> GString
Returns the name of the scene that is being played. If no scene is currently being played, returns an empty string.
pub fn set_movie_maker_enabled(&mut self, enabled: bool)
pub fn is_movie_maker_enabled(&self) -> bool
Methods from Deref<Target = Object>
pub fn get_script(&self) -> Option<Gd<Script>>
pub fn set_script(&mut self, script: impl AsArg<Option<Gd<Script>>>)
pub fn connect( &mut self, signal: impl AsArg<StringName>, callable: &Callable, ) -> Error
pub fn connect_flags( &mut self, signal: impl AsArg<StringName>, callable: &Callable, flags: ConnectFlags, ) -> Error
pub fn is_class(&self, class: impl AsArg<GString>) -> bool
pub fn is_class(&self, class: impl AsArg<GString>) -> bool
Returns true if the object inherits from the given class. See also get_class.
var sprite2d = Sprite2D.new()
sprite2d.is_class("Sprite2D") # Returns true
sprite2d.is_class("Node") # Returns true
sprite2d.is_class("Node3D") # Returns falseNote: This method ignores class_name declarations in the object’s script.
pub fn set(&mut self, property: impl AsArg<StringName>, value: &Variant)
pub fn set(&mut self, property: impl AsArg<StringName>, value: &Variant)
Assigns value to the given property. If the property does not exist or the given value’s type doesn’t match, nothing happens.
var node = Node2D.new()
node.set("global_scale", Vector2(8, 2.5))
print(node.global_scale) # Prints (8.0, 2.5)Note: In C#, property must be in snake_case when referring to built-in Godot properties. Prefer using the names exposed in the PropertyName class to avoid allocating a new StringName on each call.
pub fn get(&self, property: impl AsArg<StringName>) -> Variant
pub fn get(&self, property: impl AsArg<StringName>) -> Variant
Returns the Variant value of the given property. If the property does not exist, this method returns null.
var node = Node2D.new()
node.rotation = 1.5
var a = node.get("rotation") # a is 1.5Note: In C#, property must be in snake_case when referring to built-in Godot properties. Prefer using the names exposed in the PropertyName class to avoid allocating a new StringName on each call.
pub fn set_indexed(
&mut self,
property_path: impl AsArg<NodePath>,
value: &Variant,
)
pub fn set_indexed( &mut self, property_path: impl AsArg<NodePath>, value: &Variant, )
Assigns a new value to the property identified by the property_path. The path should be a NodePath relative to this object, and can use the colon character (:) to access nested properties.
var node = Node2D.new()
node.set_indexed("position", Vector2(42, 0))
node.set_indexed("position:y", -10)
print(node.position) # Prints (42.0, -10.0)Note: In C#, property_path must be in snake_case when referring to built-in Godot properties. Prefer using the names exposed in the PropertyName class to avoid allocating a new StringName on each call.
pub fn get_indexed(&self, property_path: impl AsArg<NodePath>) -> Variant
pub fn get_indexed(&self, property_path: impl AsArg<NodePath>) -> Variant
Gets the object’s property indexed by the given property_path. The path should be a NodePath relative to the current object and can use the colon character (:) to access nested properties.
Examples: "position:x" or "material:next_pass:blend_mode".
var node = Node2D.new()
node.position = Vector2(5, -10)
var a = node.get_indexed("position") # a is Vector2(5, -10)
var b = node.get_indexed("position:y") # b is -10Note: In C#, property_path must be in snake_case when referring to built-in Godot properties. Prefer using the names exposed in the PropertyName class to avoid allocating a new StringName on each call.
Note: This method does not support actual paths to nodes in the SceneTree, only sub-property paths. In the context of nodes, use get_node_and_resource instead.
pub fn get_property_list(&self) -> Array<Dictionary<Variant, Variant>>
pub fn get_property_list(&self) -> Array<Dictionary<Variant, Variant>>
Returns the object’s property list as an Array of dictionaries. Each Dictionary contains the following entries:
-
nameis the property’s name, as aString; -
class_nameis an emptyStringName, unless the property isVariantType::OBJECTand it inherits from a class; -
typeis the property’s type, as anint(see [enum Variant.Type]); -
hintis how the property is meant to be edited (see [enum PropertyHint]); -
hint_stringdepends on the hint (see [enum PropertyHint]); -
usageis a combination of [enum PropertyUsageFlags].
Note: In GDScript, all class members are treated as properties. In C# and GDExtension, it may be necessary to explicitly mark class members as Godot properties using decorators or attributes.
pub fn get_method_list(&self) -> Array<Dictionary<Variant, Variant>>
pub fn get_method_list(&self) -> Array<Dictionary<Variant, Variant>>
Returns this object’s methods and their signatures as an Array of dictionaries. Each Dictionary contains the following entries:
-
nameis the name of the method, as aString; -
argsis anArrayof dictionaries representing the arguments; -
default_argsis the default arguments as anArrayof variants; -
flagsis a combination of [enum MethodFlags]; -
idis the method’s internal identifierint; -
returnis the returned value, as aDictionary;
Note: The dictionaries of args and return are formatted identically to the results of get_property_list, although not all entries are used.
pub fn property_can_revert(&self, property: impl AsArg<StringName>) -> bool
pub fn property_can_revert(&self, property: impl AsArg<StringName>) -> bool
Returns true if the given property has a custom default value. Use property_get_revert to get the property’s default value.
Note: This method is used by the Inspector dock to display a revert icon. The object must implement [method _property_can_revert] to customize the default value. If [method _property_can_revert] is not implemented, this method returns false.
pub fn property_get_revert(&self, property: impl AsArg<StringName>) -> Variant
pub fn property_get_revert(&self, property: impl AsArg<StringName>) -> Variant
Returns the custom default value of the given property. Use property_can_revert to check if the property has a custom default value.
Note: This method is used by the Inspector dock to display a revert icon. The object must implement [method _property_get_revert] to customize the default value. If [method _property_get_revert] is not implemented, this method returns null.
pub fn set_meta(&mut self, name: impl AsArg<StringName>, value: &Variant)
pub fn set_meta(&mut self, name: impl AsArg<StringName>, value: &Variant)
Adds or changes the entry name inside the object’s metadata. The metadata value can be any Variant, although some types cannot be serialized correctly.
If value is null, the entry is removed. This is the equivalent of using remove_meta. See also has_meta and get_meta.
Note: A metadata’s name must be a valid identifier as per is_valid_identifier method.
Note: Metadata that has a name starting with an underscore (_) is considered editor-only. Editor-only metadata is not displayed in the Inspector and should not be edited, although it can still be found by this method.
pub fn remove_meta(&mut self, name: impl AsArg<StringName>)
pub fn remove_meta(&mut self, name: impl AsArg<StringName>)
Removes the given entry name from the object’s metadata. See also has_meta, get_meta and set_meta.
Note: A metadata’s name must be a valid identifier as per is_valid_identifier method.
Note: Metadata that has a name starting with an underscore (_) is considered editor-only. Editor-only metadata is not displayed in the Inspector and should not be edited, although it can still be found by this method.
pub fn get_meta(&self, name: impl AsArg<StringName>) -> Variant
pub fn get_meta(&self, name: impl AsArg<StringName>) -> Variant
To set the default parameters, use get_meta_ex and its builder methods. See the book for detailed usage instructions.
Returns the object’s metadata value for the given entry name. If the entry does not exist, returns default. If default is null, an error is also generated.
Note: A metadata’s name must be a valid identifier as per is_valid_identifier method.
Note: Metadata that has a name starting with an underscore (_) is considered editor-only. Editor-only metadata is not displayed in the Inspector and should not be edited, although it can still be found by this method.
pub fn get_meta_ex<'ex>(
&'ex self,
name: impl AsArg<StringName> + 'ex,
) -> ExGetMeta<'ex>
pub fn get_meta_ex<'ex>( &'ex self, name: impl AsArg<StringName> + 'ex, ) -> ExGetMeta<'ex>
Returns the object’s metadata value for the given entry name. If the entry does not exist, returns default. If default is null, an error is also generated.
Note: A metadata’s name must be a valid identifier as per is_valid_identifier method.
Note: Metadata that has a name starting with an underscore (_) is considered editor-only. Editor-only metadata is not displayed in the Inspector and should not be edited, although it can still be found by this method.
pub fn has_meta(&self, name: impl AsArg<StringName>) -> bool
pub fn has_meta(&self, name: impl AsArg<StringName>) -> bool
Returns true if a metadata entry is found with the given name. See also get_meta, set_meta and remove_meta.
Note: A metadata’s name must be a valid identifier as per is_valid_identifier method.
Note: Metadata that has a name starting with an underscore (_) is considered editor-only. Editor-only metadata is not displayed in the Inspector and should not be edited, although it can still be found by this method.
pub fn get_meta_list(&self) -> Array<StringName>
pub fn get_meta_list(&self) -> Array<StringName>
Returns the object’s metadata entry names as an Array of StringNames.
pub fn add_user_signal(&mut self, signal: impl AsArg<GString>)
pub fn add_user_signal(&mut self, signal: impl AsArg<GString>)
To set the default parameters, use add_user_signal_ex and its builder methods. See the book for detailed usage instructions.
Adds a user-defined signal named signal. Optional arguments for the signal can be added as an Array of dictionaries, each defining a name String and a type int (see [enum Variant.Type]). See also has_user_signal and remove_user_signal.
add_user_signal("hurt", [
{ "name": "damage", "type": TYPE_INT },
{ "name": "source", "type": TYPE_OBJECT }
])pub fn add_user_signal_ex<'ex>(
&'ex mut self,
signal: impl AsArg<GString> + 'ex,
) -> ExAddUserSignal<'ex>
pub fn add_user_signal_ex<'ex>( &'ex mut self, signal: impl AsArg<GString> + 'ex, ) -> ExAddUserSignal<'ex>
Adds a user-defined signal named signal. Optional arguments for the signal can be added as an Array of dictionaries, each defining a name String and a type int (see [enum Variant.Type]). See also has_user_signal and remove_user_signal.
add_user_signal("hurt", [
{ "name": "damage", "type": TYPE_INT },
{ "name": "source", "type": TYPE_OBJECT }
])pub fn has_user_signal(&self, signal: impl AsArg<StringName>) -> bool
pub fn has_user_signal(&self, signal: impl AsArg<StringName>) -> bool
Returns true if the given user-defined signal name exists. Only signals added with add_user_signal are included. See also remove_user_signal.
pub fn remove_user_signal(&mut self, signal: impl AsArg<StringName>)
pub fn remove_user_signal(&mut self, signal: impl AsArg<StringName>)
Removes the given user signal signal from the object. See also add_user_signal and has_user_signal.
pub fn emit_signal(
&mut self,
signal: impl AsArg<StringName>,
varargs: &[Variant],
) -> Error
pub fn emit_signal( &mut self, signal: impl AsArg<StringName>, varargs: &[Variant], ) -> Error
Emits the given signal by name. The signal must exist, so it should be a built-in signal of this class or one of its inherited classes, or a user-defined signal (see add_user_signal). This method supports a variable number of arguments, so parameters can be passed as a comma separated list.
Returns Error::ERR_UNAVAILABLE if signal does not exist or the parameters are invalid.
emit_signal("hit", "sword", 100)
emit_signal("game_over")Note: In C#, signal must be in snake_case when referring to built-in Godot signals. Prefer using the names exposed in the SignalName class to avoid allocating a new StringName on each call.
Panics
This is a varcall method, meaning parameters and return values are passed as Variant.
It can detect call failures and will panic in such a case.
pub fn try_emit_signal(
&mut self,
signal: impl AsArg<StringName>,
varargs: &[Variant],
) -> Result<Error, CallError>
pub fn try_emit_signal( &mut self, signal: impl AsArg<StringName>, varargs: &[Variant], ) -> Result<Error, CallError>
Return type
This is a varcall method, meaning parameters and return values are passed as Variant.
It can detect call failures and will return Err in such a case.
pub fn call(
&mut self,
method: impl AsArg<StringName>,
varargs: &[Variant],
) -> Variant
pub fn call( &mut self, method: impl AsArg<StringName>, varargs: &[Variant], ) -> Variant
Calls the method on the object and returns the result. This method supports a variable number of arguments, so parameters can be passed as a comma separated list.
var node = Node3D.new()
node.call("rotate", Vector3(1.0, 0.0, 0.0), 1.571)Note: In C#, method must be in snake_case when referring to built-in Godot methods. Prefer using the names exposed in the MethodName class to avoid allocating a new StringName on each call.
Panics
This is a varcall method, meaning parameters and return values are passed as Variant.
It can detect call failures and will panic in such a case.
pub fn try_call(
&mut self,
method: impl AsArg<StringName>,
varargs: &[Variant],
) -> Result<Variant, CallError>
pub fn try_call( &mut self, method: impl AsArg<StringName>, varargs: &[Variant], ) -> Result<Variant, CallError>
Return type
This is a varcall method, meaning parameters and return values are passed as Variant.
It can detect call failures and will return Err in such a case.
pub fn call_deferred(
&mut self,
method: impl AsArg<StringName>,
varargs: &[Variant],
) -> Variant
pub fn call_deferred( &mut self, method: impl AsArg<StringName>, varargs: &[Variant], ) -> Variant
Calls the method on the object during idle time. Always returns null, not the method’s result.
Idle time happens mainly at the end of process and physics frames. In it, deferred calls will be run until there are none left, which means you can defer calls from other deferred calls and they’ll still be run in the current idle time cycle. This means you should not call a method deferred from itself (or from a method called by it), as this causes infinite recursion the same way as if you had called the method directly.
This method supports a variable number of arguments, so parameters can be passed as a comma separated list.
var node = Node3D.new()
node.call_deferred("rotate", Vector3(1.0, 0.0, 0.0), 1.571)For methods that are deferred from the same thread, the order of execution at idle time is identical to the order in which call_deferred was called.
See also call_deferred.
Note: In C#, method must be in snake_case when referring to built-in Godot methods. Prefer using the names exposed in the MethodName class to avoid allocating a new StringName on each call.
Note: If you’re looking to delay the function call by a frame, refer to the SceneTree.process_frame and SceneTree.physics_frame signals.
var node = Node3D.new()
# Make a Callable and bind the arguments to the node's rotate() call.
var callable = node.rotate.bind(Vector3(1.0, 0.0, 0.0), 1.571)
# Connect the callable to the process_frame signal, so it gets called in the next process frame.
# CONNECT_ONE_SHOT makes sure it only gets called once instead of every frame.
get_tree().process_frame.connect(callable, CONNECT_ONE_SHOT)Panics
This is a varcall method, meaning parameters and return values are passed as Variant.
It can detect call failures and will panic in such a case.
pub fn try_call_deferred(
&mut self,
method: impl AsArg<StringName>,
varargs: &[Variant],
) -> Result<Variant, CallError>
pub fn try_call_deferred( &mut self, method: impl AsArg<StringName>, varargs: &[Variant], ) -> Result<Variant, CallError>
Return type
This is a varcall method, meaning parameters and return values are passed as Variant.
It can detect call failures and will return Err in such a case.
pub fn set_deferred(
&mut self,
property: impl AsArg<StringName>,
value: &Variant,
)
pub fn set_deferred( &mut self, property: impl AsArg<StringName>, value: &Variant, )
Assigns value to the given property, at the end of the current frame. This is equivalent to calling set through call_deferred.
var node = Node2D.new()
add_child(node)
node.rotation = 1.5
node.set_deferred("rotation", 3.0)
print(node.rotation) # Prints 1.5
await get_tree().process_frame
print(node.rotation) # Prints 3.0Note: In C#, property must be in snake_case when referring to built-in Godot properties. Prefer using the names exposed in the PropertyName class to avoid allocating a new StringName on each call.
pub fn callv(
&mut self,
method: impl AsArg<StringName>,
arg_array: &AnyArray,
) -> Variant
pub fn callv( &mut self, method: impl AsArg<StringName>, arg_array: &AnyArray, ) -> Variant
Calls the method on the object and returns the result. Unlike call, this method expects all parameters to be contained inside arg_array.
var node = Node3D.new()
node.callv("rotate", [Vector3(1.0, 0.0, 0.0), 1.571])Note: In C#, method must be in snake_case when referring to built-in Godot methods. Prefer using the names exposed in the MethodName class to avoid allocating a new StringName on each call.
pub fn has_method(&self, method: impl AsArg<StringName>) -> bool
pub fn has_method(&self, method: impl AsArg<StringName>) -> bool
Returns true if the given method name exists in the object.
Note: In C#, method must be in snake_case when referring to built-in Godot methods. Prefer using the names exposed in the MethodName class to avoid allocating a new StringName on each call.
pub fn get_method_argument_count(&self, method: impl AsArg<StringName>) -> i32
pub fn get_method_argument_count(&self, method: impl AsArg<StringName>) -> i32
Returns the number of arguments of the given method by name.
Note: In C#, method must be in snake_case when referring to built-in Godot methods. Prefer using the names exposed in the MethodName class to avoid allocating a new StringName on each call.
pub fn has_signal(&self, signal: impl AsArg<StringName>) -> bool
pub fn has_signal(&self, signal: impl AsArg<StringName>) -> bool
Returns true if the given signal name exists in the object.
Note: In C#, signal must be in snake_case when referring to built-in Godot signals. Prefer using the names exposed in the SignalName class to avoid allocating a new StringName on each call.
pub fn get_signal_list(&self) -> Array<Dictionary<Variant, Variant>>
pub fn get_signal_list(&self) -> Array<Dictionary<Variant, Variant>>
Returns the list of existing signals as an Array of dictionaries.
Note: Due to the implementation, each Dictionary is formatted very similarly to the returned values of get_method_list.
pub fn get_signal_connection_list(
&self,
signal: impl AsArg<StringName>,
) -> Array<Dictionary<Variant, Variant>>
pub fn get_signal_connection_list( &self, signal: impl AsArg<StringName>, ) -> Array<Dictionary<Variant, Variant>>
Returns an Array of connections for the given signal name. Each connection is represented as a Dictionary that contains three entries:
pub fn get_incoming_connections(&self) -> Array<Dictionary<Variant, Variant>>
pub fn get_incoming_connections(&self) -> Array<Dictionary<Variant, Variant>>
Returns an Array of signal connections received by this object. Each connection is represented as a Dictionary that contains three entries:
pub fn disconnect(
&mut self,
signal: impl AsArg<StringName>,
callable: &Callable,
)
pub fn disconnect( &mut self, signal: impl AsArg<StringName>, callable: &Callable, )
Disconnects a signal by name from a given callable. If the connection does not exist, generates an error. Use is_connected to make sure that the connection exists.
pub fn is_connected(
&self,
signal: impl AsArg<StringName>,
callable: &Callable,
) -> bool
pub fn is_connected( &self, signal: impl AsArg<StringName>, callable: &Callable, ) -> bool
Returns true if a connection exists between the given signal name and callable.
Note: In C#, signal must be in snake_case when referring to built-in Godot signals. Prefer using the names exposed in the SignalName class to avoid allocating a new StringName on each call.
pub fn has_connections(&self, signal: impl AsArg<StringName>) -> bool
pub fn has_connections(&self, signal: impl AsArg<StringName>) -> bool
Returns true if any connection exists on the given signal name.
Note: In C#, signal must be in snake_case when referring to built-in Godot methods. Prefer using the names exposed in the SignalName class to avoid allocating a new StringName on each call.
pub fn set_block_signals(&mut self, enable: bool)
pub fn set_block_signals(&mut self, enable: bool)
If set to true, the object becomes unable to emit signals. As such, emit_signal and signal connections will not work, until it is set to false.
pub fn is_blocking_signals(&self) -> bool
pub fn is_blocking_signals(&self) -> bool
Returns true if the object is blocking its signals from being emitted. See set_block_signals.
pub fn notify_property_list_changed(&mut self)
pub fn notify_property_list_changed(&mut self)
Emits the property_list_changed signal. This is mainly used to refresh the editor, so that the Inspector and editor plugins are properly updated.
pub fn set_message_translation(&mut self, enable: bool)
pub fn set_message_translation(&mut self, enable: bool)
If set to true, allows the object to translate messages with tr and tr_n. Enabled by default. See also can_translate_messages.
pub fn can_translate_messages(&self) -> bool
pub fn can_translate_messages(&self) -> bool
Returns true if the object is allowed to translate messages with tr and tr_n. See also set_message_translation.
pub fn tr(&self, message: impl AsArg<StringName>) -> GString
pub fn tr(&self, message: impl AsArg<StringName>) -> GString
To set the default parameters, use tr_ex and its builder methods. See the book for detailed usage instructions.
Translates a message, using the translation catalogs configured in the Project Settings. Further context can be specified to help with the translation. Note that most Control nodes automatically translate their strings, so this method is mostly useful for formatted strings or custom drawn text.
If can_translate_messages is false, or no translation is available, this method returns the message without changes. See set_message_translation.
For detailed examples, see Internationalizing games.
Note: This method can’t be used without an Object instance, as it requires the can_translate_messages method. To translate strings in a static context, use translate.
pub fn tr_ex<'ex>(&'ex self, message: impl AsArg<StringName> + 'ex) -> ExTr<'ex>
pub fn tr_ex<'ex>(&'ex self, message: impl AsArg<StringName> + 'ex) -> ExTr<'ex>
Translates a message, using the translation catalogs configured in the Project Settings. Further context can be specified to help with the translation. Note that most Control nodes automatically translate their strings, so this method is mostly useful for formatted strings or custom drawn text.
If can_translate_messages is false, or no translation is available, this method returns the message without changes. See set_message_translation.
For detailed examples, see Internationalizing games.
Note: This method can’t be used without an Object instance, as it requires the can_translate_messages method. To translate strings in a static context, use translate.
pub fn tr_n(
&self,
message: impl AsArg<StringName>,
plural_message: impl AsArg<StringName>,
n: i32,
) -> GString
pub fn tr_n( &self, message: impl AsArg<StringName>, plural_message: impl AsArg<StringName>, n: i32, ) -> GString
To set the default parameters, use tr_n_ex and its builder methods. See the book for detailed usage instructions.
Translates a message or plural_message, using the translation catalogs configured in the Project Settings. Further context can be specified to help with the translation.
If can_translate_messages is false, or no translation is available, this method returns message or plural_message, without changes. See set_message_translation.
The n is the number, or amount, of the message’s subject. It is used by the translation system to fetch the correct plural form for the current language.
For detailed examples, see Localization using gettext.
Note: Negative and float numbers may not properly apply to some countable subjects. It’s recommended to handle these cases with tr.
Note: This method can’t be used without an Object instance, as it requires the can_translate_messages method. To translate strings in a static context, use translate_plural.
pub fn tr_n_ex<'ex>(
&'ex self,
message: impl AsArg<StringName> + 'ex,
plural_message: impl AsArg<StringName> + 'ex,
n: i32,
) -> ExTrN<'ex>
pub fn tr_n_ex<'ex>( &'ex self, message: impl AsArg<StringName> + 'ex, plural_message: impl AsArg<StringName> + 'ex, n: i32, ) -> ExTrN<'ex>
Translates a message or plural_message, using the translation catalogs configured in the Project Settings. Further context can be specified to help with the translation.
If can_translate_messages is false, or no translation is available, this method returns message or plural_message, without changes. See set_message_translation.
The n is the number, or amount, of the message’s subject. It is used by the translation system to fetch the correct plural form for the current language.
For detailed examples, see Localization using gettext.
Note: Negative and float numbers may not properly apply to some countable subjects. It’s recommended to handle these cases with tr.
Note: This method can’t be used without an Object instance, as it requires the can_translate_messages method. To translate strings in a static context, use translate_plural.
pub fn get_translation_domain(&self) -> StringName
pub fn get_translation_domain(&self) -> StringName
Returns the name of the translation domain used by tr and tr_n. See also TranslationServer.
pub fn set_translation_domain(&mut self, domain: impl AsArg<StringName>)
pub fn set_translation_domain(&mut self, domain: impl AsArg<StringName>)
Sets the name of the translation domain used by tr and tr_n. See also TranslationServer.
pub fn is_queued_for_deletion(&self) -> bool
pub fn is_queued_for_deletion(&self) -> bool
Returns true if the queue_free method was called for the object.
pub fn cancel_free(&mut self)
pub fn cancel_free(&mut self)
If this method is called during ObjectNotification::PREDELETE, this object will reject being freed and will remain allocated. This is mostly an internal function used for error handling to avoid the user from freeing objects when they are not intended to.
pub fn notify(&mut self, what: ObjectNotification)
pub fn notify(&mut self, what: ObjectNotification)
⚠️ Sends a Godot notification to all classes inherited by the object.
Triggers calls to on_notification(), and depending on the notification, also to Godot’s lifecycle callbacks such as ready().
Starts from the highest ancestor (the Object class) and goes down the hierarchy.
See also Godot docs for Object::notification().
Panics
If you call this method on a user-defined object while holding a GdRef or GdMut guard on the instance, you will encounter
a panic. The reason is that the receiving virtual method on_notification() acquires a GdMut lock dynamically, which must
be exclusive.
pub fn notify_reversed(&mut self, what: ObjectNotification)
pub fn notify_reversed(&mut self, what: ObjectNotification)
⚠️ Like Self::notify(), but starts at the most-derived class and goes up the hierarchy.
See docs of that method, including the panics.