Theme

Struct Theme 

pub struct Theme { /* private fields */ }
Godot class Theme.

Inherits Resource.

Related symbols:

  • theme: sidecar module with related enum/flag types
  • ITheme: virtual methods

See also Godot docs for Theme.

Construction

This class is reference-counted. You can create a new instance using Theme::new_gd().

Godot docs

A resource used for styling/skinning Control and Window nodes. While individual controls can be styled using their local theme overrides (see add_theme_color_override), theme resources allow you to store and apply the same settings across all controls sharing the same type (e.g. style all Buttons the same). One theme resource can be used for the entire project, but you can also set a separate theme resource to a branch of control nodes. A theme resource assigned to a control applies to the control itself, as well as all of its direct and indirect children (as long as a chain of controls is uninterrupted).

Use [member ProjectSettings.gui/theme/custom] to set up a project-scope theme that will be available to every control in your project.

Use [member Control.theme] of any control node to set up a theme that will be available to that control and all of its direct and indirect children.

Implementations



impl Theme

pub fn set_icon( &mut self, name: impl AsArg<StringName>, theme_type: impl AsArg<StringName>, texture: impl AsArg<Option<Gd<Texture2D>>>, )

Creates or changes the value of the icon property defined by name and theme_type. Use clear_icon to remove the property.

pub fn get_icon( &self, name: impl AsArg<StringName>, theme_type: impl AsArg<StringName>, ) -> Option<Gd<Texture2D>>

Returns the icon property defined by name and theme_type, if it exists.

Returns the engine fallback icon value if the property doesn’t exist (see [member ThemeDB.fallback_icon]). Use has_icon to check for existence.

pub fn has_icon( &self, name: impl AsArg<StringName>, theme_type: impl AsArg<StringName>, ) -> bool

Returns true if the icon property defined by name and theme_type exists.

Returns false if it doesn’t exist. Use set_icon to define it.

pub fn rename_icon( &mut self, old_name: impl AsArg<StringName>, name: impl AsArg<StringName>, theme_type: impl AsArg<StringName>, )

Renames the icon property defined by old_name and theme_type to name, if it exists.

Fails if it doesn’t exist, or if a similar property with the new name already exists. Use has_icon to check for existence, and clear_icon to remove the existing property.

pub fn clear_icon( &mut self, name: impl AsArg<StringName>, theme_type: impl AsArg<StringName>, )

Removes the icon property defined by name and theme_type, if it exists.

Fails if it doesn’t exist. Use has_icon to check for existence.

pub fn get_icon_list( &self, theme_type: impl AsArg<GString>, ) -> PackedArray<GString>

Returns a list of names for icon properties defined with theme_type. Use get_icon_type_list to get a list of possible theme type names.

pub fn get_icon_type_list(&self) -> PackedArray<GString>

Returns a list of all unique theme type names for icon properties. Use get_type_list to get a list of all unique theme types.

pub fn set_stylebox( &mut self, name: impl AsArg<StringName>, theme_type: impl AsArg<StringName>, texture: impl AsArg<Option<Gd<StyleBox>>>, )

Creates or changes the value of the StyleBox property defined by name and theme_type. Use clear_stylebox to remove the property.

pub fn get_stylebox( &self, name: impl AsArg<StringName>, theme_type: impl AsArg<StringName>, ) -> Option<Gd<StyleBox>>

Returns the StyleBox property defined by name and theme_type, if it exists.

Returns the engine fallback stylebox value if the property doesn’t exist (see [member ThemeDB.fallback_stylebox]). Use has_stylebox to check for existence.

pub fn has_stylebox( &self, name: impl AsArg<StringName>, theme_type: impl AsArg<StringName>, ) -> bool

Returns true if the StyleBox property defined by name and theme_type exists.

Returns false if it doesn’t exist. Use set_stylebox to define it.

pub fn rename_stylebox( &mut self, old_name: impl AsArg<StringName>, name: impl AsArg<StringName>, theme_type: impl AsArg<StringName>, )

Renames the StyleBox property defined by old_name and theme_type to name, if it exists.

Fails if it doesn’t exist, or if a similar property with the new name already exists. Use has_stylebox to check for existence, and clear_stylebox to remove the existing property.

pub fn clear_stylebox( &mut self, name: impl AsArg<StringName>, theme_type: impl AsArg<StringName>, )

Removes the StyleBox property defined by name and theme_type, if it exists.

Fails if it doesn’t exist. Use has_stylebox to check for existence.

pub fn get_stylebox_list( &self, theme_type: impl AsArg<GString>, ) -> PackedArray<GString>

Returns a list of names for StyleBox properties defined with theme_type. Use get_stylebox_type_list to get a list of possible theme type names.

pub fn get_stylebox_type_list(&self) -> PackedArray<GString>

Returns a list of all unique theme type names for StyleBox properties. Use get_type_list to get a list of all unique theme types.

pub fn set_font( &mut self, name: impl AsArg<StringName>, theme_type: impl AsArg<StringName>, font: impl AsArg<Option<Gd<Font>>>, )

Creates or changes the value of the Font property defined by name and theme_type. Use clear_font to remove the property.

pub fn get_font( &self, name: impl AsArg<StringName>, theme_type: impl AsArg<StringName>, ) -> Option<Gd<Font>>

Returns the Font property defined by name and theme_type, if it exists.

Returns the default theme font if the property doesn’t exist and the default theme font is set up (see [member default_font]). Use has_font to check for existence of the property and has_default_font to check for existence of the default theme font.

Returns the engine fallback font value, if neither exist (see [member ThemeDB.fallback_font]).

pub fn has_font( &self, name: impl AsArg<StringName>, theme_type: impl AsArg<StringName>, ) -> bool

Returns true if the Font property defined by name and theme_type exists, or if the default theme font is set up (see has_default_font).

Returns false if neither exist. Use set_font to define the property.

pub fn rename_font( &mut self, old_name: impl AsArg<StringName>, name: impl AsArg<StringName>, theme_type: impl AsArg<StringName>, )

Renames the Font property defined by old_name and theme_type to name, if it exists.

Fails if it doesn’t exist, or if a similar property with the new name already exists. Use has_font to check for existence, and clear_font to remove the existing property.

pub fn clear_font( &mut self, name: impl AsArg<StringName>, theme_type: impl AsArg<StringName>, )

Removes the Font property defined by name and theme_type, if it exists.

Fails if it doesn’t exist. Use has_font to check for existence.

pub fn get_font_list( &self, theme_type: impl AsArg<GString>, ) -> PackedArray<GString>

Returns a list of names for Font properties defined with theme_type. Use get_font_type_list to get a list of possible theme type names.

pub fn get_font_type_list(&self) -> PackedArray<GString>

Returns a list of all unique theme type names for Font properties. Use get_type_list to get a list of all unique theme types.

pub fn set_font_size( &mut self, name: impl AsArg<StringName>, theme_type: impl AsArg<StringName>, font_size: i32, )

Creates or changes the value of the font size property defined by name and theme_type. Use clear_font_size to remove the property.

pub fn get_font_size( &self, name: impl AsArg<StringName>, theme_type: impl AsArg<StringName>, ) -> i32

Returns the font size property defined by name and theme_type, if it exists.

Returns the default theme font size if the property doesn’t exist and the default theme font size is set up (see [member default_font_size]). Use has_font_size to check for existence of the property and has_default_font_size to check for existence of the default theme font.

Returns the engine fallback font size value, if neither exist (see [member ThemeDB.fallback_font_size]).

pub fn has_font_size( &self, name: impl AsArg<StringName>, theme_type: impl AsArg<StringName>, ) -> bool

Returns true if the font size property defined by name and theme_type exists, or if the default theme font size is set up (see has_default_font_size).

Returns false if neither exist. Use set_font_size to define the property.

pub fn rename_font_size( &mut self, old_name: impl AsArg<StringName>, name: impl AsArg<StringName>, theme_type: impl AsArg<StringName>, )

Renames the font size property defined by old_name and theme_type to name, if it exists.

Fails if it doesn’t exist, or if a similar property with the new name already exists. Use has_font_size to check for existence, and clear_font_size to remove the existing property.

pub fn clear_font_size( &mut self, name: impl AsArg<StringName>, theme_type: impl AsArg<StringName>, )

Removes the font size property defined by name and theme_type, if it exists.

Fails if it doesn’t exist. Use has_font_size to check for existence.

pub fn get_font_size_list( &self, theme_type: impl AsArg<GString>, ) -> PackedArray<GString>

Returns a list of names for font size properties defined with theme_type. Use get_font_size_type_list to get a list of possible theme type names.

pub fn get_font_size_type_list(&self) -> PackedArray<GString>

Returns a list of all unique theme type names for font size properties. Use get_type_list to get a list of all unique theme types.

pub fn set_color( &mut self, name: impl AsArg<StringName>, theme_type: impl AsArg<StringName>, color: Color, )

Creates or changes the value of the Color property defined by name and theme_type. Use clear_color to remove the property.

pub fn get_color( &self, name: impl AsArg<StringName>, theme_type: impl AsArg<StringName>, ) -> Color

Returns the Color property defined by name and theme_type, if it exists.

Returns the default color value if the property doesn’t exist. Use has_color to check for existence.

pub fn has_color( &self, name: impl AsArg<StringName>, theme_type: impl AsArg<StringName>, ) -> bool

Returns true if the Color property defined by name and theme_type exists.

Returns false if it doesn’t exist. Use set_color to define it.

pub fn rename_color( &mut self, old_name: impl AsArg<StringName>, name: impl AsArg<StringName>, theme_type: impl AsArg<StringName>, )

Renames the Color property defined by old_name and theme_type to name, if it exists.

Fails if it doesn’t exist, or if a similar property with the new name already exists. Use has_color to check for existence, and clear_color to remove the existing property.

pub fn clear_color( &mut self, name: impl AsArg<StringName>, theme_type: impl AsArg<StringName>, )

Removes the Color property defined by name and theme_type, if it exists.

Fails if it doesn’t exist. Use has_color to check for existence.

pub fn get_color_list( &self, theme_type: impl AsArg<GString>, ) -> PackedArray<GString>

Returns a list of names for Color properties defined with theme_type. Use get_color_type_list to get a list of possible theme type names.

pub fn get_color_type_list(&self) -> PackedArray<GString>

Returns a list of all unique theme type names for Color properties. Use get_type_list to get a list of all unique theme types.

pub fn set_constant( &mut self, name: impl AsArg<StringName>, theme_type: impl AsArg<StringName>, constant: i32, )

Creates or changes the value of the constant property defined by name and theme_type. Use clear_constant to remove the property.

pub fn get_constant( &self, name: impl AsArg<StringName>, theme_type: impl AsArg<StringName>, ) -> i32

Returns the constant property defined by name and theme_type, if it exists.

Returns 0 if the property doesn’t exist. Use has_constant to check for existence.

pub fn has_constant( &self, name: impl AsArg<StringName>, theme_type: impl AsArg<StringName>, ) -> bool

Returns true if the constant property defined by name and theme_type exists.

Returns false if it doesn’t exist. Use set_constant to define it.

pub fn rename_constant( &mut self, old_name: impl AsArg<StringName>, name: impl AsArg<StringName>, theme_type: impl AsArg<StringName>, )

Renames the constant property defined by old_name and theme_type to name, if it exists.

Fails if it doesn’t exist, or if a similar property with the new name already exists. Use has_constant to check for existence, and clear_constant to remove the existing property.

pub fn clear_constant( &mut self, name: impl AsArg<StringName>, theme_type: impl AsArg<StringName>, )

Removes the constant property defined by name and theme_type, if it exists.

Fails if it doesn’t exist. Use has_constant to check for existence.

pub fn get_constant_list( &self, theme_type: impl AsArg<GString>, ) -> PackedArray<GString>

Returns a list of names for constant properties defined with theme_type. Use get_constant_type_list to get a list of possible theme type names.

pub fn get_constant_type_list(&self) -> PackedArray<GString>

Returns a list of all unique theme type names for constant properties. Use get_type_list to get a list of all unique theme types.

pub fn set_default_base_scale(&mut self, base_scale: f32)

pub fn get_default_base_scale(&self) -> f32

pub fn has_default_base_scale(&self) -> bool

Returns true if [member default_base_scale] has a valid value.

Returns false if it doesn’t. The value must be greater than 0.0 to be considered valid.

pub fn set_default_font(&mut self, font: impl AsArg<Option<Gd<Font>>>)

pub fn get_default_font(&self) -> Option<Gd<Font>>

pub fn has_default_font(&self) -> bool

Returns true if [member default_font] has a valid value.

Returns false if it doesn’t.

pub fn set_default_font_size(&mut self, font_size: i32)

pub fn get_default_font_size(&self) -> i32

pub fn has_default_font_size(&self) -> bool

Returns true if [member default_font_size] has a valid value.

Returns false if it doesn’t. The value must be greater than 0 to be considered valid.

pub fn set_theme_item( &mut self, data_type: DataType, name: impl AsArg<StringName>, theme_type: impl AsArg<StringName>, value: &Variant, )

Creates or changes the value of the theme property of data_type defined by name and theme_type. Use clear_theme_item to remove the property.

Fails if the value type is not accepted by data_type.

Note: This method is analogous to calling the corresponding data type specific method, but can be used for more generalized logic.

pub fn get_theme_item( &self, data_type: DataType, name: impl AsArg<StringName>, theme_type: impl AsArg<StringName>, ) -> Variant

Returns the theme property of data_type defined by name and theme_type, if it exists.

Returns the engine fallback value if the property doesn’t exist (see ThemeDB). Use has_theme_item to check for existence.

Note: This method is analogous to calling the corresponding data type specific method, but can be used for more generalized logic.

pub fn has_theme_item( &self, data_type: DataType, name: impl AsArg<StringName>, theme_type: impl AsArg<StringName>, ) -> bool

Returns true if the theme property of data_type defined by name and theme_type exists.

Returns false if it doesn’t exist. Use set_theme_item to define it.

Note: This method is analogous to calling the corresponding data type specific method, but can be used for more generalized logic.

pub fn rename_theme_item( &mut self, data_type: DataType, old_name: impl AsArg<StringName>, name: impl AsArg<StringName>, theme_type: impl AsArg<StringName>, )

Renames the theme property of data_type defined by old_name and theme_type to name, if it exists.

Fails if it doesn’t exist, or if a similar property with the new name already exists. Use has_theme_item to check for existence, and clear_theme_item to remove the existing property.

Note: This method is analogous to calling the corresponding data type specific method, but can be used for more generalized logic.

pub fn clear_theme_item( &mut self, data_type: DataType, name: impl AsArg<StringName>, theme_type: impl AsArg<StringName>, )

Removes the theme property of data_type defined by name and theme_type, if it exists.

Fails if it doesn’t exist. Use has_theme_item to check for existence.

Note: This method is analogous to calling the corresponding data type specific method, but can be used for more generalized logic.

pub fn get_theme_item_list( &self, data_type: DataType, theme_type: impl AsArg<GString>, ) -> PackedArray<GString>

Returns a list of names for properties of data_type defined with theme_type. Use get_theme_item_type_list to get a list of possible theme type names.

Note: This method is analogous to calling the corresponding data type specific method, but can be used for more generalized logic.

pub fn get_theme_item_type_list( &self, data_type: DataType, ) -> PackedArray<GString>

Returns a list of all unique theme type names for data_type properties. Use get_type_list to get a list of all unique theme types.

Note: This method is analogous to calling the corresponding data type specific method, but can be used for more generalized logic.

pub fn set_type_variation( &mut self, theme_type: impl AsArg<StringName>, base_type: impl AsArg<StringName>, )

Marks theme_type as a variation of base_type.

This adds theme_type as a suggested option for [member Control.theme_type_variation] on a Control that is of the base_type class.

Variations can also be nested, i.e. base_type can be another variation. If a chain of variations ends with a base_type matching the class of the Control, the whole chain is going to be suggested as options.

Note: Suggestions only show up if this theme resource is set as the project default theme. See [member ProjectSettings.gui/theme/custom].

pub fn is_type_variation( &self, theme_type: impl AsArg<StringName>, base_type: impl AsArg<StringName>, ) -> bool

Returns true if theme_type is marked as a variation of base_type.

pub fn clear_type_variation(&mut self, theme_type: impl AsArg<StringName>)

Unmarks theme_type as being a variation of another theme type. See set_type_variation.

pub fn get_type_variation_base( &self, theme_type: impl AsArg<StringName>, ) -> StringName

Returns the name of the base theme type if theme_type is a valid variation type. Returns an empty string otherwise.

pub fn get_type_variation_list( &self, base_type: impl AsArg<StringName>, ) -> PackedArray<GString>

Returns a list of all type variations for the given base_type.

pub fn add_type(&mut self, theme_type: impl AsArg<StringName>)

Adds an empty theme type for every valid data type.

Note: Empty types are not saved with the theme. This method only exists to perform in-memory changes to the resource. Use available set_* methods to add theme items.

pub fn remove_type(&mut self, theme_type: impl AsArg<StringName>)

Removes the theme type, gracefully discarding defined theme items. If the type is a variation, this information is also erased. If the type is a base for type variations, those variations lose their base.

pub fn rename_type( &mut self, old_theme_type: impl AsArg<StringName>, theme_type: impl AsArg<StringName>, )

Renames the theme type old_theme_type to theme_type, if the old type exists and the new one doesn’t exist.

Note: Renaming a theme type to an empty name or a variation to a type associated with a built-in class removes type variation connections in a way that cannot be undone by reversing the rename alone.

pub fn get_type_list(&self) -> PackedArray<GString>

Returns a list of all unique theme type names. Use the appropriate get_*_type_list method to get a list of unique theme types for a single data type.

pub fn merge_with(&mut self, other: impl AsArg<Option<Gd<Theme>>>)

Adds missing and overrides existing definitions with values from the other theme resource.

Note: This modifies the current theme. If you want to merge two themes together without modifying either one, create a new empty theme and merge the other two into it one after another.

pub fn clear(&mut self)

Removes all the theme properties defined on the theme resource.

Methods from Deref<Target = Resource>

pub fn set_path(&mut self, path: impl AsArg<GString>)

pub fn take_over_path(&mut self, path: impl AsArg<GString>)

Sets the [member resource_path] to path, potentially overriding an existing cache entry for this path. Further attempts to load an overridden resource by path will instead return this resource.

pub fn get_path(&self) -> GString

pub fn set_path_cache(&mut self, path: impl AsArg<GString>)

Sets the resource’s path to path without involving the resource cache. Useful for handling [enum ResourceFormatLoader.CacheMode] values when implementing a custom resource format by extending ResourceFormatLoader and ResourceFormatSaver.

pub fn set_name(&mut self, name: impl AsArg<GString>)

pub fn get_name(&self) -> GString

pub fn get_rid(&self) -> Rid

Returns the RID of this resource (or an empty RID). Many resources (such as Texture2D, Mesh, and so on) are high-level abstractions of resources stored in a specialized server (DisplayServer, RenderingServer, etc.), so this function will return the original RID.

pub fn set_local_to_scene(&mut self, enable: bool)

pub fn is_local_to_scene(&self) -> bool

pub fn get_local_scene(&self) -> Option<Gd<Node>>

If [member resource_local_to_scene] is set to true and the resource has been loaded from a PackedScene instantiation, returns the root Node of the scene where this resource is used. Otherwise, returns null.

pub fn setup_local_to_scene(&mut self)

Calls setup_local_to_scene. If [member resource_local_to_scene] is set to true, this method is automatically called from instantiate by the newly duplicated resource within the scene instance.

pub fn reset_state(&mut self)

Makes the resource clear its non-exported properties. See also reset_state. Useful when implementing a custom resource format by extending ResourceFormatLoader and ResourceFormatSaver.

pub fn set_id_for_path( &mut self, path: impl AsArg<GString>, id: impl AsArg<GString>, )

In the internal cache for scene-unique IDs, sets the ID of this resource to id for the scene at path. If id is empty, the cache entry for path is cleared. Useful to keep scene-unique IDs the same when implementing a VCS-friendly custom resource format by extending ResourceFormatLoader and ResourceFormatSaver.

Note: This method is only implemented when running in an editor context.

pub fn get_id_for_path(&self, path: impl AsArg<GString>) -> GString

From the internal cache for scene-unique IDs, returns the ID of this resource for the scene at path. If there is no entry, an empty string is returned. Useful to keep scene-unique IDs the same when implementing a VCS-friendly custom resource format by extending ResourceFormatLoader and ResourceFormatSaver.

Note: This method is only implemented when running in an editor context. At runtime, it returns an empty string.

pub fn is_built_in(&self) -> bool

Returns true if the resource is saved on disk as a part of another resource’s file.

pub fn set_scene_unique_id(&mut self, id: impl AsArg<GString>)

pub fn get_scene_unique_id(&self) -> GString

pub fn emit_changed(&mut self)

Emits the changed signal. This method is called automatically for some built-in resources.

Note: For custom resources, it’s recommended to call this method whenever a meaningful change occurs, such as a modified property. This ensures that custom Objects depending on the resource are properly updated.

var damage:
	set(new_value):
		if damage != new_value:
			damage = new_value
			emit_changed()

pub fn duplicate(&self) -> Option<Gd<Resource>>

👎Deprecated:

Use Gd::duplicate_resource() or Gd::duplicate_resource_ex().

To set the default parameters, use duplicate_ex and its builder methods. See the book for detailed usage instructions. Duplicates this resource, returning a new resource with its exported or PropertyUsageFlags::STORAGE properties copied from the original.

If deep is false, a shallow copy is returned: nested Array, Dictionary, and Resource properties are not duplicated and are shared with the original resource.

If deep is true, a deep copy is returned: all nested arrays, dictionaries, and packed arrays are also duplicated (recursively). Any Resource found inside will only be duplicated if it’s local, like DeepDuplicateMode::INTERNAL used with duplicate_deep.

The following exceptions apply:

Note: For custom resources, this method will fail if init has been defined with required parameters.

Note: When duplicating with deep set to true, each resource found, including the one on which this method is called, will be only duplicated once and referenced as many times as needed in the duplicate. For instance, if you are duplicating resource A that happens to have resource B referenced twice, you’ll get a new resource A’ referencing a new resource B’ twice.

pub fn duplicate_ex<'ex>(&'ex self) -> ExDuplicate<'ex>

👎Deprecated:

Use Gd::duplicate_resource() or Gd::duplicate_resource_ex().

Duplicates this resource, returning a new resource with its exported or PropertyUsageFlags::STORAGE properties copied from the original.

If deep is false, a shallow copy is returned: nested Array, Dictionary, and Resource properties are not duplicated and are shared with the original resource.

If deep is true, a deep copy is returned: all nested arrays, dictionaries, and packed arrays are also duplicated (recursively). Any Resource found inside will only be duplicated if it’s local, like DeepDuplicateMode::INTERNAL used with duplicate_deep.

The following exceptions apply:

Note: For custom resources, this method will fail if init has been defined with required parameters.

Note: When duplicating with deep set to true, each resource found, including the one on which this method is called, will be only duplicated once and referenced as many times as needed in the duplicate. For instance, if you are duplicating resource A that happens to have resource B referenced twice, you’ll get a new resource A’ referencing a new resource B’ twice.

pub fn duplicate_deep(&self) -> Option<Gd<Resource>>

👎Deprecated:

Use Gd::duplicate_resource() or Gd::duplicate_resource_ex().

To set the default parameters, use duplicate_deep_ex and its builder methods. See the book for detailed usage instructions. Duplicates this resource, deeply, like duplicate when passing true, with extra control over how subresources are handled.

pub fn duplicate_deep_ex<'ex>(&'ex self) -> ExDuplicateDeep<'ex>

👎Deprecated:

Use Gd::duplicate_resource() or Gd::duplicate_resource_ex().

Duplicates this resource, deeply, like duplicate when passing true, with extra control over how subresources are handled.

Methods from Deref<Target = RefCounted>

pub fn get_reference_count(&self) -> i32

Returns the current reference count.

Methods from Deref<Target = Object>

pub fn get_script(&self) -> Option<Gd<Script>>

pub fn set_script(&mut self, script: impl AsArg<Option<Gd<Script>>>)

pub fn connect( &mut self, signal: impl AsArg<StringName>, callable: &Callable, ) -> Error

pub fn connect_flags( &mut self, signal: impl AsArg<StringName>, callable: &Callable, flags: ConnectFlags, ) -> Error

pub fn get_class(&self) -> GString

Returns the object’s built-in class name, as a String. See also is_class.

Note: This method ignores class_name declarations. If this object’s script has defined a class_name, the base, built-in class name is returned instead.

pub fn is_class(&self, class: impl AsArg<GString>) -> bool

Returns true if the object inherits from the given class. See also get_class.

var sprite2d = Sprite2D.new()
sprite2d.is_class("Sprite2D") # Returns true
sprite2d.is_class("Node")     # Returns true
sprite2d.is_class("Node3D")   # Returns false

Note: This method ignores class_name declarations in the object’s script.

pub fn set(&mut self, property: impl AsArg<StringName>, value: &Variant)

Assigns value to the given property. If the property does not exist or the given value’s type doesn’t match, nothing happens.

var node = Node2D.new()
node.set("global_scale", Vector2(8, 2.5))
print(node.global_scale) # Prints (8.0, 2.5)

Note: In C#, property must be in snake_case when referring to built-in Godot properties. Prefer using the names exposed in the PropertyName class to avoid allocating a new StringName on each call.

pub fn get(&self, property: impl AsArg<StringName>) -> Variant

Returns the Variant value of the given property. If the property does not exist, this method returns null.

var node = Node2D.new()
node.rotation = 1.5
var a = node.get("rotation") # a is 1.5

Note: In C#, property must be in snake_case when referring to built-in Godot properties. Prefer using the names exposed in the PropertyName class to avoid allocating a new StringName on each call.

pub fn set_indexed( &mut self, property_path: impl AsArg<NodePath>, value: &Variant, )

Assigns a new value to the property identified by the property_path. The path should be a NodePath relative to this object, and can use the colon character (:) to access nested properties.

var node = Node2D.new()
node.set_indexed("position", Vector2(42, 0))
node.set_indexed("position:y", -10)
print(node.position) # Prints (42.0, -10.0)

Note: In C#, property_path must be in snake_case when referring to built-in Godot properties. Prefer using the names exposed in the PropertyName class to avoid allocating a new StringName on each call.

pub fn get_indexed(&self, property_path: impl AsArg<NodePath>) -> Variant

Gets the object’s property indexed by the given property_path. The path should be a NodePath relative to the current object and can use the colon character (:) to access nested properties.

Examples: "position:x" or "material:next_pass:blend_mode".

var node = Node2D.new()
node.position = Vector2(5, -10)
var a = node.get_indexed("position")   # a is Vector2(5, -10)
var b = node.get_indexed("position:y") # b is -10

Note: In C#, property_path must be in snake_case when referring to built-in Godot properties. Prefer using the names exposed in the PropertyName class to avoid allocating a new StringName on each call.

Note: This method does not support actual paths to nodes in the SceneTree, only sub-property paths. In the context of nodes, use get_node_and_resource instead.

pub fn get_property_list(&self) -> Array<Dictionary<Variant, Variant>>

Returns the object’s property list as an Array of dictionaries. Each Dictionary contains the following entries:

  • name is the property’s name, as a String;

  • class_name is an empty StringName, unless the property is VariantType::OBJECT and it inherits from a class;

  • type is the property’s type, as an int (see [enum Variant.Type]);

  • hint is how the property is meant to be edited (see [enum PropertyHint]);

  • hint_string depends on the hint (see [enum PropertyHint]);

  • usage is a combination of [enum PropertyUsageFlags].

Note: In GDScript, all class members are treated as properties. In C# and GDExtension, it may be necessary to explicitly mark class members as Godot properties using decorators or attributes.

pub fn get_method_list(&self) -> Array<Dictionary<Variant, Variant>>

Returns this object’s methods and their signatures as an Array of dictionaries. Each Dictionary contains the following entries:

  • name is the name of the method, as a String;

  • args is an Array of dictionaries representing the arguments;

  • default_args is the default arguments as an Array of variants;

  • flags is a combination of [enum MethodFlags];

  • id is the method’s internal identifier int;

  • return is the returned value, as a Dictionary;

Note: The dictionaries of args and return are formatted identically to the results of get_property_list, although not all entries are used.

pub fn property_can_revert(&self, property: impl AsArg<StringName>) -> bool

Returns true if the given property has a custom default value. Use property_get_revert to get the property’s default value.

Note: This method is used by the Inspector dock to display a revert icon. The object must implement [method _property_can_revert] to customize the default value. If [method _property_can_revert] is not implemented, this method returns false.

pub fn property_get_revert(&self, property: impl AsArg<StringName>) -> Variant

Returns the custom default value of the given property. Use property_can_revert to check if the property has a custom default value.

Note: This method is used by the Inspector dock to display a revert icon. The object must implement [method _property_get_revert] to customize the default value. If [method _property_get_revert] is not implemented, this method returns null.

pub fn set_meta(&mut self, name: impl AsArg<StringName>, value: &Variant)

Adds or changes the entry name inside the object’s metadata. The metadata value can be any Variant, although some types cannot be serialized correctly.

If value is null, the entry is removed. This is the equivalent of using remove_meta. See also has_meta and get_meta.

Note: A metadata’s name must be a valid identifier as per is_valid_identifier method.

Note: Metadata that has a name starting with an underscore (_) is considered editor-only. Editor-only metadata is not displayed in the Inspector and should not be edited, although it can still be found by this method.

pub fn remove_meta(&mut self, name: impl AsArg<StringName>)

Removes the given entry name from the object’s metadata. See also has_meta, get_meta and set_meta.

Note: A metadata’s name must be a valid identifier as per is_valid_identifier method.

Note: Metadata that has a name starting with an underscore (_) is considered editor-only. Editor-only metadata is not displayed in the Inspector and should not be edited, although it can still be found by this method.

pub fn get_meta(&self, name: impl AsArg<StringName>) -> Variant

To set the default parameters, use get_meta_ex and its builder methods. See the book for detailed usage instructions. Returns the object’s metadata value for the given entry name. If the entry does not exist, returns default. If default is null, an error is also generated.

Note: A metadata’s name must be a valid identifier as per is_valid_identifier method.

Note: Metadata that has a name starting with an underscore (_) is considered editor-only. Editor-only metadata is not displayed in the Inspector and should not be edited, although it can still be found by this method.

pub fn get_meta_ex<'ex>( &'ex self, name: impl AsArg<StringName> + 'ex, ) -> ExGetMeta<'ex>

Returns the object’s metadata value for the given entry name. If the entry does not exist, returns default. If default is null, an error is also generated.

Note: A metadata’s name must be a valid identifier as per is_valid_identifier method.

Note: Metadata that has a name starting with an underscore (_) is considered editor-only. Editor-only metadata is not displayed in the Inspector and should not be edited, although it can still be found by this method.

pub fn has_meta(&self, name: impl AsArg<StringName>) -> bool

Returns true if a metadata entry is found with the given name. See also get_meta, set_meta and remove_meta.

Note: A metadata’s name must be a valid identifier as per is_valid_identifier method.

Note: Metadata that has a name starting with an underscore (_) is considered editor-only. Editor-only metadata is not displayed in the Inspector and should not be edited, although it can still be found by this method.

pub fn get_meta_list(&self) -> Array<StringName>

Returns the object’s metadata entry names as an Array of StringNames.

pub fn add_user_signal(&mut self, signal: impl AsArg<GString>)

To set the default parameters, use add_user_signal_ex and its builder methods. See the book for detailed usage instructions. Adds a user-defined signal named signal. Optional arguments for the signal can be added as an Array of dictionaries, each defining a name String and a type int (see [enum Variant.Type]). See also has_user_signal and remove_user_signal.

add_user_signal("hurt", [
	{ "name": "damage", "type": TYPE_INT },
	{ "name": "source", "type": TYPE_OBJECT }
])

pub fn add_user_signal_ex<'ex>( &'ex mut self, signal: impl AsArg<GString> + 'ex, ) -> ExAddUserSignal<'ex>

Adds a user-defined signal named signal. Optional arguments for the signal can be added as an Array of dictionaries, each defining a name String and a type int (see [enum Variant.Type]). See also has_user_signal and remove_user_signal.

add_user_signal("hurt", [
	{ "name": "damage", "type": TYPE_INT },
	{ "name": "source", "type": TYPE_OBJECT }
])

pub fn has_user_signal(&self, signal: impl AsArg<StringName>) -> bool

Returns true if the given user-defined signal name exists. Only signals added with add_user_signal are included. See also remove_user_signal.

pub fn remove_user_signal(&mut self, signal: impl AsArg<StringName>)

Removes the given user signal signal from the object. See also add_user_signal and has_user_signal.

pub fn emit_signal( &mut self, signal: impl AsArg<StringName>, varargs: &[Variant], ) -> Error

Emits the given signal by name. The signal must exist, so it should be a built-in signal of this class or one of its inherited classes, or a user-defined signal (see add_user_signal). This method supports a variable number of arguments, so parameters can be passed as a comma separated list.

Returns Error::ERR_UNAVAILABLE if signal does not exist or the parameters are invalid.

emit_signal("hit", "sword", 100)
emit_signal("game_over")

Note: In C#, signal must be in snake_case when referring to built-in Godot signals. Prefer using the names exposed in the SignalName class to avoid allocating a new StringName on each call.

Panics

This is a varcall method, meaning parameters and return values are passed as Variant. It can detect call failures and will panic in such a case.

pub fn try_emit_signal( &mut self, signal: impl AsArg<StringName>, varargs: &[Variant], ) -> Result<Error, CallError>

Return type

This is a varcall method, meaning parameters and return values are passed as Variant. It can detect call failures and will return Err in such a case.

pub fn call( &mut self, method: impl AsArg<StringName>, varargs: &[Variant], ) -> Variant

Calls the method on the object and returns the result. This method supports a variable number of arguments, so parameters can be passed as a comma separated list.

var node = Node3D.new()
node.call("rotate", Vector3(1.0, 0.0, 0.0), 1.571)

Note: In C#, method must be in snake_case when referring to built-in Godot methods. Prefer using the names exposed in the MethodName class to avoid allocating a new StringName on each call.

Panics

This is a varcall method, meaning parameters and return values are passed as Variant. It can detect call failures and will panic in such a case.

pub fn try_call( &mut self, method: impl AsArg<StringName>, varargs: &[Variant], ) -> Result<Variant, CallError>

Return type

This is a varcall method, meaning parameters and return values are passed as Variant. It can detect call failures and will return Err in such a case.

pub fn call_deferred( &mut self, method: impl AsArg<StringName>, varargs: &[Variant], ) -> Variant

Calls the method on the object during idle time. Always returns null, not the method’s result.

Idle time happens mainly at the end of process and physics frames. In it, deferred calls will be run until there are none left, which means you can defer calls from other deferred calls and they’ll still be run in the current idle time cycle. This means you should not call a method deferred from itself (or from a method called by it), as this causes infinite recursion the same way as if you had called the method directly.

This method supports a variable number of arguments, so parameters can be passed as a comma separated list.

var node = Node3D.new()
node.call_deferred("rotate", Vector3(1.0, 0.0, 0.0), 1.571)

For methods that are deferred from the same thread, the order of execution at idle time is identical to the order in which call_deferred was called.

See also call_deferred.

Note: In C#, method must be in snake_case when referring to built-in Godot methods. Prefer using the names exposed in the MethodName class to avoid allocating a new StringName on each call.

Note: If you’re looking to delay the function call by a frame, refer to the SceneTree.process_frame and SceneTree.physics_frame signals.

var node = Node3D.new()
# Make a Callable and bind the arguments to the node's rotate() call.
var callable = node.rotate.bind(Vector3(1.0, 0.0, 0.0), 1.571)
# Connect the callable to the process_frame signal, so it gets called in the next process frame.
# CONNECT_ONE_SHOT makes sure it only gets called once instead of every frame.
get_tree().process_frame.connect(callable, CONNECT_ONE_SHOT)
Panics

This is a varcall method, meaning parameters and return values are passed as Variant. It can detect call failures and will panic in such a case.

pub fn try_call_deferred( &mut self, method: impl AsArg<StringName>, varargs: &[Variant], ) -> Result<Variant, CallError>

Return type

This is a varcall method, meaning parameters and return values are passed as Variant. It can detect call failures and will return Err in such a case.

pub fn set_deferred( &mut self, property: impl AsArg<StringName>, value: &Variant, )

Assigns value to the given property, at the end of the current frame. This is equivalent to calling set through call_deferred.

var node = Node2D.new()
add_child(node)

node.rotation = 1.5
node.set_deferred("rotation", 3.0)
print(node.rotation) # Prints 1.5

await get_tree().process_frame
print(node.rotation) # Prints 3.0

Note: In C#, property must be in snake_case when referring to built-in Godot properties. Prefer using the names exposed in the PropertyName class to avoid allocating a new StringName on each call.

pub fn callv( &mut self, method: impl AsArg<StringName>, arg_array: &AnyArray, ) -> Variant

Calls the method on the object and returns the result. Unlike call, this method expects all parameters to be contained inside arg_array.

var node = Node3D.new()
node.callv("rotate", [Vector3(1.0, 0.0, 0.0), 1.571])

Note: In C#, method must be in snake_case when referring to built-in Godot methods. Prefer using the names exposed in the MethodName class to avoid allocating a new StringName on each call.

pub fn has_method(&self, method: impl AsArg<StringName>) -> bool

Returns true if the given method name exists in the object.

Note: In C#, method must be in snake_case when referring to built-in Godot methods. Prefer using the names exposed in the MethodName class to avoid allocating a new StringName on each call.

pub fn get_method_argument_count(&self, method: impl AsArg<StringName>) -> i32

Returns the number of arguments of the given method by name.

Note: In C#, method must be in snake_case when referring to built-in Godot methods. Prefer using the names exposed in the MethodName class to avoid allocating a new StringName on each call.

pub fn has_signal(&self, signal: impl AsArg<StringName>) -> bool

Returns true if the given signal name exists in the object.

Note: In C#, signal must be in snake_case when referring to built-in Godot signals. Prefer using the names exposed in the SignalName class to avoid allocating a new StringName on each call.

pub fn get_signal_list(&self) -> Array<Dictionary<Variant, Variant>>

Returns the list of existing signals as an Array of dictionaries.

Note: Due to the implementation, each Dictionary is formatted very similarly to the returned values of get_method_list.

pub fn get_signal_connection_list( &self, signal: impl AsArg<StringName>, ) -> Array<Dictionary<Variant, Variant>>

Returns an Array of connections for the given signal name. Each connection is represented as a Dictionary that contains three entries:

  • signal is a reference to the Signal;

  • callable is a reference to the connected Callable;

  • flags is a combination of [enum ConnectFlags].

pub fn get_incoming_connections(&self) -> Array<Dictionary<Variant, Variant>>

Returns an Array of signal connections received by this object. Each connection is represented as a Dictionary that contains three entries:

  • signal is a reference to the Signal;

  • callable is a reference to the Callable;

  • flags is a combination of [enum ConnectFlags].

pub fn disconnect( &mut self, signal: impl AsArg<StringName>, callable: &Callable, )

Disconnects a signal by name from a given callable. If the connection does not exist, generates an error. Use is_connected to make sure that the connection exists.

pub fn is_connected( &self, signal: impl AsArg<StringName>, callable: &Callable, ) -> bool

Returns true if a connection exists between the given signal name and callable.

Note: In C#, signal must be in snake_case when referring to built-in Godot signals. Prefer using the names exposed in the SignalName class to avoid allocating a new StringName on each call.

pub fn has_connections(&self, signal: impl AsArg<StringName>) -> bool

Returns true if any connection exists on the given signal name.

Note: In C#, signal must be in snake_case when referring to built-in Godot methods. Prefer using the names exposed in the SignalName class to avoid allocating a new StringName on each call.

pub fn set_block_signals(&mut self, enable: bool)

If set to true, the object becomes unable to emit signals. As such, emit_signal and signal connections will not work, until it is set to false.

pub fn is_blocking_signals(&self) -> bool

Returns true if the object is blocking its signals from being emitted. See set_block_signals.

pub fn notify_property_list_changed(&mut self)

Emits the property_list_changed signal. This is mainly used to refresh the editor, so that the Inspector and editor plugins are properly updated.

pub fn set_message_translation(&mut self, enable: bool)

If set to true, allows the object to translate messages with tr and tr_n. Enabled by default. See also can_translate_messages.

pub fn can_translate_messages(&self) -> bool

Returns true if the object is allowed to translate messages with tr and tr_n. See also set_message_translation.

pub fn tr(&self, message: impl AsArg<StringName>) -> GString

To set the default parameters, use tr_ex and its builder methods. See the book for detailed usage instructions. Translates a message, using the translation catalogs configured in the Project Settings. Further context can be specified to help with the translation. Note that most Control nodes automatically translate their strings, so this method is mostly useful for formatted strings or custom drawn text.

If can_translate_messages is false, or no translation is available, this method returns the message without changes. See set_message_translation.

For detailed examples, see Internationalizing games.

Note: This method can’t be used without an Object instance, as it requires the can_translate_messages method. To translate strings in a static context, use translate.

pub fn tr_ex<'ex>(&'ex self, message: impl AsArg<StringName> + 'ex) -> ExTr<'ex>

Translates a message, using the translation catalogs configured in the Project Settings. Further context can be specified to help with the translation. Note that most Control nodes automatically translate their strings, so this method is mostly useful for formatted strings or custom drawn text.

If can_translate_messages is false, or no translation is available, this method returns the message without changes. See set_message_translation.

For detailed examples, see Internationalizing games.

Note: This method can’t be used without an Object instance, as it requires the can_translate_messages method. To translate strings in a static context, use translate.

pub fn tr_n( &self, message: impl AsArg<StringName>, plural_message: impl AsArg<StringName>, n: i32, ) -> GString

To set the default parameters, use tr_n_ex and its builder methods. See the book for detailed usage instructions. Translates a message or plural_message, using the translation catalogs configured in the Project Settings. Further context can be specified to help with the translation.

If can_translate_messages is false, or no translation is available, this method returns message or plural_message, without changes. See set_message_translation.

The n is the number, or amount, of the message’s subject. It is used by the translation system to fetch the correct plural form for the current language.

For detailed examples, see Localization using gettext.

Note: Negative and float numbers may not properly apply to some countable subjects. It’s recommended to handle these cases with tr.

Note: This method can’t be used without an Object instance, as it requires the can_translate_messages method. To translate strings in a static context, use translate_plural.

pub fn tr_n_ex<'ex>( &'ex self, message: impl AsArg<StringName> + 'ex, plural_message: impl AsArg<StringName> + 'ex, n: i32, ) -> ExTrN<'ex>

Translates a message or plural_message, using the translation catalogs configured in the Project Settings. Further context can be specified to help with the translation.

If can_translate_messages is false, or no translation is available, this method returns message or plural_message, without changes. See set_message_translation.

The n is the number, or amount, of the message’s subject. It is used by the translation system to fetch the correct plural form for the current language.

For detailed examples, see Localization using gettext.

Note: Negative and float numbers may not properly apply to some countable subjects. It’s recommended to handle these cases with tr.

Note: This method can’t be used without an Object instance, as it requires the can_translate_messages method. To translate strings in a static context, use translate_plural.

pub fn get_translation_domain(&self) -> StringName

Returns the name of the translation domain used by tr and tr_n. See also TranslationServer.

pub fn set_translation_domain(&mut self, domain: impl AsArg<StringName>)

Sets the name of the translation domain used by tr and tr_n. See also TranslationServer.

pub fn is_queued_for_deletion(&self) -> bool

Returns true if the queue_free method was called for the object.

pub fn cancel_free(&mut self)

If this method is called during ObjectNotification::PREDELETE, this object will reject being freed and will remain allocated. This is mostly an internal function used for error handling to avoid the user from freeing objects when they are not intended to.

pub fn notify(&mut self, what: ObjectNotification)

⚠️ Sends a Godot notification to all classes inherited by the object.

Triggers calls to on_notification(), and depending on the notification, also to Godot’s lifecycle callbacks such as ready().

Starts from the highest ancestor (the Object class) and goes down the hierarchy. See also Godot docs for Object::notification().

Panics

If you call this method on a user-defined object while holding a GdRef or GdMut guard on the instance, you will encounter a panic. The reason is that the receiving virtual method on_notification() acquires a GdMut lock dynamically, which must be exclusive.

pub fn notify_reversed(&mut self, what: ObjectNotification)

⚠️ Like Self::notify(), but starts at the most-derived class and goes up the hierarchy.

See docs of that method, including the panics.