IAudioStreamInteractive

Trait IAudioStreamInteractive 

pub trait IAudioStreamInteractive: GodotClass<Base = AudioStreamInteractive> + You_forgot_the_attribute__godot_api {
Show 22 methods // Required method fn instantiate_playback(&self) -> Option<Gd<AudioStreamPlayback>>; // Provided methods fn init(base: Base<Self::Base>) -> Self { ... } fn on_notification(&mut self, what: ObjectNotification) { ... } fn on_get(&self, property: StringName) -> Option<Variant> { ... } fn on_set(&mut self, property: StringName, value: Variant) -> bool { ... } fn on_validate_property(&self, property: &mut PropertyInfo) { ... } fn on_get_property_list(&mut self) -> Vec<PropertyInfo> { ... } fn on_property_get_revert(&self, property: StringName) -> Option<Variant> { ... } fn to_string(&self) -> GString { ... } fn get_stream_name(&self) -> GString { ... } fn get_length(&self) -> f64 { ... } fn is_monophonic(&self) -> bool { ... } fn get_bpm(&self) -> f64 { ... } fn get_beat_count(&self) -> i32 { ... } fn get_tags(&self) -> AnyDictionary { ... } fn get_parameter_list(&self) -> Array<AnyDictionary> { ... } fn has_loop(&self) -> bool { ... } fn get_bar_beats(&self) -> i32 { ... } fn setup_local_to_scene(&mut self) { ... } fn get_rid(&self) -> Rid { ... } fn reset_state(&mut self) { ... } fn set_path_cache(&self, path: GString) { ... }
}
Interface trait for class AudioStreamInteractive.

Functions in this trait represent constructors (init) or virtual method callbacks invoked by the engine.

Base interfaces: IAudioStream > IResource > IRefCounted > IObject.

See also Godot docs for AudioStreamInteractive methods.

Required Methods

fn instantiate_playback(&self) -> Option<Gd<AudioStreamPlayback>>

Override this method to customize the returned value of instantiate_playback. Should return a new AudioStreamPlayback created when the stream is played (such as by an AudioStreamPlayer).

Provided Methods

fn init(base: Base<Self::Base>) -> Self

Godot constructor, accepting an injected base object.

base refers to the base instance of the class, which can either be stored in a Base<T> field or discarded. This method returns a fully-constructed instance, which will then be moved into a Gd<T> pointer.

If the class has a #[class(init)] attribute, this method will be auto-generated and must not be overridden.

fn on_notification(&mut self, what: ObjectNotification)

Called when the object receives a Godot notification.

The type of notification can be identified through what. The enum is designed to hold all possible NOTIFICATION_* constants that the current class can handle. However, this is not validated in Godot, so an enum variant Unknown exists to represent integers out of known constants (mistakes or future additions).

This method is named _notification in Godot, but on_notification in Rust. To send notifications, use the Object::notify method.

See also in Godot docs:

fn on_get(&self, property: StringName) -> Option<Variant>

Called whenever get() is called or Godot gets the value of a property.

Should return the given property’s value as Some(value), or None if the property should be handled normally.

See also in Godot docs:

fn on_set(&mut self, property: StringName, value: Variant) -> bool

Called whenever Godot set() is called or Godot sets the value of a property.

Should set property to the given value and return true, or return false to indicate the property should be handled normally.

See also in Godot docs:

fn on_validate_property(&self, property: &mut PropertyInfo)

Called whenever Godot retrieves value of property. Allows to customize existing properties. Every property info goes through this method, except properties added with on_get_property_list().

Exposed property here is a shared mutable reference obtained (and returned to) from Godot.

See also in the Godot docs:

fn on_get_property_list(&mut self) -> Vec<PropertyInfo>

Available on since_api=4.3 only.

Called whenever Godot get_property_list() is called, the returned vector here is appended to the existing list of properties.

This should mainly be used for advanced purposes, such as dynamically updating the property list in the editor.

See also in Godot docs:

fn on_property_get_revert(&self, property: StringName) -> Option<Variant>

Called by Godot to tell if a property has a custom revert or not.

Return None for no custom revert, and return Some(value) to specify the custom revert.

This is a combination of Godot’s Object::_property_get_revert and Object::_property_can_revert. This means that this function will usually be called twice by Godot to find the revert.

Note that this should be a pure function. That is, it should always return the same value for a property as long as self remains unchanged. Otherwise, this may lead to unexpected (safe) behavior.

fn to_string(&self) -> GString

String representation of the Godot instance.

Override this method to define how the instance is represented as a string. Used by impl Display for Gd<T>, as well as str() and print() in GDScript.

fn get_stream_name(&self) -> GString

Override this method to customize the name assigned to this audio stream. Unused by the engine.

fn get_length(&self) -> f64

Override this method to customize the returned value of get_length. Should return the length of this audio stream, in seconds.

fn is_monophonic(&self) -> bool

Override this method to customize the returned value of is_monophonic. Should return true if this audio stream only supports one channel.

fn get_bpm(&self) -> f64

Overridable method. Should return the tempo of this audio stream, in beats per minute (BPM). Used by the engine to determine the position of every beat.

Ideally, the returned value should be based off the stream’s sample rate ([member AudioStreamWAV.mix_rate], for example).

fn get_beat_count(&self) -> i32

Overridable method. Should return the total number of beats of this audio stream. Used by the engine to determine the position of every beat.

Ideally, the returned value should be based off the stream’s sample rate ([member AudioStreamWAV.mix_rate], for example).

fn get_tags(&self) -> AnyDictionary

Override this method to customize the tags for this audio stream. Should return a Dictionary of strings with the tag as the key and its content as the value.

Commonly used tags include title, artist, album, tracknumber, and date.

fn get_parameter_list(&self) -> Array<AnyDictionary>

Return the controllable parameters of this stream. This array contains dictionaries with a property info description format (see get_property_list). Additionally, the default value for this parameter must be added tho each dictionary in “default_value” field.

fn has_loop(&self) -> bool

Override this method to return true if this stream has a loop.

fn get_bar_beats(&self) -> i32

Override this method to return the bar beats of this stream.

fn setup_local_to_scene(&mut self)

Override this method to customize the newly duplicated resource created from instantiate, if the original’s [member resource_local_to_scene] is set to true.

Example: Set a random damage value to every local resource from an instantiated scene:

extends Resource

var damage = 0

func _setup_local_to_scene():
	damage = randi_range(10, 40)

fn get_rid(&self) -> Rid

Override this method to return a custom RID when get_rid is called.

fn reset_state(&mut self)

For resources that store state in non-exported properties, such as via on_validate_property or on_get_property_list, this method must be implemented to clear them.

fn set_path_cache(&self, path: GString)

Override this method to execute additional logic after set_path_cache is called on this object.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors