Function atan
pub fn atan(x: f64) -> f64Expand description
Returns the arc tangent of x in radians. Use it to get the angle from an angle’s tangent in trigonometry.
The method cannot know in which quadrant the angle should fall. See [method atan2] if you have both y and x.
var a = atan(0.5) # a is 0.463648If x is between -PI / 2 and PI / 2 (inclusive), atan(tan(x)) is equal to x.