is_nan

Function is_nan 

pub fn is_nan(x: f64) -> bool
Returns true if x is a NaN (“Not a Number” or invalid) value. This method is needed as @GDScript.NAN is not equal to itself, which means x == NAN can’t be used to check whether a value is a NaN.