Struct EditorExportPlatformAppleEmbedded
pub struct EditorExportPlatformAppleEmbedded { /* private fields */ }Expand description
Godot class EditorExportPlatformAppleEmbedded.
Inherits EditorExportPlatform.
Related symbols:
See also Godot docs for EditorExportPlatformAppleEmbedded.
Not instantiable
This class cannot be constructed. Obtain Gd<EditorExportPlatformAppleEmbedded> instances via Godot APIs.
Final class
This class is final, meaning you cannot inherit from it, and it comes without I* interface trait. It is still possible that other Godot classes inherit from it, but that is limited to the engine itself.
Godot docs
The base class for Apple embedded platform exporters. These include iOS and visionOS, but not macOS. See the classes inheriting from this one for more details.
Methods from Deref<Target = EditorExportPlatform>
pub fn get_os_name(&self) -> GString
pub fn get_os_name(&self) -> GString
Returns the name of the export operating system handled by this EditorExportPlatform class, as a friendly string. Possible return values are Windows, Linux, macOS, Android, iOS, and Web.
pub fn create_preset(&mut self) -> Option<Gd<EditorExportPreset>>
pub fn create_preset(&mut self) -> Option<Gd<EditorExportPreset>>
Create a new preset for this platform.
pub fn find_export_template(
&self,
template_file_name: impl AsArg<GString>,
) -> Dictionary<Variant, Variant>
pub fn find_export_template( &self, template_file_name: impl AsArg<GString>, ) -> Dictionary<Variant, Variant>
Locates export template for the platform, and returns Dictionary with the following keys: path: String and error: String. This method is provided for convenience and custom export platforms aren’t required to use it or keep export templates stored in the same way official templates are.
pub fn get_current_presets(&self) -> Array<Variant>
pub fn get_current_presets(&self) -> Array<Variant>
Returns array of EditorExportPresets for this platform.
pub fn save_pack(
&mut self,
preset: impl AsArg<Option<Gd<EditorExportPreset>>>,
debug: bool,
path: impl AsArg<GString>,
) -> Dictionary<Variant, Variant>
pub fn save_pack( &mut self, preset: impl AsArg<Option<Gd<EditorExportPreset>>>, debug: bool, path: impl AsArg<GString>, ) -> Dictionary<Variant, Variant>
To set the default parameters, use save_pack_ex and its builder methods. See the book for detailed usage instructions.
Saves PCK archive and returns Dictionary with the following keys: result: Error, so_files: Array (array of the shared/static objects which contains dictionaries with the following keys: path: String, tags: PackedStringArray, and target_folder: String).
If embed is true, PCK content is appended to the end of path file and return Dictionary additionally include following keys: embedded_start: int (embedded PCK offset) and embedded_size: int (embedded PCK size).
pub fn save_pack_ex<'ex>(
&'ex mut self,
preset: impl AsArg<Option<Gd<EditorExportPreset>>> + 'ex,
debug: bool,
path: impl AsArg<GString> + 'ex,
) -> ExSavePack<'ex>
pub fn save_pack_ex<'ex>( &'ex mut self, preset: impl AsArg<Option<Gd<EditorExportPreset>>> + 'ex, debug: bool, path: impl AsArg<GString> + 'ex, ) -> ExSavePack<'ex>
Saves PCK archive and returns Dictionary with the following keys: result: Error, so_files: Array (array of the shared/static objects which contains dictionaries with the following keys: path: String, tags: PackedStringArray, and target_folder: String).
If embed is true, PCK content is appended to the end of path file and return Dictionary additionally include following keys: embedded_start: int (embedded PCK offset) and embedded_size: int (embedded PCK size).
pub fn save_zip(
&mut self,
preset: impl AsArg<Option<Gd<EditorExportPreset>>>,
debug: bool,
path: impl AsArg<GString>,
) -> Dictionary<Variant, Variant>
pub fn save_zip( &mut self, preset: impl AsArg<Option<Gd<EditorExportPreset>>>, debug: bool, path: impl AsArg<GString>, ) -> Dictionary<Variant, Variant>
Saves ZIP archive and returns Dictionary with the following keys: result: Error, so_files: Array (array of the shared/static objects which contains dictionaries with the following keys: path: String, tags: PackedStringArray, and target_folder: String).
pub fn save_pack_patch(
&mut self,
preset: impl AsArg<Option<Gd<EditorExportPreset>>>,
debug: bool,
path: impl AsArg<GString>,
) -> Dictionary<Variant, Variant>
pub fn save_pack_patch( &mut self, preset: impl AsArg<Option<Gd<EditorExportPreset>>>, debug: bool, path: impl AsArg<GString>, ) -> Dictionary<Variant, Variant>
Saves patch PCK archive and returns Dictionary with the following keys: result: Error, so_files: Array (array of the shared/static objects which contains dictionaries with the following keys: path: String, tags: PackedStringArray, and target_folder: String).
pub fn save_zip_patch(
&mut self,
preset: impl AsArg<Option<Gd<EditorExportPreset>>>,
debug: bool,
path: impl AsArg<GString>,
) -> Dictionary<Variant, Variant>
pub fn save_zip_patch( &mut self, preset: impl AsArg<Option<Gd<EditorExportPreset>>>, debug: bool, path: impl AsArg<GString>, ) -> Dictionary<Variant, Variant>
Saves patch ZIP archive and returns Dictionary with the following keys: result: Error, so_files: Array (array of the shared/static objects which contains dictionaries with the following keys: path: String, tags: PackedStringArray, and target_folder: String).
pub fn gen_export_flags(&mut self, flags: DebugFlags) -> PackedArray<GString>
pub fn gen_export_flags(&mut self, flags: DebugFlags) -> PackedArray<GString>
Generates array of command line arguments for the default export templates for the debug flags and editor settings.
pub fn export_project_files(
&mut self,
preset: impl AsArg<Option<Gd<EditorExportPreset>>>,
debug: bool,
save_cb: &Callable,
) -> Error
pub fn export_project_files( &mut self, preset: impl AsArg<Option<Gd<EditorExportPreset>>>, debug: bool, save_cb: &Callable, ) -> Error
To set the default parameters, use export_project_files_ex and its builder methods. See the book for detailed usage instructions.
Exports project files for the specified preset. This method can be used to implement custom export format, other than PCK and ZIP. One of the callbacks is called for each exported file.
save_cb is called for all exported files and have the following arguments: file_path: String, file_data: PackedByteArray, file_index: int, file_count: int, encryption_include_filters: PackedStringArray, encryption_exclude_filters: PackedStringArray, encryption_key: PackedByteArray.
shared_cb is called for exported native shared/static libraries and have the following arguments: file_path: String, tags: PackedStringArray, target_folder: String.
Note: file_index and file_count are intended for progress tracking only and aren’t necessarily unique and precise.
pub fn export_project_files_ex<'ex>(
&'ex mut self,
preset: impl AsArg<Option<Gd<EditorExportPreset>>> + 'ex,
debug: bool,
save_cb: &'ex Callable,
) -> ExExportProjectFiles<'ex>
pub fn export_project_files_ex<'ex>( &'ex mut self, preset: impl AsArg<Option<Gd<EditorExportPreset>>> + 'ex, debug: bool, save_cb: &'ex Callable, ) -> ExExportProjectFiles<'ex>
Exports project files for the specified preset. This method can be used to implement custom export format, other than PCK and ZIP. One of the callbacks is called for each exported file.
save_cb is called for all exported files and have the following arguments: file_path: String, file_data: PackedByteArray, file_index: int, file_count: int, encryption_include_filters: PackedStringArray, encryption_exclude_filters: PackedStringArray, encryption_key: PackedByteArray.
shared_cb is called for exported native shared/static libraries and have the following arguments: file_path: String, tags: PackedStringArray, target_folder: String.
Note: file_index and file_count are intended for progress tracking only and aren’t necessarily unique and precise.
pub fn export_project(
&mut self,
preset: impl AsArg<Option<Gd<EditorExportPreset>>>,
debug: bool,
path: impl AsArg<GString>,
) -> Error
pub fn export_project( &mut self, preset: impl AsArg<Option<Gd<EditorExportPreset>>>, debug: bool, path: impl AsArg<GString>, ) -> Error
To set the default parameters, use export_project_ex and its builder methods. See the book for detailed usage instructions.
Creates a full project at path for the specified preset.
pub fn export_project_ex<'ex>(
&'ex mut self,
preset: impl AsArg<Option<Gd<EditorExportPreset>>> + 'ex,
debug: bool,
path: impl AsArg<GString> + 'ex,
) -> ExExportProject<'ex>
pub fn export_project_ex<'ex>( &'ex mut self, preset: impl AsArg<Option<Gd<EditorExportPreset>>> + 'ex, debug: bool, path: impl AsArg<GString> + 'ex, ) -> ExExportProject<'ex>
Creates a full project at path for the specified preset.
pub fn export_pack(
&mut self,
preset: impl AsArg<Option<Gd<EditorExportPreset>>>,
debug: bool,
path: impl AsArg<GString>,
) -> Error
pub fn export_pack( &mut self, preset: impl AsArg<Option<Gd<EditorExportPreset>>>, debug: bool, path: impl AsArg<GString>, ) -> Error
To set the default parameters, use export_pack_ex and its builder methods. See the book for detailed usage instructions.
Creates a PCK archive at path for the specified preset.
pub fn export_pack_ex<'ex>(
&'ex mut self,
preset: impl AsArg<Option<Gd<EditorExportPreset>>> + 'ex,
debug: bool,
path: impl AsArg<GString> + 'ex,
) -> ExExportPack<'ex>
pub fn export_pack_ex<'ex>( &'ex mut self, preset: impl AsArg<Option<Gd<EditorExportPreset>>> + 'ex, debug: bool, path: impl AsArg<GString> + 'ex, ) -> ExExportPack<'ex>
Creates a PCK archive at path for the specified preset.
pub fn export_zip(
&mut self,
preset: impl AsArg<Option<Gd<EditorExportPreset>>>,
debug: bool,
path: impl AsArg<GString>,
) -> Error
pub fn export_zip( &mut self, preset: impl AsArg<Option<Gd<EditorExportPreset>>>, debug: bool, path: impl AsArg<GString>, ) -> Error
To set the default parameters, use export_zip_ex and its builder methods. See the book for detailed usage instructions.
Create a ZIP archive at path for the specified preset.
pub fn export_zip_ex<'ex>(
&'ex mut self,
preset: impl AsArg<Option<Gd<EditorExportPreset>>> + 'ex,
debug: bool,
path: impl AsArg<GString> + 'ex,
) -> ExExportZip<'ex>
pub fn export_zip_ex<'ex>( &'ex mut self, preset: impl AsArg<Option<Gd<EditorExportPreset>>> + 'ex, debug: bool, path: impl AsArg<GString> + 'ex, ) -> ExExportZip<'ex>
Create a ZIP archive at path for the specified preset.
pub fn export_pack_patch(
&mut self,
preset: impl AsArg<Option<Gd<EditorExportPreset>>>,
debug: bool,
path: impl AsArg<GString>,
) -> Error
pub fn export_pack_patch( &mut self, preset: impl AsArg<Option<Gd<EditorExportPreset>>>, debug: bool, path: impl AsArg<GString>, ) -> Error
To set the default parameters, use export_pack_patch_ex and its builder methods. See the book for detailed usage instructions.
Creates a patch PCK archive at path for the specified preset, containing only the files that have changed since the last patch.
Note: patches is an optional override of the set of patches defined in the export preset. When empty the patches defined in the export preset will be used instead.
pub fn export_pack_patch_ex<'ex>(
&'ex mut self,
preset: impl AsArg<Option<Gd<EditorExportPreset>>> + 'ex,
debug: bool,
path: impl AsArg<GString> + 'ex,
) -> ExExportPackPatch<'ex>
pub fn export_pack_patch_ex<'ex>( &'ex mut self, preset: impl AsArg<Option<Gd<EditorExportPreset>>> + 'ex, debug: bool, path: impl AsArg<GString> + 'ex, ) -> ExExportPackPatch<'ex>
Creates a patch PCK archive at path for the specified preset, containing only the files that have changed since the last patch.
Note: patches is an optional override of the set of patches defined in the export preset. When empty the patches defined in the export preset will be used instead.
pub fn export_zip_patch(
&mut self,
preset: impl AsArg<Option<Gd<EditorExportPreset>>>,
debug: bool,
path: impl AsArg<GString>,
) -> Error
pub fn export_zip_patch( &mut self, preset: impl AsArg<Option<Gd<EditorExportPreset>>>, debug: bool, path: impl AsArg<GString>, ) -> Error
To set the default parameters, use export_zip_patch_ex and its builder methods. See the book for detailed usage instructions.
Create a patch ZIP archive at path for the specified preset, containing only the files that have changed since the last patch.
Note: patches is an optional override of the set of patches defined in the export preset. When empty the patches defined in the export preset will be used instead.
pub fn export_zip_patch_ex<'ex>(
&'ex mut self,
preset: impl AsArg<Option<Gd<EditorExportPreset>>> + 'ex,
debug: bool,
path: impl AsArg<GString> + 'ex,
) -> ExExportZipPatch<'ex>
pub fn export_zip_patch_ex<'ex>( &'ex mut self, preset: impl AsArg<Option<Gd<EditorExportPreset>>> + 'ex, debug: bool, path: impl AsArg<GString> + 'ex, ) -> ExExportZipPatch<'ex>
Create a patch ZIP archive at path for the specified preset, containing only the files that have changed since the last patch.
Note: patches is an optional override of the set of patches defined in the export preset. When empty the patches defined in the export preset will be used instead.
pub fn clear_messages(&mut self)
pub fn clear_messages(&mut self)
Clears the export log.
pub fn add_message(
&mut self,
type_: ExportMessageType,
category: impl AsArg<GString>,
message: impl AsArg<GString>,
)
pub fn add_message( &mut self, type_: ExportMessageType, category: impl AsArg<GString>, message: impl AsArg<GString>, )
Adds a message to the export log that will be displayed when exporting ends.
pub fn get_message_count(&self) -> i32
pub fn get_message_count(&self) -> i32
Returns the number of messages in the export log.
pub fn get_message_type(&self, index: i32) -> ExportMessageType
pub fn get_message_type(&self, index: i32) -> ExportMessageType
Returns the type for the message with the given index.
pub fn get_message_category(&self, index: i32) -> GString
pub fn get_message_category(&self, index: i32) -> GString
Returns the message category for the message with the given index.
pub fn get_message_text(&self, index: i32) -> GString
pub fn get_message_text(&self, index: i32) -> GString
Returns the text for the message with the given index.
pub fn get_worst_message_type(&self) -> ExportMessageType
pub fn get_worst_message_type(&self) -> ExportMessageType
Returns most severe message type currently present in the export log.
pub fn ssh_run_on_remote(
&self,
host: impl AsArg<GString>,
port: impl AsArg<GString>,
ssh_arg: &PackedArray<GString>,
cmd_args: impl AsArg<GString>,
) -> Error
pub fn ssh_run_on_remote( &self, host: impl AsArg<GString>, port: impl AsArg<GString>, ssh_arg: &PackedArray<GString>, cmd_args: impl AsArg<GString>, ) -> Error
To set the default parameters, use ssh_run_on_remote_ex and its builder methods. See the book for detailed usage instructions.
Executes specified command on the remote host via SSH protocol and returns command output in the output.
pub fn ssh_run_on_remote_ex<'ex>(
&'ex self,
host: impl AsArg<GString> + 'ex,
port: impl AsArg<GString> + 'ex,
ssh_arg: &'ex PackedArray<GString>,
cmd_args: impl AsArg<GString> + 'ex,
) -> ExSshRunOnRemote<'ex>
pub fn ssh_run_on_remote_ex<'ex>( &'ex self, host: impl AsArg<GString> + 'ex, port: impl AsArg<GString> + 'ex, ssh_arg: &'ex PackedArray<GString>, cmd_args: impl AsArg<GString> + 'ex, ) -> ExSshRunOnRemote<'ex>
Executes specified command on the remote host via SSH protocol and returns command output in the output.
pub fn ssh_run_on_remote_no_wait(
&self,
host: impl AsArg<GString>,
port: impl AsArg<GString>,
ssh_args: &PackedArray<GString>,
cmd_args: impl AsArg<GString>,
) -> i64
pub fn ssh_run_on_remote_no_wait( &self, host: impl AsArg<GString>, port: impl AsArg<GString>, ssh_args: &PackedArray<GString>, cmd_args: impl AsArg<GString>, ) -> i64
To set the default parameters, use ssh_run_on_remote_no_wait_ex and its builder methods. See the book for detailed usage instructions.
Executes specified command on the remote host via SSH protocol and returns process ID (on the remote host) without waiting for command to finish.
pub fn ssh_run_on_remote_no_wait_ex<'ex>(
&'ex self,
host: impl AsArg<GString> + 'ex,
port: impl AsArg<GString> + 'ex,
ssh_args: &'ex PackedArray<GString>,
cmd_args: impl AsArg<GString> + 'ex,
) -> ExSshRunOnRemoteNoWait<'ex>
pub fn ssh_run_on_remote_no_wait_ex<'ex>( &'ex self, host: impl AsArg<GString> + 'ex, port: impl AsArg<GString> + 'ex, ssh_args: &'ex PackedArray<GString>, cmd_args: impl AsArg<GString> + 'ex, ) -> ExSshRunOnRemoteNoWait<'ex>
Executes specified command on the remote host via SSH protocol and returns process ID (on the remote host) without waiting for command to finish.
pub fn ssh_push_to_remote(
&self,
host: impl AsArg<GString>,
port: impl AsArg<GString>,
scp_args: &PackedArray<GString>,
src_file: impl AsArg<GString>,
dst_file: impl AsArg<GString>,
) -> Error
pub fn ssh_push_to_remote( &self, host: impl AsArg<GString>, port: impl AsArg<GString>, scp_args: &PackedArray<GString>, src_file: impl AsArg<GString>, dst_file: impl AsArg<GString>, ) -> Error
Uploads specified file over SCP protocol to the remote host.
pub fn get_internal_export_files(
&self,
preset: impl AsArg<Option<Gd<EditorExportPreset>>>,
debug: bool,
) -> Dictionary<Variant, Variant>
pub fn get_internal_export_files( &self, preset: impl AsArg<Option<Gd<EditorExportPreset>>>, debug: bool, ) -> Dictionary<Variant, Variant>
Returns additional files that should always be exported regardless of preset configuration, and are not part of the project source. The returned Dictionary contains filename keys (String) and their corresponding raw data (PackedByteArray).
Methods from Deref<Target = RefCounted>
pub fn get_reference_count(&self) -> i32
pub fn get_reference_count(&self) -> i32
Returns the current reference count.
Methods from Deref<Target = Object>
pub fn get_script(&self) -> Option<Gd<Script>>
pub fn set_script(&mut self, script: impl AsArg<Option<Gd<Script>>>)
pub fn connect( &mut self, signal: impl AsArg<StringName>, callable: &Callable, ) -> Error
pub fn connect_flags( &mut self, signal: impl AsArg<StringName>, callable: &Callable, flags: ConnectFlags, ) -> Error
pub fn is_class(&self, class: impl AsArg<GString>) -> bool
pub fn is_class(&self, class: impl AsArg<GString>) -> bool
Returns true if the object inherits from the given class. See also get_class.
var sprite2d = Sprite2D.new()
sprite2d.is_class("Sprite2D") # Returns true
sprite2d.is_class("Node") # Returns true
sprite2d.is_class("Node3D") # Returns falseNote: This method ignores class_name declarations in the object’s script.
pub fn set(&mut self, property: impl AsArg<StringName>, value: &Variant)
pub fn set(&mut self, property: impl AsArg<StringName>, value: &Variant)
Assigns value to the given property. If the property does not exist or the given value’s type doesn’t match, nothing happens.
var node = Node2D.new()
node.set("global_scale", Vector2(8, 2.5))
print(node.global_scale) # Prints (8.0, 2.5)Note: In C#, property must be in snake_case when referring to built-in Godot properties. Prefer using the names exposed in the PropertyName class to avoid allocating a new StringName on each call.
pub fn get(&self, property: impl AsArg<StringName>) -> Variant
pub fn get(&self, property: impl AsArg<StringName>) -> Variant
Returns the Variant value of the given property. If the property does not exist, this method returns null.
var node = Node2D.new()
node.rotation = 1.5
var a = node.get("rotation") # a is 1.5Note: In C#, property must be in snake_case when referring to built-in Godot properties. Prefer using the names exposed in the PropertyName class to avoid allocating a new StringName on each call.
pub fn set_indexed(
&mut self,
property_path: impl AsArg<NodePath>,
value: &Variant,
)
pub fn set_indexed( &mut self, property_path: impl AsArg<NodePath>, value: &Variant, )
Assigns a new value to the property identified by the property_path. The path should be a NodePath relative to this object, and can use the colon character (:) to access nested properties.
var node = Node2D.new()
node.set_indexed("position", Vector2(42, 0))
node.set_indexed("position:y", -10)
print(node.position) # Prints (42.0, -10.0)Note: In C#, property_path must be in snake_case when referring to built-in Godot properties. Prefer using the names exposed in the PropertyName class to avoid allocating a new StringName on each call.
pub fn get_indexed(&self, property_path: impl AsArg<NodePath>) -> Variant
pub fn get_indexed(&self, property_path: impl AsArg<NodePath>) -> Variant
Gets the object’s property indexed by the given property_path. The path should be a NodePath relative to the current object and can use the colon character (:) to access nested properties.
Examples: "position:x" or "material:next_pass:blend_mode".
var node = Node2D.new()
node.position = Vector2(5, -10)
var a = node.get_indexed("position") # a is Vector2(5, -10)
var b = node.get_indexed("position:y") # b is -10Note: In C#, property_path must be in snake_case when referring to built-in Godot properties. Prefer using the names exposed in the PropertyName class to avoid allocating a new StringName on each call.
Note: This method does not support actual paths to nodes in the SceneTree, only sub-property paths. In the context of nodes, use get_node_and_resource instead.
pub fn get_property_list(&self) -> Array<Dictionary<Variant, Variant>>
pub fn get_property_list(&self) -> Array<Dictionary<Variant, Variant>>
Returns the object’s property list as an Array of dictionaries. Each Dictionary contains the following entries:
-
nameis the property’s name, as aString; -
class_nameis an emptyStringName, unless the property isVariantType::OBJECTand it inherits from a class; -
typeis the property’s type, as anint(see [enum Variant.Type]); -
hintis how the property is meant to be edited (see [enum PropertyHint]); -
hint_stringdepends on the hint (see [enum PropertyHint]); -
usageis a combination of [enum PropertyUsageFlags].
Note: In GDScript, all class members are treated as properties. In C# and GDExtension, it may be necessary to explicitly mark class members as Godot properties using decorators or attributes.
pub fn get_method_list(&self) -> Array<Dictionary<Variant, Variant>>
pub fn get_method_list(&self) -> Array<Dictionary<Variant, Variant>>
Returns this object’s methods and their signatures as an Array of dictionaries. Each Dictionary contains the following entries:
-
nameis the name of the method, as aString; -
argsis anArrayof dictionaries representing the arguments; -
default_argsis the default arguments as anArrayof variants; -
flagsis a combination of [enum MethodFlags]; -
idis the method’s internal identifierint; -
returnis the returned value, as aDictionary;
Note: The dictionaries of args and return are formatted identically to the results of get_property_list, although not all entries are used.
pub fn property_can_revert(&self, property: impl AsArg<StringName>) -> bool
pub fn property_can_revert(&self, property: impl AsArg<StringName>) -> bool
Returns true if the given property has a custom default value. Use property_get_revert to get the property’s default value.
Note: This method is used by the Inspector dock to display a revert icon. The object must implement [method _property_can_revert] to customize the default value. If [method _property_can_revert] is not implemented, this method returns false.
pub fn property_get_revert(&self, property: impl AsArg<StringName>) -> Variant
pub fn property_get_revert(&self, property: impl AsArg<StringName>) -> Variant
Returns the custom default value of the given property. Use property_can_revert to check if the property has a custom default value.
Note: This method is used by the Inspector dock to display a revert icon. The object must implement [method _property_get_revert] to customize the default value. If [method _property_get_revert] is not implemented, this method returns null.
pub fn set_meta(&mut self, name: impl AsArg<StringName>, value: &Variant)
pub fn set_meta(&mut self, name: impl AsArg<StringName>, value: &Variant)
Adds or changes the entry name inside the object’s metadata. The metadata value can be any Variant, although some types cannot be serialized correctly.
If value is null, the entry is removed. This is the equivalent of using remove_meta. See also has_meta and get_meta.
Note: A metadata’s name must be a valid identifier as per is_valid_identifier method.
Note: Metadata that has a name starting with an underscore (_) is considered editor-only. Editor-only metadata is not displayed in the Inspector and should not be edited, although it can still be found by this method.
pub fn remove_meta(&mut self, name: impl AsArg<StringName>)
pub fn remove_meta(&mut self, name: impl AsArg<StringName>)
Removes the given entry name from the object’s metadata. See also has_meta, get_meta and set_meta.
Note: A metadata’s name must be a valid identifier as per is_valid_identifier method.
Note: Metadata that has a name starting with an underscore (_) is considered editor-only. Editor-only metadata is not displayed in the Inspector and should not be edited, although it can still be found by this method.
pub fn get_meta(&self, name: impl AsArg<StringName>) -> Variant
pub fn get_meta(&self, name: impl AsArg<StringName>) -> Variant
To set the default parameters, use get_meta_ex and its builder methods. See the book for detailed usage instructions.
Returns the object’s metadata value for the given entry name. If the entry does not exist, returns default. If default is null, an error is also generated.
Note: A metadata’s name must be a valid identifier as per is_valid_identifier method.
Note: Metadata that has a name starting with an underscore (_) is considered editor-only. Editor-only metadata is not displayed in the Inspector and should not be edited, although it can still be found by this method.
pub fn get_meta_ex<'ex>(
&'ex self,
name: impl AsArg<StringName> + 'ex,
) -> ExGetMeta<'ex>
pub fn get_meta_ex<'ex>( &'ex self, name: impl AsArg<StringName> + 'ex, ) -> ExGetMeta<'ex>
Returns the object’s metadata value for the given entry name. If the entry does not exist, returns default. If default is null, an error is also generated.
Note: A metadata’s name must be a valid identifier as per is_valid_identifier method.
Note: Metadata that has a name starting with an underscore (_) is considered editor-only. Editor-only metadata is not displayed in the Inspector and should not be edited, although it can still be found by this method.
pub fn has_meta(&self, name: impl AsArg<StringName>) -> bool
pub fn has_meta(&self, name: impl AsArg<StringName>) -> bool
Returns true if a metadata entry is found with the given name. See also get_meta, set_meta and remove_meta.
Note: A metadata’s name must be a valid identifier as per is_valid_identifier method.
Note: Metadata that has a name starting with an underscore (_) is considered editor-only. Editor-only metadata is not displayed in the Inspector and should not be edited, although it can still be found by this method.
pub fn get_meta_list(&self) -> Array<StringName>
pub fn get_meta_list(&self) -> Array<StringName>
Returns the object’s metadata entry names as an Array of StringNames.
pub fn add_user_signal(&mut self, signal: impl AsArg<GString>)
pub fn add_user_signal(&mut self, signal: impl AsArg<GString>)
To set the default parameters, use add_user_signal_ex and its builder methods. See the book for detailed usage instructions.
Adds a user-defined signal named signal. Optional arguments for the signal can be added as an Array of dictionaries, each defining a name String and a type int (see [enum Variant.Type]). See also has_user_signal and remove_user_signal.
add_user_signal("hurt", [
{ "name": "damage", "type": TYPE_INT },
{ "name": "source", "type": TYPE_OBJECT }
])pub fn add_user_signal_ex<'ex>(
&'ex mut self,
signal: impl AsArg<GString> + 'ex,
) -> ExAddUserSignal<'ex>
pub fn add_user_signal_ex<'ex>( &'ex mut self, signal: impl AsArg<GString> + 'ex, ) -> ExAddUserSignal<'ex>
Adds a user-defined signal named signal. Optional arguments for the signal can be added as an Array of dictionaries, each defining a name String and a type int (see [enum Variant.Type]). See also has_user_signal and remove_user_signal.
add_user_signal("hurt", [
{ "name": "damage", "type": TYPE_INT },
{ "name": "source", "type": TYPE_OBJECT }
])pub fn has_user_signal(&self, signal: impl AsArg<StringName>) -> bool
pub fn has_user_signal(&self, signal: impl AsArg<StringName>) -> bool
Returns true if the given user-defined signal name exists. Only signals added with add_user_signal are included. See also remove_user_signal.
pub fn remove_user_signal(&mut self, signal: impl AsArg<StringName>)
pub fn remove_user_signal(&mut self, signal: impl AsArg<StringName>)
Removes the given user signal signal from the object. See also add_user_signal and has_user_signal.
pub fn emit_signal(
&mut self,
signal: impl AsArg<StringName>,
varargs: &[Variant],
) -> Error
pub fn emit_signal( &mut self, signal: impl AsArg<StringName>, varargs: &[Variant], ) -> Error
Emits the given signal by name. The signal must exist, so it should be a built-in signal of this class or one of its inherited classes, or a user-defined signal (see add_user_signal). This method supports a variable number of arguments, so parameters can be passed as a comma separated list.
Returns Error::ERR_UNAVAILABLE if signal does not exist or the parameters are invalid.
emit_signal("hit", "sword", 100)
emit_signal("game_over")Note: In C#, signal must be in snake_case when referring to built-in Godot signals. Prefer using the names exposed in the SignalName class to avoid allocating a new StringName on each call.
Panics
This is a varcall method, meaning parameters and return values are passed as Variant.
It can detect call failures and will panic in such a case.
pub fn try_emit_signal(
&mut self,
signal: impl AsArg<StringName>,
varargs: &[Variant],
) -> Result<Error, CallError>
pub fn try_emit_signal( &mut self, signal: impl AsArg<StringName>, varargs: &[Variant], ) -> Result<Error, CallError>
Return type
This is a varcall method, meaning parameters and return values are passed as Variant.
It can detect call failures and will return Err in such a case.
pub fn call(
&mut self,
method: impl AsArg<StringName>,
varargs: &[Variant],
) -> Variant
pub fn call( &mut self, method: impl AsArg<StringName>, varargs: &[Variant], ) -> Variant
Calls the method on the object and returns the result. This method supports a variable number of arguments, so parameters can be passed as a comma separated list.
var node = Node3D.new()
node.call("rotate", Vector3(1.0, 0.0, 0.0), 1.571)Note: In C#, method must be in snake_case when referring to built-in Godot methods. Prefer using the names exposed in the MethodName class to avoid allocating a new StringName on each call.
Panics
This is a varcall method, meaning parameters and return values are passed as Variant.
It can detect call failures and will panic in such a case.
pub fn try_call(
&mut self,
method: impl AsArg<StringName>,
varargs: &[Variant],
) -> Result<Variant, CallError>
pub fn try_call( &mut self, method: impl AsArg<StringName>, varargs: &[Variant], ) -> Result<Variant, CallError>
Return type
This is a varcall method, meaning parameters and return values are passed as Variant.
It can detect call failures and will return Err in such a case.
pub fn call_deferred(
&mut self,
method: impl AsArg<StringName>,
varargs: &[Variant],
) -> Variant
pub fn call_deferred( &mut self, method: impl AsArg<StringName>, varargs: &[Variant], ) -> Variant
Calls the method on the object during idle time. Always returns null, not the method’s result.
Idle time happens mainly at the end of process and physics frames. In it, deferred calls will be run until there are none left, which means you can defer calls from other deferred calls and they’ll still be run in the current idle time cycle. This means you should not call a method deferred from itself (or from a method called by it), as this causes infinite recursion the same way as if you had called the method directly.
This method supports a variable number of arguments, so parameters can be passed as a comma separated list.
var node = Node3D.new()
node.call_deferred("rotate", Vector3(1.0, 0.0, 0.0), 1.571)For methods that are deferred from the same thread, the order of execution at idle time is identical to the order in which call_deferred was called.
See also call_deferred.
Note: In C#, method must be in snake_case when referring to built-in Godot methods. Prefer using the names exposed in the MethodName class to avoid allocating a new StringName on each call.
Note: If you’re looking to delay the function call by a frame, refer to the SceneTree.process_frame and SceneTree.physics_frame signals.
var node = Node3D.new()
# Make a Callable and bind the arguments to the node's rotate() call.
var callable = node.rotate.bind(Vector3(1.0, 0.0, 0.0), 1.571)
# Connect the callable to the process_frame signal, so it gets called in the next process frame.
# CONNECT_ONE_SHOT makes sure it only gets called once instead of every frame.
get_tree().process_frame.connect(callable, CONNECT_ONE_SHOT)Panics
This is a varcall method, meaning parameters and return values are passed as Variant.
It can detect call failures and will panic in such a case.
pub fn try_call_deferred(
&mut self,
method: impl AsArg<StringName>,
varargs: &[Variant],
) -> Result<Variant, CallError>
pub fn try_call_deferred( &mut self, method: impl AsArg<StringName>, varargs: &[Variant], ) -> Result<Variant, CallError>
Return type
This is a varcall method, meaning parameters and return values are passed as Variant.
It can detect call failures and will return Err in such a case.
pub fn set_deferred(
&mut self,
property: impl AsArg<StringName>,
value: &Variant,
)
pub fn set_deferred( &mut self, property: impl AsArg<StringName>, value: &Variant, )
Assigns value to the given property, at the end of the current frame. This is equivalent to calling set through call_deferred.
var node = Node2D.new()
add_child(node)
node.rotation = 1.5
node.set_deferred("rotation", 3.0)
print(node.rotation) # Prints 1.5
await get_tree().process_frame
print(node.rotation) # Prints 3.0Note: In C#, property must be in snake_case when referring to built-in Godot properties. Prefer using the names exposed in the PropertyName class to avoid allocating a new StringName on each call.
pub fn callv(
&mut self,
method: impl AsArg<StringName>,
arg_array: &AnyArray,
) -> Variant
pub fn callv( &mut self, method: impl AsArg<StringName>, arg_array: &AnyArray, ) -> Variant
Calls the method on the object and returns the result. Unlike call, this method expects all parameters to be contained inside arg_array.
var node = Node3D.new()
node.callv("rotate", [Vector3(1.0, 0.0, 0.0), 1.571])Note: In C#, method must be in snake_case when referring to built-in Godot methods. Prefer using the names exposed in the MethodName class to avoid allocating a new StringName on each call.
pub fn has_method(&self, method: impl AsArg<StringName>) -> bool
pub fn has_method(&self, method: impl AsArg<StringName>) -> bool
Returns true if the given method name exists in the object.
Note: In C#, method must be in snake_case when referring to built-in Godot methods. Prefer using the names exposed in the MethodName class to avoid allocating a new StringName on each call.
pub fn get_method_argument_count(&self, method: impl AsArg<StringName>) -> i32
pub fn get_method_argument_count(&self, method: impl AsArg<StringName>) -> i32
Returns the number of arguments of the given method by name.
Note: In C#, method must be in snake_case when referring to built-in Godot methods. Prefer using the names exposed in the MethodName class to avoid allocating a new StringName on each call.
pub fn has_signal(&self, signal: impl AsArg<StringName>) -> bool
pub fn has_signal(&self, signal: impl AsArg<StringName>) -> bool
Returns true if the given signal name exists in the object.
Note: In C#, signal must be in snake_case when referring to built-in Godot signals. Prefer using the names exposed in the SignalName class to avoid allocating a new StringName on each call.
pub fn get_signal_list(&self) -> Array<Dictionary<Variant, Variant>>
pub fn get_signal_list(&self) -> Array<Dictionary<Variant, Variant>>
Returns the list of existing signals as an Array of dictionaries.
Note: Due to the implementation, each Dictionary is formatted very similarly to the returned values of get_method_list.
pub fn get_signal_connection_list(
&self,
signal: impl AsArg<StringName>,
) -> Array<Dictionary<Variant, Variant>>
pub fn get_signal_connection_list( &self, signal: impl AsArg<StringName>, ) -> Array<Dictionary<Variant, Variant>>
Returns an Array of connections for the given signal name. Each connection is represented as a Dictionary that contains three entries:
pub fn get_incoming_connections(&self) -> Array<Dictionary<Variant, Variant>>
pub fn get_incoming_connections(&self) -> Array<Dictionary<Variant, Variant>>
Returns an Array of signal connections received by this object. Each connection is represented as a Dictionary that contains three entries:
pub fn disconnect(
&mut self,
signal: impl AsArg<StringName>,
callable: &Callable,
)
pub fn disconnect( &mut self, signal: impl AsArg<StringName>, callable: &Callable, )
Disconnects a signal by name from a given callable. If the connection does not exist, generates an error. Use is_connected to make sure that the connection exists.
pub fn is_connected(
&self,
signal: impl AsArg<StringName>,
callable: &Callable,
) -> bool
pub fn is_connected( &self, signal: impl AsArg<StringName>, callable: &Callable, ) -> bool
Returns true if a connection exists between the given signal name and callable.
Note: In C#, signal must be in snake_case when referring to built-in Godot signals. Prefer using the names exposed in the SignalName class to avoid allocating a new StringName on each call.
pub fn has_connections(&self, signal: impl AsArg<StringName>) -> bool
pub fn has_connections(&self, signal: impl AsArg<StringName>) -> bool
Returns true if any connection exists on the given signal name.
Note: In C#, signal must be in snake_case when referring to built-in Godot methods. Prefer using the names exposed in the SignalName class to avoid allocating a new StringName on each call.
pub fn set_block_signals(&mut self, enable: bool)
pub fn set_block_signals(&mut self, enable: bool)
If set to true, the object becomes unable to emit signals. As such, emit_signal and signal connections will not work, until it is set to false.
pub fn is_blocking_signals(&self) -> bool
pub fn is_blocking_signals(&self) -> bool
Returns true if the object is blocking its signals from being emitted. See set_block_signals.
pub fn notify_property_list_changed(&mut self)
pub fn notify_property_list_changed(&mut self)
Emits the property_list_changed signal. This is mainly used to refresh the editor, so that the Inspector and editor plugins are properly updated.
pub fn set_message_translation(&mut self, enable: bool)
pub fn set_message_translation(&mut self, enable: bool)
If set to true, allows the object to translate messages with tr and tr_n. Enabled by default. See also can_translate_messages.
pub fn can_translate_messages(&self) -> bool
pub fn can_translate_messages(&self) -> bool
Returns true if the object is allowed to translate messages with tr and tr_n. See also set_message_translation.
pub fn tr(&self, message: impl AsArg<StringName>) -> GString
pub fn tr(&self, message: impl AsArg<StringName>) -> GString
To set the default parameters, use tr_ex and its builder methods. See the book for detailed usage instructions.
Translates a message, using the translation catalogs configured in the Project Settings. Further context can be specified to help with the translation. Note that most Control nodes automatically translate their strings, so this method is mostly useful for formatted strings or custom drawn text.
If can_translate_messages is false, or no translation is available, this method returns the message without changes. See set_message_translation.
For detailed examples, see Internationalizing games.
Note: This method can’t be used without an Object instance, as it requires the can_translate_messages method. To translate strings in a static context, use translate.
pub fn tr_ex<'ex>(&'ex self, message: impl AsArg<StringName> + 'ex) -> ExTr<'ex>
pub fn tr_ex<'ex>(&'ex self, message: impl AsArg<StringName> + 'ex) -> ExTr<'ex>
Translates a message, using the translation catalogs configured in the Project Settings. Further context can be specified to help with the translation. Note that most Control nodes automatically translate their strings, so this method is mostly useful for formatted strings or custom drawn text.
If can_translate_messages is false, or no translation is available, this method returns the message without changes. See set_message_translation.
For detailed examples, see Internationalizing games.
Note: This method can’t be used without an Object instance, as it requires the can_translate_messages method. To translate strings in a static context, use translate.
pub fn tr_n(
&self,
message: impl AsArg<StringName>,
plural_message: impl AsArg<StringName>,
n: i32,
) -> GString
pub fn tr_n( &self, message: impl AsArg<StringName>, plural_message: impl AsArg<StringName>, n: i32, ) -> GString
To set the default parameters, use tr_n_ex and its builder methods. See the book for detailed usage instructions.
Translates a message or plural_message, using the translation catalogs configured in the Project Settings. Further context can be specified to help with the translation.
If can_translate_messages is false, or no translation is available, this method returns message or plural_message, without changes. See set_message_translation.
The n is the number, or amount, of the message’s subject. It is used by the translation system to fetch the correct plural form for the current language.
For detailed examples, see Localization using gettext.
Note: Negative and float numbers may not properly apply to some countable subjects. It’s recommended to handle these cases with tr.
Note: This method can’t be used without an Object instance, as it requires the can_translate_messages method. To translate strings in a static context, use translate_plural.
pub fn tr_n_ex<'ex>(
&'ex self,
message: impl AsArg<StringName> + 'ex,
plural_message: impl AsArg<StringName> + 'ex,
n: i32,
) -> ExTrN<'ex>
pub fn tr_n_ex<'ex>( &'ex self, message: impl AsArg<StringName> + 'ex, plural_message: impl AsArg<StringName> + 'ex, n: i32, ) -> ExTrN<'ex>
Translates a message or plural_message, using the translation catalogs configured in the Project Settings. Further context can be specified to help with the translation.
If can_translate_messages is false, or no translation is available, this method returns message or plural_message, without changes. See set_message_translation.
The n is the number, or amount, of the message’s subject. It is used by the translation system to fetch the correct plural form for the current language.
For detailed examples, see Localization using gettext.
Note: Negative and float numbers may not properly apply to some countable subjects. It’s recommended to handle these cases with tr.
Note: This method can’t be used without an Object instance, as it requires the can_translate_messages method. To translate strings in a static context, use translate_plural.
pub fn get_translation_domain(&self) -> StringName
pub fn get_translation_domain(&self) -> StringName
Returns the name of the translation domain used by tr and tr_n. See also TranslationServer.
pub fn set_translation_domain(&mut self, domain: impl AsArg<StringName>)
pub fn set_translation_domain(&mut self, domain: impl AsArg<StringName>)
Sets the name of the translation domain used by tr and tr_n. See also TranslationServer.
pub fn is_queued_for_deletion(&self) -> bool
pub fn is_queued_for_deletion(&self) -> bool
Returns true if the queue_free method was called for the object.
pub fn cancel_free(&mut self)
pub fn cancel_free(&mut self)
If this method is called during ObjectNotification::PREDELETE, this object will reject being freed and will remain allocated. This is mostly an internal function used for error handling to avoid the user from freeing objects when they are not intended to.
pub fn notify(&mut self, what: ObjectNotification)
pub fn notify(&mut self, what: ObjectNotification)
⚠️ Sends a Godot notification to all classes inherited by the object.
Triggers calls to on_notification(), and depending on the notification, also to Godot’s lifecycle callbacks such as ready().
Starts from the highest ancestor (the Object class) and goes down the hierarchy.
See also Godot docs for Object::notification().
Panics
If you call this method on a user-defined object while holding a GdRef or GdMut guard on the instance, you will encounter
a panic. The reason is that the receiving virtual method on_notification() acquires a GdMut lock dynamically, which must
be exclusive.
pub fn notify_reversed(&mut self, what: ObjectNotification)
pub fn notify_reversed(&mut self, what: ObjectNotification)
⚠️ Like Self::notify(), but starts at the most-derived class and goes up the hierarchy.
See docs of that method, including the panics.