NativeMenu

Struct NativeMenu 

pub struct NativeMenu { /* private fields */ }
Godot class NativeMenu.

Inherits Object.

Related symbols:

  • native_menu: sidecar module with related enum/flag types

See also Godot docs for NativeMenu.

Singleton

This class is a singleton. You can get the one instance using Singleton::singleton().

Final class

This class is final, meaning you cannot inherit from it, and it comes without I* interface trait. It is still possible that other Godot classes inherit from it, but that is limited to the engine itself.

Godot docs

NativeMenu handles low-level access to the OS native global menu bar and popup menus.

Note: This is low-level API, consider using MenuBar with [member MenuBar.prefer_global_menu] set to true, and PopupMenu with [member PopupMenu.prefer_native_menu] set to true.

To create a menu, use create_menu, add menu items using add_*_item methods. To remove a menu, use free_menu.

var menu

func _menu_callback(item_id):
	if item_id == "ITEM_CUT":
		cut()
	elif item_id == "ITEM_COPY":
		copy()
	elif item_id == "ITEM_PASTE":
		paste()

func _enter_tree():
	# Create new menu and add items:
	menu = NativeMenu.create_menu()
	NativeMenu.add_item(menu, "Cut", _menu_callback, Callable(), "ITEM_CUT")
	NativeMenu.add_item(menu, "Copy", _menu_callback, Callable(), "ITEM_COPY")
	NativeMenu.add_separator(menu)
	NativeMenu.add_item(menu, "Paste", _menu_callback, Callable(), "ITEM_PASTE")

func _on_button_pressed():
	# Show popup menu at mouse position:
	NativeMenu.popup(menu, DisplayServer.mouse_get_position())

func _exit_tree():
	# Remove menu when it's no longer needed:
	NativeMenu.free_menu(menu)

Implementations



impl NativeMenu

pub fn has_feature(&self, feature: Feature) -> bool

Returns true if the specified feature is supported by the current NativeMenu, false otherwise.

Note: This method is implemented on macOS and Windows.

pub fn has_system_menu(&self, menu_id: SystemMenus) -> bool

Returns true if a special system menu is supported.

Note: This method is implemented only on macOS.

pub fn get_system_menu(&self, menu_id: SystemMenus) -> Rid

Returns RID of a special system menu.

Note: This method is implemented only on macOS.

pub fn get_system_menu_name(&self, menu_id: SystemMenus) -> GString

Returns readable name of a special system menu.

Note: This method is implemented only on macOS.

pub fn get_system_menu_text(&self, menu_id: SystemMenus) -> GString

Returns the text of the system menu item.

Note: This method is implemented on macOS.

pub fn set_system_menu_text( &mut self, menu_id: SystemMenus, name: impl AsArg<GString>, )

Sets the text of the system menu item.

Note: This method is implemented on macOS.

pub fn create_menu(&mut self) -> Rid

Creates a new global menu object.

Note: This method is implemented on macOS and Windows.

pub fn has_menu(&self, rid: Rid) -> bool

Returns true if rid is valid global menu.

Note: This method is implemented on macOS and Windows.

pub fn free_menu(&mut self, rid: Rid)

Frees a global menu object created by this NativeMenu.

Note: This method is implemented on macOS and Windows.

pub fn get_size(&self, rid: Rid) -> Vector2

Returns global menu size.

Note: This method is implemented on macOS and Windows.

pub fn popup(&mut self, rid: Rid, position: Vector2i)

Shows the global menu at position in the screen coordinates.

Note: This method is implemented on macOS and Windows.

pub fn set_interface_direction(&mut self, rid: Rid, is_rtl: bool)

Sets the menu text layout direction from right-to-left if is_rtl is true.

Note: This method is implemented on macOS and Windows.

pub fn set_popup_open_callback(&mut self, rid: Rid, callback: &Callable)

Registers callable to emit after the menu is closed.

Note: This method is implemented only on macOS.

pub fn get_popup_open_callback(&self, rid: Rid) -> Callable

Returns global menu open callback.

Note: This method is implemented only on macOS.

pub fn set_popup_close_callback(&mut self, rid: Rid, callback: &Callable)

Registers callable to emit when the menu is about to show.

Note: The OS can simulate menu opening to track menu item changes and global shortcuts, in which case the corresponding close callback is not triggered. Use is_opened to check if the menu is currently opened.

Note: This method is implemented on macOS and Windows.

pub fn get_popup_close_callback(&self, rid: Rid) -> Callable

Returns global menu close callback.

Note: This method is implemented on macOS and Windows.

pub fn set_minimum_width(&mut self, rid: Rid, width: f32)

Sets the minimum width of the global menu.

Note: This method is implemented only on macOS.

pub fn get_minimum_width(&self, rid: Rid) -> f32

Returns global menu minimum width.

Note: This method is implemented only on macOS.

pub fn is_opened(&self, rid: Rid) -> bool

Returns true if the menu is currently opened.

Note: This method is implemented only on macOS.

pub fn add_submenu_item( &mut self, rid: Rid, label: impl AsArg<GString>, submenu_rid: Rid, ) -> i32

To set the default parameters, use add_submenu_item_ex and its builder methods. See the book for detailed usage instructions. Adds an item that will act as a submenu of the global menu rid. The submenu_rid argument is the RID of the global menu that will be shown when the item is clicked.

Returns index of the inserted item, it’s not guaranteed to be the same as index value.

Note: This method is implemented on macOS and Windows.

pub fn add_submenu_item_ex<'ex>( &'ex mut self, rid: Rid, label: impl AsArg<GString> + 'ex, submenu_rid: Rid, ) -> ExAddSubmenuItem<'ex>

Adds an item that will act as a submenu of the global menu rid. The submenu_rid argument is the RID of the global menu that will be shown when the item is clicked.

Returns index of the inserted item, it’s not guaranteed to be the same as index value.

Note: This method is implemented on macOS and Windows.

pub fn add_item(&mut self, rid: Rid, label: impl AsArg<GString>) -> i32

To set the default parameters, use add_item_ex and its builder methods. See the book for detailed usage instructions. Adds a new item with text label to the global menu rid.

Returns index of the inserted item, it’s not guaranteed to be the same as index value.

An accelerator can optionally be defined, which is a keyboard shortcut that can be pressed to trigger the menu button even if it’s not currently open. The accelerator is generally a combination of [enum KeyModifierMask]s and [enum Key]s using bitwise OR such as KEY_MASK_CTRL | KEY_A (Ctrl + A).

Note: The callback and key_callback Callables need to accept exactly one Variant parameter, the parameter passed to the Callables will be the value passed to tag.

Note: This method is implemented on macOS and Windows.

Note: On Windows, accelerator and key_callback are ignored.

pub fn add_item_ex<'ex>( &'ex mut self, rid: Rid, label: impl AsArg<GString> + 'ex, ) -> ExAddItem<'ex>

Adds a new item with text label to the global menu rid.

Returns index of the inserted item, it’s not guaranteed to be the same as index value.

An accelerator can optionally be defined, which is a keyboard shortcut that can be pressed to trigger the menu button even if it’s not currently open. The accelerator is generally a combination of [enum KeyModifierMask]s and [enum Key]s using bitwise OR such as KEY_MASK_CTRL | KEY_A (Ctrl + A).

Note: The callback and key_callback Callables need to accept exactly one Variant parameter, the parameter passed to the Callables will be the value passed to tag.

Note: This method is implemented on macOS and Windows.

Note: On Windows, accelerator and key_callback are ignored.

pub fn add_check_item(&mut self, rid: Rid, label: impl AsArg<GString>) -> i32

To set the default parameters, use add_check_item_ex and its builder methods. See the book for detailed usage instructions. Adds a new checkable item with text label to the global menu rid.

Returns index of the inserted item, it’s not guaranteed to be the same as index value.

An accelerator can optionally be defined, which is a keyboard shortcut that can be pressed to trigger the menu button even if it’s not currently open. The accelerator is generally a combination of [enum KeyModifierMask]s and [enum Key]s using bitwise OR such as KEY_MASK_CTRL | KEY_A (Ctrl + A).

Note: The callback and key_callback Callables need to accept exactly one Variant parameter, the parameter passed to the Callables will be the value passed to tag.

Note: This method is implemented on macOS and Windows.

Note: On Windows, accelerator and key_callback are ignored.

pub fn add_check_item_ex<'ex>( &'ex mut self, rid: Rid, label: impl AsArg<GString> + 'ex, ) -> ExAddCheckItem<'ex>

Adds a new checkable item with text label to the global menu rid.

Returns index of the inserted item, it’s not guaranteed to be the same as index value.

An accelerator can optionally be defined, which is a keyboard shortcut that can be pressed to trigger the menu button even if it’s not currently open. The accelerator is generally a combination of [enum KeyModifierMask]s and [enum Key]s using bitwise OR such as KEY_MASK_CTRL | KEY_A (Ctrl + A).

Note: The callback and key_callback Callables need to accept exactly one Variant parameter, the parameter passed to the Callables will be the value passed to tag.

Note: This method is implemented on macOS and Windows.

Note: On Windows, accelerator and key_callback are ignored.

pub fn add_icon_item( &mut self, rid: Rid, icon: impl AsArg<Option<Gd<Texture2D>>>, label: impl AsArg<GString>, ) -> i32

To set the default parameters, use add_icon_item_ex and its builder methods. See the book for detailed usage instructions. Adds a new item with text label and icon icon to the global menu rid.

Returns index of the inserted item, it’s not guaranteed to be the same as index value.

An accelerator can optionally be defined, which is a keyboard shortcut that can be pressed to trigger the menu button even if it’s not currently open. The accelerator is generally a combination of [enum KeyModifierMask]s and [enum Key]s using bitwise OR such as KEY_MASK_CTRL | KEY_A (Ctrl + A).

Note: The callback and key_callback Callables need to accept exactly one Variant parameter, the parameter passed to the Callables will be the value passed to tag.

Note: This method is implemented on macOS and Windows.

Note: On Windows, accelerator and key_callback are ignored.

pub fn add_icon_item_ex<'ex>( &'ex mut self, rid: Rid, icon: impl AsArg<Option<Gd<Texture2D>>> + 'ex, label: impl AsArg<GString> + 'ex, ) -> ExAddIconItem<'ex>

Adds a new item with text label and icon icon to the global menu rid.

Returns index of the inserted item, it’s not guaranteed to be the same as index value.

An accelerator can optionally be defined, which is a keyboard shortcut that can be pressed to trigger the menu button even if it’s not currently open. The accelerator is generally a combination of [enum KeyModifierMask]s and [enum Key]s using bitwise OR such as KEY_MASK_CTRL | KEY_A (Ctrl + A).

Note: The callback and key_callback Callables need to accept exactly one Variant parameter, the parameter passed to the Callables will be the value passed to tag.

Note: This method is implemented on macOS and Windows.

Note: On Windows, accelerator and key_callback are ignored.

pub fn add_icon_check_item( &mut self, rid: Rid, icon: impl AsArg<Option<Gd<Texture2D>>>, label: impl AsArg<GString>, ) -> i32

To set the default parameters, use add_icon_check_item_ex and its builder methods. See the book for detailed usage instructions. Adds a new checkable item with text label and icon icon to the global menu rid.

Returns index of the inserted item, it’s not guaranteed to be the same as index value.

An accelerator can optionally be defined, which is a keyboard shortcut that can be pressed to trigger the menu button even if it’s not currently open. The accelerator is generally a combination of [enum KeyModifierMask]s and [enum Key]s using bitwise OR such as KEY_MASK_CTRL | KEY_A (Ctrl + A).

Note: The callback and key_callback Callables need to accept exactly one Variant parameter, the parameter passed to the Callables will be the value passed to tag.

Note: This method is implemented on macOS and Windows.

Note: On Windows, accelerator and key_callback are ignored.

pub fn add_icon_check_item_ex<'ex>( &'ex mut self, rid: Rid, icon: impl AsArg<Option<Gd<Texture2D>>> + 'ex, label: impl AsArg<GString> + 'ex, ) -> ExAddIconCheckItem<'ex>

Adds a new checkable item with text label and icon icon to the global menu rid.

Returns index of the inserted item, it’s not guaranteed to be the same as index value.

An accelerator can optionally be defined, which is a keyboard shortcut that can be pressed to trigger the menu button even if it’s not currently open. The accelerator is generally a combination of [enum KeyModifierMask]s and [enum Key]s using bitwise OR such as KEY_MASK_CTRL | KEY_A (Ctrl + A).

Note: The callback and key_callback Callables need to accept exactly one Variant parameter, the parameter passed to the Callables will be the value passed to tag.

Note: This method is implemented on macOS and Windows.

Note: On Windows, accelerator and key_callback are ignored.

pub fn add_radio_check_item( &mut self, rid: Rid, label: impl AsArg<GString>, ) -> i32

To set the default parameters, use add_radio_check_item_ex and its builder methods. See the book for detailed usage instructions. Adds a new radio-checkable item with text label to the global menu rid.

Returns index of the inserted item, it’s not guaranteed to be the same as index value.

An accelerator can optionally be defined, which is a keyboard shortcut that can be pressed to trigger the menu button even if it’s not currently open. The accelerator is generally a combination of [enum KeyModifierMask]s and [enum Key]s using bitwise OR such as KEY_MASK_CTRL | KEY_A (Ctrl + A).

Note: Radio-checkable items just display a checkmark, but don’t have any built-in checking behavior and must be checked/unchecked manually. See set_item_checked for more info on how to control it.

Note: The callback and key_callback Callables need to accept exactly one Variant parameter, the parameter passed to the Callables will be the value passed to tag.

Note: This method is implemented on macOS and Windows.

Note: On Windows, accelerator and key_callback are ignored.

pub fn add_radio_check_item_ex<'ex>( &'ex mut self, rid: Rid, label: impl AsArg<GString> + 'ex, ) -> ExAddRadioCheckItem<'ex>

Adds a new radio-checkable item with text label to the global menu rid.

Returns index of the inserted item, it’s not guaranteed to be the same as index value.

An accelerator can optionally be defined, which is a keyboard shortcut that can be pressed to trigger the menu button even if it’s not currently open. The accelerator is generally a combination of [enum KeyModifierMask]s and [enum Key]s using bitwise OR such as KEY_MASK_CTRL | KEY_A (Ctrl + A).

Note: Radio-checkable items just display a checkmark, but don’t have any built-in checking behavior and must be checked/unchecked manually. See set_item_checked for more info on how to control it.

Note: The callback and key_callback Callables need to accept exactly one Variant parameter, the parameter passed to the Callables will be the value passed to tag.

Note: This method is implemented on macOS and Windows.

Note: On Windows, accelerator and key_callback are ignored.

pub fn add_icon_radio_check_item( &mut self, rid: Rid, icon: impl AsArg<Option<Gd<Texture2D>>>, label: impl AsArg<GString>, ) -> i32

To set the default parameters, use add_icon_radio_check_item_ex and its builder methods. See the book for detailed usage instructions. Adds a new radio-checkable item with text label and icon icon to the global menu rid.

Returns index of the inserted item, it’s not guaranteed to be the same as index value.

An accelerator can optionally be defined, which is a keyboard shortcut that can be pressed to trigger the menu button even if it’s not currently open. The accelerator is generally a combination of [enum KeyModifierMask]s and [enum Key]s using bitwise OR such as KEY_MASK_CTRL | KEY_A (Ctrl + A).

Note: Radio-checkable items just display a checkmark, but don’t have any built-in checking behavior and must be checked/unchecked manually. See set_item_checked for more info on how to control it.

Note: The callback and key_callback Callables need to accept exactly one Variant parameter, the parameter passed to the Callables will be the value passed to tag.

Note: This method is implemented on macOS and Windows.

Note: On Windows, accelerator and key_callback are ignored.

pub fn add_icon_radio_check_item_ex<'ex>( &'ex mut self, rid: Rid, icon: impl AsArg<Option<Gd<Texture2D>>> + 'ex, label: impl AsArg<GString> + 'ex, ) -> ExAddIconRadioCheckItem<'ex>

Adds a new radio-checkable item with text label and icon icon to the global menu rid.

Returns index of the inserted item, it’s not guaranteed to be the same as index value.

An accelerator can optionally be defined, which is a keyboard shortcut that can be pressed to trigger the menu button even if it’s not currently open. The accelerator is generally a combination of [enum KeyModifierMask]s and [enum Key]s using bitwise OR such as KEY_MASK_CTRL | KEY_A (Ctrl + A).

Note: Radio-checkable items just display a checkmark, but don’t have any built-in checking behavior and must be checked/unchecked manually. See set_item_checked for more info on how to control it.

Note: The callback and key_callback Callables need to accept exactly one Variant parameter, the parameter passed to the Callables will be the value passed to tag.

Note: This method is implemented on macOS and Windows.

Note: On Windows, accelerator and key_callback are ignored.

pub fn add_multistate_item( &mut self, rid: Rid, label: impl AsArg<GString>, max_states: i32, default_state: i32, ) -> i32

To set the default parameters, use add_multistate_item_ex and its builder methods. See the book for detailed usage instructions. Adds a new item with text label to the global menu rid.

Contrarily to normal binary items, multistate items can have more than two states, as defined by max_states. Each press or activate of the item will increase the state by one. The default value is defined by default_state.

Returns index of the inserted item, it’s not guaranteed to be the same as index value.

An accelerator can optionally be defined, which is a keyboard shortcut that can be pressed to trigger the menu button even if it’s not currently open. The accelerator is generally a combination of [enum KeyModifierMask]s and [enum Key]s using bitwise OR such as KEY_MASK_CTRL | KEY_A (Ctrl + A).

Note: By default, there’s no indication of the current item state, it should be changed manually.

Note: The callback and key_callback Callables need to accept exactly one Variant parameter, the parameter passed to the Callables will be the value passed to tag.

Note: This method is implemented on macOS and Windows.

Note: On Windows, accelerator and key_callback are ignored.

pub fn add_multistate_item_ex<'ex>( &'ex mut self, rid: Rid, label: impl AsArg<GString> + 'ex, max_states: i32, default_state: i32, ) -> ExAddMultistateItem<'ex>

Adds a new item with text label to the global menu rid.

Contrarily to normal binary items, multistate items can have more than two states, as defined by max_states. Each press or activate of the item will increase the state by one. The default value is defined by default_state.

Returns index of the inserted item, it’s not guaranteed to be the same as index value.

An accelerator can optionally be defined, which is a keyboard shortcut that can be pressed to trigger the menu button even if it’s not currently open. The accelerator is generally a combination of [enum KeyModifierMask]s and [enum Key]s using bitwise OR such as KEY_MASK_CTRL | KEY_A (Ctrl + A).

Note: By default, there’s no indication of the current item state, it should be changed manually.

Note: The callback and key_callback Callables need to accept exactly one Variant parameter, the parameter passed to the Callables will be the value passed to tag.

Note: This method is implemented on macOS and Windows.

Note: On Windows, accelerator and key_callback are ignored.

pub fn add_separator(&mut self, rid: Rid) -> i32

To set the default parameters, use add_separator_ex and its builder methods. See the book for detailed usage instructions. Adds a separator between items to the global menu rid. Separators also occupy an index.

Returns index of the inserted item, it’s not guaranteed to be the same as index value.

Note: This method is implemented on macOS and Windows.

pub fn add_separator_ex<'ex>(&'ex mut self, rid: Rid) -> ExAddSeparator<'ex>

Adds a separator between items to the global menu rid. Separators also occupy an index.

Returns index of the inserted item, it’s not guaranteed to be the same as index value.

Note: This method is implemented on macOS and Windows.

pub fn find_item_index_with_text( &self, rid: Rid, text: impl AsArg<GString>, ) -> i32

Returns the index of the item with the specified text. Indices are automatically assigned to each item by the engine, and cannot be set manually.

Note: This method is implemented on macOS and Windows.

pub fn find_item_index_with_tag(&self, rid: Rid, tag: &Variant) -> i32

Returns the index of the item with the specified tag. Indices are automatically assigned to each item by the engine, and cannot be set manually.

Note: This method is implemented on macOS and Windows.

pub fn find_item_index_with_submenu(&self, rid: Rid, submenu_rid: Rid) -> i32

Returns the index of the item with the submenu specified by submenu_rid. Indices are automatically assigned to each item by the engine, and cannot be set manually.

Note: This method is implemented on macOS and Windows.

pub fn is_item_checked(&self, rid: Rid, idx: i32) -> bool

Returns true if the item at index idx is checked.

Note: This method is implemented on macOS and Windows.

pub fn is_item_checkable(&self, rid: Rid, idx: i32) -> bool

Returns true if the item at index idx is checkable in some way, i.e. if it has a checkbox or radio button.

Note: This method is implemented on macOS and Windows.

pub fn is_item_radio_checkable(&self, rid: Rid, idx: i32) -> bool

Returns true if the item at index idx has radio button-style checkability.

Note: This is purely cosmetic; you must add the logic for checking/unchecking items in radio groups.

Note: This method is implemented on macOS and Windows.

pub fn get_item_callback(&self, rid: Rid, idx: i32) -> Callable

Returns the callback of the item at index idx.

Note: This method is implemented on macOS and Windows.

pub fn get_item_key_callback(&self, rid: Rid, idx: i32) -> Callable

Returns the callback of the item accelerator at index idx.

Note: This method is implemented only on macOS.

pub fn get_item_tag(&self, rid: Rid, idx: i32) -> Variant

Returns the metadata of the specified item, which might be of any type. You can set it with set_item_tag, which provides a simple way of assigning context data to items.

Note: This method is implemented on macOS and Windows.

pub fn get_item_text(&self, rid: Rid, idx: i32) -> GString

Returns the text of the item at index idx.

Note: This method is implemented on macOS and Windows.

pub fn get_item_submenu(&self, rid: Rid, idx: i32) -> Rid

Returns the submenu ID of the item at index idx. See add_submenu_item for more info on how to add a submenu.

Note: This method is implemented on macOS and Windows.

pub fn get_item_accelerator(&self, rid: Rid, idx: i32) -> Key

Returns the accelerator of the item at index idx. Accelerators are special combinations of keys that activate the item, no matter which control is focused.

Note: This method is implemented only on macOS.

pub fn is_item_disabled(&self, rid: Rid, idx: i32) -> bool

Returns true if the item at index idx is disabled. When it is disabled it can’t be selected, or its action invoked.

See set_item_disabled for more info on how to disable an item.

Note: This method is implemented on macOS and Windows.

pub fn is_item_hidden(&self, rid: Rid, idx: i32) -> bool

Returns true if the item at index idx is hidden.

See set_item_hidden for more info on how to hide an item.

Note: This method is implemented only on macOS.

pub fn get_item_tooltip(&self, rid: Rid, idx: i32) -> GString

Returns the tooltip associated with the specified index idx.

Note: This method is implemented only on macOS.

pub fn get_item_state(&self, rid: Rid, idx: i32) -> i32

Returns the state of a multistate item. See add_multistate_item for details.

Note: This method is implemented on macOS and Windows.

pub fn get_item_max_states(&self, rid: Rid, idx: i32) -> i32

Returns number of states of a multistate item. See add_multistate_item for details.

Note: This method is implemented on macOS and Windows.

pub fn get_item_icon(&self, rid: Rid, idx: i32) -> Option<Gd<Texture2D>>

Returns the icon of the item at index idx.

Note: This method is implemented on macOS and Windows.

pub fn get_item_indentation_level(&self, rid: Rid, idx: i32) -> i32

Returns the horizontal offset of the item at the given idx.

Note: This method is implemented only on macOS.

pub fn set_item_checked(&mut self, rid: Rid, idx: i32, checked: bool)

Sets the checkstate status of the item at index idx.

Note: This method is implemented on macOS and Windows.

pub fn set_item_checkable(&mut self, rid: Rid, idx: i32, checkable: bool)

Sets whether the item at index idx has a checkbox. If false, sets the type of the item to plain text.

Note: This method is implemented on macOS and Windows.

pub fn set_item_radio_checkable(&mut self, rid: Rid, idx: i32, checkable: bool)

Sets the type of the item at the specified index idx to radio button. If false, sets the type of the item to plain text.

Note: This is purely cosmetic; you must add the logic for checking/unchecking items in radio groups.

Note: This method is implemented on macOS and Windows.

pub fn set_item_callback(&mut self, rid: Rid, idx: i32, callback: &Callable)

Sets the callback of the item at index idx. Callback is emitted when an item is pressed.

Note: The callback Callable needs to accept exactly one Variant parameter, the parameter passed to the Callable will be the value passed to the tag parameter when the menu item was created.

Note: This method is implemented on macOS and Windows.

pub fn set_item_hover_callbacks( &mut self, rid: Rid, idx: i32, callback: &Callable, )

Sets the callback of the item at index idx. The callback is emitted when an item is hovered.

Note: The callback Callable needs to accept exactly one Variant parameter, the parameter passed to the Callable will be the value passed to the tag parameter when the menu item was created.

Note: This method is implemented only on macOS.

pub fn set_item_key_callback( &mut self, rid: Rid, idx: i32, key_callback: &Callable, )

Sets the callback of the item at index idx. Callback is emitted when its accelerator is activated.

Note: The key_callback Callable needs to accept exactly one Variant parameter, the parameter passed to the Callable will be the value passed to the tag parameter when the menu item was created.

Note: This method is implemented only on macOS.

pub fn set_item_tag(&mut self, rid: Rid, idx: i32, tag: &Variant)

Sets the metadata of an item, which may be of any type. You can later get it with get_item_tag, which provides a simple way of assigning context data to items.

Note: This method is implemented on macOS and Windows.

pub fn set_item_text(&mut self, rid: Rid, idx: i32, text: impl AsArg<GString>)

Sets the text of the item at index idx.

Note: This method is implemented on macOS and Windows.

pub fn set_item_submenu(&mut self, rid: Rid, idx: i32, submenu_rid: Rid)

Sets the submenu RID of the item at index idx. The submenu is a global menu that would be shown when the item is clicked.

Note: This method is implemented on macOS and Windows.

pub fn set_item_accelerator(&mut self, rid: Rid, idx: i32, keycode: Key)

Sets the accelerator of the item at index idx. keycode can be a single [enum Key], or a combination of [enum KeyModifierMask]s and [enum Key]s using bitwise OR such as KEY_MASK_CTRL | KEY_A (Ctrl + A).

Note: This method is implemented only on macOS.

pub fn set_item_disabled(&mut self, rid: Rid, idx: i32, disabled: bool)

Enables/disables the item at index idx. When it is disabled, it can’t be selected and its action can’t be invoked.

Note: This method is implemented on macOS and Windows.

pub fn set_item_hidden(&mut self, rid: Rid, idx: i32, hidden: bool)

Hides/shows the item at index idx. When it is hidden, an item does not appear in a menu and its action cannot be invoked.

Note: This method is implemented only on macOS.

pub fn set_item_tooltip( &mut self, rid: Rid, idx: i32, tooltip: impl AsArg<GString>, )

Sets the String tooltip of the item at the specified index idx.

Note: This method is implemented only on macOS.

pub fn set_item_state(&mut self, rid: Rid, idx: i32, state: i32)

Sets the state of a multistate item. See add_multistate_item for details.

Note: This method is implemented on macOS and Windows.

pub fn set_item_max_states(&mut self, rid: Rid, idx: i32, max_states: i32)

Sets number of state of a multistate item. See add_multistate_item for details.

Note: This method is implemented on macOS and Windows.

pub fn set_item_icon( &mut self, rid: Rid, idx: i32, icon: impl AsArg<Option<Gd<Texture2D>>>, )

Replaces the Texture2D icon of the specified idx.

Note: This method is implemented on macOS and Windows.

Note: This method is not supported by macOS Dock menu items.

pub fn set_item_indentation_level(&mut self, rid: Rid, idx: i32, level: i32)

Sets the horizontal offset of the item at the given idx.

Note: This method is implemented only on macOS.

pub fn get_item_count(&self, rid: Rid) -> i32

Returns number of items in the global menu rid.

Note: This method is implemented on macOS and Windows.

pub fn is_system_menu(&self, rid: Rid) -> bool

Return true is global menu is a special system menu.

Note: This method is implemented only on macOS.

pub fn remove_item(&mut self, rid: Rid, idx: i32)

Removes the item at index idx from the global menu rid.

Note: The indices of items after the removed item will be shifted by one.

Note: This method is implemented on macOS and Windows.

pub fn clear(&mut self, rid: Rid)

Removes all items from the global menu rid.

Note: This method is implemented on macOS and Windows.

Methods from Deref<Target = Object>

pub fn get_script(&self) -> Option<Gd<Script>>

pub fn set_script(&mut self, script: impl AsArg<Option<Gd<Script>>>)

pub fn connect( &mut self, signal: impl AsArg<StringName>, callable: &Callable, ) -> Error

pub fn connect_flags( &mut self, signal: impl AsArg<StringName>, callable: &Callable, flags: ConnectFlags, ) -> Error

pub fn get_class(&self) -> GString

Returns the object’s built-in class name, as a String. See also is_class.

Note: This method ignores class_name declarations. If this object’s script has defined a class_name, the base, built-in class name is returned instead.

pub fn is_class(&self, class: impl AsArg<GString>) -> bool

Returns true if the object inherits from the given class. See also get_class.

var sprite2d = Sprite2D.new()
sprite2d.is_class("Sprite2D") # Returns true
sprite2d.is_class("Node")     # Returns true
sprite2d.is_class("Node3D")   # Returns false

Note: This method ignores class_name declarations in the object’s script.

pub fn set(&mut self, property: impl AsArg<StringName>, value: &Variant)

Assigns value to the given property. If the property does not exist or the given value’s type doesn’t match, nothing happens.

var node = Node2D.new()
node.set("global_scale", Vector2(8, 2.5))
print(node.global_scale) # Prints (8.0, 2.5)

Note: In C#, property must be in snake_case when referring to built-in Godot properties. Prefer using the names exposed in the PropertyName class to avoid allocating a new StringName on each call.

pub fn get(&self, property: impl AsArg<StringName>) -> Variant

Returns the Variant value of the given property. If the property does not exist, this method returns null.

var node = Node2D.new()
node.rotation = 1.5
var a = node.get("rotation") # a is 1.5

Note: In C#, property must be in snake_case when referring to built-in Godot properties. Prefer using the names exposed in the PropertyName class to avoid allocating a new StringName on each call.

pub fn set_indexed( &mut self, property_path: impl AsArg<NodePath>, value: &Variant, )

Assigns a new value to the property identified by the property_path. The path should be a NodePath relative to this object, and can use the colon character (:) to access nested properties.

var node = Node2D.new()
node.set_indexed("position", Vector2(42, 0))
node.set_indexed("position:y", -10)
print(node.position) # Prints (42.0, -10.0)

Note: In C#, property_path must be in snake_case when referring to built-in Godot properties. Prefer using the names exposed in the PropertyName class to avoid allocating a new StringName on each call.

pub fn get_indexed(&self, property_path: impl AsArg<NodePath>) -> Variant

Gets the object’s property indexed by the given property_path. The path should be a NodePath relative to the current object and can use the colon character (:) to access nested properties.

Examples: "position:x" or "material:next_pass:blend_mode".

var node = Node2D.new()
node.position = Vector2(5, -10)
var a = node.get_indexed("position")   # a is Vector2(5, -10)
var b = node.get_indexed("position:y") # b is -10

Note: In C#, property_path must be in snake_case when referring to built-in Godot properties. Prefer using the names exposed in the PropertyName class to avoid allocating a new StringName on each call.

Note: This method does not support actual paths to nodes in the SceneTree, only sub-property paths. In the context of nodes, use get_node_and_resource instead.

pub fn get_property_list(&self) -> Array<Dictionary<Variant, Variant>>

Returns the object’s property list as an Array of dictionaries. Each Dictionary contains the following entries:

  • name is the property’s name, as a String;

  • class_name is an empty StringName, unless the property is VariantType::OBJECT and it inherits from a class;

  • type is the property’s type, as an int (see [enum Variant.Type]);

  • hint is how the property is meant to be edited (see [enum PropertyHint]);

  • hint_string depends on the hint (see [enum PropertyHint]);

  • usage is a combination of [enum PropertyUsageFlags].

Note: In GDScript, all class members are treated as properties. In C# and GDExtension, it may be necessary to explicitly mark class members as Godot properties using decorators or attributes.

pub fn get_method_list(&self) -> Array<Dictionary<Variant, Variant>>

Returns this object’s methods and their signatures as an Array of dictionaries. Each Dictionary contains the following entries:

  • name is the name of the method, as a String;

  • args is an Array of dictionaries representing the arguments;

  • default_args is the default arguments as an Array of variants;

  • flags is a combination of [enum MethodFlags];

  • id is the method’s internal identifier int;

  • return is the returned value, as a Dictionary;

Note: The dictionaries of args and return are formatted identically to the results of get_property_list, although not all entries are used.

pub fn property_can_revert(&self, property: impl AsArg<StringName>) -> bool

Returns true if the given property has a custom default value. Use property_get_revert to get the property’s default value.

Note: This method is used by the Inspector dock to display a revert icon. The object must implement [method _property_can_revert] to customize the default value. If [method _property_can_revert] is not implemented, this method returns false.

pub fn property_get_revert(&self, property: impl AsArg<StringName>) -> Variant

Returns the custom default value of the given property. Use property_can_revert to check if the property has a custom default value.

Note: This method is used by the Inspector dock to display a revert icon. The object must implement [method _property_get_revert] to customize the default value. If [method _property_get_revert] is not implemented, this method returns null.

pub fn set_meta(&mut self, name: impl AsArg<StringName>, value: &Variant)

Adds or changes the entry name inside the object’s metadata. The metadata value can be any Variant, although some types cannot be serialized correctly.

If value is null, the entry is removed. This is the equivalent of using remove_meta. See also has_meta and get_meta.

Note: A metadata’s name must be a valid identifier as per is_valid_identifier method.

Note: Metadata that has a name starting with an underscore (_) is considered editor-only. Editor-only metadata is not displayed in the Inspector and should not be edited, although it can still be found by this method.

pub fn remove_meta(&mut self, name: impl AsArg<StringName>)

Removes the given entry name from the object’s metadata. See also has_meta, get_meta and set_meta.

Note: A metadata’s name must be a valid identifier as per is_valid_identifier method.

Note: Metadata that has a name starting with an underscore (_) is considered editor-only. Editor-only metadata is not displayed in the Inspector and should not be edited, although it can still be found by this method.

pub fn get_meta(&self, name: impl AsArg<StringName>) -> Variant

To set the default parameters, use get_meta_ex and its builder methods. See the book for detailed usage instructions. Returns the object’s metadata value for the given entry name. If the entry does not exist, returns default. If default is null, an error is also generated.

Note: A metadata’s name must be a valid identifier as per is_valid_identifier method.

Note: Metadata that has a name starting with an underscore (_) is considered editor-only. Editor-only metadata is not displayed in the Inspector and should not be edited, although it can still be found by this method.

pub fn get_meta_ex<'ex>( &'ex self, name: impl AsArg<StringName> + 'ex, ) -> ExGetMeta<'ex>

Returns the object’s metadata value for the given entry name. If the entry does not exist, returns default. If default is null, an error is also generated.

Note: A metadata’s name must be a valid identifier as per is_valid_identifier method.

Note: Metadata that has a name starting with an underscore (_) is considered editor-only. Editor-only metadata is not displayed in the Inspector and should not be edited, although it can still be found by this method.

pub fn has_meta(&self, name: impl AsArg<StringName>) -> bool

Returns true if a metadata entry is found with the given name. See also get_meta, set_meta and remove_meta.

Note: A metadata’s name must be a valid identifier as per is_valid_identifier method.

Note: Metadata that has a name starting with an underscore (_) is considered editor-only. Editor-only metadata is not displayed in the Inspector and should not be edited, although it can still be found by this method.

pub fn get_meta_list(&self) -> Array<StringName>

Returns the object’s metadata entry names as an Array of StringNames.

pub fn add_user_signal(&mut self, signal: impl AsArg<GString>)

To set the default parameters, use add_user_signal_ex and its builder methods. See the book for detailed usage instructions. Adds a user-defined signal named signal. Optional arguments for the signal can be added as an Array of dictionaries, each defining a name String and a type int (see [enum Variant.Type]). See also has_user_signal and remove_user_signal.

add_user_signal("hurt", [
	{ "name": "damage", "type": TYPE_INT },
	{ "name": "source", "type": TYPE_OBJECT }
])

pub fn add_user_signal_ex<'ex>( &'ex mut self, signal: impl AsArg<GString> + 'ex, ) -> ExAddUserSignal<'ex>

Adds a user-defined signal named signal. Optional arguments for the signal can be added as an Array of dictionaries, each defining a name String and a type int (see [enum Variant.Type]). See also has_user_signal and remove_user_signal.

add_user_signal("hurt", [
	{ "name": "damage", "type": TYPE_INT },
	{ "name": "source", "type": TYPE_OBJECT }
])

pub fn has_user_signal(&self, signal: impl AsArg<StringName>) -> bool

Returns true if the given user-defined signal name exists. Only signals added with add_user_signal are included. See also remove_user_signal.

pub fn remove_user_signal(&mut self, signal: impl AsArg<StringName>)

Removes the given user signal signal from the object. See also add_user_signal and has_user_signal.

pub fn emit_signal( &mut self, signal: impl AsArg<StringName>, varargs: &[Variant], ) -> Error

Emits the given signal by name. The signal must exist, so it should be a built-in signal of this class or one of its inherited classes, or a user-defined signal (see add_user_signal). This method supports a variable number of arguments, so parameters can be passed as a comma separated list.

Returns Error::ERR_UNAVAILABLE if signal does not exist or the parameters are invalid.

emit_signal("hit", "sword", 100)
emit_signal("game_over")

Note: In C#, signal must be in snake_case when referring to built-in Godot signals. Prefer using the names exposed in the SignalName class to avoid allocating a new StringName on each call.

Panics

This is a varcall method, meaning parameters and return values are passed as Variant. It can detect call failures and will panic in such a case.

pub fn try_emit_signal( &mut self, signal: impl AsArg<StringName>, varargs: &[Variant], ) -> Result<Error, CallError>

Return type

This is a varcall method, meaning parameters and return values are passed as Variant. It can detect call failures and will return Err in such a case.

pub fn call( &mut self, method: impl AsArg<StringName>, varargs: &[Variant], ) -> Variant

Calls the method on the object and returns the result. This method supports a variable number of arguments, so parameters can be passed as a comma separated list.

var node = Node3D.new()
node.call("rotate", Vector3(1.0, 0.0, 0.0), 1.571)

Note: In C#, method must be in snake_case when referring to built-in Godot methods. Prefer using the names exposed in the MethodName class to avoid allocating a new StringName on each call.

Panics

This is a varcall method, meaning parameters and return values are passed as Variant. It can detect call failures and will panic in such a case.

pub fn try_call( &mut self, method: impl AsArg<StringName>, varargs: &[Variant], ) -> Result<Variant, CallError>

Return type

This is a varcall method, meaning parameters and return values are passed as Variant. It can detect call failures and will return Err in such a case.

pub fn call_deferred( &mut self, method: impl AsArg<StringName>, varargs: &[Variant], ) -> Variant

Calls the method on the object during idle time. Always returns null, not the method’s result.

Idle time happens mainly at the end of process and physics frames. In it, deferred calls will be run until there are none left, which means you can defer calls from other deferred calls and they’ll still be run in the current idle time cycle. This means you should not call a method deferred from itself (or from a method called by it), as this causes infinite recursion the same way as if you had called the method directly.

This method supports a variable number of arguments, so parameters can be passed as a comma separated list.

var node = Node3D.new()
node.call_deferred("rotate", Vector3(1.0, 0.0, 0.0), 1.571)

For methods that are deferred from the same thread, the order of execution at idle time is identical to the order in which call_deferred was called.

See also call_deferred.

Note: In C#, method must be in snake_case when referring to built-in Godot methods. Prefer using the names exposed in the MethodName class to avoid allocating a new StringName on each call.

Note: If you’re looking to delay the function call by a frame, refer to the SceneTree.process_frame and SceneTree.physics_frame signals.

var node = Node3D.new()
# Make a Callable and bind the arguments to the node's rotate() call.
var callable = node.rotate.bind(Vector3(1.0, 0.0, 0.0), 1.571)
# Connect the callable to the process_frame signal, so it gets called in the next process frame.
# CONNECT_ONE_SHOT makes sure it only gets called once instead of every frame.
get_tree().process_frame.connect(callable, CONNECT_ONE_SHOT)
Panics

This is a varcall method, meaning parameters and return values are passed as Variant. It can detect call failures and will panic in such a case.

pub fn try_call_deferred( &mut self, method: impl AsArg<StringName>, varargs: &[Variant], ) -> Result<Variant, CallError>

Return type

This is a varcall method, meaning parameters and return values are passed as Variant. It can detect call failures and will return Err in such a case.

pub fn set_deferred( &mut self, property: impl AsArg<StringName>, value: &Variant, )

Assigns value to the given property, at the end of the current frame. This is equivalent to calling set through call_deferred.

var node = Node2D.new()
add_child(node)

node.rotation = 1.5
node.set_deferred("rotation", 3.0)
print(node.rotation) # Prints 1.5

await get_tree().process_frame
print(node.rotation) # Prints 3.0

Note: In C#, property must be in snake_case when referring to built-in Godot properties. Prefer using the names exposed in the PropertyName class to avoid allocating a new StringName on each call.

pub fn callv( &mut self, method: impl AsArg<StringName>, arg_array: &AnyArray, ) -> Variant

Calls the method on the object and returns the result. Unlike call, this method expects all parameters to be contained inside arg_array.

var node = Node3D.new()
node.callv("rotate", [Vector3(1.0, 0.0, 0.0), 1.571])

Note: In C#, method must be in snake_case when referring to built-in Godot methods. Prefer using the names exposed in the MethodName class to avoid allocating a new StringName on each call.

pub fn has_method(&self, method: impl AsArg<StringName>) -> bool

Returns true if the given method name exists in the object.

Note: In C#, method must be in snake_case when referring to built-in Godot methods. Prefer using the names exposed in the MethodName class to avoid allocating a new StringName on each call.

pub fn get_method_argument_count(&self, method: impl AsArg<StringName>) -> i32

Returns the number of arguments of the given method by name.

Note: In C#, method must be in snake_case when referring to built-in Godot methods. Prefer using the names exposed in the MethodName class to avoid allocating a new StringName on each call.

pub fn has_signal(&self, signal: impl AsArg<StringName>) -> bool

Returns true if the given signal name exists in the object.

Note: In C#, signal must be in snake_case when referring to built-in Godot signals. Prefer using the names exposed in the SignalName class to avoid allocating a new StringName on each call.

pub fn get_signal_list(&self) -> Array<Dictionary<Variant, Variant>>

Returns the list of existing signals as an Array of dictionaries.

Note: Due to the implementation, each Dictionary is formatted very similarly to the returned values of get_method_list.

pub fn get_signal_connection_list( &self, signal: impl AsArg<StringName>, ) -> Array<Dictionary<Variant, Variant>>

Returns an Array of connections for the given signal name. Each connection is represented as a Dictionary that contains three entries:

  • signal is a reference to the Signal;

  • callable is a reference to the connected Callable;

  • flags is a combination of [enum ConnectFlags].

pub fn get_incoming_connections(&self) -> Array<Dictionary<Variant, Variant>>

Returns an Array of signal connections received by this object. Each connection is represented as a Dictionary that contains three entries:

  • signal is a reference to the Signal;

  • callable is a reference to the Callable;

  • flags is a combination of [enum ConnectFlags].

pub fn disconnect( &mut self, signal: impl AsArg<StringName>, callable: &Callable, )

Disconnects a signal by name from a given callable. If the connection does not exist, generates an error. Use is_connected to make sure that the connection exists.

pub fn is_connected( &self, signal: impl AsArg<StringName>, callable: &Callable, ) -> bool

Returns true if a connection exists between the given signal name and callable.

Note: In C#, signal must be in snake_case when referring to built-in Godot signals. Prefer using the names exposed in the SignalName class to avoid allocating a new StringName on each call.

pub fn has_connections(&self, signal: impl AsArg<StringName>) -> bool

Returns true if any connection exists on the given signal name.

Note: In C#, signal must be in snake_case when referring to built-in Godot methods. Prefer using the names exposed in the SignalName class to avoid allocating a new StringName on each call.

pub fn set_block_signals(&mut self, enable: bool)

If set to true, the object becomes unable to emit signals. As such, emit_signal and signal connections will not work, until it is set to false.

pub fn is_blocking_signals(&self) -> bool

Returns true if the object is blocking its signals from being emitted. See set_block_signals.

pub fn notify_property_list_changed(&mut self)

Emits the property_list_changed signal. This is mainly used to refresh the editor, so that the Inspector and editor plugins are properly updated.

pub fn set_message_translation(&mut self, enable: bool)

If set to true, allows the object to translate messages with tr and tr_n. Enabled by default. See also can_translate_messages.

pub fn can_translate_messages(&self) -> bool

Returns true if the object is allowed to translate messages with tr and tr_n. See also set_message_translation.

pub fn tr(&self, message: impl AsArg<StringName>) -> GString

To set the default parameters, use tr_ex and its builder methods. See the book for detailed usage instructions. Translates a message, using the translation catalogs configured in the Project Settings. Further context can be specified to help with the translation. Note that most Control nodes automatically translate their strings, so this method is mostly useful for formatted strings or custom drawn text.

If can_translate_messages is false, or no translation is available, this method returns the message without changes. See set_message_translation.

For detailed examples, see Internationalizing games.

Note: This method can’t be used without an Object instance, as it requires the can_translate_messages method. To translate strings in a static context, use translate.

pub fn tr_ex<'ex>(&'ex self, message: impl AsArg<StringName> + 'ex) -> ExTr<'ex>

Translates a message, using the translation catalogs configured in the Project Settings. Further context can be specified to help with the translation. Note that most Control nodes automatically translate their strings, so this method is mostly useful for formatted strings or custom drawn text.

If can_translate_messages is false, or no translation is available, this method returns the message without changes. See set_message_translation.

For detailed examples, see Internationalizing games.

Note: This method can’t be used without an Object instance, as it requires the can_translate_messages method. To translate strings in a static context, use translate.

pub fn tr_n( &self, message: impl AsArg<StringName>, plural_message: impl AsArg<StringName>, n: i32, ) -> GString

To set the default parameters, use tr_n_ex and its builder methods. See the book for detailed usage instructions. Translates a message or plural_message, using the translation catalogs configured in the Project Settings. Further context can be specified to help with the translation.

If can_translate_messages is false, or no translation is available, this method returns message or plural_message, without changes. See set_message_translation.

The n is the number, or amount, of the message’s subject. It is used by the translation system to fetch the correct plural form for the current language.

For detailed examples, see Localization using gettext.

Note: Negative and float numbers may not properly apply to some countable subjects. It’s recommended to handle these cases with tr.

Note: This method can’t be used without an Object instance, as it requires the can_translate_messages method. To translate strings in a static context, use translate_plural.

pub fn tr_n_ex<'ex>( &'ex self, message: impl AsArg<StringName> + 'ex, plural_message: impl AsArg<StringName> + 'ex, n: i32, ) -> ExTrN<'ex>

Translates a message or plural_message, using the translation catalogs configured in the Project Settings. Further context can be specified to help with the translation.

If can_translate_messages is false, or no translation is available, this method returns message or plural_message, without changes. See set_message_translation.

The n is the number, or amount, of the message’s subject. It is used by the translation system to fetch the correct plural form for the current language.

For detailed examples, see Localization using gettext.

Note: Negative and float numbers may not properly apply to some countable subjects. It’s recommended to handle these cases with tr.

Note: This method can’t be used without an Object instance, as it requires the can_translate_messages method. To translate strings in a static context, use translate_plural.

pub fn get_translation_domain(&self) -> StringName

Returns the name of the translation domain used by tr and tr_n. See also TranslationServer.

pub fn set_translation_domain(&mut self, domain: impl AsArg<StringName>)

Sets the name of the translation domain used by tr and tr_n. See also TranslationServer.

pub fn is_queued_for_deletion(&self) -> bool

Returns true if the queue_free method was called for the object.

pub fn cancel_free(&mut self)

If this method is called during ObjectNotification::PREDELETE, this object will reject being freed and will remain allocated. This is mostly an internal function used for error handling to avoid the user from freeing objects when they are not intended to.

pub fn notify(&mut self, what: ObjectNotification)

⚠️ Sends a Godot notification to all classes inherited by the object.

Triggers calls to on_notification(), and depending on the notification, also to Godot’s lifecycle callbacks such as ready().

Starts from the highest ancestor (the Object class) and goes down the hierarchy. See also Godot docs for Object::notification().

Panics

If you call this method on a user-defined object while holding a GdRef or GdMut guard on the instance, you will encounter a panic. The reason is that the receiving virtual method on_notification() acquires a GdMut lock dynamically, which must be exclusive.

pub fn notify_reversed(&mut self, what: ObjectNotification)

⚠️ Like Self::notify(), but starts at the most-derived class and goes up the hierarchy.

See docs of that method, including the panics.