str

Function str 

pub fn str(varargs: &[Variant]) -> GString
Converts one or more arguments of any Variant type to a String in the best way possible.

var a = [10, 20, 30]
var b = str(a)
print(len(a)) # Prints 3 (the number of elements in the array).
print(len(b)) # Prints 12 (the length of the string "[10, 20, 30]").