InParamTuple

Trait InParamTuple 

pub trait InParamTuple: ParamTuple {
    // Required method
    fn from_variant_array(array: &[&Variant]) -> Self;
}
Represents a parameter list that is received from some external location (usually Godot).

As an example, this would be used for user-defined functions that will be called from Godot, however this is not used when calling a Godot function from Rust code.

Required Methods

fn from_variant_array(array: &[&Variant]) -> Self

Converts array to Self by calling from_variant on each argument.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types



impl InParamTuple for ()



impl<P0> InParamTuple for (P0,)
where P0: EngineFromGodot + Debug,



impl<P0, P1> InParamTuple for (P0, P1)
where P0: EngineFromGodot + Debug, P1: EngineFromGodot + Debug,



impl<P0, P1, P2> InParamTuple for (P0, P1, P2)
where P0: EngineFromGodot + Debug, P1: EngineFromGodot + Debug, P2: EngineFromGodot + Debug,



impl<P0, P1, P2, P3> InParamTuple for (P0, P1, P2, P3)
where P0: EngineFromGodot + Debug, P1: EngineFromGodot + Debug, P2: EngineFromGodot + Debug, P3: EngineFromGodot + Debug,



impl<P0, P1, P2, P3, P4> InParamTuple for (P0, P1, P2, P3, P4)
where P0: EngineFromGodot + Debug, P1: EngineFromGodot + Debug, P2: EngineFromGodot + Debug, P3: EngineFromGodot + Debug, P4: EngineFromGodot + Debug,



impl<P0, P1, P2, P3, P4, P5> InParamTuple for (P0, P1, P2, P3, P4, P5)
where P0: EngineFromGodot + Debug, P1: EngineFromGodot + Debug, P2: EngineFromGodot + Debug, P3: EngineFromGodot + Debug, P4: EngineFromGodot + Debug, P5: EngineFromGodot + Debug,



impl<P0, P1, P2, P3, P4, P5, P6> InParamTuple for (P0, P1, P2, P3, P4, P5, P6)
where P0: EngineFromGodot + Debug, P1: EngineFromGodot + Debug, P2: EngineFromGodot + Debug, P3: EngineFromGodot + Debug, P4: EngineFromGodot + Debug, P5: EngineFromGodot + Debug, P6: EngineFromGodot + Debug,



impl<P0, P1, P2, P3, P4, P5, P6, P7> InParamTuple for (P0, P1, P2, P3, P4, P5, P6, P7)
where P0: EngineFromGodot + Debug, P1: EngineFromGodot + Debug, P2: EngineFromGodot + Debug, P3: EngineFromGodot + Debug, P4: EngineFromGodot + Debug, P5: EngineFromGodot + Debug, P6: EngineFromGodot + Debug, P7: EngineFromGodot + Debug,



impl<P0, P1, P2, P3, P4, P5, P6, P7, P8> InParamTuple for (P0, P1, P2, P3, P4, P5, P6, P7, P8)
where P0: EngineFromGodot + Debug, P1: EngineFromGodot + Debug, P2: EngineFromGodot + Debug, P3: EngineFromGodot + Debug, P4: EngineFromGodot + Debug, P5: EngineFromGodot + Debug, P6: EngineFromGodot + Debug, P7: EngineFromGodot + Debug, P8: EngineFromGodot + Debug,



impl<P0, P1, P2, P3, P4, P5, P6, P7, P8, P9> InParamTuple for (P0, P1, P2, P3, P4, P5, P6, P7, P8, P9)
where P0: EngineFromGodot + Debug, P1: EngineFromGodot + Debug, P2: EngineFromGodot + Debug, P3: EngineFromGodot + Debug, P4: EngineFromGodot + Debug, P5: EngineFromGodot + Debug, P6: EngineFromGodot + Debug, P7: EngineFromGodot + Debug, P8: EngineFromGodot + Debug, P9: EngineFromGodot + Debug,



impl<P0, P1, P2, P3, P4, P5, P6, P7, P8, P9, P10> InParamTuple for (P0, P1, P2, P3, P4, P5, P6, P7, P8, P9, P10)
where P0: EngineFromGodot + Debug, P1: EngineFromGodot + Debug, P2: EngineFromGodot + Debug, P3: EngineFromGodot + Debug, P4: EngineFromGodot + Debug, P5: EngineFromGodot + Debug, P6: EngineFromGodot + Debug, P7: EngineFromGodot + Debug, P8: EngineFromGodot + Debug, P9: EngineFromGodot + Debug, P10: EngineFromGodot + Debug,



impl<P0, P1, P2, P3, P4, P5, P6, P7, P8, P9, P10, P11> InParamTuple for (P0, P1, P2, P3, P4, P5, P6, P7, P8, P9, P10, P11)
where P0: EngineFromGodot + Debug, P1: EngineFromGodot + Debug, P2: EngineFromGodot + Debug, P3: EngineFromGodot + Debug, P4: EngineFromGodot + Debug, P5: EngineFromGodot + Debug, P6: EngineFromGodot + Debug, P7: EngineFromGodot + Debug, P8: EngineFromGodot + Debug, P9: EngineFromGodot + Debug, P10: EngineFromGodot + Debug, P11: EngineFromGodot + Debug,



impl<P0, P1, P2, P3, P4, P5, P6, P7, P8, P9, P10, P11, P12> InParamTuple for (P0, P1, P2, P3, P4, P5, P6, P7, P8, P9, P10, P11, P12)
where P0: EngineFromGodot + Debug, P1: EngineFromGodot + Debug, P2: EngineFromGodot + Debug, P3: EngineFromGodot + Debug, P4: EngineFromGodot + Debug, P5: EngineFromGodot + Debug, P6: EngineFromGodot + Debug, P7: EngineFromGodot + Debug, P8: EngineFromGodot + Debug, P9: EngineFromGodot + Debug, P10: EngineFromGodot + Debug, P11: EngineFromGodot + Debug, P12: EngineFromGodot + Debug,



impl<P0, P1, P2, P3, P4, P5, P6, P7, P8, P9, P10, P11, P12, P13> InParamTuple for (P0, P1, P2, P3, P4, P5, P6, P7, P8, P9, P10, P11, P12, P13)
where P0: EngineFromGodot + Debug, P1: EngineFromGodot + Debug, P2: EngineFromGodot + Debug, P3: EngineFromGodot + Debug, P4: EngineFromGodot + Debug, P5: EngineFromGodot + Debug, P6: EngineFromGodot + Debug, P7: EngineFromGodot + Debug, P8: EngineFromGodot + Debug, P9: EngineFromGodot + Debug, P10: EngineFromGodot + Debug, P11: EngineFromGodot + Debug, P12: EngineFromGodot + Debug, P13: EngineFromGodot + Debug,

Implementors