Trait SignedRange
pub trait SignedRange: SealedRange { }Expand description
Trait supporting regular usize ranges, as well as negative indices.
If a lower or upper bound is negative, then its value is relative to the end of the given collection.
Use the wrapped() utility function to construct such ranges.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".