Trait SimpleVar
pub trait SimpleVar:
ToGodot
+ FromGodot
+ Clone { }Expand description
Simplified way to implement the Var trait, for godot-convertible types.
Implementing this trait will auto-implement Var in a standard way for types supporting ToGodot and FromGodot.
Types implementing this trait will use clone() for the public getter and direct assignment for the public setter, with PubType = Self.
This is the standard behavior for most types.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".