Function cubic_interpolate_angle_in_time
pub fn cubic_interpolate_angle_in_time(
from: f64,
to: f64,
pre: f64,
post: f64,
weight: f64,
to_t: f64,
pre_t: f64,
post_t: f64,
) -> f64Expand description
Cubic interpolates between two rotation values with shortest path by the factor defined in weight with pre and post values. See also [method lerp_angle].
It can perform smoother interpolation than [method cubic_interpolate] by the time values.