ToGodot

Trait ToGodot 

pub trait ToGodot: Sized + GodotConvert {
    type Pass: ArgPassing;
    type Threads: ThreadSafety;

    // Required method
    fn to_godot(&self) -> <Self::Pass as ArgPassing>::Output<'_, Self::Via>;

    // Provided methods
    fn to_godot_owned(&self) -> Self::Via { ... }
    fn to_variant(&self) -> Variant { ... }
}
Defines the canonical conversion to Godot for a type.

It is assumed that all the methods return equal values given equal inputs. Additionally, it is assumed that if FromGodot is implemented, converting to Godot and back again will return a value equal to the starting value.

Violating these assumptions is safe but will give unexpected results.

Please read the godot::meta module docs for further information about conversions.

This trait can be derived using the #[derive(GodotConvert)] macro.

Required Associated Types

type Pass: ArgPassing

Whether arguments of this type are passed by value or by reference.

Can be either ByValue or ByRef. In most cases, you need ByValue.

Select ByValue if:

  • Self is Copy (e.g. i32, f64, Vector2, Color, etc).
  • You need a conversion (e.g. Self = MyString, Via = GString).
  • You like the simple life and can’t be bothered with lifetimes.

Select ByRef if:

  • Performance of argument passing is very important and you have measured it.
  • You store a cached value which can be borrowed (e.g. &GString).

Will auto-implement AsArg<T> for either T (by-value) or for &T (by-reference). This has an influence on contexts such as Array::push(), the array![...] macro or generated signal emit() signatures.

type Threads: ThreadSafety

Whether arguments of this type are thread-safe or not.

Can be either ThreadSafeArg or NonThreadSafeArg. Only engine types make use of NonThreadSafeArg, all user defined types should use ThreadSafeArg by deriving GodotConvert or by manually implementing this trait. The use of ThreadSafeArg also requires the type to be Send. Non Send user defined types are currenlty not supported.

Required Methods

fn to_godot(&self) -> <Self::Pass as ArgPassing>::Output<'_, Self::Via>

Converts this type to Godot representation, optimizing for zero-copy when possible.

Return type
  • For Pass = ByValue, returns owned Self::Via.
  • For Pass = ByRef, returns borrowed &Self::Via.
Panics

Generally never panics, except for the Result<T, E> impl in case of Err(E).

Provided Methods

fn to_godot_owned(&self) -> Self::Via

Converts this type to owned Godot representation.

Always returns Self::Via, cloning if necessary for ByRef types.

Panics

See to_godot().

fn to_variant(&self) -> Variant

Converts this type to a Variant.

Panics

See to_godot().

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementations on Foreign Types



impl ToGodot for &str



impl ToGodot for bool



impl ToGodot for f32



impl ToGodot for f64



impl ToGodot for i8



impl ToGodot for i16



impl ToGodot for i32



impl ToGodot for i64



impl ToGodot for u8



impl ToGodot for u16



impl ToGodot for u32



impl ToGodot for ()



impl ToGodot for String



impl<T> ToGodot for &[T]
where T: Element,



type Pass = ByValue



type Threads = <T as ToGodot>::Threads



fn to_godot(&self) -> <&[T] as GodotConvert>::Via



impl<T> ToGodot for Option<T>
where T: ToGodot<Pass = ByObject>, <T as GodotConvert>::Via: GodotNullableType,



impl<T> ToGodot for Vec<T>
where T: Element,



impl<T, E> ToGodot for Result<T, E>
where T: ToGodot, E: ErrorToGodot<T>,



type Pass = ByValue



type Threads = <<E as ErrorToGodot<T>>::Mapped as ToGodot>::Threads



fn to_godot(&self) -> <Result<T, E> as GodotConvert>::Via



impl<T, const LEN: usize> ToGodot for [T; LEN]
where T: Element,

Implementors



impl ToGodot for Corner



impl ToGodot for Side



impl ToGodot for ClockDirection



impl ToGodot for godot::global::Orientation



impl ToGodot for EulerOrder



impl ToGodot for Rid



impl ToGodot for Vector2Axis



impl ToGodot for Vector3Axis



impl ToGodot for Vector4Axis



impl ToGodot for CellShape



impl ToGodot for DiagonalMode



impl ToGodot for Heuristic



impl ToGodot for godot::classes::aes_context::Mode



impl ToGodot for FindMode



impl ToGodot for InterpolationType



impl ToGodot for godot::classes::animation::LoopMode



impl ToGodot for LoopedFlag



impl ToGodot for TrackType



impl ToGodot for godot::classes::animation::UpdateMode



impl ToGodot for AnimationCallbackModeDiscrete



impl ToGodot for AnimationCallbackModeMethod



impl ToGodot for AnimationCallbackModeProcess



impl ToGodot for FilterAction



impl ToGodot for PlayMode



impl ToGodot for godot::classes::animation_node_blend_space_1d::BlendMode



impl ToGodot for godot::classes::animation_node_blend_space_2d::BlendMode



impl ToGodot for MixMode



impl ToGodot for OneShotRequest



impl ToGodot for StateMachineType



impl ToGodot for AdvanceMode



impl ToGodot for SwitchMode



impl ToGodot for AnimationMethodCallMode



impl ToGodot for godot::classes::animation_player::AnimationProcessCallback



impl ToGodot for godot::classes::animation_tree::AnimationProcessCallback



impl ToGodot for godot::classes::area_2d::SpaceOverride



impl ToGodot for godot::classes::area_3d::SpaceOverride



impl ToGodot for godot::classes::aspect_ratio_container::AlignmentMode



impl ToGodot for godot::classes::aspect_ratio_container::StretchMode



impl ToGodot for godot::classes::audio_effect_distortion::Mode



impl ToGodot for FilterDb



impl ToGodot for godot::classes::audio_effect_pitch_shift::FftSize



impl ToGodot for godot::classes::audio_effect_spectrum_analyzer::FftSize



impl ToGodot for MagnitudeMode



impl ToGodot for godot::classes::audio_listener_3d::DopplerTracking



impl ToGodot for PlaybackType



impl ToGodot for SpeakerMode



impl ToGodot for AudioStreamGeneratorMixRate



impl ToGodot for AutoAdvanceMode



impl ToGodot for FadeMode



impl ToGodot for TransitionFromTime



impl ToGodot for TransitionToTime



impl ToGodot for MixTarget



impl ToGodot for AttenuationModel



impl ToGodot for godot::classes::audio_stream_player_3d::DopplerTracking



impl ToGodot for PlaybackMode



impl ToGodot for godot::classes::audio_stream_wav::Format



impl ToGodot for godot::classes::audio_stream_wav::LoopMode



impl ToGodot for CopyMode



impl ToGodot for ActionMode



impl ToGodot for DrawMode



impl ToGodot for AlphaAntiAliasing



impl ToGodot for BillboardMode



impl ToGodot for godot::classes::base_material_3d::BlendMode



impl ToGodot for godot::classes::base_material_3d::CullMode



impl ToGodot for DepthDrawMode



impl ToGodot for DepthTest



impl ToGodot for DetailUv



impl ToGodot for DiffuseMode



impl ToGodot for DistanceFadeMode



impl ToGodot for EmissionOperator



impl ToGodot for godot::classes::base_material_3d::Feature



impl ToGodot for godot::classes::base_material_3d::Flags



impl ToGodot for ShadingMode



impl ToGodot for SpecularMode



impl ToGodot for StencilCompare



impl ToGodot for StencilFlags



impl ToGodot for StencilMode



impl ToGodot for TextureChannel



impl ToGodot for godot::classes::base_material_3d::TextureFilter



impl ToGodot for TextureParam



impl ToGodot for Transparency



impl ToGodot for ReferenceType



impl ToGodot for DisperseMode



impl ToGodot for godot::classes::box_container::AlignmentMode



impl ToGodot for AnchorMode



impl ToGodot for Camera2DProcessCallback



impl ToGodot for godot::classes::camera_3d::DopplerTracking



impl ToGodot for KeepAspect



impl ToGodot for ProjectionType



impl ToGodot for FeedDataType



impl ToGodot for FeedPosition



impl ToGodot for FeedImage



impl ToGodot for ClipChildrenMode



impl ToGodot for godot::classes::canvas_item::TextureFilter



impl ToGodot for godot::classes::canvas_item::TextureRepeat



impl ToGodot for godot::classes::canvas_item_material::BlendMode



impl ToGodot for LightMode



impl ToGodot for godot::classes::character_body_2d::MotionMode



impl ToGodot for godot::classes::character_body_2d::PlatformOnLeave



impl ToGodot for godot::classes::character_body_3d::MotionMode



impl ToGodot for godot::classes::character_body_3d::PlatformOnLeave



impl ToGodot for ApiType



impl ToGodot for godot::classes::code_edit::CodeCompletionKind



impl ToGodot for godot::classes::code_edit::CodeCompletionLocation



impl ToGodot for godot::classes::collision_object_2d::DisableMode



impl ToGodot for godot::classes::collision_object_3d::DisableMode



impl ToGodot for BuildMode



impl ToGodot for ColorModeType



impl ToGodot for PickerShapeType



impl ToGodot for EffectCallbackType



impl ToGodot for godot::classes::cone_twist_joint_3d::Param



impl ToGodot for Anchor



impl ToGodot for godot::classes::control::CursorShape



impl ToGodot for FocusBehaviorRecursive



impl ToGodot for FocusMode



impl ToGodot for GrowDirection



impl ToGodot for godot::classes::control::LayoutDirection



impl ToGodot for LayoutPreset



impl ToGodot for LayoutPresetMode



impl ToGodot for MouseBehaviorRecursive



impl ToGodot for MouseFilter



impl ToGodot for SizeFlags



impl ToGodot for TextDirection



impl ToGodot for TransformMode



impl ToGodot for AxisFlag



impl ToGodot for godot::classes::copy_transform_modifier_3d::TransformFlag



impl ToGodot for godot::classes::cpu_particles_2d::DrawOrder



impl ToGodot for godot::classes::cpu_particles_2d::EmissionShape



impl ToGodot for godot::classes::cpu_particles_2d::Parameter



impl ToGodot for godot::classes::cpu_particles_2d::ParticleFlags



impl ToGodot for godot::classes::cpu_particles_3d::DrawOrder



impl ToGodot for godot::classes::cpu_particles_3d::EmissionShape



impl ToGodot for godot::classes::cpu_particles_3d::Parameter



impl ToGodot for godot::classes::cpu_particles_3d::ParticleFlags



impl ToGodot for godot::classes::csg_polygon_3d::Mode



impl ToGodot for PathIntervalType



impl ToGodot for PathRotation



impl ToGodot for Operation



impl ToGodot for TangentMode



impl ToGodot for TextureMode



impl ToGodot for godot::classes::decal::DecalTexture



impl ToGodot for godot::classes::directional_light_3d::ShadowMode



impl ToGodot for godot::classes::directional_light_3d::SkyMode



impl ToGodot for AccessibilityAction



impl ToGodot for AccessibilityFlags



impl ToGodot for AccessibilityLiveMode



impl ToGodot for AccessibilityPopupType



impl ToGodot for AccessibilityRole



impl ToGodot for AccessibilityScrollHint



impl ToGodot for AccessibilityScrollUnit



impl ToGodot for godot::classes::display_server::CursorShape



impl ToGodot for godot::classes::display_server::Feature



impl ToGodot for FileDialogMode



impl ToGodot for HandleType



impl ToGodot for godot::classes::display_server::MouseMode



impl ToGodot for ScreenOrientation



impl ToGodot for TtsUtteranceEvent



impl ToGodot for VSyncMode



impl ToGodot for godot::classes::display_server::VirtualKeyboardType



impl ToGodot for WindowEvent



impl ToGodot for WindowFlags



impl ToGodot for WindowMode



impl ToGodot for WindowResizeEdge



impl ToGodot for ContextMenuSlot



impl ToGodot for DockLayout



impl ToGodot for godot::classes::editor_dock::DockSlot



impl ToGodot for DebugFlags



impl ToGodot for ExportMessageType



impl ToGodot for ExportFilter



impl ToGodot for FileExportMode



impl ToGodot for ScriptExportMode



impl ToGodot for godot::classes::editor_feature_profile::Feature



impl ToGodot for AfterGuiInput



impl ToGodot for CustomControlContainer



impl ToGodot for godot::classes::editor_plugin::DockSlot



impl ToGodot for InternalImportCategory



impl ToGodot for ControlState



impl ToGodot for Severity



impl ToGodot for SpecialHistory



impl ToGodot for ChangeType



impl ToGodot for TreeArea



impl ToGodot for godot::classes::enet_connection::CompressionMode



impl ToGodot for EventType



impl ToGodot for HostStatistic



impl ToGodot for PeerState



impl ToGodot for PeerStatistic



impl ToGodot for AmbientSource



impl ToGodot for BgMode



impl ToGodot for FogMode



impl ToGodot for GlowBlendMode



impl ToGodot for ReflectionSource



impl ToGodot for SdfgiYScale



impl ToGodot for ToneMapper



impl ToGodot for CellularDistanceFunction



impl ToGodot for CellularReturnType



impl ToGodot for DomainWarpFractalType



impl ToGodot for DomainWarpType



impl ToGodot for FractalType



impl ToGodot for NoiseType



impl ToGodot for godot::classes::file_access::CompressionMode



impl ToGodot for ModeFlags



impl ToGodot for UnixPermissionFlags



impl ToGodot for Access



impl ToGodot for Customization



impl ToGodot for DisplayMode



impl ToGodot for FileMode



impl ToGodot for godot::classes::flow_container::AlignmentMode



impl ToGodot for LastWrapAlignmentMode



impl ToGodot for TitlePosition



impl ToGodot for InitializationLevel



impl ToGodot for LoadStatus



impl ToGodot for godot::classes::generic6_dof_joint_3d::Flag



impl ToGodot for godot::classes::generic6_dof_joint_3d::Param



impl ToGodot for PolyBooleanOperation



impl ToGodot for PolyEndType



impl ToGodot for PolyJoinType



impl ToGodot for GiMode



impl ToGodot for LightmapScale



impl ToGodot for godot::classes::geometry_instance_3d::ShadowCastingSetting



impl ToGodot for godot::classes::geometry_instance_3d::VisibilityRangeFadeMode



impl ToGodot for GltfAccessorType



impl ToGodot for GltfComponentType



impl ToGodot for RootNodeMode



impl ToGodot for godot::classes::gltf_document::VisibilityMode



impl ToGodot for GltfObjectModelType



impl ToGodot for HandleBinaryImageMode



impl ToGodot for godot::classes::gpu_particles_2d::DrawOrder



impl ToGodot for godot::classes::gpu_particles_2d::EmitFlags



impl ToGodot for godot::classes::gpu_particles_3d::DrawOrder



impl ToGodot for godot::classes::gpu_particles_3d::EmitFlags



impl ToGodot for TransformAlign



impl ToGodot for godot::classes::gpu_particles_collision_height_field_3d::Resolution



impl ToGodot for godot::classes::gpu_particles_collision_height_field_3d::UpdateMode



impl ToGodot for godot::classes::gpu_particles_collision_sdf_3d::Resolution



impl ToGodot for ColorSpace



impl ToGodot for InterpolationMode



impl ToGodot for Fill



impl ToGodot for Repeat



impl ToGodot for GridPattern



impl ToGodot for PanningScheme



impl ToGodot for HashType



impl ToGodot for godot::classes::hinge_joint_3d::Flag



impl ToGodot for godot::classes::hinge_joint_3d::Param



impl ToGodot for Method



impl ToGodot for ResponseCode



impl ToGodot for godot::classes::http_client::Status



impl ToGodot for godot::classes::http_request::Result



impl ToGodot for AlphaMode



impl ToGodot for AstcFormat



impl ToGodot for CompressMode



impl ToGodot for CompressSource



impl ToGodot for godot::classes::image::Format



impl ToGodot for Interpolation



impl ToGodot for UsedChannels



impl ToGodot for LoaderFlags



impl ToGodot for godot::classes::input::CursorShape



impl ToGodot for godot::classes::input::MouseMode



impl ToGodot for ResolverStatus



impl ToGodot for godot::classes::ip::Type



impl ToGodot for IconMode



impl ToGodot for godot::classes::item_list::ScrollHintMode



impl ToGodot for godot::classes::item_list::SelectMode



impl ToGodot for ErrorCode



impl ToGodot for godot::classes::label_3d::AlphaCutMode



impl ToGodot for godot::classes::label_3d::DrawFlags



impl ToGodot for godot::classes::light_2d::BlendMode



impl ToGodot for ShadowFilter



impl ToGodot for BakeMode



impl ToGodot for godot::classes::light_3d::Param



impl ToGodot for BakeError



impl ToGodot for BakeQuality



impl ToGodot for EnvironmentMode



impl ToGodot for GenerateProbes



impl ToGodot for ShadowmaskMode



impl ToGodot for LineCapMode



impl ToGodot for LineJointMode



impl ToGodot for LineTextureMode



impl ToGodot for godot::classes::line_edit::ExpandMode



impl ToGodot for godot::classes::line_edit::MenuItems



impl ToGodot for godot::classes::line_edit::VirtualKeyboardType



impl ToGodot for UnderlineMode



impl ToGodot for ErrorType



impl ToGodot for OriginFrom



impl ToGodot for godot::classes::mesh::ArrayCustomFormat



impl ToGodot for godot::classes::mesh::ArrayFormat



impl ToGodot for godot::classes::mesh::ArrayType



impl ToGodot for godot::classes::mesh::BlendShapeMode



impl ToGodot for godot::classes::mesh::PrimitiveType



impl ToGodot for godot::classes::mesh_convex_decomposition_settings::Mode



impl ToGodot for PhysicsInterpolationQuality



impl ToGodot for TransformFormat



impl ToGodot for RpcMode



impl ToGodot for ConnectionStatus



impl ToGodot for TransferMode



impl ToGodot for VisibilityUpdateMode



impl ToGodot for godot::classes::native_menu::Feature



impl ToGodot for SystemMenus



impl ToGodot for godot::classes::navigation_mesh::ParsedGeometryType



impl ToGodot for godot::classes::navigation_mesh::SamplePartitionType



impl ToGodot for godot::classes::navigation_mesh::SourceGeometryMode



impl ToGodot for godot::classes::navigation_path_query_parameters_2d::PathMetadataFlags



impl ToGodot for godot::classes::navigation_path_query_parameters_2d::PathPostProcessing



impl ToGodot for godot::classes::navigation_path_query_parameters_2d::PathfindingAlgorithm



impl ToGodot for godot::classes::navigation_path_query_parameters_3d::PathMetadataFlags



impl ToGodot for godot::classes::navigation_path_query_parameters_3d::PathPostProcessing



impl ToGodot for godot::classes::navigation_path_query_parameters_3d::PathfindingAlgorithm



impl ToGodot for godot::classes::navigation_path_query_result_2d::PathSegmentType



impl ToGodot for godot::classes::navigation_path_query_result_3d::PathSegmentType



impl ToGodot for godot::classes::navigation_polygon::ParsedGeometryType



impl ToGodot for godot::classes::navigation_polygon::SamplePartitionType



impl ToGodot for godot::classes::navigation_polygon::SourceGeometryMode



impl ToGodot for godot::classes::navigation_server_2d::ProcessInfo



impl ToGodot for godot::classes::navigation_server_3d::ProcessInfo



impl ToGodot for godot::classes::nine_patch_rect::AxisStretchMode



impl ToGodot for AutoTranslateMode



impl ToGodot for DuplicateFlags



impl ToGodot for InternalMode



impl ToGodot for PhysicsInterpolationMode



impl ToGodot for godot::classes::node::ProcessMode



impl ToGodot for ProcessThreadGroup



impl ToGodot for ProcessThreadMessages



impl ToGodot for RotationEditMode



impl ToGodot for ConnectFlags



impl ToGodot for godot::classes::occluder_polygon_2d::CullMode



impl ToGodot for godot::classes::omni_light_3d::ShadowMode



impl ToGodot for ActionType



impl ToGodot for ThreadType



impl ToGodot for OpenXrAlphaBlendModeSupport



impl ToGodot for Filter



impl ToGodot for MipmapMode



impl ToGodot for Swizzle



impl ToGodot for Wrap



impl ToGodot for ResultStatus



impl ToGodot for godot::classes::open_xr_hand::BoneUpdate



impl ToGodot for Hands



impl ToGodot for MotionRange



impl ToGodot for SkeletonRig



impl ToGodot for Hand



impl ToGodot for godot::classes::open_xr_interface::HandJointFlags



impl ToGodot for HandJoints



impl ToGodot for HandMotionRange



impl ToGodot for HandTrackedSource



impl ToGodot for PerfSettingsLevel



impl ToGodot for PerfSettingsNotificationLevel



impl ToGodot for PerfSettingsSubDomain



impl ToGodot for SessionState



impl ToGodot for RenderModelTracker



impl ToGodot for PersistenceScope



impl ToGodot for AprilTagDict



impl ToGodot for ArucoDict



impl ToGodot for MarkerType



impl ToGodot for PlaneAlignment



impl ToGodot for PlaneSemanticLabel



impl ToGodot for Capability



impl ToGodot for ComponentType



impl ToGodot for EntityTrackingState



impl ToGodot for RenderingDriver



impl ToGodot for StdHandleType



impl ToGodot for SystemDir



impl ToGodot for godot::classes::packed_scene::GenEditState



impl ToGodot for godot::classes::packet_peer_dtls::Status



impl ToGodot for CollisionMode



impl ToGodot for godot::classes::particle_process_material::EmissionShape



impl ToGodot for godot::classes::particle_process_material::Parameter



impl ToGodot for godot::classes::particle_process_material::ParticleFlags



impl ToGodot for SubEmitterMode



impl ToGodot for godot::classes::path_follow_3d::RotationMode



impl ToGodot for Monitor



impl ToGodot for MonitorType



impl ToGodot for godot::classes::physical_bone_3d::DampMode



impl ToGodot for godot::classes::physical_bone_3d::JointType



impl ToGodot for godot::classes::physics_server_2d::AreaBodyStatus



impl ToGodot for godot::classes::physics_server_2d::AreaParameter



impl ToGodot for godot::classes::physics_server_2d::AreaSpaceOverrideMode



impl ToGodot for godot::classes::physics_server_2d::BodyDampMode



impl ToGodot for godot::classes::physics_server_2d::BodyMode



impl ToGodot for godot::classes::physics_server_2d::BodyParameter



impl ToGodot for godot::classes::physics_server_2d::BodyState



impl ToGodot for godot::classes::physics_server_2d::CcdMode



impl ToGodot for DampedSpringParam



impl ToGodot for JointParam



impl ToGodot for godot::classes::physics_server_2d::JointType



impl ToGodot for PinJointFlag



impl ToGodot for godot::classes::physics_server_2d::PinJointParam



impl ToGodot for godot::classes::physics_server_2d::ProcessInfo



impl ToGodot for godot::classes::physics_server_2d::ShapeType



impl ToGodot for godot::classes::physics_server_2d::SpaceParameter



impl ToGodot for godot::classes::physics_server_3d::AreaBodyStatus



impl ToGodot for godot::classes::physics_server_3d::AreaParameter



impl ToGodot for godot::classes::physics_server_3d::AreaSpaceOverrideMode



impl ToGodot for BodyAxis



impl ToGodot for godot::classes::physics_server_3d::BodyDampMode



impl ToGodot for godot::classes::physics_server_3d::BodyMode



impl ToGodot for godot::classes::physics_server_3d::BodyParameter



impl ToGodot for godot::classes::physics_server_3d::BodyState



impl ToGodot for ConeTwistJointParam



impl ToGodot for G6dofJointAxisFlag



impl ToGodot for G6dofJointAxisParam



impl ToGodot for HingeJointFlag



impl ToGodot for HingeJointParam



impl ToGodot for godot::classes::physics_server_3d::JointType



impl ToGodot for godot::classes::physics_server_3d::PinJointParam



impl ToGodot for godot::classes::physics_server_3d::ProcessInfo



impl ToGodot for godot::classes::physics_server_3d::ShapeType



impl ToGodot for SliderJointParam



impl ToGodot for godot::classes::physics_server_3d::SpaceParameter



impl ToGodot for godot::classes::pin_joint_3d::Param



impl ToGodot for godot::classes::plane_mesh::Orientation



impl ToGodot for godot::classes::portable_compressed_texture_2d::CompressionMode



impl ToGodot for godot::classes::progress_bar::FillMode



impl ToGodot for AmbientMode



impl ToGodot for godot::classes::reflection_probe::UpdateMode



impl ToGodot for BarrierMask



impl ToGodot for BlendFactor



impl ToGodot for BlendOperation



impl ToGodot for BreadcrumbMarker



impl ToGodot for BufferCreationBits



impl ToGodot for CompareOperator



impl ToGodot for DataFormat



impl ToGodot for DeviceType



impl ToGodot for godot::classes::rendering_device::DrawFlags



impl ToGodot for DriverResource



impl ToGodot for godot::classes::rendering_device::Features



impl ToGodot for FinalAction



impl ToGodot for IndexBufferFormat



impl ToGodot for InitialAction



impl ToGodot for Limit



impl ToGodot for LogicOperation



impl ToGodot for MemoryType



impl ToGodot for PipelineDynamicStateFlags



impl ToGodot for PipelineSpecializationConstantType



impl ToGodot for PolygonCullMode



impl ToGodot for PolygonFrontFace



impl ToGodot for RenderPrimitive



impl ToGodot for SamplerBorderColor



impl ToGodot for SamplerFilter



impl ToGodot for SamplerRepeatMode



impl ToGodot for ShaderLanguage



impl ToGodot for ShaderStage



impl ToGodot for StencilOperation



impl ToGodot for StorageBufferUsage



impl ToGodot for TextureSamples



impl ToGodot for TextureSliceType



impl ToGodot for TextureSwizzle



impl ToGodot for godot::classes::rendering_device::TextureType



impl ToGodot for TextureUsageBits



impl ToGodot for UniformType



impl ToGodot for VertexFrequency



impl ToGodot for godot::classes::rendering_server::ArrayCustomFormat



impl ToGodot for godot::classes::rendering_server::ArrayFormat



impl ToGodot for godot::classes::rendering_server::ArrayType



impl ToGodot for BakeChannels



impl ToGodot for godot::classes::rendering_server::BlendShapeMode



impl ToGodot for CanvasGroupMode



impl ToGodot for CanvasItemTextureFilter



impl ToGodot for CanvasItemTextureRepeat



impl ToGodot for CanvasLightBlendMode



impl ToGodot for CanvasLightMode



impl ToGodot for CanvasLightShadowFilter



impl ToGodot for CanvasOccluderPolygonCullMode



impl ToGodot for CanvasTextureChannel



impl ToGodot for CompositorEffectCallbackType



impl ToGodot for CompositorEffectFlags



impl ToGodot for CubeMapLayer



impl ToGodot for DecalFilter



impl ToGodot for godot::classes::rendering_server::DecalTexture



impl ToGodot for DofBlurQuality



impl ToGodot for DofBokehShape



impl ToGodot for EnvironmentAmbientSource



impl ToGodot for EnvironmentBg



impl ToGodot for EnvironmentFogMode



impl ToGodot for EnvironmentGlowBlendMode



impl ToGodot for EnvironmentReflectionSource



impl ToGodot for EnvironmentSdfgiFramesToConverge



impl ToGodot for EnvironmentSdfgiFramesToUpdateLight



impl ToGodot for EnvironmentSdfgiRayCount



impl ToGodot for EnvironmentSdfgiYScale



impl ToGodot for EnvironmentSsaoQuality



impl ToGodot for EnvironmentSsilQuality



impl ToGodot for EnvironmentSsrRoughnessQuality



impl ToGodot for EnvironmentToneMapper



impl ToGodot for godot::classes::rendering_server::Features



impl ToGodot for FogVolumeShape



impl ToGodot for GlobalShaderParameterType



impl ToGodot for InstanceFlags



impl ToGodot for InstanceType



impl ToGodot for LightBakeMode



impl ToGodot for LightDirectionalShadowMode



impl ToGodot for LightDirectionalSkyMode



impl ToGodot for LightOmniShadowMode



impl ToGodot for LightParam



impl ToGodot for LightProjectorFilter



impl ToGodot for LightType



impl ToGodot for MultimeshPhysicsInterpolationQuality



impl ToGodot for MultimeshTransformFormat



impl ToGodot for NinePatchAxisMode



impl ToGodot for ParticlesCollisionHeightfieldResolution



impl ToGodot for ParticlesCollisionType



impl ToGodot for ParticlesDrawOrder



impl ToGodot for ParticlesMode



impl ToGodot for ParticlesTransformAlign



impl ToGodot for PipelineSource



impl ToGodot for godot::classes::rendering_server::PrimitiveType



impl ToGodot for ReflectionProbeAmbientMode



impl ToGodot for ReflectionProbeUpdateMode



impl ToGodot for RenderingInfo



impl ToGodot for ShaderMode



impl ToGodot for godot::classes::rendering_server::ShadowCastingSetting



impl ToGodot for ShadowQuality



impl ToGodot for godot::classes::rendering_server::SkyMode



impl ToGodot for SplashStretchMode



impl ToGodot for SubSurfaceScatteringQuality



impl ToGodot for TextureLayeredType



impl ToGodot for godot::classes::rendering_server::TextureType



impl ToGodot for ViewportAnisotropicFiltering



impl ToGodot for ViewportClearMode



impl ToGodot for ViewportDebugDraw



impl ToGodot for ViewportEnvironmentMode



impl ToGodot for ViewportMsaa



impl ToGodot for ViewportOcclusionCullingBuildQuality



impl ToGodot for ViewportRenderInfo



impl ToGodot for ViewportRenderInfoType



impl ToGodot for ViewportScaling3DMode



impl ToGodot for ViewportScreenSpaceAa



impl ToGodot for ViewportSdfOversize



impl ToGodot for ViewportSdfScale



impl ToGodot for ViewportUpdateMode



impl ToGodot for ViewportVrsMode



impl ToGodot for ViewportVrsUpdateMode



impl ToGodot for godot::classes::rendering_server::VisibilityRangeFadeMode



impl ToGodot for VoxelGiQuality



impl ToGodot for DeepDuplicateMode



impl ToGodot for godot::classes::resource_format_loader::CacheMode



impl ToGodot for ImportOrder



impl ToGodot for godot::classes::resource_loader::CacheMode



impl ToGodot for ThreadLoadStatus



impl ToGodot for SaverFlags



impl ToGodot for godot::classes::retarget_modifier_3d::TransformFlag



impl ToGodot for Shape



impl ToGodot for ImageUpdateMask



impl ToGodot for ListType



impl ToGodot for godot::classes::rich_text_label::MenuItems



impl ToGodot for MetaUnderline



impl ToGodot for godot::classes::rigid_body_2d::CcdMode



impl ToGodot for godot::classes::rigid_body_2d::CenterOfMassMode



impl ToGodot for godot::classes::rigid_body_2d::DampMode



impl ToGodot for godot::classes::rigid_body_2d::FreezeMode



impl ToGodot for godot::classes::rigid_body_3d::CenterOfMassMode



impl ToGodot for godot::classes::rigid_body_3d::DampMode



impl ToGodot for godot::classes::rigid_body_3d::FreezeMode



impl ToGodot for ReplicationMode



impl ToGodot for godot::classes::scene_state::GenEditState



impl ToGodot for GroupCallFlags



impl ToGodot for ScriptNameCasing



impl ToGodot for godot::classes::script_language_extension::CodeCompletionKind



impl ToGodot for godot::classes::script_language_extension::CodeCompletionLocation



impl ToGodot for LookupResultType



impl ToGodot for godot::classes::scroll_container::ScrollHintMode



impl ToGodot for ScrollMode



impl ToGodot for godot::classes::shader::Mode



impl ToGodot for ModifierCallbackModeProcess



impl ToGodot for BoneAxis



impl ToGodot for BoneDirection



impl ToGodot for RotationAxis



impl ToGodot for SecondaryDirection



impl ToGodot for TailDirection



impl ToGodot for godot::classes::sky::ProcessMode



impl ToGodot for RadianceSize



impl ToGodot for TickPosition



impl ToGodot for godot::classes::slider_joint_3d::Param



impl ToGodot for godot::classes::soft_body_3d::DisableMode



impl ToGodot for DraggerVisibility



impl ToGodot for CenterFrom



impl ToGodot for godot::classes::sprite_base_3d::AlphaCutMode



impl ToGodot for godot::classes::sprite_base_3d::DrawFlags



impl ToGodot for godot::classes::stream_peer_socket::Status



impl ToGodot for godot::classes::stream_peer_tls::Status



impl ToGodot for godot::classes::style_box_texture::AxisStretchMode



impl ToGodot for ClearMode



impl ToGodot for godot::classes::sub_viewport::UpdateMode



impl ToGodot for CustomFormat



impl ToGodot for SkinWeightCount



impl ToGodot for godot::classes::tab_bar::AlignmentMode



impl ToGodot for CloseButtonDisplayPolicy



impl ToGodot for TabPosition



impl ToGodot for CaretType



impl ToGodot for EditAction



impl ToGodot for GutterType



impl ToGodot for LineWrappingMode



impl ToGodot for godot::classes::text_edit::MenuItems



impl ToGodot for SearchFlags



impl ToGodot for SelectionMode



impl ToGodot for AutowrapMode



impl ToGodot for ContourPointTag



impl ToGodot for Direction



impl ToGodot for godot::classes::text_server::Feature



impl ToGodot for FixedSizeScaleMode



impl ToGodot for FontAntialiasing



impl ToGodot for FontLcdSubpixelLayout



impl ToGodot for FontStyle



impl ToGodot for GraphemeFlag



impl ToGodot for Hinting



impl ToGodot for JustificationFlag



impl ToGodot for LineBreakFlag



impl ToGodot for godot::classes::text_server::Orientation



impl ToGodot for OverrunBehavior



impl ToGodot for SpacingType



impl ToGodot for StructuredTextParser



impl ToGodot for SubpixelPositioning



impl ToGodot for TextOverrunFlag



impl ToGodot for VisibleCharactersBehavior



impl ToGodot for godot::classes::texture_button::StretchMode



impl ToGodot for LayeredType



impl ToGodot for godot::classes::texture_progress_bar::FillMode



impl ToGodot for godot::classes::texture_rect::ExpandMode



impl ToGodot for godot::classes::texture_rect::StretchMode



impl ToGodot for DataType



impl ToGodot for godot::classes::tile_map::VisibilityMode



impl ToGodot for DebugVisibilityMode



impl ToGodot for CellNeighbor



impl ToGodot for TerrainMode



impl ToGodot for TileLayout



impl ToGodot for TileOffsetAxis



impl ToGodot for TileShape



impl ToGodot for TileAnimationMode



impl ToGodot for Month



impl ToGodot for Weekday



impl ToGodot for TimerProcessCallback



impl ToGodot for godot::classes::touch_screen_button::VisibilityMode



impl ToGodot for DropModeFlags



impl ToGodot for godot::classes::tree::ScrollHintMode



impl ToGodot for godot::classes::tree::SelectMode



impl ToGodot for TreeCellMode



impl ToGodot for EaseType



impl ToGodot for TransitionType



impl ToGodot for TweenPauseMode



impl ToGodot for TweenProcessMode



impl ToGodot for MergeMode



impl ToGodot for UpnpResult



impl ToGodot for IgdStatus



impl ToGodot for AnisotropicFiltering



impl ToGodot for DebugDraw



impl ToGodot for DefaultCanvasItemTextureFilter



impl ToGodot for DefaultCanvasItemTextureRepeat



impl ToGodot for Msaa



impl ToGodot for PositionalShadowAtlasQuadrantSubdiv



impl ToGodot for RenderInfo



impl ToGodot for RenderInfoType



impl ToGodot for Scaling3DMode



impl ToGodot for ScreenSpaceAa



impl ToGodot for SdfOversize



impl ToGodot for SdfScale



impl ToGodot for VrsMode



impl ToGodot for VrsUpdateMode



impl ToGodot for godot::classes::visible_on_screen_enabler_2d::EnableMode



impl ToGodot for godot::classes::visible_on_screen_enabler_3d::EnableMode



impl ToGodot for godot::classes::visual_shader::Type



impl ToGodot for VaryingMode



impl ToGodot for VaryingType



impl ToGodot for PortType



impl ToGodot for BillboardType



impl ToGodot for godot::classes::visual_shader_node_clamp::OpType



impl ToGodot for godot::classes::visual_shader_node_color_func::Function



impl ToGodot for godot::classes::visual_shader_node_color_op::Operator



impl ToGodot for ComparisonType



impl ToGodot for Condition



impl ToGodot for godot::classes::visual_shader_node_compare::Function



impl ToGodot for godot::classes::visual_shader_node_cubemap::Source



impl ToGodot for godot::classes::visual_shader_node_cubemap::TextureType



impl ToGodot for godot::classes::visual_shader_node_derivative_func::Function



impl ToGodot for godot::classes::visual_shader_node_derivative_func::OpType



impl ToGodot for Precision



impl ToGodot for godot::classes::visual_shader_node_float_func::Function



impl ToGodot for godot::classes::visual_shader_node_float_op::Operator



impl ToGodot for godot::classes::visual_shader_node_float_parameter::Hint



impl ToGodot for godot::classes::visual_shader_node_int_func::Function



impl ToGodot for godot::classes::visual_shader_node_int_op::Operator



impl ToGodot for godot::classes::visual_shader_node_int_parameter::Hint



impl ToGodot for godot::classes::visual_shader_node_is::Function



impl ToGodot for godot::classes::visual_shader_node_mix::OpType



impl ToGodot for godot::classes::visual_shader_node_multiply_add::OpType



impl ToGodot for Qualifier



impl ToGodot for godot::classes::visual_shader_node_particle_accelerator::Mode



impl ToGodot for godot::classes::visual_shader_node_particle_emit::EmitFlags



impl ToGodot for godot::classes::visual_shader_node_particle_randomness::OpType



impl ToGodot for godot::classes::visual_shader_node_remap::OpType



impl ToGodot for godot::classes::visual_shader_node_sample_3d::Source



impl ToGodot for godot::classes::visual_shader_node_smooth_step::OpType



impl ToGodot for godot::classes::visual_shader_node_step::OpType



impl ToGodot for godot::classes::visual_shader_node_switch::OpType



impl ToGodot for godot::classes::visual_shader_node_texture::Source



impl ToGodot for godot::classes::visual_shader_node_texture::TextureType



impl ToGodot for ColorDefault



impl ToGodot for godot::classes::visual_shader_node_texture_parameter::TextureFilter



impl ToGodot for godot::classes::visual_shader_node_texture_parameter::TextureRepeat



impl ToGodot for TextureSource



impl ToGodot for godot::classes::visual_shader_node_texture_parameter::TextureType



impl ToGodot for godot::classes::visual_shader_node_transform_func::Function



impl ToGodot for godot::classes::visual_shader_node_transform_op::Operator



impl ToGodot for godot::classes::visual_shader_node_transform_vec_mult::Operator



impl ToGodot for godot::classes::visual_shader_node_u_int_func::Function



impl ToGodot for godot::classes::visual_shader_node_u_int_op::Operator



impl ToGodot for godot::classes::visual_shader_node_uv_func::Function



impl ToGodot for godot::classes::visual_shader_node_vector_base::OpType



impl ToGodot for godot::classes::visual_shader_node_vector_func::Function



impl ToGodot for godot::classes::visual_shader_node_vector_op::Operator



impl ToGodot for Subdiv



impl ToGodot for ChannelState



impl ToGodot for godot::classes::web_rtc_data_channel::WriteMode



impl ToGodot for ConnectionState



impl ToGodot for GatheringState



impl ToGodot for SignalingState



impl ToGodot for State



impl ToGodot for godot::classes::web_socket_peer::WriteMode



impl ToGodot for TargetRayMode



impl ToGodot for ContentScaleAspect



impl ToGodot for ContentScaleMode



impl ToGodot for ContentScaleStretch



impl ToGodot for godot::classes::window::Flags



impl ToGodot for godot::classes::window::LayoutDirection



impl ToGodot for godot::classes::window::Mode



impl ToGodot for WindowInitialPosition



impl ToGodot for NodeType



impl ToGodot for BodyUpdate



impl ToGodot for godot::classes::xr_body_modifier_3d::BoneUpdate



impl ToGodot for BodyFlags



impl ToGodot for Joint



impl ToGodot for JointFlags



impl ToGodot for BlendShapeEntry



impl ToGodot for godot::classes::xr_hand_modifier_3d::BoneUpdate



impl ToGodot for HandJoint



impl ToGodot for godot::classes::xr_hand_tracker::HandJointFlags



impl ToGodot for HandTrackingSource



impl ToGodot for Capabilities



impl ToGodot for EnvironmentBlendMode



impl ToGodot for PlayAreaMode



impl ToGodot for TrackingStatus



impl ToGodot for VrsTextureFormat



impl ToGodot for TrackingConfidence



impl ToGodot for TrackerHand



impl ToGodot for godot::classes::xr_server::RotationMode



impl ToGodot for TrackerType



impl ToGodot for CompressionLevel



impl ToGodot for ZipAppend



impl ToGodot for Error



impl ToGodot for HorizontalAlignment



impl ToGodot for InlineAlignment



impl ToGodot for JoyAxis



impl ToGodot for JoyButton



impl ToGodot for Key



impl ToGodot for KeyLocation



impl ToGodot for KeyModifierMask



impl ToGodot for MidiMessage



impl ToGodot for MouseButton



impl ToGodot for MouseButtonMask



impl ToGodot for VerticalAlignment



impl ToGodot for MethodFlags



impl ToGodot for PropertyHint



impl ToGodot for PropertyUsageFlags



impl ToGodot for Aabb



impl ToGodot for AnyArray



impl ToGodot for AnyDictionary



impl ToGodot for Basis



impl ToGodot for Callable



impl ToGodot for Color



impl ToGodot for GString



impl ToGodot for InstanceId



impl ToGodot for NodePath



impl ToGodot for Plane



impl ToGodot for Projection



impl ToGodot for Quaternion



impl ToGodot for Rect2



impl ToGodot for Rect2i



impl ToGodot for Signal



impl ToGodot for StringName



impl ToGodot for Transform2D



impl ToGodot for Transform3D



impl ToGodot for Variant



impl ToGodot for VariantOperator



impl ToGodot for VariantType



impl ToGodot for Vector2



impl ToGodot for Vector2i



impl ToGodot for Vector3



impl ToGodot for Vector3i



impl ToGodot for Vector4



impl ToGodot for Vector4i



impl<K, V> ToGodot for Dictionary<K, V>
where K: Element, V: Element,



impl<P> ToGodot for RawPtr<P>
where P: FfiRawPointer + 'static,



impl<T> ToGodot for Array<T>
where T: Element,



impl<T> ToGodot for Gd<T>
where T: GodotClass,



impl<T> ToGodot for PackedArray<T>
where T: PackedElement,



impl<T, D> ToGodot for DynGd<T, D>
where T: GodotClass, D: 'static + ?Sized,



type Pass = <Gd<T> as ToGodot>::Pass



type Threads = <Gd<T> as ToGodot>::Threads