Function cubic_interpolate_angle
pub fn cubic_interpolate_angle(
from: f64,
to: f64,
pre: f64,
post: f64,
weight: f64,
) -> f64Expand description
Cubic interpolates between two rotation values with shortest path by the factor defined in weight with pre and post values. See also [method lerp_angle].