Function rid_allocate_id
pub fn rid_allocate_id() -> i64Expand description
Allocates a unique ID which can be used by the implementation to construct an RID. This is used mainly from native extensions to implement servers.
pub fn rid_allocate_id() -> i64Allocates a unique ID which can be used by the implementation to construct an RID. This is used mainly from native extensions to implement servers.