Function is_class_available
pub fn is_class_available<T>() -> boolwhere
T: GodotClass,Expand description
Return whether a certain class API can be used in Godot.
This is only relevant when you operate before all stages have been initialized, or once deinitialization has started.
See also is_singleton_available() and this section in ExtensionLibrary.