Struct AudioServer
pub struct AudioServer { /* private fields */ }Expand description
Godot class AudioServer.
Inherits Object.
Related symbols:
audio_server: sidecar module with related enum/flag typesSignalsOfAudioServer: signal collection
See also Godot docs for AudioServer.
Singleton
This class is a singleton. You can get the one instance using Singleton::singleton().
Final class
This class is final, meaning you cannot inherit from it, and it comes without I* interface trait. It is still possible that other Godot classes inherit from it, but that is limited to the engine itself.
Godot docs
AudioServer is a low-level server interface for audio access. It is in charge of creating sample data (playable audio) as well as its playback via a voice interface.
Implementations
impl AudioServer
impl AudioServer
pub fn set_bus_count(&mut self, amount: i32)
pub fn get_bus_count(&self) -> i32
pub fn remove_bus(&mut self, index: i32)
pub fn remove_bus(&mut self, index: i32)
Removes the bus at index index.
pub fn add_bus(&mut self)
pub fn add_bus(&mut self)
To set the default parameters, use add_bus_ex and its builder methods. See the book for detailed usage instructions.
Adds a bus at at_position.
pub fn add_bus_ex<'ex>(&'ex mut self) -> ExAddBus<'ex>
pub fn add_bus_ex<'ex>(&'ex mut self) -> ExAddBus<'ex>
Adds a bus at at_position.
pub fn move_bus(&mut self, index: i32, to_index: i32)
pub fn move_bus(&mut self, index: i32, to_index: i32)
Moves the bus from index index to index to_index.
pub fn set_bus_name(&mut self, bus_idx: i32, name: impl AsArg<GString>)
pub fn set_bus_name(&mut self, bus_idx: i32, name: impl AsArg<GString>)
Sets the name of the bus at index bus_idx to name.
pub fn get_bus_name(&self, bus_idx: i32) -> GString
pub fn get_bus_name(&self, bus_idx: i32) -> GString
Returns the name of the bus with the index bus_idx.
pub fn get_bus_index(&self, bus_name: impl AsArg<StringName>) -> i32
pub fn get_bus_index(&self, bus_name: impl AsArg<StringName>) -> i32
Returns the index of the bus with the name bus_name. Returns -1 if no bus with the specified name exist.
pub fn get_bus_channels(&self, bus_idx: i32) -> i32
pub fn get_bus_channels(&self, bus_idx: i32) -> i32
Returns the number of channels of the bus at index bus_idx.
pub fn set_bus_volume_db(&mut self, bus_idx: i32, volume_db: f32)
pub fn set_bus_volume_db(&mut self, bus_idx: i32, volume_db: f32)
Sets the volume in decibels of the bus at index bus_idx to volume_db.
pub fn get_bus_volume_db(&self, bus_idx: i32) -> f32
pub fn get_bus_volume_db(&self, bus_idx: i32) -> f32
Returns the volume of the bus at index bus_idx in dB.
pub fn set_bus_volume_linear(&mut self, bus_idx: i32, volume_linear: f32)
pub fn set_bus_volume_linear(&mut self, bus_idx: i32, volume_linear: f32)
Sets the volume as a linear value of the bus at index bus_idx to volume_linear.
Note: Using this method is equivalent to calling set_bus_volume_db with the result of linear_to_db on a value.
pub fn get_bus_volume_linear(&self, bus_idx: i32) -> f32
pub fn get_bus_volume_linear(&self, bus_idx: i32) -> f32
Returns the volume of the bus at index bus_idx as a linear value.
Note: The returned value is equivalent to the result of db_to_linear on the result of get_bus_volume_db.
pub fn set_bus_send(&mut self, bus_idx: i32, send: impl AsArg<StringName>)
pub fn set_bus_send(&mut self, bus_idx: i32, send: impl AsArg<StringName>)
Connects the output of the bus at bus_idx to the bus named send.
pub fn get_bus_send(&self, bus_idx: i32) -> StringName
pub fn get_bus_send(&self, bus_idx: i32) -> StringName
Returns the name of the bus that the bus at index bus_idx sends to.
pub fn set_bus_solo(&mut self, bus_idx: i32, enable: bool)
pub fn set_bus_solo(&mut self, bus_idx: i32, enable: bool)
If true, the bus at index bus_idx is in solo mode.
pub fn is_bus_solo(&self, bus_idx: i32) -> bool
pub fn is_bus_solo(&self, bus_idx: i32) -> bool
If true, the bus at index bus_idx is in solo mode.
pub fn set_bus_mute(&mut self, bus_idx: i32, enable: bool)
pub fn set_bus_mute(&mut self, bus_idx: i32, enable: bool)
If true, the bus at index bus_idx is muted.
pub fn is_bus_mute(&self, bus_idx: i32) -> bool
pub fn is_bus_mute(&self, bus_idx: i32) -> bool
If true, the bus at index bus_idx is muted.
pub fn set_bus_bypass_effects(&mut self, bus_idx: i32, enable: bool)
pub fn set_bus_bypass_effects(&mut self, bus_idx: i32, enable: bool)
If true, the bus at index bus_idx is bypassing effects.
pub fn is_bus_bypassing_effects(&self, bus_idx: i32) -> bool
pub fn is_bus_bypassing_effects(&self, bus_idx: i32) -> bool
If true, the bus at index bus_idx is bypassing effects.
pub fn add_bus_effect(
&mut self,
bus_idx: i32,
effect: impl AsArg<Option<Gd<AudioEffect>>>,
)
pub fn add_bus_effect( &mut self, bus_idx: i32, effect: impl AsArg<Option<Gd<AudioEffect>>>, )
To set the default parameters, use add_bus_effect_ex and its builder methods. See the book for detailed usage instructions.
Adds an AudioEffect effect to the bus bus_idx at at_position.
pub fn add_bus_effect_ex<'ex>(
&'ex mut self,
bus_idx: i32,
effect: impl AsArg<Option<Gd<AudioEffect>>> + 'ex,
) -> ExAddBusEffect<'ex>
pub fn add_bus_effect_ex<'ex>( &'ex mut self, bus_idx: i32, effect: impl AsArg<Option<Gd<AudioEffect>>> + 'ex, ) -> ExAddBusEffect<'ex>
Adds an AudioEffect effect to the bus bus_idx at at_position.
pub fn remove_bus_effect(&mut self, bus_idx: i32, effect_idx: i32)
pub fn remove_bus_effect(&mut self, bus_idx: i32, effect_idx: i32)
Removes the effect at index effect_idx from the bus at index bus_idx.
pub fn get_bus_effect_count(&self, bus_idx: i32) -> i32
pub fn get_bus_effect_count(&self, bus_idx: i32) -> i32
Returns the number of effects on the bus at bus_idx.
pub fn get_bus_effect(
&self,
bus_idx: i32,
effect_idx: i32,
) -> Option<Gd<AudioEffect>>
pub fn get_bus_effect( &self, bus_idx: i32, effect_idx: i32, ) -> Option<Gd<AudioEffect>>
Returns the AudioEffect at position effect_idx in bus bus_idx.
pub fn get_bus_effect_instance(
&self,
bus_idx: i32,
effect_idx: i32,
) -> Option<Gd<AudioEffectInstance>>
pub fn get_bus_effect_instance( &self, bus_idx: i32, effect_idx: i32, ) -> Option<Gd<AudioEffectInstance>>
To set the default parameters, use get_bus_effect_instance_ex and its builder methods. See the book for detailed usage instructions.
Returns the AudioEffectInstance assigned to the given bus and effect indices (and optionally channel).
pub fn get_bus_effect_instance_ex<'ex>(
&'ex self,
bus_idx: i32,
effect_idx: i32,
) -> ExGetBusEffectInstance<'ex>
pub fn get_bus_effect_instance_ex<'ex>( &'ex self, bus_idx: i32, effect_idx: i32, ) -> ExGetBusEffectInstance<'ex>
Returns the AudioEffectInstance assigned to the given bus and effect indices (and optionally channel).
pub fn swap_bus_effects(
&mut self,
bus_idx: i32,
effect_idx: i32,
by_effect_idx: i32,
)
pub fn swap_bus_effects( &mut self, bus_idx: i32, effect_idx: i32, by_effect_idx: i32, )
Swaps the position of two effects in bus bus_idx.
pub fn set_bus_effect_enabled(
&mut self,
bus_idx: i32,
effect_idx: i32,
enabled: bool,
)
pub fn set_bus_effect_enabled( &mut self, bus_idx: i32, effect_idx: i32, enabled: bool, )
If true, the effect at index effect_idx on the bus at index bus_idx is enabled.
pub fn is_bus_effect_enabled(&self, bus_idx: i32, effect_idx: i32) -> bool
pub fn is_bus_effect_enabled(&self, bus_idx: i32, effect_idx: i32) -> bool
If true, the effect at index effect_idx on the bus at index bus_idx is enabled.
pub fn get_bus_peak_volume_left_db(&self, bus_idx: i32, channel: i32) -> f32
pub fn get_bus_peak_volume_left_db(&self, bus_idx: i32, channel: i32) -> f32
Returns the peak volume of the left speaker at bus index bus_idx and channel index channel.
pub fn get_bus_peak_volume_right_db(&self, bus_idx: i32, channel: i32) -> f32
pub fn get_bus_peak_volume_right_db(&self, bus_idx: i32, channel: i32) -> f32
Returns the peak volume of the right speaker at bus index bus_idx and channel index channel.
pub fn set_playback_speed_scale(&mut self, scale: f32)
pub fn get_playback_speed_scale(&self) -> f32
pub fn lock(&mut self)
pub fn lock(&mut self)
Locks the audio driver’s main loop.
Note: Remember to unlock it afterwards.
pub fn unlock(&mut self)
pub fn unlock(&mut self)
Unlocks the audio driver’s main loop. (After locking it, you should always unlock it.)
pub fn get_speaker_mode(&self) -> SpeakerMode
pub fn get_speaker_mode(&self) -> SpeakerMode
Returns the speaker configuration.
pub fn get_mix_rate(&self) -> f32
pub fn get_mix_rate(&self) -> f32
Returns the sample rate at the output of the AudioServer.
pub fn get_input_mix_rate(&self) -> f32
pub fn get_input_mix_rate(&self) -> f32
Returns the sample rate at the input of the AudioServer.
pub fn get_driver_name(&self) -> GString
pub fn get_driver_name(&self) -> GString
Returns the name of the current audio driver. The default usually depends on the operating system, but may be overridden via the --audio-driver command line argument. --headless also automatically sets the audio driver to Dummy. See also [member ProjectSettings.audio/driver/driver].
pub fn get_output_device_list(&self) -> PackedArray<GString>
pub fn get_output_device_list(&self) -> PackedArray<GString>
Returns the names of all audio output devices detected on the system.
pub fn get_output_device(&self) -> GString
pub fn set_output_device(&mut self, name: impl AsArg<GString>)
pub fn get_time_to_next_mix(&self) -> f64
pub fn get_time_to_next_mix(&self) -> f64
Returns the relative time until the next mix occurs.
pub fn get_time_since_last_mix(&self) -> f64
pub fn get_time_since_last_mix(&self) -> f64
Returns the relative time since the last mix occurred.
pub fn get_output_latency(&self) -> f64
pub fn get_output_latency(&self) -> f64
Returns the audio driver’s effective output latency. This is based on [member ProjectSettings.audio/driver/output_latency], but the exact returned value will differ depending on the operating system and audio driver.
Note: This can be expensive; it is not recommended to call get_output_latency every frame.
pub fn get_input_device_list(&self) -> PackedArray<GString>
pub fn get_input_device_list(&self) -> PackedArray<GString>
Returns the names of all audio input devices detected on the system.
Note: [member ProjectSettings.audio/driver/enable_input] must be true for audio input to work. See also that setting’s description for caveats related to permissions and operating system privacy settings.
pub fn get_input_device(&self) -> GString
pub fn set_input_device(&mut self, name: impl AsArg<GString>)
pub fn set_input_device_active(&mut self, active: bool) -> Error
pub fn set_input_device_active(&mut self, active: bool) -> Error
If active is true, starts the microphone input stream specified by [member input_device] or returns an error if it failed.
If active is false, stops the input stream if it is running.
pub fn get_input_frames_available(&self) -> i32
pub fn get_input_frames_available(&self) -> i32
Returns the number of frames available to read using get_input_frames.
pub fn get_input_buffer_length_frames(&self) -> i32
pub fn get_input_buffer_length_frames(&self) -> i32
Returns the absolute size of the microphone input buffer. This is set to a multiple of the audio latency and can be used to estimate the minimum rate at which the frames need to be fetched.
pub fn get_input_frames(&self, frames: i32) -> PackedArray<Vector2>
pub fn get_input_frames(&self, frames: i32) -> PackedArray<Vector2>
Returns a PackedVector2Array containing exactly frames audio samples from the internal microphone buffer if available, otherwise returns an empty PackedVector2Array.
The buffer is filled at the rate of get_input_mix_rate frames per second when set_input_device_active has successfully been set to true.
The samples are signed floating-point PCM values between -1 and 1.
pub fn set_bus_layout(
&mut self,
bus_layout: impl AsArg<Option<Gd<AudioBusLayout>>>,
)
pub fn set_bus_layout( &mut self, bus_layout: impl AsArg<Option<Gd<AudioBusLayout>>>, )
Overwrites the currently used AudioBusLayout.
pub fn generate_bus_layout(&self) -> Option<Gd<AudioBusLayout>>
pub fn generate_bus_layout(&self) -> Option<Gd<AudioBusLayout>>
Generates an AudioBusLayout using the available buses and effects.
pub fn set_enable_tagging_used_audio_streams(&mut self, enable: bool)
pub fn set_enable_tagging_used_audio_streams(&mut self, enable: bool)
If set to true, all instances of AudioStreamPlayback will call tag_used_streams every mix step.
Note: This is enabled by default in the editor, as it is used by editor plugins for the audio stream previews.
pub fn is_stream_registered_as_sample(
&self,
stream: impl AsArg<Option<Gd<AudioStream>>>,
) -> bool
pub fn is_stream_registered_as_sample( &self, stream: impl AsArg<Option<Gd<AudioStream>>>, ) -> bool
If true, the stream is registered as a sample. The engine will not have to register it before playing the sample.
If false, the stream will have to be registered before playing it. To prevent lag spikes, register the stream as sample with register_stream_as_sample.
pub fn register_stream_as_sample(
&mut self,
stream: impl AsArg<Option<Gd<AudioStream>>>,
)
pub fn register_stream_as_sample( &mut self, stream: impl AsArg<Option<Gd<AudioStream>>>, )
Forces the registration of a stream as a sample.
Note: Lag spikes may occur when calling this method, especially on single-threaded builds. It is suggested to call this method while loading assets, where the lag spike could be masked, instead of registering the sample right before it needs to be played.
Methods from Deref<Target = Object>
pub fn get_script(&self) -> Option<Gd<Script>>
pub fn set_script(&mut self, script: impl AsArg<Option<Gd<Script>>>)
pub fn connect( &mut self, signal: impl AsArg<StringName>, callable: &Callable, ) -> Error
pub fn connect_flags( &mut self, signal: impl AsArg<StringName>, callable: &Callable, flags: ConnectFlags, ) -> Error
pub fn is_class(&self, class: impl AsArg<GString>) -> bool
pub fn is_class(&self, class: impl AsArg<GString>) -> bool
Returns true if the object inherits from the given class. See also get_class.
var sprite2d = Sprite2D.new()
sprite2d.is_class("Sprite2D") # Returns true
sprite2d.is_class("Node") # Returns true
sprite2d.is_class("Node3D") # Returns falseNote: This method ignores class_name declarations in the object’s script.
pub fn set(&mut self, property: impl AsArg<StringName>, value: &Variant)
pub fn set(&mut self, property: impl AsArg<StringName>, value: &Variant)
Assigns value to the given property. If the property does not exist or the given value’s type doesn’t match, nothing happens.
var node = Node2D.new()
node.set("global_scale", Vector2(8, 2.5))
print(node.global_scale) # Prints (8.0, 2.5)Note: In C#, property must be in snake_case when referring to built-in Godot properties. Prefer using the names exposed in the PropertyName class to avoid allocating a new StringName on each call.
pub fn get(&self, property: impl AsArg<StringName>) -> Variant
pub fn get(&self, property: impl AsArg<StringName>) -> Variant
Returns the Variant value of the given property. If the property does not exist, this method returns null.
var node = Node2D.new()
node.rotation = 1.5
var a = node.get("rotation") # a is 1.5Note: In C#, property must be in snake_case when referring to built-in Godot properties. Prefer using the names exposed in the PropertyName class to avoid allocating a new StringName on each call.
pub fn set_indexed(
&mut self,
property_path: impl AsArg<NodePath>,
value: &Variant,
)
pub fn set_indexed( &mut self, property_path: impl AsArg<NodePath>, value: &Variant, )
Assigns a new value to the property identified by the property_path. The path should be a NodePath relative to this object, and can use the colon character (:) to access nested properties.
var node = Node2D.new()
node.set_indexed("position", Vector2(42, 0))
node.set_indexed("position:y", -10)
print(node.position) # Prints (42.0, -10.0)Note: In C#, property_path must be in snake_case when referring to built-in Godot properties. Prefer using the names exposed in the PropertyName class to avoid allocating a new StringName on each call.
pub fn get_indexed(&self, property_path: impl AsArg<NodePath>) -> Variant
pub fn get_indexed(&self, property_path: impl AsArg<NodePath>) -> Variant
Gets the object’s property indexed by the given property_path. The path should be a NodePath relative to the current object and can use the colon character (:) to access nested properties.
Examples: "position:x" or "material:next_pass:blend_mode".
var node = Node2D.new()
node.position = Vector2(5, -10)
var a = node.get_indexed("position") # a is Vector2(5, -10)
var b = node.get_indexed("position:y") # b is -10Note: In C#, property_path must be in snake_case when referring to built-in Godot properties. Prefer using the names exposed in the PropertyName class to avoid allocating a new StringName on each call.
Note: This method does not support actual paths to nodes in the SceneTree, only sub-property paths. In the context of nodes, use get_node_and_resource instead.
pub fn get_property_list(&self) -> Array<Dictionary<Variant, Variant>>
pub fn get_property_list(&self) -> Array<Dictionary<Variant, Variant>>
Returns the object’s property list as an Array of dictionaries. Each Dictionary contains the following entries:
-
nameis the property’s name, as aString; -
class_nameis an emptyStringName, unless the property isVariantType::OBJECTand it inherits from a class; -
typeis the property’s type, as anint(see [enum Variant.Type]); -
hintis how the property is meant to be edited (see [enum PropertyHint]); -
hint_stringdepends on the hint (see [enum PropertyHint]); -
usageis a combination of [enum PropertyUsageFlags].
Note: In GDScript, all class members are treated as properties. In C# and GDExtension, it may be necessary to explicitly mark class members as Godot properties using decorators or attributes.
pub fn get_method_list(&self) -> Array<Dictionary<Variant, Variant>>
pub fn get_method_list(&self) -> Array<Dictionary<Variant, Variant>>
Returns this object’s methods and their signatures as an Array of dictionaries. Each Dictionary contains the following entries:
-
nameis the name of the method, as aString; -
argsis anArrayof dictionaries representing the arguments; -
default_argsis the default arguments as anArrayof variants; -
flagsis a combination of [enum MethodFlags]; -
idis the method’s internal identifierint; -
returnis the returned value, as aDictionary;
Note: The dictionaries of args and return are formatted identically to the results of get_property_list, although not all entries are used.
pub fn property_can_revert(&self, property: impl AsArg<StringName>) -> bool
pub fn property_can_revert(&self, property: impl AsArg<StringName>) -> bool
Returns true if the given property has a custom default value. Use property_get_revert to get the property’s default value.
Note: This method is used by the Inspector dock to display a revert icon. The object must implement [method _property_can_revert] to customize the default value. If [method _property_can_revert] is not implemented, this method returns false.
pub fn property_get_revert(&self, property: impl AsArg<StringName>) -> Variant
pub fn property_get_revert(&self, property: impl AsArg<StringName>) -> Variant
Returns the custom default value of the given property. Use property_can_revert to check if the property has a custom default value.
Note: This method is used by the Inspector dock to display a revert icon. The object must implement [method _property_get_revert] to customize the default value. If [method _property_get_revert] is not implemented, this method returns null.
pub fn set_meta(&mut self, name: impl AsArg<StringName>, value: &Variant)
pub fn set_meta(&mut self, name: impl AsArg<StringName>, value: &Variant)
Adds or changes the entry name inside the object’s metadata. The metadata value can be any Variant, although some types cannot be serialized correctly.
If value is null, the entry is removed. This is the equivalent of using remove_meta. See also has_meta and get_meta.
Note: A metadata’s name must be a valid identifier as per is_valid_identifier method.
Note: Metadata that has a name starting with an underscore (_) is considered editor-only. Editor-only metadata is not displayed in the Inspector and should not be edited, although it can still be found by this method.
pub fn remove_meta(&mut self, name: impl AsArg<StringName>)
pub fn remove_meta(&mut self, name: impl AsArg<StringName>)
Removes the given entry name from the object’s metadata. See also has_meta, get_meta and set_meta.
Note: A metadata’s name must be a valid identifier as per is_valid_identifier method.
Note: Metadata that has a name starting with an underscore (_) is considered editor-only. Editor-only metadata is not displayed in the Inspector and should not be edited, although it can still be found by this method.
pub fn get_meta(&self, name: impl AsArg<StringName>) -> Variant
pub fn get_meta(&self, name: impl AsArg<StringName>) -> Variant
To set the default parameters, use get_meta_ex and its builder methods. See the book for detailed usage instructions.
Returns the object’s metadata value for the given entry name. If the entry does not exist, returns default. If default is null, an error is also generated.
Note: A metadata’s name must be a valid identifier as per is_valid_identifier method.
Note: Metadata that has a name starting with an underscore (_) is considered editor-only. Editor-only metadata is not displayed in the Inspector and should not be edited, although it can still be found by this method.
pub fn get_meta_ex<'ex>(
&'ex self,
name: impl AsArg<StringName> + 'ex,
) -> ExGetMeta<'ex>
pub fn get_meta_ex<'ex>( &'ex self, name: impl AsArg<StringName> + 'ex, ) -> ExGetMeta<'ex>
Returns the object’s metadata value for the given entry name. If the entry does not exist, returns default. If default is null, an error is also generated.
Note: A metadata’s name must be a valid identifier as per is_valid_identifier method.
Note: Metadata that has a name starting with an underscore (_) is considered editor-only. Editor-only metadata is not displayed in the Inspector and should not be edited, although it can still be found by this method.
pub fn has_meta(&self, name: impl AsArg<StringName>) -> bool
pub fn has_meta(&self, name: impl AsArg<StringName>) -> bool
Returns true if a metadata entry is found with the given name. See also get_meta, set_meta and remove_meta.
Note: A metadata’s name must be a valid identifier as per is_valid_identifier method.
Note: Metadata that has a name starting with an underscore (_) is considered editor-only. Editor-only metadata is not displayed in the Inspector and should not be edited, although it can still be found by this method.
pub fn get_meta_list(&self) -> Array<StringName>
pub fn get_meta_list(&self) -> Array<StringName>
Returns the object’s metadata entry names as an Array of StringNames.
pub fn add_user_signal(&mut self, signal: impl AsArg<GString>)
pub fn add_user_signal(&mut self, signal: impl AsArg<GString>)
To set the default parameters, use add_user_signal_ex and its builder methods. See the book for detailed usage instructions.
Adds a user-defined signal named signal. Optional arguments for the signal can be added as an Array of dictionaries, each defining a name String and a type int (see [enum Variant.Type]). See also has_user_signal and remove_user_signal.
add_user_signal("hurt", [
{ "name": "damage", "type": TYPE_INT },
{ "name": "source", "type": TYPE_OBJECT }
])pub fn add_user_signal_ex<'ex>(
&'ex mut self,
signal: impl AsArg<GString> + 'ex,
) -> ExAddUserSignal<'ex>
pub fn add_user_signal_ex<'ex>( &'ex mut self, signal: impl AsArg<GString> + 'ex, ) -> ExAddUserSignal<'ex>
Adds a user-defined signal named signal. Optional arguments for the signal can be added as an Array of dictionaries, each defining a name String and a type int (see [enum Variant.Type]). See also has_user_signal and remove_user_signal.
add_user_signal("hurt", [
{ "name": "damage", "type": TYPE_INT },
{ "name": "source", "type": TYPE_OBJECT }
])pub fn has_user_signal(&self, signal: impl AsArg<StringName>) -> bool
pub fn has_user_signal(&self, signal: impl AsArg<StringName>) -> bool
Returns true if the given user-defined signal name exists. Only signals added with add_user_signal are included. See also remove_user_signal.
pub fn remove_user_signal(&mut self, signal: impl AsArg<StringName>)
pub fn remove_user_signal(&mut self, signal: impl AsArg<StringName>)
Removes the given user signal signal from the object. See also add_user_signal and has_user_signal.
pub fn emit_signal(
&mut self,
signal: impl AsArg<StringName>,
varargs: &[Variant],
) -> Error
pub fn emit_signal( &mut self, signal: impl AsArg<StringName>, varargs: &[Variant], ) -> Error
Emits the given signal by name. The signal must exist, so it should be a built-in signal of this class or one of its inherited classes, or a user-defined signal (see add_user_signal). This method supports a variable number of arguments, so parameters can be passed as a comma separated list.
Returns Error::ERR_UNAVAILABLE if signal does not exist or the parameters are invalid.
emit_signal("hit", "sword", 100)
emit_signal("game_over")Note: In C#, signal must be in snake_case when referring to built-in Godot signals. Prefer using the names exposed in the SignalName class to avoid allocating a new StringName on each call.
Panics
This is a varcall method, meaning parameters and return values are passed as Variant.
It can detect call failures and will panic in such a case.
pub fn try_emit_signal(
&mut self,
signal: impl AsArg<StringName>,
varargs: &[Variant],
) -> Result<Error, CallError>
pub fn try_emit_signal( &mut self, signal: impl AsArg<StringName>, varargs: &[Variant], ) -> Result<Error, CallError>
Return type
This is a varcall method, meaning parameters and return values are passed as Variant.
It can detect call failures and will return Err in such a case.
pub fn call(
&mut self,
method: impl AsArg<StringName>,
varargs: &[Variant],
) -> Variant
pub fn call( &mut self, method: impl AsArg<StringName>, varargs: &[Variant], ) -> Variant
Calls the method on the object and returns the result. This method supports a variable number of arguments, so parameters can be passed as a comma separated list.
var node = Node3D.new()
node.call("rotate", Vector3(1.0, 0.0, 0.0), 1.571)Note: In C#, method must be in snake_case when referring to built-in Godot methods. Prefer using the names exposed in the MethodName class to avoid allocating a new StringName on each call.
Panics
This is a varcall method, meaning parameters and return values are passed as Variant.
It can detect call failures and will panic in such a case.
pub fn try_call(
&mut self,
method: impl AsArg<StringName>,
varargs: &[Variant],
) -> Result<Variant, CallError>
pub fn try_call( &mut self, method: impl AsArg<StringName>, varargs: &[Variant], ) -> Result<Variant, CallError>
Return type
This is a varcall method, meaning parameters and return values are passed as Variant.
It can detect call failures and will return Err in such a case.
pub fn call_deferred(
&mut self,
method: impl AsArg<StringName>,
varargs: &[Variant],
) -> Variant
pub fn call_deferred( &mut self, method: impl AsArg<StringName>, varargs: &[Variant], ) -> Variant
Calls the method on the object during idle time. Always returns null, not the method’s result.
Idle time happens mainly at the end of process and physics frames. In it, deferred calls will be run until there are none left, which means you can defer calls from other deferred calls and they’ll still be run in the current idle time cycle. This means you should not call a method deferred from itself (or from a method called by it), as this causes infinite recursion the same way as if you had called the method directly.
This method supports a variable number of arguments, so parameters can be passed as a comma separated list.
var node = Node3D.new()
node.call_deferred("rotate", Vector3(1.0, 0.0, 0.0), 1.571)For methods that are deferred from the same thread, the order of execution at idle time is identical to the order in which call_deferred was called.
See also call_deferred.
Note: In C#, method must be in snake_case when referring to built-in Godot methods. Prefer using the names exposed in the MethodName class to avoid allocating a new StringName on each call.
Note: If you’re looking to delay the function call by a frame, refer to the SceneTree.process_frame and SceneTree.physics_frame signals.
var node = Node3D.new()
# Make a Callable and bind the arguments to the node's rotate() call.
var callable = node.rotate.bind(Vector3(1.0, 0.0, 0.0), 1.571)
# Connect the callable to the process_frame signal, so it gets called in the next process frame.
# CONNECT_ONE_SHOT makes sure it only gets called once instead of every frame.
get_tree().process_frame.connect(callable, CONNECT_ONE_SHOT)Panics
This is a varcall method, meaning parameters and return values are passed as Variant.
It can detect call failures and will panic in such a case.
pub fn try_call_deferred(
&mut self,
method: impl AsArg<StringName>,
varargs: &[Variant],
) -> Result<Variant, CallError>
pub fn try_call_deferred( &mut self, method: impl AsArg<StringName>, varargs: &[Variant], ) -> Result<Variant, CallError>
Return type
This is a varcall method, meaning parameters and return values are passed as Variant.
It can detect call failures and will return Err in such a case.
pub fn set_deferred(
&mut self,
property: impl AsArg<StringName>,
value: &Variant,
)
pub fn set_deferred( &mut self, property: impl AsArg<StringName>, value: &Variant, )
Assigns value to the given property, at the end of the current frame. This is equivalent to calling set through call_deferred.
var node = Node2D.new()
add_child(node)
node.rotation = 1.5
node.set_deferred("rotation", 3.0)
print(node.rotation) # Prints 1.5
await get_tree().process_frame
print(node.rotation) # Prints 3.0Note: In C#, property must be in snake_case when referring to built-in Godot properties. Prefer using the names exposed in the PropertyName class to avoid allocating a new StringName on each call.
pub fn callv(
&mut self,
method: impl AsArg<StringName>,
arg_array: &AnyArray,
) -> Variant
pub fn callv( &mut self, method: impl AsArg<StringName>, arg_array: &AnyArray, ) -> Variant
Calls the method on the object and returns the result. Unlike call, this method expects all parameters to be contained inside arg_array.
var node = Node3D.new()
node.callv("rotate", [Vector3(1.0, 0.0, 0.0), 1.571])Note: In C#, method must be in snake_case when referring to built-in Godot methods. Prefer using the names exposed in the MethodName class to avoid allocating a new StringName on each call.
pub fn has_method(&self, method: impl AsArg<StringName>) -> bool
pub fn has_method(&self, method: impl AsArg<StringName>) -> bool
Returns true if the given method name exists in the object.
Note: In C#, method must be in snake_case when referring to built-in Godot methods. Prefer using the names exposed in the MethodName class to avoid allocating a new StringName on each call.
pub fn get_method_argument_count(&self, method: impl AsArg<StringName>) -> i32
pub fn get_method_argument_count(&self, method: impl AsArg<StringName>) -> i32
Returns the number of arguments of the given method by name.
Note: In C#, method must be in snake_case when referring to built-in Godot methods. Prefer using the names exposed in the MethodName class to avoid allocating a new StringName on each call.
pub fn has_signal(&self, signal: impl AsArg<StringName>) -> bool
pub fn has_signal(&self, signal: impl AsArg<StringName>) -> bool
Returns true if the given signal name exists in the object.
Note: In C#, signal must be in snake_case when referring to built-in Godot signals. Prefer using the names exposed in the SignalName class to avoid allocating a new StringName on each call.
pub fn get_signal_list(&self) -> Array<Dictionary<Variant, Variant>>
pub fn get_signal_list(&self) -> Array<Dictionary<Variant, Variant>>
Returns the list of existing signals as an Array of dictionaries.
Note: Due to the implementation, each Dictionary is formatted very similarly to the returned values of get_method_list.
pub fn get_signal_connection_list(
&self,
signal: impl AsArg<StringName>,
) -> Array<Dictionary<Variant, Variant>>
pub fn get_signal_connection_list( &self, signal: impl AsArg<StringName>, ) -> Array<Dictionary<Variant, Variant>>
Returns an Array of connections for the given signal name. Each connection is represented as a Dictionary that contains three entries:
pub fn get_incoming_connections(&self) -> Array<Dictionary<Variant, Variant>>
pub fn get_incoming_connections(&self) -> Array<Dictionary<Variant, Variant>>
Returns an Array of signal connections received by this object. Each connection is represented as a Dictionary that contains three entries:
pub fn disconnect(
&mut self,
signal: impl AsArg<StringName>,
callable: &Callable,
)
pub fn disconnect( &mut self, signal: impl AsArg<StringName>, callable: &Callable, )
Disconnects a signal by name from a given callable. If the connection does not exist, generates an error. Use is_connected to make sure that the connection exists.
pub fn is_connected(
&self,
signal: impl AsArg<StringName>,
callable: &Callable,
) -> bool
pub fn is_connected( &self, signal: impl AsArg<StringName>, callable: &Callable, ) -> bool
Returns true if a connection exists between the given signal name and callable.
Note: In C#, signal must be in snake_case when referring to built-in Godot signals. Prefer using the names exposed in the SignalName class to avoid allocating a new StringName on each call.
pub fn has_connections(&self, signal: impl AsArg<StringName>) -> bool
pub fn has_connections(&self, signal: impl AsArg<StringName>) -> bool
Returns true if any connection exists on the given signal name.
Note: In C#, signal must be in snake_case when referring to built-in Godot methods. Prefer using the names exposed in the SignalName class to avoid allocating a new StringName on each call.
pub fn set_block_signals(&mut self, enable: bool)
pub fn set_block_signals(&mut self, enable: bool)
If set to true, the object becomes unable to emit signals. As such, emit_signal and signal connections will not work, until it is set to false.
pub fn is_blocking_signals(&self) -> bool
pub fn is_blocking_signals(&self) -> bool
Returns true if the object is blocking its signals from being emitted. See set_block_signals.
pub fn notify_property_list_changed(&mut self)
pub fn notify_property_list_changed(&mut self)
Emits the property_list_changed signal. This is mainly used to refresh the editor, so that the Inspector and editor plugins are properly updated.
pub fn set_message_translation(&mut self, enable: bool)
pub fn set_message_translation(&mut self, enable: bool)
If set to true, allows the object to translate messages with tr and tr_n. Enabled by default. See also can_translate_messages.
pub fn can_translate_messages(&self) -> bool
pub fn can_translate_messages(&self) -> bool
Returns true if the object is allowed to translate messages with tr and tr_n. See also set_message_translation.
pub fn tr(&self, message: impl AsArg<StringName>) -> GString
pub fn tr(&self, message: impl AsArg<StringName>) -> GString
To set the default parameters, use tr_ex and its builder methods. See the book for detailed usage instructions.
Translates a message, using the translation catalogs configured in the Project Settings. Further context can be specified to help with the translation. Note that most Control nodes automatically translate their strings, so this method is mostly useful for formatted strings or custom drawn text.
If can_translate_messages is false, or no translation is available, this method returns the message without changes. See set_message_translation.
For detailed examples, see Internationalizing games.
Note: This method can’t be used without an Object instance, as it requires the can_translate_messages method. To translate strings in a static context, use translate.
pub fn tr_ex<'ex>(&'ex self, message: impl AsArg<StringName> + 'ex) -> ExTr<'ex>
pub fn tr_ex<'ex>(&'ex self, message: impl AsArg<StringName> + 'ex) -> ExTr<'ex>
Translates a message, using the translation catalogs configured in the Project Settings. Further context can be specified to help with the translation. Note that most Control nodes automatically translate their strings, so this method is mostly useful for formatted strings or custom drawn text.
If can_translate_messages is false, or no translation is available, this method returns the message without changes. See set_message_translation.
For detailed examples, see Internationalizing games.
Note: This method can’t be used without an Object instance, as it requires the can_translate_messages method. To translate strings in a static context, use translate.
pub fn tr_n(
&self,
message: impl AsArg<StringName>,
plural_message: impl AsArg<StringName>,
n: i32,
) -> GString
pub fn tr_n( &self, message: impl AsArg<StringName>, plural_message: impl AsArg<StringName>, n: i32, ) -> GString
To set the default parameters, use tr_n_ex and its builder methods. See the book for detailed usage instructions.
Translates a message or plural_message, using the translation catalogs configured in the Project Settings. Further context can be specified to help with the translation.
If can_translate_messages is false, or no translation is available, this method returns message or plural_message, without changes. See set_message_translation.
The n is the number, or amount, of the message’s subject. It is used by the translation system to fetch the correct plural form for the current language.
For detailed examples, see Localization using gettext.
Note: Negative and float numbers may not properly apply to some countable subjects. It’s recommended to handle these cases with tr.
Note: This method can’t be used without an Object instance, as it requires the can_translate_messages method. To translate strings in a static context, use translate_plural.
pub fn tr_n_ex<'ex>(
&'ex self,
message: impl AsArg<StringName> + 'ex,
plural_message: impl AsArg<StringName> + 'ex,
n: i32,
) -> ExTrN<'ex>
pub fn tr_n_ex<'ex>( &'ex self, message: impl AsArg<StringName> + 'ex, plural_message: impl AsArg<StringName> + 'ex, n: i32, ) -> ExTrN<'ex>
Translates a message or plural_message, using the translation catalogs configured in the Project Settings. Further context can be specified to help with the translation.
If can_translate_messages is false, or no translation is available, this method returns message or plural_message, without changes. See set_message_translation.
The n is the number, or amount, of the message’s subject. It is used by the translation system to fetch the correct plural form for the current language.
For detailed examples, see Localization using gettext.
Note: Negative and float numbers may not properly apply to some countable subjects. It’s recommended to handle these cases with tr.
Note: This method can’t be used without an Object instance, as it requires the can_translate_messages method. To translate strings in a static context, use translate_plural.
pub fn get_translation_domain(&self) -> StringName
pub fn get_translation_domain(&self) -> StringName
Returns the name of the translation domain used by tr and tr_n. See also TranslationServer.
pub fn set_translation_domain(&mut self, domain: impl AsArg<StringName>)
pub fn set_translation_domain(&mut self, domain: impl AsArg<StringName>)
Sets the name of the translation domain used by tr and tr_n. See also TranslationServer.
pub fn is_queued_for_deletion(&self) -> bool
pub fn is_queued_for_deletion(&self) -> bool
Returns true if the queue_free method was called for the object.
pub fn cancel_free(&mut self)
pub fn cancel_free(&mut self)
If this method is called during ObjectNotification::PREDELETE, this object will reject being freed and will remain allocated. This is mostly an internal function used for error handling to avoid the user from freeing objects when they are not intended to.
pub fn notify(&mut self, what: ObjectNotification)
pub fn notify(&mut self, what: ObjectNotification)
⚠️ Sends a Godot notification to all classes inherited by the object.
Triggers calls to on_notification(), and depending on the notification, also to Godot’s lifecycle callbacks such as ready().
Starts from the highest ancestor (the Object class) and goes down the hierarchy.
See also Godot docs for Object::notification().
Panics
If you call this method on a user-defined object while holding a GdRef or GdMut guard on the instance, you will encounter
a panic. The reason is that the receiving virtual method on_notification() acquires a GdMut lock dynamically, which must
be exclusive.
pub fn notify_reversed(&mut self, what: ObjectNotification)
pub fn notify_reversed(&mut self, what: ObjectNotification)
⚠️ Like Self::notify(), but starts at the most-derived class and goes up the hierarchy.
See docs of that method, including the panics.