Function is_editor_hint
pub fn is_editor_hint() -> boolExpand description
Returns whether the engine is running inside the Godot editor.
This is different from whether the Godot binary is an editor build (as opposed to an export/release build).