Function export_node_path
pub fn export_node_path<T>(node_paths: &[&str]) -> PropertyHintInfowhere
T: Export,Expand description
Equivalent to @export_node_path in Godot.
Accepts a list of node class names to restrict which node types can be selected. An empty slice means any node type is allowed.